var iq=Object.defineProperty;var sq=(e,t,n)=>t in e?iq(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n;var Qr=(e,t,n)=>sq(e,typeof t!="symbol"?t+"":t,n);function lq(e,t){for(var n=0;n<t.length;n++){const r=t[n];if(typeof r!="string"&&!Array.isArray(r)){for(const a in r)if(a!=="default"&&!(a in e)){const o=Object.getOwnPropertyDescriptor(r,a);o&&Object.defineProperty(e,a,o.get?o:{enumerable:!0,get:()=>r[a]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}(function(){const t=document.createElement("link").relList;if(t&&t.supports&&t.supports("modulepreload"))return;for(const a of document.querySelectorAll('link[rel="modulepreload"]'))r(a);new MutationObserver(a=>{for(const o of a)if(o.type==="childList")for(const s of o.addedNodes)s.tagName==="LINK"&&s.rel==="modulepreload"&&r(s)}).observe(document,{childList:!0,subtree:!0});function n(a){const o={};return a.integrity&&(o.integrity=a.integrity),a.referrerPolicy&&(o.referrerPolicy=a.referrerPolicy),a.crossOrigin==="use-credentials"?o.credentials="include":a.crossOrigin==="anonymous"?o.credentials="omit":o.credentials="same-origin",o}function r(a){if(a.ep)return;a.ep=!0;const o=n(a);fetch(a.href,o)}})();var gf=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function un(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}function cq(e){if(e.__esModule)return e;var t=e.default;if(typeof t=="function"){var n=function r(){return this instanceof r?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};n.prototype=t.prototype}else n={};return Object.defineProperty(n,"__esModule",{value:!0}),Object.keys(e).forEach(function(r){var a=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(n,r,a.get?a:{enumerable:!0,get:function(){return e[r]}})}),n}var Wh={exports:{}},Zl={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var t_;function uq(){if(t_)return Zl;t_=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(r,a,o){var s=null;if(o!==void 0&&(s=""+o),a.key!==void 0&&(s=""+a.key),"key"in a){o={};for(var l in a)l!=="key"&&(o[l]=a[l])}else o=a;return a=o.ref,{$$typeof:e,type:r,key:s,ref:a!==void 0?a:null,props:o}}return Zl.Fragment=t,Zl.jsx=n,Zl.jsxs=n,Zl}var n_;function dq(){return n_||(n_=1,Wh.exports=uq()),Wh.exports}var E=dq(),Yh={exports:{}},lt={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var r_;function fq(){if(r_)return lt;r_=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),a=Symbol.for("react.profiler"),o=Symbol.for("react.consumer"),s=Symbol.for("react.context"),l=Symbol.for("react.forward_ref"),u=Symbol.for("react.suspense"),d=Symbol.for("react.memo"),p=Symbol.for("react.lazy"),g=Symbol.iterator;function m(L){return L===null||typeof L!="object"?null:(L=g&&L[g]||L["@@iterator"],typeof L=="function"?L:null)}var b={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},v=Object.assign,y={};function k(L,V,j){this.props=L,this.context=V,this.refs=y,this.updater=j||b}k.prototype.isReactComponent={},k.prototype.setState=function(L,V){if(typeof L!="object"&&typeof L!="function"&&L!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,L,V,"setState")},k.prototype.forceUpdate=function(L){this.updater.enqueueForceUpdate(this,L,"forceUpdate")};function A(){}A.prototype=k.prototype;function x(L,V,j){this.props=L,this.context=V,this.refs=y,this.updater=j||b}var R=x.prototype=new A;R.constructor=x,v(R,k.prototype),R.isPureReactComponent=!0;var O=Array.isArray,N={H:null,A:null,T:null,S:null},C=Object.prototype.hasOwnProperty;function _(L,V,j,P,Z,Q){return j=Q.ref,{$$typeof:e,type:L,key:V,ref:j!==void 0?j:null,props:Q}}function M(L,V){return _(L.type,V,void 0,void 0,void 0,L.props)}function I(L){return typeof L=="object"&&L!==null&&L.$$typeof===e}function D(L){var V={"=":"=0",":":"=2"};return"$"+L.replace(/[=:]/g,function(j){return V[j]})}var U=/\/+/g;function $(L,V){return typeof L=="object"&&L!==null&&L.key!=null?D(""+L.key):V.toString(36)}function B(){}function W(L){switch(L.status){case"fulfilled":return L.value;case"rejected":throw L.reason;default:switch(typeof L.status=="string"?L.then(B,B):(L.status="pending",L.then(function(V){L.status==="pending"&&(L.status="fulfilled",L.value=V)},function(V){L.status==="pending"&&(L.status="rejected",L.reason=V)})),L.status){case"fulfilled":return L.value;case"rejected":throw L.reason}}throw L}function K(L,V,j,P,Z){var Q=typeof L;(Q==="undefined"||Q==="boolean")&&(L=null);var oe=!1;if(L===null)oe=!0;else switch(Q){case"bigint":case"string":case"number":oe=!0;break;case"object":switch(L.$$typeof){case e:case t:oe=!0;break;case p:return oe=L._init,K(oe(L._payload),V,j,P,Z)}}if(oe)return Z=Z(L),oe=P===""?"."+$(L,0):P,O(Z)?(j="",oe!=null&&(j=oe.replace(U,"$&/")+"/"),K(Z,V,j,"",function(Re){return Re})):Z!=null&&(I(Z)&&(Z=M(Z,j+(Z.key==null||L&&L.key===Z.key?"":(""+Z.key).replace(U,"$&/")+"/")+oe)),V.push(Z)),1;oe=0;var ae=P===""?".":P+":";if(O(L))for(var ce=0;ce<L.length;ce++)P=L[ce],Q=ae+$(P,ce),oe+=K(P,V,j,Q,Z);else if(ce=m(L),typeof ce=="function")for(L=ce.call(L),ce=0;!(P=L.next()).done;)P=P.value,Q=ae+$(P,ce++),oe+=K(P,V,j,Q,Z);else if(Q==="object"){if(typeof L.then=="function")return K(W(L),V,j,P,Z);throw V=String(L),Error("Objects are not valid as a React child (found: "+(V==="[object Object]"?"object with keys {"+Object.keys(L).join(", ")+"}":V)+"). If you meant to render a collection of children, use an array instead.")}return oe}function H(L,V,j){if(L==null)return L;var P=[],Z=0;return K(L,P,"","",function(Q){return V.call(j,Q,Z++)}),P}function G(L){if(L._status===-1){var V=L._result;V=V(),V.then(function(j){(L._status===0||L._status===-1)&&(L._status=1,L._result=j)},function(j){(L._status===0||L._status===-1)&&(L._status=2,L._result=j)}),L._status===-1&&(L._status=0,L._result=V)}if(L._status===1)return L._result.default;throw L._result}var z=typeof reportError=="function"?reportError:function(L){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var V=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof L=="object"&&L!==null&&typeof L.message=="string"?String(L.message):String(L),error:L});if(!window.dispatchEvent(V))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",L);return}console.error(L)};function Y(){}return lt.Children={map:H,forEach:function(L,V,j){H(L,function(){V.apply(this,arguments)},j)},count:function(L){var V=0;return H(L,function(){V++}),V},toArray:function(L){return H(L,function(V){return V})||[]},only:function(L){if(!I(L))throw Error("React.Children.only expected to receive a single React element child.");return L}},lt.Component=k,lt.Fragment=n,lt.Profiler=a,lt.PureComponent=x,lt.StrictMode=r,lt.Suspense=u,lt.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=N,lt.act=function(){throw Error("act(...) is not supported in production builds of React.")},lt.cache=function(L){return function(){return L.apply(null,arguments)}},lt.cloneElement=function(L,V,j){if(L==null)throw Error("The argument must be a React element, but you passed "+L+".");var P=v({},L.props),Z=L.key,Q=void 0;if(V!=null)for(oe in V.ref!==void 0&&(Q=void 0),V.key!==void 0&&(Z=""+V.key),V)!C.call(V,oe)||oe==="key"||oe==="__self"||oe==="__source"||oe==="ref"&&V.ref===void 0||(P[oe]=V[oe]);var oe=arguments.length-2;if(oe===1)P.children=j;else if(1<oe){for(var ae=Array(oe),ce=0;ce<oe;ce++)ae[ce]=arguments[ce+2];P.children=ae}return _(L.type,Z,void 0,void 0,Q,P)},lt.createContext=function(L){return L={$$typeof:s,_currentValue:L,_currentValue2:L,_threadCount:0,Provider:null,Consumer:null},L.Provider=L,L.Consumer={$$typeof:o,_context:L},L},lt.createElement=function(L,V,j){var P,Z={},Q=null;if(V!=null)for(P in V.key!==void 0&&(Q=""+V.key),V)C.call(V,P)&&P!=="key"&&P!=="__self"&&P!=="__source"&&(Z[P]=V[P]);var oe=arguments.length-2;if(oe===1)Z.children=j;else if(1<oe){for(var ae=Array(oe),ce=0;ce<oe;ce++)ae[ce]=arguments[ce+2];Z.children=ae}if(L&&L.defaultProps)for(P in oe=L.defaultProps,oe)Z[P]===void 0&&(Z[P]=oe[P]);return _(L,Q,void 0,void 0,null,Z)},lt.createRef=function(){return{current:null}},lt.forwardRef=function(L){return{$$typeof:l,render:L}},lt.isValidElement=I,lt.lazy=function(L){return{$$typeof:p,_payload:{_status:-1,_result:L},_init:G}},lt.memo=function(L,V){return{$$typeof:d,type:L,compare:V===void 0?null:V}},lt.startTransition=function(L){var V=N.T,j={};N.T=j;try{var P=L(),Z=N.S;Z!==null&&Z(j,P),typeof P=="object"&&P!==null&&typeof P.then=="function"&&P.then(Y,z)}catch(Q){z(Q)}finally{N.T=V}},lt.unstable_useCacheRefresh=function(){return N.H.useCacheRefresh()},lt.use=function(L){return N.H.use(L)},lt.useActionState=function(L,V,j){return N.H.useActionState(L,V,j)},lt.useCallback=function(L,V){return N.H.useCallback(L,V)},lt.useContext=function(L){return N.H.useContext(L)},lt.useDebugValue=function(){},lt.useDeferredValue=function(L,V){return N.H.useDeferredValue(L,V)},lt.useEffect=function(L,V){return N.H.useEffect(L,V)},lt.useId=function(){return N.H.useId()},lt.useImperativeHandle=function(L,V,j){return N.H.useImperativeHandle(L,V,j)},lt.useInsertionEffect=function(L,V){return N.H.useInsertionEffect(L,V)},lt.useLayoutEffect=function(L,V){return N.H.useLayoutEffect(L,V)},lt.useMemo=function(L,V){return N.H.useMemo(L,V)},lt.useOptimistic=function(L,V){return N.H.useOptimistic(L,V)},lt.useReducer=function(L,V,j){return N.H.useReducer(L,V,j)},lt.useRef=function(L){return N.H.useRef(L)},lt.useState=function(L){return N.H.useState(L)},lt.useSyncExternalStore=function(L,V,j){return N.H.useSyncExternalStore(L,V,j)},lt.useTransition=function(){return N.H.useTransition()},lt.version="19.0.0",lt}var a_;function qf(){return a_||(a_=1,Yh.exports=fq()),Yh.exports}var w=qf();const we=un(w),pq=lq({__proto__:null,default:we},[w]);var Kh={exports:{}},Ql={},Xh={exports:{}},Zh={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var o_;function gq(){return o_||(o_=1,function(e){function t(H,G){var z=H.length;H.push(G);e:for(;0<z;){var Y=z-1>>>1,L=H[Y];if(0<a(L,G))H[Y]=G,H[z]=L,z=Y;else break e}}function n(H){return H.length===0?null:H[0]}function r(H){if(H.length===0)return null;var G=H[0],z=H.pop();if(z!==G){H[0]=z;e:for(var Y=0,L=H.length,V=L>>>1;Y<V;){var j=2*(Y+1)-1,P=H[j],Z=j+1,Q=H[Z];if(0>a(P,z))Z<L&&0>a(Q,P)?(H[Y]=Q,H[Z]=z,Y=Z):(H[Y]=P,H[j]=z,Y=j);else if(Z<L&&0>a(Q,z))H[Y]=Q,H[Z]=z,Y=Z;else break e}}return G}function a(H,G){var z=H.sortIndex-G.sortIndex;return z!==0?z:H.id-G.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var o=performance;e.unstable_now=function(){return o.now()}}else{var s=Date,l=s.now();e.unstable_now=function(){return s.now()-l}}var u=[],d=[],p=1,g=null,m=3,b=!1,v=!1,y=!1,k=typeof setTimeout=="function"?setTimeout:null,A=typeof clearTimeout=="function"?clearTimeout:null,x=typeof setImmediate<"u"?setImmediate:null;function R(H){for(var G=n(d);G!==null;){if(G.callback===null)r(d);else if(G.startTime<=H)r(d),G.sortIndex=G.expirationTime,t(u,G);else break;G=n(d)}}function O(H){if(y=!1,R(H),!v)if(n(u)!==null)v=!0,W();else{var G=n(d);G!==null&&K(O,G.startTime-H)}}var N=!1,C=-1,_=5,M=-1;function I(){return!(e.unstable_now()-M<_)}function D(){if(N){var H=e.unstable_now();M=H;var G=!0;try{e:{v=!1,y&&(y=!1,A(C),C=-1),b=!0;var z=m;try{t:{for(R(H),g=n(u);g!==null&&!(g.expirationTime>H&&I());){var Y=g.callback;if(typeof Y=="function"){g.callback=null,m=g.priorityLevel;var L=Y(g.expirationTime<=H);if(H=e.unstable_now(),typeof L=="function"){g.callback=L,R(H),G=!0;break t}g===n(u)&&r(u),R(H)}else r(u);g=n(u)}if(g!==null)G=!0;else{var V=n(d);V!==null&&K(O,V.startTime-H),G=!1}}break e}finally{g=null,m=z,b=!1}G=void 0}}finally{G?U():N=!1}}}var U;if(typeof x=="function")U=function(){x(D)};else if(typeof MessageChannel<"u"){var $=new MessageChannel,B=$.port2;$.port1.onmessage=D,U=function(){B.postMessage(null)}}else U=function(){k(D,0)};function W(){N||(N=!0,U())}function K(H,G){C=k(function(){H(e.unstable_now())},G)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function(H){H.callback=null},e.unstable_continueExecution=function(){v||b||(v=!0,W())},e.unstable_forceFrameRate=function(H){0>H||125<H?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):_=0<H?Math.floor(1e3/H):5},e.unstable_getCurrentPriorityLevel=function(){return m},e.unstable_getFirstCallbackNode=function(){return n(u)},e.unstable_next=function(H){switch(m){case 1:case 2:case 3:var G=3;break;default:G=m}var z=m;m=G;try{return H()}finally{m=z}},e.unstable_pauseExecution=function(){},e.unstable_requestPaint=function(){},e.unstable_runWithPriority=function(H,G){switch(H){case 1:case 2:case 3:case 4:case 5:break;default:H=3}var z=m;m=H;try{return G()}finally{m=z}},e.unstable_scheduleCallback=function(H,G,z){var Y=e.unstable_now();switch(typeof z=="object"&&z!==null?(z=z.delay,z=typeof z=="number"&&0<z?Y+z:Y):z=Y,H){case 1:var L=-1;break;case 2:L=250;break;case 5:L=1073741823;break;case 4:L=1e4;break;default:L=5e3}return L=z+L,H={id:p++,callback:G,priorityLevel:H,startTime:z,expirationTime:L,sortIndex:-1},z>Y?(H.sortIndex=z,t(d,H),n(u)===null&&H===n(d)&&(y?(A(C),C=-1):y=!0,K(O,z-Y))):(H.sortIndex=L,t(u,H),v||b||(v=!0,W())),H},e.unstable_shouldYield=I,e.unstable_wrapCallback=function(H){var G=m;return function(){var z=m;m=G;try{return H.apply(this,arguments)}finally{m=z}}}}(Zh)),Zh}var i_;function hq(){return i_||(i_=1,Xh.exports=gq()),Xh.exports}var Qh={exports:{}},wn={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var s_;function mq(){if(s_)return wn;s_=1;var e=qf();function t(u){var d="https://react.dev/errors/"+u;if(1<arguments.length){d+="?args[]="+encodeURIComponent(arguments[1]);for(var p=2;p<arguments.length;p++)d+="&args[]="+encodeURIComponent(arguments[p])}return"Minified React error #"+u+"; visit "+d+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function n(){}var r={d:{f:n,r:function(){throw Error(t(522))},D:n,C:n,L:n,m:n,X:n,S:n,M:n},p:0,findDOMNode:null},a=Symbol.for("react.portal");function o(u,d,p){var g=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:a,key:g==null?null:""+g,children:u,containerInfo:d,implementation:p}}var s=e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function l(u,d){if(u==="font")return"";if(typeof d=="string")return d==="use-credentials"?d:""}return wn.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,wn.createPortal=function(u,d){var p=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!d||d.nodeType!==1&&d.nodeType!==9&&d.nodeType!==11)throw Error(t(299));return o(u,d,null,p)},wn.flushSync=function(u){var d=s.T,p=r.p;try{if(s.T=null,r.p=2,u)return u()}finally{s.T=d,r.p=p,r.d.f()}},wn.preconnect=function(u,d){typeof u=="string"&&(d?(d=d.crossOrigin,d=typeof d=="string"?d==="use-credentials"?d:"":void 0):d=null,r.d.C(u,d))},wn.prefetchDNS=function(u){typeof u=="string"&&r.d.D(u)},wn.preinit=function(u,d){if(typeof u=="string"&&d&&typeof d.as=="string"){var p=d.as,g=l(p,d.crossOrigin),m=typeof d.integrity=="string"?d.integrity:void 0,b=typeof d.fetchPriority=="string"?d.fetchPriority:void 0;p==="style"?r.d.S(u,typeof d.precedence=="string"?d.precedence:void 0,{crossOrigin:g,integrity:m,fetchPriority:b}):p==="script"&&r.d.X(u,{crossOrigin:g,integrity:m,fetchPriority:b,nonce:typeof d.nonce=="string"?d.nonce:void 0})}},wn.preinitModule=function(u,d){if(typeof u=="string")if(typeof d=="object"&&d!==null){if(d.as==null||d.as==="script"){var p=l(d.as,d.crossOrigin);r.d.M(u,{crossOrigin:p,integrity:typeof d.integrity=="string"?d.integrity:void 0,nonce:typeof d.nonce=="string"?d.nonce:void 0})}}else d==null&&r.d.M(u)},wn.preload=function(u,d){if(typeof u=="string"&&typeof d=="object"&&d!==null&&typeof d.as=="string"){var p=d.as,g=l(p,d.crossOrigin);r.d.L(u,p,{crossOrigin:g,integrity:typeof d.integrity=="string"?d.integrity:void 0,nonce:typeof d.nonce=="string"?d.nonce:void 0,type:typeof d.type=="string"?d.type:void 0,fetchPriority:typeof d.fetchPriority=="string"?d.fetchPriority:void 0,referrerPolicy:typeof d.referrerPolicy=="string"?d.referrerPolicy:void 0,imageSrcSet:typeof d.imageSrcSet=="string"?d.imageSrcSet:void 0,imageSizes:typeof d.imageSizes=="string"?d.imageSizes:void 0,media:typeof d.media=="string"?d.media:void 0})}},wn.preloadModule=function(u,d){if(typeof u=="string")if(d){var p=l(d.as,d.crossOrigin);r.d.m(u,{as:typeof d.as=="string"&&d.as!=="script"?d.as:void 0,crossOrigin:p,integrity:typeof d.integrity=="string"?d.integrity:void 0})}else r.d.m(u)},wn.requestFormReset=function(u){r.d.r(u)},wn.unstable_batchedUpdates=function(u,d){return u(d)},wn.useFormState=function(u,d,p){return s.H.useFormState(u,d,p)},wn.useFormStatus=function(){return s.H.useHostTransitionStatus()},wn.version="19.0.0",wn}var l_;function Wz(){if(l_)return Qh.exports;l_=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),Qh.exports=mq(),Qh.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var c_;function bq(){if(c_)return Ql;c_=1;var e=hq(),t=qf(),n=Wz();function r(i){var c="https://react.dev/errors/"+i;if(1<arguments.length){c+="?args[]="+encodeURIComponent(arguments[1]);for(var f=2;f<arguments.length;f++)c+="&args[]="+encodeURIComponent(arguments[f])}return"Minified React error #"+i+"; visit "+c+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function a(i){return!(!i||i.nodeType!==1&&i.nodeType!==9&&i.nodeType!==11)}var o=Symbol.for("react.element"),s=Symbol.for("react.transitional.element"),l=Symbol.for("react.portal"),u=Symbol.for("react.fragment"),d=Symbol.for("react.strict_mode"),p=Symbol.for("react.profiler"),g=Symbol.for("react.provider"),m=Symbol.for("react.consumer"),b=Symbol.for("react.context"),v=Symbol.for("react.forward_ref"),y=Symbol.for("react.suspense"),k=Symbol.for("react.suspense_list"),A=Symbol.for("react.memo"),x=Symbol.for("react.lazy"),R=Symbol.for("react.offscreen"),O=Symbol.for("react.memo_cache_sentinel"),N=Symbol.iterator;function C(i){return i===null||typeof i!="object"?null:(i=N&&i[N]||i["@@iterator"],typeof i=="function"?i:null)}var _=Symbol.for("react.client.reference");function M(i){if(i==null)return null;if(typeof i=="function")return i.$$typeof===_?null:i.displayName||i.name||null;if(typeof i=="string")return i;switch(i){case u:return"Fragment";case l:return"Portal";case p:return"Profiler";case d:return"StrictMode";case y:return"Suspense";case k:return"SuspenseList"}if(typeof i=="object")switch(i.$$typeof){case b:return(i.displayName||"Context")+".Provider";case m:return(i._context.displayName||"Context")+".Consumer";case v:var c=i.render;return i=i.displayName,i||(i=c.displayName||c.name||"",i=i!==""?"ForwardRef("+i+")":"ForwardRef"),i;case A:return c=i.displayName||null,c!==null?c:M(i.type)||"Memo";case x:c=i._payload,i=i._init;try{return M(i(c))}catch{}}return null}var I=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,D=Object.assign,U,$;function B(i){if(U===void 0)try{throw Error()}catch(f){var c=f.stack.trim().match(/\n( *(at )?)/);U=c&&c[1]||"",$=-1<f.stack.indexOf(`
    at`)?" (<anonymous>)":-1<f.stack.indexOf("@")?"@unknown:0:0":""}return`
`+U+i+$}var W=!1;function K(i,c){if(!i||W)return"";W=!0;var f=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var h={DetermineComponentFrameRoot:function(){try{if(c){var Ce=function(){throw Error()};if(Object.defineProperty(Ce.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(Ce,[])}catch(me){var fe=me}Reflect.construct(i,[],Ce)}else{try{Ce.call()}catch(me){fe=me}i.call(Ce.prototype)}}else{try{throw Error()}catch(me){fe=me}(Ce=i())&&typeof Ce.catch=="function"&&Ce.catch(function(){})}}catch(me){if(me&&fe&&typeof me.stack=="string")return[me.stack,fe.stack]}return[null,null]}};h.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var S=Object.getOwnPropertyDescriptor(h.DetermineComponentFrameRoot,"name");S&&S.configurable&&Object.defineProperty(h.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var T=h.DetermineComponentFrameRoot(),F=T[0],q=T[1];if(F&&q){var X=F.split(`
`),re=q.split(`
`);for(S=h=0;h<X.length&&!X[h].includes("DetermineComponentFrameRoot");)h++;for(;S<re.length&&!re[S].includes("DetermineComponentFrameRoot");)S++;if(h===X.length||S===re.length)for(h=X.length-1,S=re.length-1;1<=h&&0<=S&&X[h]!==re[S];)S--;for(;1<=h&&0<=S;h--,S--)if(X[h]!==re[S]){if(h!==1||S!==1)do if(h--,S--,0>S||X[h]!==re[S]){var ve=`
`+X[h].replace(" at new "," at ");return i.displayName&&ve.includes("<anonymous>")&&(ve=ve.replace("<anonymous>",i.displayName)),ve}while(1<=h&&0<=S);break}}}finally{W=!1,Error.prepareStackTrace=f}return(f=i?i.displayName||i.name:"")?B(f):""}function H(i){switch(i.tag){case 26:case 27:case 5:return B(i.type);case 16:return B("Lazy");case 13:return B("Suspense");case 19:return B("SuspenseList");case 0:case 15:return i=K(i.type,!1),i;case 11:return i=K(i.type.render,!1),i;case 1:return i=K(i.type,!0),i;default:return""}}function G(i){try{var c="";do c+=H(i),i=i.return;while(i);return c}catch(f){return`
Error generating stack: `+f.message+`
`+f.stack}}function z(i){var c=i,f=i;if(i.alternate)for(;c.return;)c=c.return;else{i=c;do c=i,c.flags&4098&&(f=c.return),i=c.return;while(i)}return c.tag===3?f:null}function Y(i){if(i.tag===13){var c=i.memoizedState;if(c===null&&(i=i.alternate,i!==null&&(c=i.memoizedState)),c!==null)return c.dehydrated}return null}function L(i){if(z(i)!==i)throw Error(r(188))}function V(i){var c=i.alternate;if(!c){if(c=z(i),c===null)throw Error(r(188));return c!==i?null:i}for(var f=i,h=c;;){var S=f.return;if(S===null)break;var T=S.alternate;if(T===null){if(h=S.return,h!==null){f=h;continue}break}if(S.child===T.child){for(T=S.child;T;){if(T===f)return L(S),i;if(T===h)return L(S),c;T=T.sibling}throw Error(r(188))}if(f.return!==h.return)f=S,h=T;else{for(var F=!1,q=S.child;q;){if(q===f){F=!0,f=S,h=T;break}if(q===h){F=!0,h=S,f=T;break}q=q.sibling}if(!F){for(q=T.child;q;){if(q===f){F=!0,f=T,h=S;break}if(q===h){F=!0,h=T,f=S;break}q=q.sibling}if(!F)throw Error(r(189))}}if(f.alternate!==h)throw Error(r(190))}if(f.tag!==3)throw Error(r(188));return f.stateNode.current===f?i:c}function j(i){var c=i.tag;if(c===5||c===26||c===27||c===6)return i;for(i=i.child;i!==null;){if(c=j(i),c!==null)return c;i=i.sibling}return null}var P=Array.isArray,Z=n.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,Q={pending:!1,data:null,method:null,action:null},oe=[],ae=-1;function ce(i){return{current:i}}function Re(i){0>ae||(i.current=oe[ae],oe[ae]=null,ae--)}function ie(i,c){ae++,oe[ae]=i.current,i.current=c}var Te=ce(null),ne=ce(null),xe=ce(null),Se=ce(null);function be(i,c){switch(ie(xe,c),ie(ne,i),ie(Te,null),i=c.nodeType,i){case 9:case 11:c=(c=c.documentElement)&&(c=c.namespaceURI)?NC(c):0;break;default:if(i=i===8?c.parentNode:c,c=i.tagName,i=i.namespaceURI)i=NC(i),c=OC(i,c);else switch(c){case"svg":c=1;break;case"math":c=2;break;default:c=0}}Re(Te),ie(Te,c)}function J(){Re(Te),Re(ne),Re(xe)}function pe(i){i.memoizedState!==null&&ie(Se,i);var c=Te.current,f=OC(c,i.type);c!==f&&(ie(ne,i),ie(Te,f))}function ke(i){ne.current===i&&(Re(Te),Re(ne)),Se.current===i&&(Re(Se),Vl._currentValue=Q)}var he=Object.prototype.hasOwnProperty,Ee=e.unstable_scheduleCallback,se=e.unstable_cancelCallback,Be=e.unstable_shouldYield,je=e.unstable_requestPaint,ye=e.unstable_now,Oe=e.unstable_getCurrentPriorityLevel,ee=e.unstable_ImmediatePriority,de=e.unstable_UserBlockingPriority,Ne=e.unstable_NormalPriority,Fe=e.unstable_LowPriority,We=e.unstable_IdlePriority,St=e.log,Tt=e.unstable_setDisableYieldValue,bt=null,et=null;function At(i){if(et&&typeof et.onCommitFiberRoot=="function")try{et.onCommitFiberRoot(bt,i,void 0,(i.current.flags&128)===128)}catch{}}function st(i){if(typeof St=="function"&&Tt(i),et&&typeof et.setStrictMode=="function")try{et.setStrictMode(bt,i)}catch{}}var wt=Math.clz32?Math.clz32:zt,Ht=Math.log,pn=Math.LN2;function zt(i){return i>>>=0,i===0?32:31-(Ht(i)/pn|0)|0}var ir=128,Vr=4194304;function Jt(i){var c=i&42;if(c!==0)return c;switch(i&-i){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return i&4194176;case 4194304:case 8388608:case 16777216:case 33554432:return i&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return i}}function pa(i,c){var f=i.pendingLanes;if(f===0)return 0;var h=0,S=i.suspendedLanes,T=i.pingedLanes,F=i.warmLanes;i=i.finishedLanes!==0;var q=f&134217727;return q!==0?(f=q&~S,f!==0?h=Jt(f):(T&=q,T!==0?h=Jt(T):i||(F=q&~F,F!==0&&(h=Jt(F))))):(q=f&~S,q!==0?h=Jt(q):T!==0?h=Jt(T):i||(F=f&~F,F!==0&&(h=Jt(F)))),h===0?0:c!==0&&c!==h&&!(c&S)&&(S=h&-h,F=c&-c,S>=F||S===32&&(F&4194176)!==0)?c:h}function Xe(i,c){return(i.pendingLanes&~(i.suspendedLanes&~i.pingedLanes)&c)===0}function yt(i,c){switch(i){case 1:case 2:case 4:case 8:return c+250;case 16:case 32:case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return c+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Nt(){var i=ir;return ir<<=1,!(ir&4194176)&&(ir=128),i}function Ln(){var i=Vr;return Vr<<=1,!(Vr&62914560)&&(Vr=4194304),i}function _n(i){for(var c=[],f=0;31>f;f++)c.push(i);return c}function Mn(i,c){i.pendingLanes|=c,c!==268435456&&(i.suspendedLanes=0,i.pingedLanes=0,i.warmLanes=0)}function ga(i,c,f,h,S,T){var F=i.pendingLanes;i.pendingLanes=f,i.suspendedLanes=0,i.pingedLanes=0,i.warmLanes=0,i.expiredLanes&=f,i.entangledLanes&=f,i.errorRecoveryDisabledLanes&=f,i.shellSuspendCounter=0;var q=i.entanglements,X=i.expirationTimes,re=i.hiddenUpdates;for(f=F&~f;0<f;){var ve=31-wt(f),Ce=1<<ve;q[ve]=0,X[ve]=-1;var fe=re[ve];if(fe!==null)for(re[ve]=null,ve=0;ve<fe.length;ve++){var me=fe[ve];me!==null&&(me.lane&=-536870913)}f&=~Ce}h!==0&&Pn(i,h,0),T!==0&&S===0&&i.tag!==0&&(i.suspendedLanes|=T&~(F&~c))}function Pn(i,c,f){i.pendingLanes|=c,i.suspendedLanes&=~c;var h=31-wt(c);i.entangledLanes|=c,i.entanglements[h]=i.entanglements[h]|1073741824|f&4194218}function _r(i,c){var f=i.entangledLanes|=c;for(i=i.entanglements;f;){var h=31-wt(f),S=1<<h;S&c|i[h]&c&&(i[h]|=c),f&=~S}}function AA(i){return i&=-i,2<i?8<i?i&134217727?32:268435456:8:2}function RA(){var i=Z.p;return i!==0?i:(i=window.event,i===void 0?32:KC(i.type))}function XH(i,c){var f=Z.p;try{return Z.p=i,c()}finally{Z.p=f}}var Wa=Math.random().toString(36).slice(2),Sn="__reactFiber$"+Wa,Fn="__reactProps$"+Wa,_i="__reactContainer$"+Wa,Hp="__reactEvents$"+Wa,ZH="__reactListeners$"+Wa,QH="__reactHandles$"+Wa,CA="__reactResources$"+Wa,al="__reactMarker$"+Wa;function $p(i){delete i[Sn],delete i[Fn],delete i[Hp],delete i[ZH],delete i[QH]}function Po(i){var c=i[Sn];if(c)return c;for(var f=i.parentNode;f;){if(c=f[_i]||f[Sn]){if(f=c.alternate,c.child!==null||f!==null&&f.child!==null)for(i=LC(i);i!==null;){if(f=i[Sn])return f;i=LC(i)}return c}i=f,f=i.parentNode}return null}function Ni(i){if(i=i[Sn]||i[_i]){var c=i.tag;if(c===5||c===6||c===13||c===26||c===27||c===3)return i}return null}function ol(i){var c=i.tag;if(c===5||c===26||c===27||c===6)return i.stateNode;throw Error(r(33))}function Oi(i){var c=i[CA];return c||(c=i[CA]={hoistableStyles:new Map,hoistableScripts:new Map}),c}function an(i){i[al]=!0}var _A=new Set,NA={};function Fo(i,c){Ii(i,c),Ii(i+"Capture",c)}function Ii(i,c){for(NA[i]=c,i=0;i<c.length;i++)_A.add(c[i])}var ha=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),JH=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),OA={},IA={};function e6(i){return he.call(IA,i)?!0:he.call(OA,i)?!1:JH.test(i)?IA[i]=!0:(OA[i]=!0,!1)}function uu(i,c,f){if(e6(c))if(f===null)i.removeAttribute(c);else{switch(typeof f){case"undefined":case"function":case"symbol":i.removeAttribute(c);return;case"boolean":var h=c.toLowerCase().slice(0,5);if(h!=="data-"&&h!=="aria-"){i.removeAttribute(c);return}}i.setAttribute(c,""+f)}}function du(i,c,f){if(f===null)i.removeAttribute(c);else{switch(typeof f){case"undefined":case"function":case"symbol":case"boolean":i.removeAttribute(c);return}i.setAttribute(c,""+f)}}function ma(i,c,f,h){if(h===null)i.removeAttribute(f);else{switch(typeof h){case"undefined":case"function":case"symbol":case"boolean":i.removeAttribute(f);return}i.setAttributeNS(c,f,""+h)}}function sr(i){switch(typeof i){case"bigint":case"boolean":case"number":case"string":case"undefined":return i;case"object":return i;default:return""}}function DA(i){var c=i.type;return(i=i.nodeName)&&i.toLowerCase()==="input"&&(c==="checkbox"||c==="radio")}function t6(i){var c=DA(i)?"checked":"value",f=Object.getOwnPropertyDescriptor(i.constructor.prototype,c),h=""+i[c];if(!i.hasOwnProperty(c)&&typeof f<"u"&&typeof f.get=="function"&&typeof f.set=="function"){var S=f.get,T=f.set;return Object.defineProperty(i,c,{configurable:!0,get:function(){return S.call(this)},set:function(F){h=""+F,T.call(this,F)}}),Object.defineProperty(i,c,{enumerable:f.enumerable}),{getValue:function(){return h},setValue:function(F){h=""+F},stopTracking:function(){i._valueTracker=null,delete i[c]}}}}function fu(i){i._valueTracker||(i._valueTracker=t6(i))}function LA(i){if(!i)return!1;var c=i._valueTracker;if(!c)return!0;var f=c.getValue(),h="";return i&&(h=DA(i)?i.checked?"true":"false":i.value),i=h,i!==f?(c.setValue(i),!0):!1}function pu(i){if(i=i||(typeof document<"u"?document:void 0),typeof i>"u")return null;try{return i.activeElement||i.body}catch{return i.body}}var n6=/[\n"\\]/g;function lr(i){return i.replace(n6,function(c){return"\\"+c.charCodeAt(0).toString(16)+" "})}function qp(i,c,f,h,S,T,F,q){i.name="",F!=null&&typeof F!="function"&&typeof F!="symbol"&&typeof F!="boolean"?i.type=F:i.removeAttribute("type"),c!=null?F==="number"?(c===0&&i.value===""||i.value!=c)&&(i.value=""+sr(c)):i.value!==""+sr(c)&&(i.value=""+sr(c)):F!=="submit"&&F!=="reset"||i.removeAttribute("value"),c!=null?Vp(i,F,sr(c)):f!=null?Vp(i,F,sr(f)):h!=null&&i.removeAttribute("value"),S==null&&T!=null&&(i.defaultChecked=!!T),S!=null&&(i.checked=S&&typeof S!="function"&&typeof S!="symbol"),q!=null&&typeof q!="function"&&typeof q!="symbol"&&typeof q!="boolean"?i.name=""+sr(q):i.removeAttribute("name")}function MA(i,c,f,h,S,T,F,q){if(T!=null&&typeof T!="function"&&typeof T!="symbol"&&typeof T!="boolean"&&(i.type=T),c!=null||f!=null){if(!(T!=="submit"&&T!=="reset"||c!=null))return;f=f!=null?""+sr(f):"",c=c!=null?""+sr(c):f,q||c===i.value||(i.value=c),i.defaultValue=c}h=h??S,h=typeof h!="function"&&typeof h!="symbol"&&!!h,i.checked=q?i.checked:!!h,i.defaultChecked=!!h,F!=null&&typeof F!="function"&&typeof F!="symbol"&&typeof F!="boolean"&&(i.name=F)}function Vp(i,c,f){c==="number"&&pu(i.ownerDocument)===i||i.defaultValue===""+f||(i.defaultValue=""+f)}function Di(i,c,f,h){if(i=i.options,c){c={};for(var S=0;S<f.length;S++)c["$"+f[S]]=!0;for(f=0;f<i.length;f++)S=c.hasOwnProperty("$"+i[f].value),i[f].selected!==S&&(i[f].selected=S),S&&h&&(i[f].defaultSelected=!0)}else{for(f=""+sr(f),c=null,S=0;S<i.length;S++){if(i[S].value===f){i[S].selected=!0,h&&(i[S].defaultSelected=!0);return}c!==null||i[S].disabled||(c=i[S])}c!==null&&(c.selected=!0)}}function PA(i,c,f){if(c!=null&&(c=""+sr(c),c!==i.value&&(i.value=c),f==null)){i.defaultValue!==c&&(i.defaultValue=c);return}i.defaultValue=f!=null?""+sr(f):""}function FA(i,c,f,h){if(c==null){if(h!=null){if(f!=null)throw Error(r(92));if(P(h)){if(1<h.length)throw Error(r(93));h=h[0]}f=h}f==null&&(f=""),c=f}f=sr(c),i.defaultValue=f,h=i.textContent,h===f&&h!==""&&h!==null&&(i.value=h)}function Li(i,c){if(c){var f=i.firstChild;if(f&&f===i.lastChild&&f.nodeType===3){f.nodeValue=c;return}}i.textContent=c}var r6=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function zA(i,c,f){var h=c.indexOf("--")===0;f==null||typeof f=="boolean"||f===""?h?i.setProperty(c,""):c==="float"?i.cssFloat="":i[c]="":h?i.setProperty(c,f):typeof f!="number"||f===0||r6.has(c)?c==="float"?i.cssFloat=f:i[c]=(""+f).trim():i[c]=f+"px"}function BA(i,c,f){if(c!=null&&typeof c!="object")throw Error(r(62));if(i=i.style,f!=null){for(var h in f)!f.hasOwnProperty(h)||c!=null&&c.hasOwnProperty(h)||(h.indexOf("--")===0?i.setProperty(h,""):h==="float"?i.cssFloat="":i[h]="");for(var S in c)h=c[S],c.hasOwnProperty(S)&&f[S]!==h&&zA(i,S,h)}else for(var T in c)c.hasOwnProperty(T)&&zA(i,T,c[T])}function Wp(i){if(i.indexOf("-")===-1)return!1;switch(i){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var a6=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),o6=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function gu(i){return o6.test(""+i)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":i}var Yp=null;function Kp(i){return i=i.target||i.srcElement||window,i.correspondingUseElement&&(i=i.correspondingUseElement),i.nodeType===3?i.parentNode:i}var Mi=null,Pi=null;function jA(i){var c=Ni(i);if(c&&(i=c.stateNode)){var f=i[Fn]||null;e:switch(i=c.stateNode,c.type){case"input":if(qp(i,f.value,f.defaultValue,f.defaultValue,f.checked,f.defaultChecked,f.type,f.name),c=f.name,f.type==="radio"&&c!=null){for(f=i;f.parentNode;)f=f.parentNode;for(f=f.querySelectorAll('input[name="'+lr(""+c)+'"][type="radio"]'),c=0;c<f.length;c++){var h=f[c];if(h!==i&&h.form===i.form){var S=h[Fn]||null;if(!S)throw Error(r(90));qp(h,S.value,S.defaultValue,S.defaultValue,S.checked,S.defaultChecked,S.type,S.name)}}for(c=0;c<f.length;c++)h=f[c],h.form===i.form&&LA(h)}break e;case"textarea":PA(i,f.value,f.defaultValue);break e;case"select":c=f.value,c!=null&&Di(i,!!f.multiple,c,!1)}}}var Xp=!1;function UA(i,c,f){if(Xp)return i(c,f);Xp=!0;try{var h=i(c);return h}finally{if(Xp=!1,(Mi!==null||Pi!==null)&&(Zu(),Mi&&(c=Mi,i=Pi,Pi=Mi=null,jA(c),i)))for(c=0;c<i.length;c++)jA(i[c])}}function il(i,c){var f=i.stateNode;if(f===null)return null;var h=f[Fn]||null;if(h===null)return null;f=h[c];e:switch(c){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(h=!h.disabled)||(i=i.type,h=!(i==="button"||i==="input"||i==="select"||i==="textarea")),i=!h;break e;default:i=!1}if(i)return null;if(f&&typeof f!="function")throw Error(r(231,c,typeof f));return f}var Zp=!1;if(ha)try{var sl={};Object.defineProperty(sl,"passive",{get:function(){Zp=!0}}),window.addEventListener("test",sl,sl),window.removeEventListener("test",sl,sl)}catch{Zp=!1}var Ya=null,Qp=null,hu=null;function GA(){if(hu)return hu;var i,c=Qp,f=c.length,h,S="value"in Ya?Ya.value:Ya.textContent,T=S.length;for(i=0;i<f&&c[i]===S[i];i++);var F=f-i;for(h=1;h<=F&&c[f-h]===S[T-h];h++);return hu=S.slice(i,1<h?1-h:void 0)}function mu(i){var c=i.keyCode;return"charCode"in i?(i=i.charCode,i===0&&c===13&&(i=13)):i=c,i===10&&(i=13),32<=i||i===13?i:0}function bu(){return!0}function HA(){return!1}function zn(i){function c(f,h,S,T,F){this._reactName=f,this._targetInst=S,this.type=h,this.nativeEvent=T,this.target=F,this.currentTarget=null;for(var q in i)i.hasOwnProperty(q)&&(f=i[q],this[q]=f?f(T):T[q]);return this.isDefaultPrevented=(T.defaultPrevented!=null?T.defaultPrevented:T.returnValue===!1)?bu:HA,this.isPropagationStopped=HA,this}return D(c.prototype,{preventDefault:function(){this.defaultPrevented=!0;var f=this.nativeEvent;f&&(f.preventDefault?f.preventDefault():typeof f.returnValue!="unknown"&&(f.returnValue=!1),this.isDefaultPrevented=bu)},stopPropagation:function(){var f=this.nativeEvent;f&&(f.stopPropagation?f.stopPropagation():typeof f.cancelBubble!="unknown"&&(f.cancelBubble=!0),this.isPropagationStopped=bu)},persist:function(){},isPersistent:bu}),c}var zo={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(i){return i.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},yu=zn(zo),ll=D({},zo,{view:0,detail:0}),i6=zn(ll),Jp,eg,cl,vu=D({},ll,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:ng,button:0,buttons:0,relatedTarget:function(i){return i.relatedTarget===void 0?i.fromElement===i.srcElement?i.toElement:i.fromElement:i.relatedTarget},movementX:function(i){return"movementX"in i?i.movementX:(i!==cl&&(cl&&i.type==="mousemove"?(Jp=i.screenX-cl.screenX,eg=i.screenY-cl.screenY):eg=Jp=0,cl=i),Jp)},movementY:function(i){return"movementY"in i?i.movementY:eg}}),$A=zn(vu),s6=D({},vu,{dataTransfer:0}),l6=zn(s6),c6=D({},ll,{relatedTarget:0}),tg=zn(c6),u6=D({},zo,{animationName:0,elapsedTime:0,pseudoElement:0}),d6=zn(u6),f6=D({},zo,{clipboardData:function(i){return"clipboardData"in i?i.clipboardData:window.clipboardData}}),p6=zn(f6),g6=D({},zo,{data:0}),qA=zn(g6),h6={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},m6={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},b6={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function y6(i){var c=this.nativeEvent;return c.getModifierState?c.getModifierState(i):(i=b6[i])?!!c[i]:!1}function ng(){return y6}var v6=D({},ll,{key:function(i){if(i.key){var c=h6[i.key]||i.key;if(c!=="Unidentified")return c}return i.type==="keypress"?(i=mu(i),i===13?"Enter":String.fromCharCode(i)):i.type==="keydown"||i.type==="keyup"?m6[i.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:ng,charCode:function(i){return i.type==="keypress"?mu(i):0},keyCode:function(i){return i.type==="keydown"||i.type==="keyup"?i.keyCode:0},which:function(i){return i.type==="keypress"?mu(i):i.type==="keydown"||i.type==="keyup"?i.keyCode:0}}),S6=zn(v6),E6=D({},vu,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),VA=zn(E6),w6=D({},ll,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:ng}),x6=zn(w6),k6=D({},zo,{propertyName:0,elapsedTime:0,pseudoElement:0}),T6=zn(k6),A6=D({},vu,{deltaX:function(i){return"deltaX"in i?i.deltaX:"wheelDeltaX"in i?-i.wheelDeltaX:0},deltaY:function(i){return"deltaY"in i?i.deltaY:"wheelDeltaY"in i?-i.wheelDeltaY:"wheelDelta"in i?-i.wheelDelta:0},deltaZ:0,deltaMode:0}),R6=zn(A6),C6=D({},zo,{newState:0,oldState:0}),_6=zn(C6),N6=[9,13,27,32],rg=ha&&"CompositionEvent"in window,ul=null;ha&&"documentMode"in document&&(ul=document.documentMode);var O6=ha&&"TextEvent"in window&&!ul,WA=ha&&(!rg||ul&&8<ul&&11>=ul),YA=" ",KA=!1;function XA(i,c){switch(i){case"keyup":return N6.indexOf(c.keyCode)!==-1;case"keydown":return c.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function ZA(i){return i=i.detail,typeof i=="object"&&"data"in i?i.data:null}var Fi=!1;function I6(i,c){switch(i){case"compositionend":return ZA(c);case"keypress":return c.which!==32?null:(KA=!0,YA);case"textInput":return i=c.data,i===YA&&KA?null:i;default:return null}}function D6(i,c){if(Fi)return i==="compositionend"||!rg&&XA(i,c)?(i=GA(),hu=Qp=Ya=null,Fi=!1,i):null;switch(i){case"paste":return null;case"keypress":if(!(c.ctrlKey||c.altKey||c.metaKey)||c.ctrlKey&&c.altKey){if(c.char&&1<c.char.length)return c.char;if(c.which)return String.fromCharCode(c.which)}return null;case"compositionend":return WA&&c.locale!=="ko"?null:c.data;default:return null}}var L6={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function QA(i){var c=i&&i.nodeName&&i.nodeName.toLowerCase();return c==="input"?!!L6[i.type]:c==="textarea"}function JA(i,c,f,h){Mi?Pi?Pi.push(h):Pi=[h]:Mi=h,c=nd(c,"onChange"),0<c.length&&(f=new yu("onChange","change",null,f,h),i.push({event:f,listeners:c}))}var dl=null,fl=null;function M6(i){TC(i,0)}function Su(i){var c=ol(i);if(LA(c))return i}function e1(i,c){if(i==="change")return c}var t1=!1;if(ha){var ag;if(ha){var og="oninput"in document;if(!og){var n1=document.createElement("div");n1.setAttribute("oninput","return;"),og=typeof n1.oninput=="function"}ag=og}else ag=!1;t1=ag&&(!document.documentMode||9<document.documentMode)}function r1(){dl&&(dl.detachEvent("onpropertychange",a1),fl=dl=null)}function a1(i){if(i.propertyName==="value"&&Su(fl)){var c=[];JA(c,fl,i,Kp(i)),UA(M6,c)}}function P6(i,c,f){i==="focusin"?(r1(),dl=c,fl=f,dl.attachEvent("onpropertychange",a1)):i==="focusout"&&r1()}function F6(i){if(i==="selectionchange"||i==="keyup"||i==="keydown")return Su(fl)}function z6(i,c){if(i==="click")return Su(c)}function B6(i,c){if(i==="input"||i==="change")return Su(c)}function j6(i,c){return i===c&&(i!==0||1/i===1/c)||i!==i&&c!==c}var Yn=typeof Object.is=="function"?Object.is:j6;function pl(i,c){if(Yn(i,c))return!0;if(typeof i!="object"||i===null||typeof c!="object"||c===null)return!1;var f=Object.keys(i),h=Object.keys(c);if(f.length!==h.length)return!1;for(h=0;h<f.length;h++){var S=f[h];if(!he.call(c,S)||!Yn(i[S],c[S]))return!1}return!0}function o1(i){for(;i&&i.firstChild;)i=i.firstChild;return i}function i1(i,c){var f=o1(i);i=0;for(var h;f;){if(f.nodeType===3){if(h=i+f.textContent.length,i<=c&&h>=c)return{node:f,offset:c-i};i=h}e:{for(;f;){if(f.nextSibling){f=f.nextSibling;break e}f=f.parentNode}f=void 0}f=o1(f)}}function s1(i,c){return i&&c?i===c?!0:i&&i.nodeType===3?!1:c&&c.nodeType===3?s1(i,c.parentNode):"contains"in i?i.contains(c):i.compareDocumentPosition?!!(i.compareDocumentPosition(c)&16):!1:!1}function l1(i){i=i!=null&&i.ownerDocument!=null&&i.ownerDocument.defaultView!=null?i.ownerDocument.defaultView:window;for(var c=pu(i.document);c instanceof i.HTMLIFrameElement;){try{var f=typeof c.contentWindow.location.href=="string"}catch{f=!1}if(f)i=c.contentWindow;else break;c=pu(i.document)}return c}function ig(i){var c=i&&i.nodeName&&i.nodeName.toLowerCase();return c&&(c==="input"&&(i.type==="text"||i.type==="search"||i.type==="tel"||i.type==="url"||i.type==="password")||c==="textarea"||i.contentEditable==="true")}function U6(i,c){var f=l1(c);c=i.focusedElem;var h=i.selectionRange;if(f!==c&&c&&c.ownerDocument&&s1(c.ownerDocument.documentElement,c)){if(h!==null&&ig(c)){if(i=h.start,f=h.end,f===void 0&&(f=i),"selectionStart"in c)c.selectionStart=i,c.selectionEnd=Math.min(f,c.value.length);else if(f=(i=c.ownerDocument||document)&&i.defaultView||window,f.getSelection){f=f.getSelection();var S=c.textContent.length,T=Math.min(h.start,S);h=h.end===void 0?T:Math.min(h.end,S),!f.extend&&T>h&&(S=h,h=T,T=S),S=i1(c,T);var F=i1(c,h);S&&F&&(f.rangeCount!==1||f.anchorNode!==S.node||f.anchorOffset!==S.offset||f.focusNode!==F.node||f.focusOffset!==F.offset)&&(i=i.createRange(),i.setStart(S.node,S.offset),f.removeAllRanges(),T>h?(f.addRange(i),f.extend(F.node,F.offset)):(i.setEnd(F.node,F.offset),f.addRange(i)))}}for(i=[],f=c;f=f.parentNode;)f.nodeType===1&&i.push({element:f,left:f.scrollLeft,top:f.scrollTop});for(typeof c.focus=="function"&&c.focus(),c=0;c<i.length;c++)f=i[c],f.element.scrollLeft=f.left,f.element.scrollTop=f.top}}var G6=ha&&"documentMode"in document&&11>=document.documentMode,zi=null,sg=null,gl=null,lg=!1;function c1(i,c,f){var h=f.window===f?f.document:f.nodeType===9?f:f.ownerDocument;lg||zi==null||zi!==pu(h)||(h=zi,"selectionStart"in h&&ig(h)?h={start:h.selectionStart,end:h.selectionEnd}:(h=(h.ownerDocument&&h.ownerDocument.defaultView||window).getSelection(),h={anchorNode:h.anchorNode,anchorOffset:h.anchorOffset,focusNode:h.focusNode,focusOffset:h.focusOffset}),gl&&pl(gl,h)||(gl=h,h=nd(sg,"onSelect"),0<h.length&&(c=new yu("onSelect","select",null,c,f),i.push({event:c,listeners:h}),c.target=zi)))}function Bo(i,c){var f={};return f[i.toLowerCase()]=c.toLowerCase(),f["Webkit"+i]="webkit"+c,f["Moz"+i]="moz"+c,f}var Bi={animationend:Bo("Animation","AnimationEnd"),animationiteration:Bo("Animation","AnimationIteration"),animationstart:Bo("Animation","AnimationStart"),transitionrun:Bo("Transition","TransitionRun"),transitionstart:Bo("Transition","TransitionStart"),transitioncancel:Bo("Transition","TransitionCancel"),transitionend:Bo("Transition","TransitionEnd")},cg={},u1={};ha&&(u1=document.createElement("div").style,"AnimationEvent"in window||(delete Bi.animationend.animation,delete Bi.animationiteration.animation,delete Bi.animationstart.animation),"TransitionEvent"in window||delete Bi.transitionend.transition);function jo(i){if(cg[i])return cg[i];if(!Bi[i])return i;var c=Bi[i],f;for(f in c)if(c.hasOwnProperty(f)&&f in u1)return cg[i]=c[f];return i}var d1=jo("animationend"),f1=jo("animationiteration"),p1=jo("animationstart"),H6=jo("transitionrun"),$6=jo("transitionstart"),q6=jo("transitioncancel"),g1=jo("transitionend"),h1=new Map,m1="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll scrollEnd toggle touchMove waiting wheel".split(" ");function Nr(i,c){h1.set(i,c),Fo(c,[i])}var cr=[],ji=0,ug=0;function Eu(){for(var i=ji,c=ug=ji=0;c<i;){var f=cr[c];cr[c++]=null;var h=cr[c];cr[c++]=null;var S=cr[c];cr[c++]=null;var T=cr[c];if(cr[c++]=null,h!==null&&S!==null){var F=h.pending;F===null?S.next=S:(S.next=F.next,F.next=S),h.pending=S}T!==0&&b1(f,S,T)}}function wu(i,c,f,h){cr[ji++]=i,cr[ji++]=c,cr[ji++]=f,cr[ji++]=h,ug|=h,i.lanes|=h,i=i.alternate,i!==null&&(i.lanes|=h)}function dg(i,c,f,h){return wu(i,c,f,h),xu(i)}function Ka(i,c){return wu(i,null,null,c),xu(i)}function b1(i,c,f){i.lanes|=f;var h=i.alternate;h!==null&&(h.lanes|=f);for(var S=!1,T=i.return;T!==null;)T.childLanes|=f,h=T.alternate,h!==null&&(h.childLanes|=f),T.tag===22&&(i=T.stateNode,i===null||i._visibility&1||(S=!0)),i=T,T=T.return;S&&c!==null&&i.tag===3&&(T=i.stateNode,S=31-wt(f),T=T.hiddenUpdates,i=T[S],i===null?T[S]=[c]:i.push(c),c.lane=f|536870912)}function xu(i){if(50<Bl)throw Bl=0,bh=null,Error(r(185));for(var c=i.return;c!==null;)i=c,c=i.return;return i.tag===3?i.stateNode:null}var Ui={},y1=new WeakMap;function ur(i,c){if(typeof i=="object"&&i!==null){var f=y1.get(i);return f!==void 0?f:(c={value:i,source:c,stack:G(c)},y1.set(i,c),c)}return{value:i,source:c,stack:G(c)}}var Gi=[],Hi=0,ku=null,Tu=0,dr=[],fr=0,Uo=null,ba=1,ya="";function Go(i,c){Gi[Hi++]=Tu,Gi[Hi++]=ku,ku=i,Tu=c}function v1(i,c,f){dr[fr++]=ba,dr[fr++]=ya,dr[fr++]=Uo,Uo=i;var h=ba;i=ya;var S=32-wt(h)-1;h&=~(1<<S),f+=1;var T=32-wt(c)+S;if(30<T){var F=S-S%5;T=(h&(1<<F)-1).toString(32),h>>=F,S-=F,ba=1<<32-wt(c)+S|f<<S|h,ya=T+i}else ba=1<<T|f<<S|h,ya=i}function fg(i){i.return!==null&&(Go(i,1),v1(i,1,0))}function pg(i){for(;i===ku;)ku=Gi[--Hi],Gi[Hi]=null,Tu=Gi[--Hi],Gi[Hi]=null;for(;i===Uo;)Uo=dr[--fr],dr[fr]=null,ya=dr[--fr],dr[fr]=null,ba=dr[--fr],dr[fr]=null}var Nn=null,gn=null,xt=!1,Or=null,Wr=!1,gg=Error(r(519));function Ho(i){var c=Error(r(418,""));throw bl(ur(c,i)),gg}function S1(i){var c=i.stateNode,f=i.type,h=i.memoizedProps;switch(c[Sn]=i,c[Fn]=h,f){case"dialog":ht("cancel",c),ht("close",c);break;case"iframe":case"object":case"embed":ht("load",c);break;case"video":case"audio":for(f=0;f<Ul.length;f++)ht(Ul[f],c);break;case"source":ht("error",c);break;case"img":case"image":case"link":ht("error",c),ht("load",c);break;case"details":ht("toggle",c);break;case"input":ht("invalid",c),MA(c,h.value,h.defaultValue,h.checked,h.defaultChecked,h.type,h.name,!0),fu(c);break;case"select":ht("invalid",c);break;case"textarea":ht("invalid",c),FA(c,h.value,h.defaultValue,h.children),fu(c)}f=h.children,typeof f!="string"&&typeof f!="number"&&typeof f!="bigint"||c.textContent===""+f||h.suppressHydrationWarning===!0||_C(c.textContent,f)?(h.popover!=null&&(ht("beforetoggle",c),ht("toggle",c)),h.onScroll!=null&&ht("scroll",c),h.onScrollEnd!=null&&ht("scrollend",c),h.onClick!=null&&(c.onclick=rd),c=!0):c=!1,c||Ho(i)}function E1(i){for(Nn=i.return;Nn;)switch(Nn.tag){case 3:case 27:Wr=!0;return;case 5:case 13:Wr=!1;return;default:Nn=Nn.return}}function hl(i){if(i!==Nn)return!1;if(!xt)return E1(i),xt=!0,!1;var c=!1,f;if((f=i.tag!==3&&i.tag!==27)&&((f=i.tag===5)&&(f=i.type,f=!(f!=="form"&&f!=="button")||Lh(i.type,i.memoizedProps)),f=!f),f&&(c=!0),c&&gn&&Ho(i),E1(i),i.tag===13){if(i=i.memoizedState,i=i!==null?i.dehydrated:null,!i)throw Error(r(317));e:{for(i=i.nextSibling,c=0;i;){if(i.nodeType===8)if(f=i.data,f==="/$"){if(c===0){gn=Dr(i.nextSibling);break e}c--}else f!=="$"&&f!=="$!"&&f!=="$?"||c++;i=i.nextSibling}gn=null}}else gn=Nn?Dr(i.stateNode.nextSibling):null;return!0}function ml(){gn=Nn=null,xt=!1}function bl(i){Or===null?Or=[i]:Or.push(i)}var yl=Error(r(460)),w1=Error(r(474)),hg={then:function(){}};function x1(i){return i=i.status,i==="fulfilled"||i==="rejected"}function Au(){}function k1(i,c,f){switch(f=i[f],f===void 0?i.push(c):f!==c&&(c.then(Au,Au),c=f),c.status){case"fulfilled":return c.value;case"rejected":throw i=c.reason,i===yl?Error(r(483)):i;default:if(typeof c.status=="string")c.then(Au,Au);else{if(i=Lt,i!==null&&100<i.shellSuspendCounter)throw Error(r(482));i=c,i.status="pending",i.then(function(h){if(c.status==="pending"){var S=c;S.status="fulfilled",S.value=h}},function(h){if(c.status==="pending"){var S=c;S.status="rejected",S.reason=h}})}switch(c.status){case"fulfilled":return c.value;case"rejected":throw i=c.reason,i===yl?Error(r(483)):i}throw vl=c,yl}}var vl=null;function T1(){if(vl===null)throw Error(r(459));var i=vl;return vl=null,i}var $i=null,Sl=0;function Ru(i){var c=Sl;return Sl+=1,$i===null&&($i=[]),k1($i,i,c)}function El(i,c){c=c.props.ref,i.ref=c!==void 0?c:null}function Cu(i,c){throw c.$$typeof===o?Error(r(525)):(i=Object.prototype.toString.call(c),Error(r(31,i==="[object Object]"?"object with keys {"+Object.keys(c).join(", ")+"}":i)))}function A1(i){var c=i._init;return c(i._payload)}function R1(i){function c(le,te){if(i){var ue=le.deletions;ue===null?(le.deletions=[te],le.flags|=16):ue.push(te)}}function f(le,te){if(!i)return null;for(;te!==null;)c(le,te),te=te.sibling;return null}function h(le){for(var te=new Map;le!==null;)le.key!==null?te.set(le.key,le):te.set(le.index,le),le=le.sibling;return te}function S(le,te){return le=so(le,te),le.index=0,le.sibling=null,le}function T(le,te,ue){return le.index=ue,i?(ue=le.alternate,ue!==null?(ue=ue.index,ue<te?(le.flags|=33554434,te):ue):(le.flags|=33554434,te)):(le.flags|=1048576,te)}function F(le){return i&&le.alternate===null&&(le.flags|=33554434),le}function q(le,te,ue,Ae){return te===null||te.tag!==6?(te=ch(ue,le.mode,Ae),te.return=le,te):(te=S(te,ue),te.return=le,te)}function X(le,te,ue,Ae){var Ge=ue.type;return Ge===u?ve(le,te,ue.props.children,Ae,ue.key):te!==null&&(te.elementType===Ge||typeof Ge=="object"&&Ge!==null&&Ge.$$typeof===x&&A1(Ge)===te.type)?(te=S(te,ue.props),El(te,ue),te.return=le,te):(te=Vu(ue.type,ue.key,ue.props,null,le.mode,Ae),El(te,ue),te.return=le,te)}function re(le,te,ue,Ae){return te===null||te.tag!==4||te.stateNode.containerInfo!==ue.containerInfo||te.stateNode.implementation!==ue.implementation?(te=uh(ue,le.mode,Ae),te.return=le,te):(te=S(te,ue.children||[]),te.return=le,te)}function ve(le,te,ue,Ae,Ge){return te===null||te.tag!==7?(te=Jo(ue,le.mode,Ae,Ge),te.return=le,te):(te=S(te,ue),te.return=le,te)}function Ce(le,te,ue){if(typeof te=="string"&&te!==""||typeof te=="number"||typeof te=="bigint")return te=ch(""+te,le.mode,ue),te.return=le,te;if(typeof te=="object"&&te!==null){switch(te.$$typeof){case s:return ue=Vu(te.type,te.key,te.props,null,le.mode,ue),El(ue,te),ue.return=le,ue;case l:return te=uh(te,le.mode,ue),te.return=le,te;case x:var Ae=te._init;return te=Ae(te._payload),Ce(le,te,ue)}if(P(te)||C(te))return te=Jo(te,le.mode,ue,null),te.return=le,te;if(typeof te.then=="function")return Ce(le,Ru(te),ue);if(te.$$typeof===b)return Ce(le,Hu(le,te),ue);Cu(le,te)}return null}function fe(le,te,ue,Ae){var Ge=te!==null?te.key:null;if(typeof ue=="string"&&ue!==""||typeof ue=="number"||typeof ue=="bigint")return Ge!==null?null:q(le,te,""+ue,Ae);if(typeof ue=="object"&&ue!==null){switch(ue.$$typeof){case s:return ue.key===Ge?X(le,te,ue,Ae):null;case l:return ue.key===Ge?re(le,te,ue,Ae):null;case x:return Ge=ue._init,ue=Ge(ue._payload),fe(le,te,ue,Ae)}if(P(ue)||C(ue))return Ge!==null?null:ve(le,te,ue,Ae,null);if(typeof ue.then=="function")return fe(le,te,Ru(ue),Ae);if(ue.$$typeof===b)return fe(le,te,Hu(le,ue),Ae);Cu(le,ue)}return null}function me(le,te,ue,Ae,Ge){if(typeof Ae=="string"&&Ae!==""||typeof Ae=="number"||typeof Ae=="bigint")return le=le.get(ue)||null,q(te,le,""+Ae,Ge);if(typeof Ae=="object"&&Ae!==null){switch(Ae.$$typeof){case s:return le=le.get(Ae.key===null?ue:Ae.key)||null,X(te,le,Ae,Ge);case l:return le=le.get(Ae.key===null?ue:Ae.key)||null,re(te,le,Ae,Ge);case x:var ut=Ae._init;return Ae=ut(Ae._payload),me(le,te,ue,Ae,Ge)}if(P(Ae)||C(Ae))return le=le.get(ue)||null,ve(te,le,Ae,Ge,null);if(typeof Ae.then=="function")return me(le,te,ue,Ru(Ae),Ge);if(Ae.$$typeof===b)return me(le,te,ue,Hu(te,Ae),Ge);Cu(te,Ae)}return null}function qe(le,te,ue,Ae){for(var Ge=null,ut=null,Ye=te,Qe=te=0,ln=null;Ye!==null&&Qe<ue.length;Qe++){Ye.index>Qe?(ln=Ye,Ye=null):ln=Ye.sibling;var kt=fe(le,Ye,ue[Qe],Ae);if(kt===null){Ye===null&&(Ye=ln);break}i&&Ye&&kt.alternate===null&&c(le,Ye),te=T(kt,te,Qe),ut===null?Ge=kt:ut.sibling=kt,ut=kt,Ye=ln}if(Qe===ue.length)return f(le,Ye),xt&&Go(le,Qe),Ge;if(Ye===null){for(;Qe<ue.length;Qe++)Ye=Ce(le,ue[Qe],Ae),Ye!==null&&(te=T(Ye,te,Qe),ut===null?Ge=Ye:ut.sibling=Ye,ut=Ye);return xt&&Go(le,Qe),Ge}for(Ye=h(Ye);Qe<ue.length;Qe++)ln=me(Ye,le,Qe,ue[Qe],Ae),ln!==null&&(i&&ln.alternate!==null&&Ye.delete(ln.key===null?Qe:ln.key),te=T(ln,te,Qe),ut===null?Ge=ln:ut.sibling=ln,ut=ln);return i&&Ye.forEach(function(ho){return c(le,ho)}),xt&&Go(le,Qe),Ge}function rt(le,te,ue,Ae){if(ue==null)throw Error(r(151));for(var Ge=null,ut=null,Ye=te,Qe=te=0,ln=null,kt=ue.next();Ye!==null&&!kt.done;Qe++,kt=ue.next()){Ye.index>Qe?(ln=Ye,Ye=null):ln=Ye.sibling;var ho=fe(le,Ye,kt.value,Ae);if(ho===null){Ye===null&&(Ye=ln);break}i&&Ye&&ho.alternate===null&&c(le,Ye),te=T(ho,te,Qe),ut===null?Ge=ho:ut.sibling=ho,ut=ho,Ye=ln}if(kt.done)return f(le,Ye),xt&&Go(le,Qe),Ge;if(Ye===null){for(;!kt.done;Qe++,kt=ue.next())kt=Ce(le,kt.value,Ae),kt!==null&&(te=T(kt,te,Qe),ut===null?Ge=kt:ut.sibling=kt,ut=kt);return xt&&Go(le,Qe),Ge}for(Ye=h(Ye);!kt.done;Qe++,kt=ue.next())kt=me(Ye,le,Qe,kt.value,Ae),kt!==null&&(i&&kt.alternate!==null&&Ye.delete(kt.key===null?Qe:kt.key),te=T(kt,te,Qe),ut===null?Ge=kt:ut.sibling=kt,ut=kt);return i&&Ye.forEach(function(oq){return c(le,oq)}),xt&&Go(le,Qe),Ge}function Vt(le,te,ue,Ae){if(typeof ue=="object"&&ue!==null&&ue.type===u&&ue.key===null&&(ue=ue.props.children),typeof ue=="object"&&ue!==null){switch(ue.$$typeof){case s:e:{for(var Ge=ue.key;te!==null;){if(te.key===Ge){if(Ge=ue.type,Ge===u){if(te.tag===7){f(le,te.sibling),Ae=S(te,ue.props.children),Ae.return=le,le=Ae;break e}}else if(te.elementType===Ge||typeof Ge=="object"&&Ge!==null&&Ge.$$typeof===x&&A1(Ge)===te.type){f(le,te.sibling),Ae=S(te,ue.props),El(Ae,ue),Ae.return=le,le=Ae;break e}f(le,te);break}else c(le,te);te=te.sibling}ue.type===u?(Ae=Jo(ue.props.children,le.mode,Ae,ue.key),Ae.return=le,le=Ae):(Ae=Vu(ue.type,ue.key,ue.props,null,le.mode,Ae),El(Ae,ue),Ae.return=le,le=Ae)}return F(le);case l:e:{for(Ge=ue.key;te!==null;){if(te.key===Ge)if(te.tag===4&&te.stateNode.containerInfo===ue.containerInfo&&te.stateNode.implementation===ue.implementation){f(le,te.sibling),Ae=S(te,ue.children||[]),Ae.return=le,le=Ae;break e}else{f(le,te);break}else c(le,te);te=te.sibling}Ae=uh(ue,le.mode,Ae),Ae.return=le,le=Ae}return F(le);case x:return Ge=ue._init,ue=Ge(ue._payload),Vt(le,te,ue,Ae)}if(P(ue))return qe(le,te,ue,Ae);if(C(ue)){if(Ge=C(ue),typeof Ge!="function")throw Error(r(150));return ue=Ge.call(ue),rt(le,te,ue,Ae)}if(typeof ue.then=="function")return Vt(le,te,Ru(ue),Ae);if(ue.$$typeof===b)return Vt(le,te,Hu(le,ue),Ae);Cu(le,ue)}return typeof ue=="string"&&ue!==""||typeof ue=="number"||typeof ue=="bigint"?(ue=""+ue,te!==null&&te.tag===6?(f(le,te.sibling),Ae=S(te,ue),Ae.return=le,le=Ae):(f(le,te),Ae=ch(ue,le.mode,Ae),Ae.return=le,le=Ae),F(le)):f(le,te)}return function(le,te,ue,Ae){try{Sl=0;var Ge=Vt(le,te,ue,Ae);return $i=null,Ge}catch(Ye){if(Ye===yl)throw Ye;var ut=mr(29,Ye,null,le.mode);return ut.lanes=Ae,ut.return=le,ut}finally{}}}var $o=R1(!0),C1=R1(!1),qi=ce(null),_u=ce(0);function _1(i,c){i=_a,ie(_u,i),ie(qi,c),_a=i|c.baseLanes}function mg(){ie(_u,_a),ie(qi,qi.current)}function bg(){_a=_u.current,Re(qi),Re(_u)}var pr=ce(null),Yr=null;function Xa(i){var c=i.alternate;ie(en,en.current&1),ie(pr,i),Yr===null&&(c===null||qi.current!==null||c.memoizedState!==null)&&(Yr=i)}function N1(i){if(i.tag===22){if(ie(en,en.current),ie(pr,i),Yr===null){var c=i.alternate;c!==null&&c.memoizedState!==null&&(Yr=i)}}else Za()}function Za(){ie(en,en.current),ie(pr,pr.current)}function va(i){Re(pr),Yr===i&&(Yr=null),Re(en)}var en=ce(0);function Nu(i){for(var c=i;c!==null;){if(c.tag===13){var f=c.memoizedState;if(f!==null&&(f=f.dehydrated,f===null||f.data==="$?"||f.data==="$!"))return c}else if(c.tag===19&&c.memoizedProps.revealOrder!==void 0){if(c.flags&128)return c}else if(c.child!==null){c.child.return=c,c=c.child;continue}if(c===i)break;for(;c.sibling===null;){if(c.return===null||c.return===i)return null;c=c.return}c.sibling.return=c.return,c=c.sibling}return null}var V6=typeof AbortController<"u"?AbortController:function(){var i=[],c=this.signal={aborted:!1,addEventListener:function(f,h){i.push(h)}};this.abort=function(){c.aborted=!0,i.forEach(function(f){return f()})}},W6=e.unstable_scheduleCallback,Y6=e.unstable_NormalPriority,tn={$$typeof:b,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function yg(){return{controller:new V6,data:new Map,refCount:0}}function wl(i){i.refCount--,i.refCount===0&&W6(Y6,function(){i.controller.abort()})}var xl=null,vg=0,Vi=0,Wi=null;function K6(i,c){if(xl===null){var f=xl=[];vg=0,Vi=Th(),Wi={status:"pending",value:void 0,then:function(h){f.push(h)}}}return vg++,c.then(O1,O1),c}function O1(){if(--vg===0&&xl!==null){Wi!==null&&(Wi.status="fulfilled");var i=xl;xl=null,Vi=0,Wi=null;for(var c=0;c<i.length;c++)(0,i[c])()}}function X6(i,c){var f=[],h={status:"pending",value:null,reason:null,then:function(S){f.push(S)}};return i.then(function(){h.status="fulfilled",h.value=c;for(var S=0;S<f.length;S++)(0,f[S])(c)},function(S){for(h.status="rejected",h.reason=S,S=0;S<f.length;S++)(0,f[S])(void 0)}),h}var I1=I.S;I.S=function(i,c){typeof c=="object"&&c!==null&&typeof c.then=="function"&&K6(i,c),I1!==null&&I1(i,c)};var qo=ce(null);function Sg(){var i=qo.current;return i!==null?i:Lt.pooledCache}function Ou(i,c){c===null?ie(qo,qo.current):ie(qo,c.pool)}function D1(){var i=Sg();return i===null?null:{parent:tn._currentValue,pool:i}}var Qa=0,ct=null,Rt=null,Kt=null,Iu=!1,Yi=!1,Vo=!1,Du=0,kl=0,Ki=null,Z6=0;function Wt(){throw Error(r(321))}function Eg(i,c){if(c===null)return!1;for(var f=0;f<c.length&&f<i.length;f++)if(!Yn(i[f],c[f]))return!1;return!0}function wg(i,c,f,h,S,T){return Qa=T,ct=c,c.memoizedState=null,c.updateQueue=null,c.lanes=0,I.H=i===null||i.memoizedState===null?Wo:Ja,Vo=!1,T=f(h,S),Vo=!1,Yi&&(T=M1(c,f,h,S)),L1(i),T}function L1(i){I.H=Kr;var c=Rt!==null&&Rt.next!==null;if(Qa=0,Kt=Rt=ct=null,Iu=!1,kl=0,Ki=null,c)throw Error(r(300));i===null||on||(i=i.dependencies,i!==null&&Gu(i)&&(on=!0))}function M1(i,c,f,h){ct=i;var S=0;do{if(Yi&&(Ki=null),kl=0,Yi=!1,25<=S)throw Error(r(301));if(S+=1,Kt=Rt=null,i.updateQueue!=null){var T=i.updateQueue;T.lastEffect=null,T.events=null,T.stores=null,T.memoCache!=null&&(T.memoCache.index=0)}I.H=Yo,T=c(f,h)}while(Yi);return T}function Q6(){var i=I.H,c=i.useState()[0];return c=typeof c.then=="function"?Tl(c):c,i=i.useState()[0],(Rt!==null?Rt.memoizedState:null)!==i&&(ct.flags|=1024),c}function xg(){var i=Du!==0;return Du=0,i}function kg(i,c,f){c.updateQueue=i.updateQueue,c.flags&=-2053,i.lanes&=~f}function Tg(i){if(Iu){for(i=i.memoizedState;i!==null;){var c=i.queue;c!==null&&(c.pending=null),i=i.next}Iu=!1}Qa=0,Kt=Rt=ct=null,Yi=!1,kl=Du=0,Ki=null}function Bn(){var i={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Kt===null?ct.memoizedState=Kt=i:Kt=Kt.next=i,Kt}function Xt(){if(Rt===null){var i=ct.alternate;i=i!==null?i.memoizedState:null}else i=Rt.next;var c=Kt===null?ct.memoizedState:Kt.next;if(c!==null)Kt=c,Rt=i;else{if(i===null)throw ct.alternate===null?Error(r(467)):Error(r(310));Rt=i,i={memoizedState:Rt.memoizedState,baseState:Rt.baseState,baseQueue:Rt.baseQueue,queue:Rt.queue,next:null},Kt===null?ct.memoizedState=Kt=i:Kt=Kt.next=i}return Kt}var Lu;Lu=function(){return{lastEffect:null,events:null,stores:null,memoCache:null}};function Tl(i){var c=kl;return kl+=1,Ki===null&&(Ki=[]),i=k1(Ki,i,c),c=ct,(Kt===null?c.memoizedState:Kt.next)===null&&(c=c.alternate,I.H=c===null||c.memoizedState===null?Wo:Ja),i}function Mu(i){if(i!==null&&typeof i=="object"){if(typeof i.then=="function")return Tl(i);if(i.$$typeof===b)return En(i)}throw Error(r(438,String(i)))}function Ag(i){var c=null,f=ct.updateQueue;if(f!==null&&(c=f.memoCache),c==null){var h=ct.alternate;h!==null&&(h=h.updateQueue,h!==null&&(h=h.memoCache,h!=null&&(c={data:h.data.map(function(S){return S.slice()}),index:0})))}if(c==null&&(c={data:[],index:0}),f===null&&(f=Lu(),ct.updateQueue=f),f.memoCache=c,f=c.data[c.index],f===void 0)for(f=c.data[c.index]=Array(i),h=0;h<i;h++)f[h]=O;return c.index++,f}function Sa(i,c){return typeof c=="function"?c(i):c}function Pu(i){var c=Xt();return Rg(c,Rt,i)}function Rg(i,c,f){var h=i.queue;if(h===null)throw Error(r(311));h.lastRenderedReducer=f;var S=i.baseQueue,T=h.pending;if(T!==null){if(S!==null){var F=S.next;S.next=T.next,T.next=F}c.baseQueue=S=T,h.pending=null}if(T=i.baseState,S===null)i.memoizedState=T;else{c=S.next;var q=F=null,X=null,re=c,ve=!1;do{var Ce=re.lane&-536870913;if(Ce!==re.lane?(vt&Ce)===Ce:(Qa&Ce)===Ce){var fe=re.revertLane;if(fe===0)X!==null&&(X=X.next={lane:0,revertLane:0,action:re.action,hasEagerState:re.hasEagerState,eagerState:re.eagerState,next:null}),Ce===Vi&&(ve=!0);else if((Qa&fe)===fe){re=re.next,fe===Vi&&(ve=!0);continue}else Ce={lane:0,revertLane:re.revertLane,action:re.action,hasEagerState:re.hasEagerState,eagerState:re.eagerState,next:null},X===null?(q=X=Ce,F=T):X=X.next=Ce,ct.lanes|=fe,lo|=fe;Ce=re.action,Vo&&f(T,Ce),T=re.hasEagerState?re.eagerState:f(T,Ce)}else fe={lane:Ce,revertLane:re.revertLane,action:re.action,hasEagerState:re.hasEagerState,eagerState:re.eagerState,next:null},X===null?(q=X=fe,F=T):X=X.next=fe,ct.lanes|=Ce,lo|=Ce;re=re.next}while(re!==null&&re!==c);if(X===null?F=T:X.next=q,!Yn(T,i.memoizedState)&&(on=!0,ve&&(f=Wi,f!==null)))throw f;i.memoizedState=T,i.baseState=F,i.baseQueue=X,h.lastRenderedState=T}return S===null&&(h.lanes=0),[i.memoizedState,h.dispatch]}function Cg(i){var c=Xt(),f=c.queue;if(f===null)throw Error(r(311));f.lastRenderedReducer=i;var h=f.dispatch,S=f.pending,T=c.memoizedState;if(S!==null){f.pending=null;var F=S=S.next;do T=i(T,F.action),F=F.next;while(F!==S);Yn(T,c.memoizedState)||(on=!0),c.memoizedState=T,c.baseQueue===null&&(c.baseState=T),f.lastRenderedState=T}return[T,h]}function P1(i,c,f){var h=ct,S=Xt(),T=xt;if(T){if(f===void 0)throw Error(r(407));f=f()}else f=c();var F=!Yn((Rt||S).memoizedState,f);if(F&&(S.memoizedState=f,on=!0),S=S.queue,Og(B1.bind(null,h,S,i),[i]),S.getSnapshot!==c||F||Kt!==null&&Kt.memoizedState.tag&1){if(h.flags|=2048,Xi(9,z1.bind(null,h,S,f,c),{destroy:void 0},null),Lt===null)throw Error(r(349));T||Qa&60||F1(h,c,f)}return f}function F1(i,c,f){i.flags|=16384,i={getSnapshot:c,value:f},c=ct.updateQueue,c===null?(c=Lu(),ct.updateQueue=c,c.stores=[i]):(f=c.stores,f===null?c.stores=[i]:f.push(i))}function z1(i,c,f,h){c.value=f,c.getSnapshot=h,j1(c)&&U1(i)}function B1(i,c,f){return f(function(){j1(c)&&U1(i)})}function j1(i){var c=i.getSnapshot;i=i.value;try{var f=c();return!Yn(i,f)}catch{return!0}}function U1(i){var c=Ka(i,2);c!==null&&On(c,i,2)}function _g(i){var c=Bn();if(typeof i=="function"){var f=i;if(i=f(),Vo){st(!0);try{f()}finally{st(!1)}}}return c.memoizedState=c.baseState=i,c.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Sa,lastRenderedState:i},c}function G1(i,c,f,h){return i.baseState=f,Rg(i,Rt,typeof h=="function"?h:Sa)}function J6(i,c,f,h,S){if(Bu(i))throw Error(r(485));if(i=c.action,i!==null){var T={payload:S,action:i,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(F){T.listeners.push(F)}};I.T!==null?f(!0):T.isTransition=!1,h(T),f=c.pending,f===null?(T.next=c.pending=T,H1(c,T)):(T.next=f.next,c.pending=f.next=T)}}function H1(i,c){var f=c.action,h=c.payload,S=i.state;if(c.isTransition){var T=I.T,F={};I.T=F;try{var q=f(S,h),X=I.S;X!==null&&X(F,q),$1(i,c,q)}catch(re){Ng(i,c,re)}finally{I.T=T}}else try{T=f(S,h),$1(i,c,T)}catch(re){Ng(i,c,re)}}function $1(i,c,f){f!==null&&typeof f=="object"&&typeof f.then=="function"?f.then(function(h){q1(i,c,h)},function(h){return Ng(i,c,h)}):q1(i,c,f)}function q1(i,c,f){c.status="fulfilled",c.value=f,V1(c),i.state=f,c=i.pending,c!==null&&(f=c.next,f===c?i.pending=null:(f=f.next,c.next=f,H1(i,f)))}function Ng(i,c,f){var h=i.pending;if(i.pending=null,h!==null){h=h.next;do c.status="rejected",c.reason=f,V1(c),c=c.next;while(c!==h)}i.action=null}function V1(i){i=i.listeners;for(var c=0;c<i.length;c++)(0,i[c])()}function W1(i,c){return c}function Y1(i,c){if(xt){var f=Lt.formState;if(f!==null){e:{var h=ct;if(xt){if(gn){t:{for(var S=gn,T=Wr;S.nodeType!==8;){if(!T){S=null;break t}if(S=Dr(S.nextSibling),S===null){S=null;break t}}T=S.data,S=T==="F!"||T==="F"?S:null}if(S){gn=Dr(S.nextSibling),h=S.data==="F!";break e}}Ho(h)}h=!1}h&&(c=f[0])}}return f=Bn(),f.memoizedState=f.baseState=c,h={pending:null,lanes:0,dispatch:null,lastRenderedReducer:W1,lastRenderedState:c},f.queue=h,f=fR.bind(null,ct,h),h.dispatch=f,h=_g(!1),T=Pg.bind(null,ct,!1,h.queue),h=Bn(),S={state:c,dispatch:null,action:i,pending:null},h.queue=S,f=J6.bind(null,ct,S,T,f),S.dispatch=f,h.memoizedState=i,[c,f,!1]}function K1(i){var c=Xt();return X1(c,Rt,i)}function X1(i,c,f){c=Rg(i,c,W1)[0],i=Pu(Sa)[0],c=typeof c=="object"&&c!==null&&typeof c.then=="function"?Tl(c):c;var h=Xt(),S=h.queue,T=S.dispatch;return f!==h.memoizedState&&(ct.flags|=2048,Xi(9,e$.bind(null,S,f),{destroy:void 0},null)),[c,T,i]}function e$(i,c){i.action=c}function Z1(i){var c=Xt(),f=Rt;if(f!==null)return X1(c,f,i);Xt(),c=c.memoizedState,f=Xt();var h=f.queue.dispatch;return f.memoizedState=i,[c,h,!1]}function Xi(i,c,f,h){return i={tag:i,create:c,inst:f,deps:h,next:null},c=ct.updateQueue,c===null&&(c=Lu(),ct.updateQueue=c),f=c.lastEffect,f===null?c.lastEffect=i.next=i:(h=f.next,f.next=i,i.next=h,c.lastEffect=i),i}function Q1(){return Xt().memoizedState}function Fu(i,c,f,h){var S=Bn();ct.flags|=i,S.memoizedState=Xi(1|c,f,{destroy:void 0},h===void 0?null:h)}function zu(i,c,f,h){var S=Xt();h=h===void 0?null:h;var T=S.memoizedState.inst;Rt!==null&&h!==null&&Eg(h,Rt.memoizedState.deps)?S.memoizedState=Xi(c,f,T,h):(ct.flags|=i,S.memoizedState=Xi(1|c,f,T,h))}function J1(i,c){Fu(8390656,8,i,c)}function Og(i,c){zu(2048,8,i,c)}function eR(i,c){return zu(4,2,i,c)}function tR(i,c){return zu(4,4,i,c)}function nR(i,c){if(typeof c=="function"){i=i();var f=c(i);return function(){typeof f=="function"?f():c(null)}}if(c!=null)return i=i(),c.current=i,function(){c.current=null}}function rR(i,c,f){f=f!=null?f.concat([i]):null,zu(4,4,nR.bind(null,c,i),f)}function Ig(){}function aR(i,c){var f=Xt();c=c===void 0?null:c;var h=f.memoizedState;return c!==null&&Eg(c,h[1])?h[0]:(f.memoizedState=[i,c],i)}function oR(i,c){var f=Xt();c=c===void 0?null:c;var h=f.memoizedState;if(c!==null&&Eg(c,h[1]))return h[0];if(h=i(),Vo){st(!0);try{i()}finally{st(!1)}}return f.memoizedState=[h,c],h}function Dg(i,c,f){return f===void 0||Qa&1073741824?i.memoizedState=c:(i.memoizedState=f,i=sC(),ct.lanes|=i,lo|=i,f)}function iR(i,c,f,h){return Yn(f,c)?f:qi.current!==null?(i=Dg(i,f,h),Yn(i,c)||(on=!0),i):Qa&42?(i=sC(),ct.lanes|=i,lo|=i,c):(on=!0,i.memoizedState=f)}function sR(i,c,f,h,S){var T=Z.p;Z.p=T!==0&&8>T?T:8;var F=I.T,q={};I.T=q,Pg(i,!1,c,f);try{var X=S(),re=I.S;if(re!==null&&re(q,X),X!==null&&typeof X=="object"&&typeof X.then=="function"){var ve=X6(X,h);Al(i,c,ve,Qn(i))}else Al(i,c,h,Qn(i))}catch(Ce){Al(i,c,{then:function(){},status:"rejected",reason:Ce},Qn())}finally{Z.p=T,I.T=F}}function t$(){}function Lg(i,c,f,h){if(i.tag!==5)throw Error(r(476));var S=lR(i).queue;sR(i,S,c,Q,f===null?t$:function(){return cR(i),f(h)})}function lR(i){var c=i.memoizedState;if(c!==null)return c;c={memoizedState:Q,baseState:Q,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Sa,lastRenderedState:Q},next:null};var f={};return c.next={memoizedState:f,baseState:f,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Sa,lastRenderedState:f},next:null},i.memoizedState=c,i=i.alternate,i!==null&&(i.memoizedState=c),c}function cR(i){var c=lR(i).next.queue;Al(i,c,{},Qn())}function Mg(){return En(Vl)}function uR(){return Xt().memoizedState}function dR(){return Xt().memoizedState}function n$(i){for(var c=i.return;c!==null;){switch(c.tag){case 24:case 3:var f=Qn();i=no(f);var h=ro(c,i,f);h!==null&&(On(h,c,f),_l(h,c,f)),c={cache:yg()},i.payload=c;return}c=c.return}}function r$(i,c,f){var h=Qn();f={lane:h,revertLane:0,action:f,hasEagerState:!1,eagerState:null,next:null},Bu(i)?pR(c,f):(f=dg(i,c,f,h),f!==null&&(On(f,i,h),gR(f,c,h)))}function fR(i,c,f){var h=Qn();Al(i,c,f,h)}function Al(i,c,f,h){var S={lane:h,revertLane:0,action:f,hasEagerState:!1,eagerState:null,next:null};if(Bu(i))pR(c,S);else{var T=i.alternate;if(i.lanes===0&&(T===null||T.lanes===0)&&(T=c.lastRenderedReducer,T!==null))try{var F=c.lastRenderedState,q=T(F,f);if(S.hasEagerState=!0,S.eagerState=q,Yn(q,F))return wu(i,c,S,0),Lt===null&&Eu(),!1}catch{}finally{}if(f=dg(i,c,S,h),f!==null)return On(f,i,h),gR(f,c,h),!0}return!1}function Pg(i,c,f,h){if(h={lane:2,revertLane:Th(),action:h,hasEagerState:!1,eagerState:null,next:null},Bu(i)){if(c)throw Error(r(479))}else c=dg(i,f,h,2),c!==null&&On(c,i,2)}function Bu(i){var c=i.alternate;return i===ct||c!==null&&c===ct}function pR(i,c){Yi=Iu=!0;var f=i.pending;f===null?c.next=c:(c.next=f.next,f.next=c),i.pending=c}function gR(i,c,f){if(f&4194176){var h=c.lanes;h&=i.pendingLanes,f|=h,c.lanes=f,_r(i,f)}}var Kr={readContext:En,use:Mu,useCallback:Wt,useContext:Wt,useEffect:Wt,useImperativeHandle:Wt,useLayoutEffect:Wt,useInsertionEffect:Wt,useMemo:Wt,useReducer:Wt,useRef:Wt,useState:Wt,useDebugValue:Wt,useDeferredValue:Wt,useTransition:Wt,useSyncExternalStore:Wt,useId:Wt};Kr.useCacheRefresh=Wt,Kr.useMemoCache=Wt,Kr.useHostTransitionStatus=Wt,Kr.useFormState=Wt,Kr.useActionState=Wt,Kr.useOptimistic=Wt;var Wo={readContext:En,use:Mu,useCallback:function(i,c){return Bn().memoizedState=[i,c===void 0?null:c],i},useContext:En,useEffect:J1,useImperativeHandle:function(i,c,f){f=f!=null?f.concat([i]):null,Fu(4194308,4,nR.bind(null,c,i),f)},useLayoutEffect:function(i,c){return Fu(4194308,4,i,c)},useInsertionEffect:function(i,c){Fu(4,2,i,c)},useMemo:function(i,c){var f=Bn();c=c===void 0?null:c;var h=i();if(Vo){st(!0);try{i()}finally{st(!1)}}return f.memoizedState=[h,c],h},useReducer:function(i,c,f){var h=Bn();if(f!==void 0){var S=f(c);if(Vo){st(!0);try{f(c)}finally{st(!1)}}}else S=c;return h.memoizedState=h.baseState=S,i={pending:null,lanes:0,dispatch:null,lastRenderedReducer:i,lastRenderedState:S},h.queue=i,i=i.dispatch=r$.bind(null,ct,i),[h.memoizedState,i]},useRef:function(i){var c=Bn();return i={current:i},c.memoizedState=i},useState:function(i){i=_g(i);var c=i.queue,f=fR.bind(null,ct,c);return c.dispatch=f,[i.memoizedState,f]},useDebugValue:Ig,useDeferredValue:function(i,c){var f=Bn();return Dg(f,i,c)},useTransition:function(){var i=_g(!1);return i=sR.bind(null,ct,i.queue,!0,!1),Bn().memoizedState=i,[!1,i]},useSyncExternalStore:function(i,c,f){var h=ct,S=Bn();if(xt){if(f===void 0)throw Error(r(407));f=f()}else{if(f=c(),Lt===null)throw Error(r(349));vt&60||F1(h,c,f)}S.memoizedState=f;var T={value:f,getSnapshot:c};return S.queue=T,J1(B1.bind(null,h,T,i),[i]),h.flags|=2048,Xi(9,z1.bind(null,h,T,f,c),{destroy:void 0},null),f},useId:function(){var i=Bn(),c=Lt.identifierPrefix;if(xt){var f=ya,h=ba;f=(h&~(1<<32-wt(h)-1)).toString(32)+f,c=":"+c+"R"+f,f=Du++,0<f&&(c+="H"+f.toString(32)),c+=":"}else f=Z6++,c=":"+c+"r"+f.toString(32)+":";return i.memoizedState=c},useCacheRefresh:function(){return Bn().memoizedState=n$.bind(null,ct)}};Wo.useMemoCache=Ag,Wo.useHostTransitionStatus=Mg,Wo.useFormState=Y1,Wo.useActionState=Y1,Wo.useOptimistic=function(i){var c=Bn();c.memoizedState=c.baseState=i;var f={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return c.queue=f,c=Pg.bind(null,ct,!0,f),f.dispatch=c,[i,c]};var Ja={readContext:En,use:Mu,useCallback:aR,useContext:En,useEffect:Og,useImperativeHandle:rR,useInsertionEffect:eR,useLayoutEffect:tR,useMemo:oR,useReducer:Pu,useRef:Q1,useState:function(){return Pu(Sa)},useDebugValue:Ig,useDeferredValue:function(i,c){var f=Xt();return iR(f,Rt.memoizedState,i,c)},useTransition:function(){var i=Pu(Sa)[0],c=Xt().memoizedState;return[typeof i=="boolean"?i:Tl(i),c]},useSyncExternalStore:P1,useId:uR};Ja.useCacheRefresh=dR,Ja.useMemoCache=Ag,Ja.useHostTransitionStatus=Mg,Ja.useFormState=K1,Ja.useActionState=K1,Ja.useOptimistic=function(i,c){var f=Xt();return G1(f,Rt,i,c)};var Yo={readContext:En,use:Mu,useCallback:aR,useContext:En,useEffect:Og,useImperativeHandle:rR,useInsertionEffect:eR,useLayoutEffect:tR,useMemo:oR,useReducer:Cg,useRef:Q1,useState:function(){return Cg(Sa)},useDebugValue:Ig,useDeferredValue:function(i,c){var f=Xt();return Rt===null?Dg(f,i,c):iR(f,Rt.memoizedState,i,c)},useTransition:function(){var i=Cg(Sa)[0],c=Xt().memoizedState;return[typeof i=="boolean"?i:Tl(i),c]},useSyncExternalStore:P1,useId:uR};Yo.useCacheRefresh=dR,Yo.useMemoCache=Ag,Yo.useHostTransitionStatus=Mg,Yo.useFormState=Z1,Yo.useActionState=Z1,Yo.useOptimistic=function(i,c){var f=Xt();return Rt!==null?G1(f,Rt,i,c):(f.baseState=i,[i,f.queue.dispatch])};function Fg(i,c,f,h){c=i.memoizedState,f=f(h,c),f=f==null?c:D({},c,f),i.memoizedState=f,i.lanes===0&&(i.updateQueue.baseState=f)}var zg={isMounted:function(i){return(i=i._reactInternals)?z(i)===i:!1},enqueueSetState:function(i,c,f){i=i._reactInternals;var h=Qn(),S=no(h);S.payload=c,f!=null&&(S.callback=f),c=ro(i,S,h),c!==null&&(On(c,i,h),_l(c,i,h))},enqueueReplaceState:function(i,c,f){i=i._reactInternals;var h=Qn(),S=no(h);S.tag=1,S.payload=c,f!=null&&(S.callback=f),c=ro(i,S,h),c!==null&&(On(c,i,h),_l(c,i,h))},enqueueForceUpdate:function(i,c){i=i._reactInternals;var f=Qn(),h=no(f);h.tag=2,c!=null&&(h.callback=c),c=ro(i,h,f),c!==null&&(On(c,i,f),_l(c,i,f))}};function hR(i,c,f,h,S,T,F){return i=i.stateNode,typeof i.shouldComponentUpdate=="function"?i.shouldComponentUpdate(h,T,F):c.prototype&&c.prototype.isPureReactComponent?!pl(f,h)||!pl(S,T):!0}function mR(i,c,f,h){i=c.state,typeof c.componentWillReceiveProps=="function"&&c.componentWillReceiveProps(f,h),typeof c.UNSAFE_componentWillReceiveProps=="function"&&c.UNSAFE_componentWillReceiveProps(f,h),c.state!==i&&zg.enqueueReplaceState(c,c.state,null)}function Ko(i,c){var f=c;if("ref"in c){f={};for(var h in c)h!=="ref"&&(f[h]=c[h])}if(i=i.defaultProps){f===c&&(f=D({},f));for(var S in i)f[S]===void 0&&(f[S]=i[S])}return f}var ju=typeof reportError=="function"?reportError:function(i){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var c=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof i=="object"&&i!==null&&typeof i.message=="string"?String(i.message):String(i),error:i});if(!window.dispatchEvent(c))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",i);return}console.error(i)};function bR(i){ju(i)}function yR(i){console.error(i)}function vR(i){ju(i)}function Uu(i,c){try{var f=i.onUncaughtError;f(c.value,{componentStack:c.stack})}catch(h){setTimeout(function(){throw h})}}function SR(i,c,f){try{var h=i.onCaughtError;h(f.value,{componentStack:f.stack,errorBoundary:c.tag===1?c.stateNode:null})}catch(S){setTimeout(function(){throw S})}}function Bg(i,c,f){return f=no(f),f.tag=3,f.payload={element:null},f.callback=function(){Uu(i,c)},f}function ER(i){return i=no(i),i.tag=3,i}function wR(i,c,f,h){var S=f.type.getDerivedStateFromError;if(typeof S=="function"){var T=h.value;i.payload=function(){return S(T)},i.callback=function(){SR(c,f,h)}}var F=f.stateNode;F!==null&&typeof F.componentDidCatch=="function"&&(i.callback=function(){SR(c,f,h),typeof S!="function"&&(co===null?co=new Set([this]):co.add(this));var q=h.stack;this.componentDidCatch(h.value,{componentStack:q!==null?q:""})})}function a$(i,c,f,h,S){if(f.flags|=32768,h!==null&&typeof h=="object"&&typeof h.then=="function"){if(c=f.alternate,c!==null&&Cl(c,f,S,!0),f=pr.current,f!==null){switch(f.tag){case 13:return Yr===null?Sh():f.alternate===null&&qt===0&&(qt=3),f.flags&=-257,f.flags|=65536,f.lanes=S,h===hg?f.flags|=16384:(c=f.updateQueue,c===null?f.updateQueue=new Set([h]):c.add(h),wh(i,h,S)),!1;case 22:return f.flags|=65536,h===hg?f.flags|=16384:(c=f.updateQueue,c===null?(c={transitions:null,markerInstances:null,retryQueue:new Set([h])},f.updateQueue=c):(f=c.retryQueue,f===null?c.retryQueue=new Set([h]):f.add(h)),wh(i,h,S)),!1}throw Error(r(435,f.tag))}return wh(i,h,S),Sh(),!1}if(xt)return c=pr.current,c!==null?(!(c.flags&65536)&&(c.flags|=256),c.flags|=65536,c.lanes=S,h!==gg&&(i=Error(r(422),{cause:h}),bl(ur(i,f)))):(h!==gg&&(c=Error(r(423),{cause:h}),bl(ur(c,f))),i=i.current.alternate,i.flags|=65536,S&=-S,i.lanes|=S,h=ur(h,f),S=Bg(i.stateNode,h,S),eh(i,S),qt!==4&&(qt=2)),!1;var T=Error(r(520),{cause:h});if(T=ur(T,f),Fl===null?Fl=[T]:Fl.push(T),qt!==4&&(qt=2),c===null)return!0;h=ur(h,f),f=c;do{switch(f.tag){case 3:return f.flags|=65536,i=S&-S,f.lanes|=i,i=Bg(f.stateNode,h,i),eh(f,i),!1;case 1:if(c=f.type,T=f.stateNode,(f.flags&128)===0&&(typeof c.getDerivedStateFromError=="function"||T!==null&&typeof T.componentDidCatch=="function"&&(co===null||!co.has(T))))return f.flags|=65536,S&=-S,f.lanes|=S,S=ER(S),wR(S,i,f,h),eh(f,S),!1}f=f.return}while(f!==null);return!1}var xR=Error(r(461)),on=!1;function hn(i,c,f,h){c.child=i===null?C1(c,null,f,h):$o(c,i.child,f,h)}function kR(i,c,f,h,S){f=f.render;var T=c.ref;if("ref"in h){var F={};for(var q in h)q!=="ref"&&(F[q]=h[q])}else F=h;return Zo(c),h=wg(i,c,f,F,T,S),q=xg(),i!==null&&!on?(kg(i,c,S),Ea(i,c,S)):(xt&&q&&fg(c),c.flags|=1,hn(i,c,h,S),c.child)}function TR(i,c,f,h,S){if(i===null){var T=f.type;return typeof T=="function"&&!lh(T)&&T.defaultProps===void 0&&f.compare===null?(c.tag=15,c.type=T,AR(i,c,T,h,S)):(i=Vu(f.type,null,h,c,c.mode,S),i.ref=c.ref,i.return=c,c.child=i)}if(T=i.child,!Yg(i,S)){var F=T.memoizedProps;if(f=f.compare,f=f!==null?f:pl,f(F,h)&&i.ref===c.ref)return Ea(i,c,S)}return c.flags|=1,i=so(T,h),i.ref=c.ref,i.return=c,c.child=i}function AR(i,c,f,h,S){if(i!==null){var T=i.memoizedProps;if(pl(T,h)&&i.ref===c.ref)if(on=!1,c.pendingProps=h=T,Yg(i,S))i.flags&131072&&(on=!0);else return c.lanes=i.lanes,Ea(i,c,S)}return jg(i,c,f,h,S)}function RR(i,c,f){var h=c.pendingProps,S=h.children,T=(c.stateNode._pendingVisibility&2)!==0,F=i!==null?i.memoizedState:null;if(Rl(i,c),h.mode==="hidden"||T){if(c.flags&128){if(h=F!==null?F.baseLanes|f:f,i!==null){for(S=c.child=i.child,T=0;S!==null;)T=T|S.lanes|S.childLanes,S=S.sibling;c.childLanes=T&~h}else c.childLanes=0,c.child=null;return CR(i,c,h,f)}if(f&536870912)c.memoizedState={baseLanes:0,cachePool:null},i!==null&&Ou(c,F!==null?F.cachePool:null),F!==null?_1(c,F):mg(),N1(c);else return c.lanes=c.childLanes=536870912,CR(i,c,F!==null?F.baseLanes|f:f,f)}else F!==null?(Ou(c,F.cachePool),_1(c,F),Za(),c.memoizedState=null):(i!==null&&Ou(c,null),mg(),Za());return hn(i,c,S,f),c.child}function CR(i,c,f,h){var S=Sg();return S=S===null?null:{parent:tn._currentValue,pool:S},c.memoizedState={baseLanes:f,cachePool:S},i!==null&&Ou(c,null),mg(),N1(c),i!==null&&Cl(i,c,h,!0),null}function Rl(i,c){var f=c.ref;if(f===null)i!==null&&i.ref!==null&&(c.flags|=2097664);else{if(typeof f!="function"&&typeof f!="object")throw Error(r(284));(i===null||i.ref!==f)&&(c.flags|=2097664)}}function jg(i,c,f,h,S){return Zo(c),f=wg(i,c,f,h,void 0,S),h=xg(),i!==null&&!on?(kg(i,c,S),Ea(i,c,S)):(xt&&h&&fg(c),c.flags|=1,hn(i,c,f,S),c.child)}function _R(i,c,f,h,S,T){return Zo(c),c.updateQueue=null,f=M1(c,h,f,S),L1(i),h=xg(),i!==null&&!on?(kg(i,c,T),Ea(i,c,T)):(xt&&h&&fg(c),c.flags|=1,hn(i,c,f,T),c.child)}function NR(i,c,f,h,S){if(Zo(c),c.stateNode===null){var T=Ui,F=f.contextType;typeof F=="object"&&F!==null&&(T=En(F)),T=new f(h,T),c.memoizedState=T.state!==null&&T.state!==void 0?T.state:null,T.updater=zg,c.stateNode=T,T._reactInternals=c,T=c.stateNode,T.props=h,T.state=c.memoizedState,T.refs={},Qg(c),F=f.contextType,T.context=typeof F=="object"&&F!==null?En(F):Ui,T.state=c.memoizedState,F=f.getDerivedStateFromProps,typeof F=="function"&&(Fg(c,f,F,h),T.state=c.memoizedState),typeof f.getDerivedStateFromProps=="function"||typeof T.getSnapshotBeforeUpdate=="function"||typeof T.UNSAFE_componentWillMount!="function"&&typeof T.componentWillMount!="function"||(F=T.state,typeof T.componentWillMount=="function"&&T.componentWillMount(),typeof T.UNSAFE_componentWillMount=="function"&&T.UNSAFE_componentWillMount(),F!==T.state&&zg.enqueueReplaceState(T,T.state,null),Ol(c,h,T,S),Nl(),T.state=c.memoizedState),typeof T.componentDidMount=="function"&&(c.flags|=4194308),h=!0}else if(i===null){T=c.stateNode;var q=c.memoizedProps,X=Ko(f,q);T.props=X;var re=T.context,ve=f.contextType;F=Ui,typeof ve=="object"&&ve!==null&&(F=En(ve));var Ce=f.getDerivedStateFromProps;ve=typeof Ce=="function"||typeof T.getSnapshotBeforeUpdate=="function",q=c.pendingProps!==q,ve||typeof T.UNSAFE_componentWillReceiveProps!="function"&&typeof T.componentWillReceiveProps!="function"||(q||re!==F)&&mR(c,T,h,F),to=!1;var fe=c.memoizedState;T.state=fe,Ol(c,h,T,S),Nl(),re=c.memoizedState,q||fe!==re||to?(typeof Ce=="function"&&(Fg(c,f,Ce,h),re=c.memoizedState),(X=to||hR(c,f,X,h,fe,re,F))?(ve||typeof T.UNSAFE_componentWillMount!="function"&&typeof T.componentWillMount!="function"||(typeof T.componentWillMount=="function"&&T.componentWillMount(),typeof T.UNSAFE_componentWillMount=="function"&&T.UNSAFE_componentWillMount()),typeof T.componentDidMount=="function"&&(c.flags|=4194308)):(typeof T.componentDidMount=="function"&&(c.flags|=4194308),c.memoizedProps=h,c.memoizedState=re),T.props=h,T.state=re,T.context=F,h=X):(typeof T.componentDidMount=="function"&&(c.flags|=4194308),h=!1)}else{T=c.stateNode,Jg(i,c),F=c.memoizedProps,ve=Ko(f,F),T.props=ve,Ce=c.pendingProps,fe=T.context,re=f.contextType,X=Ui,typeof re=="object"&&re!==null&&(X=En(re)),q=f.getDerivedStateFromProps,(re=typeof q=="function"||typeof T.getSnapshotBeforeUpdate=="function")||typeof T.UNSAFE_componentWillReceiveProps!="function"&&typeof T.componentWillReceiveProps!="function"||(F!==Ce||fe!==X)&&mR(c,T,h,X),to=!1,fe=c.memoizedState,T.state=fe,Ol(c,h,T,S),Nl();var me=c.memoizedState;F!==Ce||fe!==me||to||i!==null&&i.dependencies!==null&&Gu(i.dependencies)?(typeof q=="function"&&(Fg(c,f,q,h),me=c.memoizedState),(ve=to||hR(c,f,ve,h,fe,me,X)||i!==null&&i.dependencies!==null&&Gu(i.dependencies))?(re||typeof T.UNSAFE_componentWillUpdate!="function"&&typeof T.componentWillUpdate!="function"||(typeof T.componentWillUpdate=="function"&&T.componentWillUpdate(h,me,X),typeof T.UNSAFE_componentWillUpdate=="function"&&T.UNSAFE_componentWillUpdate(h,me,X)),typeof T.componentDidUpdate=="function"&&(c.flags|=4),typeof T.getSnapshotBeforeUpdate=="function"&&(c.flags|=1024)):(typeof T.componentDidUpdate!="function"||F===i.memoizedProps&&fe===i.memoizedState||(c.flags|=4),typeof T.getSnapshotBeforeUpdate!="function"||F===i.memoizedProps&&fe===i.memoizedState||(c.flags|=1024),c.memoizedProps=h,c.memoizedState=me),T.props=h,T.state=me,T.context=X,h=ve):(typeof T.componentDidUpdate!="function"||F===i.memoizedProps&&fe===i.memoizedState||(c.flags|=4),typeof T.getSnapshotBeforeUpdate!="function"||F===i.memoizedProps&&fe===i.memoizedState||(c.flags|=1024),h=!1)}return T=h,Rl(i,c),h=(c.flags&128)!==0,T||h?(T=c.stateNode,f=h&&typeof f.getDerivedStateFromError!="function"?null:T.render(),c.flags|=1,i!==null&&h?(c.child=$o(c,i.child,null,S),c.child=$o(c,null,f,S)):hn(i,c,f,S),c.memoizedState=T.state,i=c.child):i=Ea(i,c,S),i}function OR(i,c,f,h){return ml(),c.flags|=256,hn(i,c,f,h),c.child}var Ug={dehydrated:null,treeContext:null,retryLane:0};function Gg(i){return{baseLanes:i,cachePool:D1()}}function Hg(i,c,f){return i=i!==null?i.childLanes&~f:0,c&&(i|=br),i}function IR(i,c,f){var h=c.pendingProps,S=!1,T=(c.flags&128)!==0,F;if((F=T)||(F=i!==null&&i.memoizedState===null?!1:(en.current&2)!==0),F&&(S=!0,c.flags&=-129),F=(c.flags&32)!==0,c.flags&=-33,i===null){if(xt){if(S?Xa(c):Za(),xt){var q=gn,X;if(X=q){e:{for(X=q,q=Wr;X.nodeType!==8;){if(!q){q=null;break e}if(X=Dr(X.nextSibling),X===null){q=null;break e}}q=X}q!==null?(c.memoizedState={dehydrated:q,treeContext:Uo!==null?{id:ba,overflow:ya}:null,retryLane:536870912},X=mr(18,null,null,0),X.stateNode=q,X.return=c,c.child=X,Nn=c,gn=null,X=!0):X=!1}X||Ho(c)}if(q=c.memoizedState,q!==null&&(q=q.dehydrated,q!==null))return q.data==="$!"?c.lanes=16:c.lanes=536870912,null;va(c)}return q=h.children,h=h.fallback,S?(Za(),S=c.mode,q=qg({mode:"hidden",children:q},S),h=Jo(h,S,f,null),q.return=c,h.return=c,q.sibling=h,c.child=q,S=c.child,S.memoizedState=Gg(f),S.childLanes=Hg(i,F,f),c.memoizedState=Ug,h):(Xa(c),$g(c,q))}if(X=i.memoizedState,X!==null&&(q=X.dehydrated,q!==null)){if(T)c.flags&256?(Xa(c),c.flags&=-257,c=Vg(i,c,f)):c.memoizedState!==null?(Za(),c.child=i.child,c.flags|=128,c=null):(Za(),S=h.fallback,q=c.mode,h=qg({mode:"visible",children:h.children},q),S=Jo(S,q,f,null),S.flags|=2,h.return=c,S.return=c,h.sibling=S,c.child=h,$o(c,i.child,null,f),h=c.child,h.memoizedState=Gg(f),h.childLanes=Hg(i,F,f),c.memoizedState=Ug,c=S);else if(Xa(c),q.data==="$!"){if(F=q.nextSibling&&q.nextSibling.dataset,F)var re=F.dgst;F=re,h=Error(r(419)),h.stack="",h.digest=F,bl({value:h,source:null,stack:null}),c=Vg(i,c,f)}else if(on||Cl(i,c,f,!1),F=(f&i.childLanes)!==0,on||F){if(F=Lt,F!==null){if(h=f&-f,h&42)h=1;else switch(h){case 2:h=1;break;case 8:h=4;break;case 32:h=16;break;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:h=64;break;case 268435456:h=134217728;break;default:h=0}if(h=h&(F.suspendedLanes|f)?0:h,h!==0&&h!==X.retryLane)throw X.retryLane=h,Ka(i,h),On(F,i,h),xR}q.data==="$?"||Sh(),c=Vg(i,c,f)}else q.data==="$?"?(c.flags|=128,c.child=i.child,c=v$.bind(null,i),q._reactRetry=c,c=null):(i=X.treeContext,gn=Dr(q.nextSibling),Nn=c,xt=!0,Or=null,Wr=!1,i!==null&&(dr[fr++]=ba,dr[fr++]=ya,dr[fr++]=Uo,ba=i.id,ya=i.overflow,Uo=c),c=$g(c,h.children),c.flags|=4096);return c}return S?(Za(),S=h.fallback,q=c.mode,X=i.child,re=X.sibling,h=so(X,{mode:"hidden",children:h.children}),h.subtreeFlags=X.subtreeFlags&31457280,re!==null?S=so(re,S):(S=Jo(S,q,f,null),S.flags|=2),S.return=c,h.return=c,h.sibling=S,c.child=h,h=S,S=c.child,q=i.child.memoizedState,q===null?q=Gg(f):(X=q.cachePool,X!==null?(re=tn._currentValue,X=X.parent!==re?{parent:re,pool:re}:X):X=D1(),q={baseLanes:q.baseLanes|f,cachePool:X}),S.memoizedState=q,S.childLanes=Hg(i,F,f),c.memoizedState=Ug,h):(Xa(c),f=i.child,i=f.sibling,f=so(f,{mode:"visible",children:h.children}),f.return=c,f.sibling=null,i!==null&&(F=c.deletions,F===null?(c.deletions=[i],c.flags|=16):F.push(i)),c.child=f,c.memoizedState=null,f)}function $g(i,c){return c=qg({mode:"visible",children:c},i.mode),c.return=i,i.child=c}function qg(i,c){return aC(i,c,0,null)}function Vg(i,c,f){return $o(c,i.child,null,f),i=$g(c,c.pendingProps.children),i.flags|=2,c.memoizedState=null,i}function DR(i,c,f){i.lanes|=c;var h=i.alternate;h!==null&&(h.lanes|=c),Xg(i.return,c,f)}function Wg(i,c,f,h,S){var T=i.memoizedState;T===null?i.memoizedState={isBackwards:c,rendering:null,renderingStartTime:0,last:h,tail:f,tailMode:S}:(T.isBackwards=c,T.rendering=null,T.renderingStartTime=0,T.last=h,T.tail=f,T.tailMode=S)}function LR(i,c,f){var h=c.pendingProps,S=h.revealOrder,T=h.tail;if(hn(i,c,h.children,f),h=en.current,h&2)h=h&1|2,c.flags|=128;else{if(i!==null&&i.flags&128)e:for(i=c.child;i!==null;){if(i.tag===13)i.memoizedState!==null&&DR(i,f,c);else if(i.tag===19)DR(i,f,c);else if(i.child!==null){i.child.return=i,i=i.child;continue}if(i===c)break e;for(;i.sibling===null;){if(i.return===null||i.return===c)break e;i=i.return}i.sibling.return=i.return,i=i.sibling}h&=1}switch(ie(en,h),S){case"forwards":for(f=c.child,S=null;f!==null;)i=f.alternate,i!==null&&Nu(i)===null&&(S=f),f=f.sibling;f=S,f===null?(S=c.child,c.child=null):(S=f.sibling,f.sibling=null),Wg(c,!1,S,f,T);break;case"backwards":for(f=null,S=c.child,c.child=null;S!==null;){if(i=S.alternate,i!==null&&Nu(i)===null){c.child=S;break}i=S.sibling,S.sibling=f,f=S,S=i}Wg(c,!0,f,null,T);break;case"together":Wg(c,!1,null,null,void 0);break;default:c.memoizedState=null}return c.child}function Ea(i,c,f){if(i!==null&&(c.dependencies=i.dependencies),lo|=c.lanes,!(f&c.childLanes))if(i!==null){if(Cl(i,c,f,!1),(f&c.childLanes)===0)return null}else return null;if(i!==null&&c.child!==i.child)throw Error(r(153));if(c.child!==null){for(i=c.child,f=so(i,i.pendingProps),c.child=f,f.return=c;i.sibling!==null;)i=i.sibling,f=f.sibling=so(i,i.pendingProps),f.return=c;f.sibling=null}return c.child}function Yg(i,c){return i.lanes&c?!0:(i=i.dependencies,!!(i!==null&&Gu(i)))}function o$(i,c,f){switch(c.tag){case 3:be(c,c.stateNode.containerInfo),eo(c,tn,i.memoizedState.cache),ml();break;case 27:case 5:pe(c);break;case 4:be(c,c.stateNode.containerInfo);break;case 10:eo(c,c.type,c.memoizedProps.value);break;case 13:var h=c.memoizedState;if(h!==null)return h.dehydrated!==null?(Xa(c),c.flags|=128,null):f&c.child.childLanes?IR(i,c,f):(Xa(c),i=Ea(i,c,f),i!==null?i.sibling:null);Xa(c);break;case 19:var S=(i.flags&128)!==0;if(h=(f&c.childLanes)!==0,h||(Cl(i,c,f,!1),h=(f&c.childLanes)!==0),S){if(h)return LR(i,c,f);c.flags|=128}if(S=c.memoizedState,S!==null&&(S.rendering=null,S.tail=null,S.lastEffect=null),ie(en,en.current),h)break;return null;case 22:case 23:return c.lanes=0,RR(i,c,f);case 24:eo(c,tn,i.memoizedState.cache)}return Ea(i,c,f)}function MR(i,c,f){if(i!==null)if(i.memoizedProps!==c.pendingProps)on=!0;else{if(!Yg(i,f)&&!(c.flags&128))return on=!1,o$(i,c,f);on=!!(i.flags&131072)}else on=!1,xt&&c.flags&1048576&&v1(c,Tu,c.index);switch(c.lanes=0,c.tag){case 16:e:{i=c.pendingProps;var h=c.elementType,S=h._init;if(h=S(h._payload),c.type=h,typeof h=="function")lh(h)?(i=Ko(h,i),c.tag=1,c=NR(null,c,h,i,f)):(c.tag=0,c=jg(null,c,h,i,f));else{if(h!=null){if(S=h.$$typeof,S===v){c.tag=11,c=kR(null,c,h,i,f);break e}else if(S===A){c.tag=14,c=TR(null,c,h,i,f);break e}}throw c=M(h)||h,Error(r(306,c,""))}}return c;case 0:return jg(i,c,c.type,c.pendingProps,f);case 1:return h=c.type,S=Ko(h,c.pendingProps),NR(i,c,h,S,f);case 3:e:{if(be(c,c.stateNode.containerInfo),i===null)throw Error(r(387));var T=c.pendingProps;S=c.memoizedState,h=S.element,Jg(i,c),Ol(c,T,null,f);var F=c.memoizedState;if(T=F.cache,eo(c,tn,T),T!==S.cache&&Zg(c,[tn],f,!0),Nl(),T=F.element,S.isDehydrated)if(S={element:T,isDehydrated:!1,cache:F.cache},c.updateQueue.baseState=S,c.memoizedState=S,c.flags&256){c=OR(i,c,T,f);break e}else if(T!==h){h=ur(Error(r(424)),c),bl(h),c=OR(i,c,T,f);break e}else for(gn=Dr(c.stateNode.containerInfo.firstChild),Nn=c,xt=!0,Or=null,Wr=!0,f=C1(c,null,T,f),c.child=f;f;)f.flags=f.flags&-3|4096,f=f.sibling;else{if(ml(),T===h){c=Ea(i,c,f);break e}hn(i,c,T,f)}c=c.child}return c;case 26:return Rl(i,c),i===null?(f=zC(c.type,null,c.pendingProps,null))?c.memoizedState=f:xt||(f=c.type,i=c.pendingProps,h=ad(xe.current).createElement(f),h[Sn]=c,h[Fn]=i,mn(h,f,i),an(h),c.stateNode=h):c.memoizedState=zC(c.type,i.memoizedProps,c.pendingProps,i.memoizedState),null;case 27:return pe(c),i===null&&xt&&(h=c.stateNode=MC(c.type,c.pendingProps,xe.current),Nn=c,Wr=!0,gn=Dr(h.firstChild)),h=c.pendingProps.children,i!==null||xt?hn(i,c,h,f):c.child=$o(c,null,h,f),Rl(i,c),c.child;case 5:return i===null&&xt&&((S=h=gn)&&(h=M$(h,c.type,c.pendingProps,Wr),h!==null?(c.stateNode=h,Nn=c,gn=Dr(h.firstChild),Wr=!1,S=!0):S=!1),S||Ho(c)),pe(c),S=c.type,T=c.pendingProps,F=i!==null?i.memoizedProps:null,h=T.children,Lh(S,T)?h=null:F!==null&&Lh(S,F)&&(c.flags|=32),c.memoizedState!==null&&(S=wg(i,c,Q6,null,null,f),Vl._currentValue=S),Rl(i,c),hn(i,c,h,f),c.child;case 6:return i===null&&xt&&((i=f=gn)&&(f=P$(f,c.pendingProps,Wr),f!==null?(c.stateNode=f,Nn=c,gn=null,i=!0):i=!1),i||Ho(c)),null;case 13:return IR(i,c,f);case 4:return be(c,c.stateNode.containerInfo),h=c.pendingProps,i===null?c.child=$o(c,null,h,f):hn(i,c,h,f),c.child;case 11:return kR(i,c,c.type,c.pendingProps,f);case 7:return hn(i,c,c.pendingProps,f),c.child;case 8:return hn(i,c,c.pendingProps.children,f),c.child;case 12:return hn(i,c,c.pendingProps.children,f),c.child;case 10:return h=c.pendingProps,eo(c,c.type,h.value),hn(i,c,h.children,f),c.child;case 9:return S=c.type._context,h=c.pendingProps.children,Zo(c),S=En(S),h=h(S),c.flags|=1,hn(i,c,h,f),c.child;case 14:return TR(i,c,c.type,c.pendingProps,f);case 15:return AR(i,c,c.type,c.pendingProps,f);case 19:return LR(i,c,f);case 22:return RR(i,c,f);case 24:return Zo(c),h=En(tn),i===null?(S=Sg(),S===null&&(S=Lt,T=yg(),S.pooledCache=T,T.refCount++,T!==null&&(S.pooledCacheLanes|=f),S=T),c.memoizedState={parent:h,cache:S},Qg(c),eo(c,tn,S)):(i.lanes&f&&(Jg(i,c),Ol(c,null,null,f),Nl()),S=i.memoizedState,T=c.memoizedState,S.parent!==h?(S={parent:h,cache:h},c.memoizedState=S,c.lanes===0&&(c.memoizedState=c.updateQueue.baseState=S),eo(c,tn,h)):(h=T.cache,eo(c,tn,h),h!==S.cache&&Zg(c,[tn],f,!0))),hn(i,c,c.pendingProps.children,f),c.child;case 29:throw c.pendingProps}throw Error(r(156,c.tag))}var Kg=ce(null),Xo=null,wa=null;function eo(i,c,f){ie(Kg,c._currentValue),c._currentValue=f}function xa(i){i._currentValue=Kg.current,Re(Kg)}function Xg(i,c,f){for(;i!==null;){var h=i.alternate;if((i.childLanes&c)!==c?(i.childLanes|=c,h!==null&&(h.childLanes|=c)):h!==null&&(h.childLanes&c)!==c&&(h.childLanes|=c),i===f)break;i=i.return}}function Zg(i,c,f,h){var S=i.child;for(S!==null&&(S.return=i);S!==null;){var T=S.dependencies;if(T!==null){var F=S.child;T=T.firstContext;e:for(;T!==null;){var q=T;T=S;for(var X=0;X<c.length;X++)if(q.context===c[X]){T.lanes|=f,q=T.alternate,q!==null&&(q.lanes|=f),Xg(T.return,f,i),h||(F=null);break e}T=q.next}}else if(S.tag===18){if(F=S.return,F===null)throw Error(r(341));F.lanes|=f,T=F.alternate,T!==null&&(T.lanes|=f),Xg(F,f,i),F=null}else F=S.child;if(F!==null)F.return=S;else for(F=S;F!==null;){if(F===i){F=null;break}if(S=F.sibling,S!==null){S.return=F.return,F=S;break}F=F.return}S=F}}function Cl(i,c,f,h){i=null;for(var S=c,T=!1;S!==null;){if(!T){if(S.flags&524288)T=!0;else if(S.flags&262144)break}if(S.tag===10){var F=S.alternate;if(F===null)throw Error(r(387));if(F=F.memoizedProps,F!==null){var q=S.type;Yn(S.pendingProps.value,F.value)||(i!==null?i.push(q):i=[q])}}else if(S===Se.current){if(F=S.alternate,F===null)throw Error(r(387));F.memoizedState.memoizedState!==S.memoizedState.memoizedState&&(i!==null?i.push(Vl):i=[Vl])}S=S.return}i!==null&&Zg(c,i,f,h),c.flags|=262144}function Gu(i){for(i=i.firstContext;i!==null;){if(!Yn(i.context._currentValue,i.memoizedValue))return!0;i=i.next}return!1}function Zo(i){Xo=i,wa=null,i=i.dependencies,i!==null&&(i.firstContext=null)}function En(i){return PR(Xo,i)}function Hu(i,c){return Xo===null&&Zo(i),PR(i,c)}function PR(i,c){var f=c._currentValue;if(c={context:c,memoizedValue:f,next:null},wa===null){if(i===null)throw Error(r(308));wa=c,i.dependencies={lanes:0,firstContext:c},i.flags|=524288}else wa=wa.next=c;return f}var to=!1;function Qg(i){i.updateQueue={baseState:i.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Jg(i,c){i=i.updateQueue,c.updateQueue===i&&(c.updateQueue={baseState:i.baseState,firstBaseUpdate:i.firstBaseUpdate,lastBaseUpdate:i.lastBaseUpdate,shared:i.shared,callbacks:null})}function no(i){return{lane:i,tag:0,payload:null,callback:null,next:null}}function ro(i,c,f){var h=i.updateQueue;if(h===null)return null;if(h=h.shared,jt&2){var S=h.pending;return S===null?c.next=c:(c.next=S.next,S.next=c),h.pending=c,c=xu(i),b1(i,null,f),c}return wu(i,h,c,f),xu(i)}function _l(i,c,f){if(c=c.updateQueue,c!==null&&(c=c.shared,(f&4194176)!==0)){var h=c.lanes;h&=i.pendingLanes,f|=h,c.lanes=f,_r(i,f)}}function eh(i,c){var f=i.updateQueue,h=i.alternate;if(h!==null&&(h=h.updateQueue,f===h)){var S=null,T=null;if(f=f.firstBaseUpdate,f!==null){do{var F={lane:f.lane,tag:f.tag,payload:f.payload,callback:null,next:null};T===null?S=T=F:T=T.next=F,f=f.next}while(f!==null);T===null?S=T=c:T=T.next=c}else S=T=c;f={baseState:h.baseState,firstBaseUpdate:S,lastBaseUpdate:T,shared:h.shared,callbacks:h.callbacks},i.updateQueue=f;return}i=f.lastBaseUpdate,i===null?f.firstBaseUpdate=c:i.next=c,f.lastBaseUpdate=c}var th=!1;function Nl(){if(th){var i=Wi;if(i!==null)throw i}}function Ol(i,c,f,h){th=!1;var S=i.updateQueue;to=!1;var T=S.firstBaseUpdate,F=S.lastBaseUpdate,q=S.shared.pending;if(q!==null){S.shared.pending=null;var X=q,re=X.next;X.next=null,F===null?T=re:F.next=re,F=X;var ve=i.alternate;ve!==null&&(ve=ve.updateQueue,q=ve.lastBaseUpdate,q!==F&&(q===null?ve.firstBaseUpdate=re:q.next=re,ve.lastBaseUpdate=X))}if(T!==null){var Ce=S.baseState;F=0,ve=re=X=null,q=T;do{var fe=q.lane&-536870913,me=fe!==q.lane;if(me?(vt&fe)===fe:(h&fe)===fe){fe!==0&&fe===Vi&&(th=!0),ve!==null&&(ve=ve.next={lane:0,tag:q.tag,payload:q.payload,callback:null,next:null});e:{var qe=i,rt=q;fe=c;var Vt=f;switch(rt.tag){case 1:if(qe=rt.payload,typeof qe=="function"){Ce=qe.call(Vt,Ce,fe);break e}Ce=qe;break e;case 3:qe.flags=qe.flags&-65537|128;case 0:if(qe=rt.payload,fe=typeof qe=="function"?qe.call(Vt,Ce,fe):qe,fe==null)break e;Ce=D({},Ce,fe);break e;case 2:to=!0}}fe=q.callback,fe!==null&&(i.flags|=64,me&&(i.flags|=8192),me=S.callbacks,me===null?S.callbacks=[fe]:me.push(fe))}else me={lane:fe,tag:q.tag,payload:q.payload,callback:q.callback,next:null},ve===null?(re=ve=me,X=Ce):ve=ve.next=me,F|=fe;if(q=q.next,q===null){if(q=S.shared.pending,q===null)break;me=q,q=me.next,me.next=null,S.lastBaseUpdate=me,S.shared.pending=null}}while(!0);ve===null&&(X=Ce),S.baseState=X,S.firstBaseUpdate=re,S.lastBaseUpdate=ve,T===null&&(S.shared.lanes=0),lo|=F,i.lanes=F,i.memoizedState=Ce}}function FR(i,c){if(typeof i!="function")throw Error(r(191,i));i.call(c)}function zR(i,c){var f=i.callbacks;if(f!==null)for(i.callbacks=null,i=0;i<f.length;i++)FR(f[i],c)}function Il(i,c){try{var f=c.updateQueue,h=f!==null?f.lastEffect:null;if(h!==null){var S=h.next;f=S;do{if((f.tag&i)===i){h=void 0;var T=f.create,F=f.inst;h=T(),F.destroy=h}f=f.next}while(f!==S)}}catch(q){Ot(c,c.return,q)}}function ao(i,c,f){try{var h=c.updateQueue,S=h!==null?h.lastEffect:null;if(S!==null){var T=S.next;h=T;do{if((h.tag&i)===i){var F=h.inst,q=F.destroy;if(q!==void 0){F.destroy=void 0,S=c;var X=f;try{q()}catch(re){Ot(S,X,re)}}}h=h.next}while(h!==T)}}catch(re){Ot(c,c.return,re)}}function BR(i){var c=i.updateQueue;if(c!==null){var f=i.stateNode;try{zR(c,f)}catch(h){Ot(i,i.return,h)}}}function jR(i,c,f){f.props=Ko(i.type,i.memoizedProps),f.state=i.memoizedState;try{f.componentWillUnmount()}catch(h){Ot(i,c,h)}}function Qo(i,c){try{var f=i.ref;if(f!==null){var h=i.stateNode;switch(i.tag){case 26:case 27:case 5:var S=h;break;default:S=h}typeof f=="function"?i.refCleanup=f(S):f.current=S}}catch(T){Ot(i,c,T)}}function Kn(i,c){var f=i.ref,h=i.refCleanup;if(f!==null)if(typeof h=="function")try{h()}catch(S){Ot(i,c,S)}finally{i.refCleanup=null,i=i.alternate,i!=null&&(i.refCleanup=null)}else if(typeof f=="function")try{f(null)}catch(S){Ot(i,c,S)}else f.current=null}function UR(i){var c=i.type,f=i.memoizedProps,h=i.stateNode;try{e:switch(c){case"button":case"input":case"select":case"textarea":f.autoFocus&&h.focus();break e;case"img":f.src?h.src=f.src:f.srcSet&&(h.srcset=f.srcSet)}}catch(S){Ot(i,i.return,S)}}function GR(i,c,f){try{var h=i.stateNode;N$(h,i.type,f,c),h[Fn]=c}catch(S){Ot(i,i.return,S)}}function HR(i){return i.tag===5||i.tag===3||i.tag===26||i.tag===27||i.tag===4}function nh(i){e:for(;;){for(;i.sibling===null;){if(i.return===null||HR(i.return))return null;i=i.return}for(i.sibling.return=i.return,i=i.sibling;i.tag!==5&&i.tag!==6&&i.tag!==27&&i.tag!==18;){if(i.flags&2||i.child===null||i.tag===4)continue e;i.child.return=i,i=i.child}if(!(i.flags&2))return i.stateNode}}function rh(i,c,f){var h=i.tag;if(h===5||h===6)i=i.stateNode,c?f.nodeType===8?f.parentNode.insertBefore(i,c):f.insertBefore(i,c):(f.nodeType===8?(c=f.parentNode,c.insertBefore(i,f)):(c=f,c.appendChild(i)),f=f._reactRootContainer,f!=null||c.onclick!==null||(c.onclick=rd));else if(h!==4&&h!==27&&(i=i.child,i!==null))for(rh(i,c,f),i=i.sibling;i!==null;)rh(i,c,f),i=i.sibling}function $u(i,c,f){var h=i.tag;if(h===5||h===6)i=i.stateNode,c?f.insertBefore(i,c):f.appendChild(i);else if(h!==4&&h!==27&&(i=i.child,i!==null))for($u(i,c,f),i=i.sibling;i!==null;)$u(i,c,f),i=i.sibling}var ka=!1,$t=!1,ah=!1,$R=typeof WeakSet=="function"?WeakSet:Set,sn=null,qR=!1;function i$(i,c){if(i=i.containerInfo,Ih=ud,i=l1(i),ig(i)){if("selectionStart"in i)var f={start:i.selectionStart,end:i.selectionEnd};else e:{f=(f=i.ownerDocument)&&f.defaultView||window;var h=f.getSelection&&f.getSelection();if(h&&h.rangeCount!==0){f=h.anchorNode;var S=h.anchorOffset,T=h.focusNode;h=h.focusOffset;try{f.nodeType,T.nodeType}catch{f=null;break e}var F=0,q=-1,X=-1,re=0,ve=0,Ce=i,fe=null;t:for(;;){for(var me;Ce!==f||S!==0&&Ce.nodeType!==3||(q=F+S),Ce!==T||h!==0&&Ce.nodeType!==3||(X=F+h),Ce.nodeType===3&&(F+=Ce.nodeValue.length),(me=Ce.firstChild)!==null;)fe=Ce,Ce=me;for(;;){if(Ce===i)break t;if(fe===f&&++re===S&&(q=F),fe===T&&++ve===h&&(X=F),(me=Ce.nextSibling)!==null)break;Ce=fe,fe=Ce.parentNode}Ce=me}f=q===-1||X===-1?null:{start:q,end:X}}else f=null}f=f||{start:0,end:0}}else f=null;for(Dh={focusedElem:i,selectionRange:f},ud=!1,sn=c;sn!==null;)if(c=sn,i=c.child,(c.subtreeFlags&1028)!==0&&i!==null)i.return=c,sn=i;else for(;sn!==null;){switch(c=sn,T=c.alternate,i=c.flags,c.tag){case 0:break;case 11:case 15:break;case 1:if(i&1024&&T!==null){i=void 0,f=c,S=T.memoizedProps,T=T.memoizedState,h=f.stateNode;try{var qe=Ko(f.type,S,f.elementType===f.type);i=h.getSnapshotBeforeUpdate(qe,T),h.__reactInternalSnapshotBeforeUpdate=i}catch(rt){Ot(f,f.return,rt)}}break;case 3:if(i&1024){if(i=c.stateNode.containerInfo,f=i.nodeType,f===9)Fh(i);else if(f===1)switch(i.nodeName){case"HEAD":case"HTML":case"BODY":Fh(i);break;default:i.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if(i&1024)throw Error(r(163))}if(i=c.sibling,i!==null){i.return=c.return,sn=i;break}sn=c.return}return qe=qR,qR=!1,qe}function VR(i,c,f){var h=f.flags;switch(f.tag){case 0:case 11:case 15:Aa(i,f),h&4&&Il(5,f);break;case 1:if(Aa(i,f),h&4)if(i=f.stateNode,c===null)try{i.componentDidMount()}catch(q){Ot(f,f.return,q)}else{var S=Ko(f.type,c.memoizedProps);c=c.memoizedState;try{i.componentDidUpdate(S,c,i.__reactInternalSnapshotBeforeUpdate)}catch(q){Ot(f,f.return,q)}}h&64&&BR(f),h&512&&Qo(f,f.return);break;case 3:if(Aa(i,f),h&64&&(h=f.updateQueue,h!==null)){if(i=null,f.child!==null)switch(f.child.tag){case 27:case 5:i=f.child.stateNode;break;case 1:i=f.child.stateNode}try{zR(h,i)}catch(q){Ot(f,f.return,q)}}break;case 26:Aa(i,f),h&512&&Qo(f,f.return);break;case 27:case 5:Aa(i,f),c===null&&h&4&&UR(f),h&512&&Qo(f,f.return);break;case 12:Aa(i,f);break;case 13:Aa(i,f),h&4&&KR(i,f);break;case 22:if(S=f.memoizedState!==null||ka,!S){c=c!==null&&c.memoizedState!==null||$t;var T=ka,F=$t;ka=S,($t=c)&&!F?oo(i,f,(f.subtreeFlags&8772)!==0):Aa(i,f),ka=T,$t=F}h&512&&(f.memoizedProps.mode==="manual"?Qo(f,f.return):Kn(f,f.return));break;default:Aa(i,f)}}function WR(i){var c=i.alternate;c!==null&&(i.alternate=null,WR(c)),i.child=null,i.deletions=null,i.sibling=null,i.tag===5&&(c=i.stateNode,c!==null&&$p(c)),i.stateNode=null,i.return=null,i.dependencies=null,i.memoizedProps=null,i.memoizedState=null,i.pendingProps=null,i.stateNode=null,i.updateQueue=null}var Zt=null,Xn=!1;function Ta(i,c,f){for(f=f.child;f!==null;)YR(i,c,f),f=f.sibling}function YR(i,c,f){if(et&&typeof et.onCommitFiberUnmount=="function")try{et.onCommitFiberUnmount(bt,f)}catch{}switch(f.tag){case 26:$t||Kn(f,c),Ta(i,c,f),f.memoizedState?f.memoizedState.count--:f.stateNode&&(f=f.stateNode,f.parentNode.removeChild(f));break;case 27:$t||Kn(f,c);var h=Zt,S=Xn;for(Zt=f.stateNode,Ta(i,c,f),f=f.stateNode,c=f.attributes;c.length;)f.removeAttributeNode(c[0]);$p(f),Zt=h,Xn=S;break;case 5:$t||Kn(f,c);case 6:S=Zt;var T=Xn;if(Zt=null,Ta(i,c,f),Zt=S,Xn=T,Zt!==null)if(Xn)try{i=Zt,h=f.stateNode,i.nodeType===8?i.parentNode.removeChild(h):i.removeChild(h)}catch(F){Ot(f,c,F)}else try{Zt.removeChild(f.stateNode)}catch(F){Ot(f,c,F)}break;case 18:Zt!==null&&(Xn?(c=Zt,f=f.stateNode,c.nodeType===8?Ph(c.parentNode,f):c.nodeType===1&&Ph(c,f),Xl(c)):Ph(Zt,f.stateNode));break;case 4:h=Zt,S=Xn,Zt=f.stateNode.containerInfo,Xn=!0,Ta(i,c,f),Zt=h,Xn=S;break;case 0:case 11:case 14:case 15:$t||ao(2,f,c),$t||ao(4,f,c),Ta(i,c,f);break;case 1:$t||(Kn(f,c),h=f.stateNode,typeof h.componentWillUnmount=="function"&&jR(f,c,h)),Ta(i,c,f);break;case 21:Ta(i,c,f);break;case 22:$t||Kn(f,c),$t=(h=$t)||f.memoizedState!==null,Ta(i,c,f),$t=h;break;default:Ta(i,c,f)}}function KR(i,c){if(c.memoizedState===null&&(i=c.alternate,i!==null&&(i=i.memoizedState,i!==null&&(i=i.dehydrated,i!==null))))try{Xl(i)}catch(f){Ot(c,c.return,f)}}function s$(i){switch(i.tag){case 13:case 19:var c=i.stateNode;return c===null&&(c=i.stateNode=new $R),c;case 22:return i=i.stateNode,c=i._retryCache,c===null&&(c=i._retryCache=new $R),c;default:throw Error(r(435,i.tag))}}function oh(i,c){var f=s$(i);c.forEach(function(h){var S=S$.bind(null,i,h);f.has(h)||(f.add(h),h.then(S,S))})}function gr(i,c){var f=c.deletions;if(f!==null)for(var h=0;h<f.length;h++){var S=f[h],T=i,F=c,q=F;e:for(;q!==null;){switch(q.tag){case 27:case 5:Zt=q.stateNode,Xn=!1;break e;case 3:Zt=q.stateNode.containerInfo,Xn=!0;break e;case 4:Zt=q.stateNode.containerInfo,Xn=!0;break e}q=q.return}if(Zt===null)throw Error(r(160));YR(T,F,S),Zt=null,Xn=!1,T=S.alternate,T!==null&&(T.return=null),S.return=null}if(c.subtreeFlags&13878)for(c=c.child;c!==null;)XR(c,i),c=c.sibling}var Ir=null;function XR(i,c){var f=i.alternate,h=i.flags;switch(i.tag){case 0:case 11:case 14:case 15:gr(c,i),hr(i),h&4&&(ao(3,i,i.return),Il(3,i),ao(5,i,i.return));break;case 1:gr(c,i),hr(i),h&512&&($t||f===null||Kn(f,f.return)),h&64&&ka&&(i=i.updateQueue,i!==null&&(h=i.callbacks,h!==null&&(f=i.shared.hiddenCallbacks,i.shared.hiddenCallbacks=f===null?h:f.concat(h))));break;case 26:var S=Ir;if(gr(c,i),hr(i),h&512&&($t||f===null||Kn(f,f.return)),h&4){var T=f!==null?f.memoizedState:null;if(h=i.memoizedState,f===null)if(h===null)if(i.stateNode===null){e:{h=i.type,f=i.memoizedProps,S=S.ownerDocument||S;t:switch(h){case"title":T=S.getElementsByTagName("title")[0],(!T||T[al]||T[Sn]||T.namespaceURI==="http://www.w3.org/2000/svg"||T.hasAttribute("itemprop"))&&(T=S.createElement(h),S.head.insertBefore(T,S.querySelector("head > title"))),mn(T,h,f),T[Sn]=i,an(T),h=T;break e;case"link":var F=UC("link","href",S).get(h+(f.href||""));if(F){for(var q=0;q<F.length;q++)if(T=F[q],T.getAttribute("href")===(f.href==null?null:f.href)&&T.getAttribute("rel")===(f.rel==null?null:f.rel)&&T.getAttribute("title")===(f.title==null?null:f.title)&&T.getAttribute("crossorigin")===(f.crossOrigin==null?null:f.crossOrigin)){F.splice(q,1);break t}}T=S.createElement(h),mn(T,h,f),S.head.appendChild(T);break;case"meta":if(F=UC("meta","content",S).get(h+(f.content||""))){for(q=0;q<F.length;q++)if(T=F[q],T.getAttribute("content")===(f.content==null?null:""+f.content)&&T.getAttribute("name")===(f.name==null?null:f.name)&&T.getAttribute("property")===(f.property==null?null:f.property)&&T.getAttribute("http-equiv")===(f.httpEquiv==null?null:f.httpEquiv)&&T.getAttribute("charset")===(f.charSet==null?null:f.charSet)){F.splice(q,1);break t}}T=S.createElement(h),mn(T,h,f),S.head.appendChild(T);break;default:throw Error(r(468,h))}T[Sn]=i,an(T),h=T}i.stateNode=h}else GC(S,i.type,i.stateNode);else i.stateNode=jC(S,h,i.memoizedProps);else T!==h?(T===null?f.stateNode!==null&&(f=f.stateNode,f.parentNode.removeChild(f)):T.count--,h===null?GC(S,i.type,i.stateNode):jC(S,h,i.memoizedProps)):h===null&&i.stateNode!==null&&GR(i,i.memoizedProps,f.memoizedProps)}break;case 27:if(h&4&&i.alternate===null){S=i.stateNode,T=i.memoizedProps;try{for(var X=S.firstChild;X;){var re=X.nextSibling,ve=X.nodeName;X[al]||ve==="HEAD"||ve==="BODY"||ve==="SCRIPT"||ve==="STYLE"||ve==="LINK"&&X.rel.toLowerCase()==="stylesheet"||S.removeChild(X),X=re}for(var Ce=i.type,fe=S.attributes;fe.length;)S.removeAttributeNode(fe[0]);mn(S,Ce,T),S[Sn]=i,S[Fn]=T}catch(qe){Ot(i,i.return,qe)}}case 5:if(gr(c,i),hr(i),h&512&&($t||f===null||Kn(f,f.return)),i.flags&32){S=i.stateNode;try{Li(S,"")}catch(qe){Ot(i,i.return,qe)}}h&4&&i.stateNode!=null&&(S=i.memoizedProps,GR(i,S,f!==null?f.memoizedProps:S)),h&1024&&(ah=!0);break;case 6:if(gr(c,i),hr(i),h&4){if(i.stateNode===null)throw Error(r(162));h=i.memoizedProps,f=i.stateNode;try{f.nodeValue=h}catch(qe){Ot(i,i.return,qe)}}break;case 3:if(sd=null,S=Ir,Ir=od(c.containerInfo),gr(c,i),Ir=S,hr(i),h&4&&f!==null&&f.memoizedState.isDehydrated)try{Xl(c.containerInfo)}catch(qe){Ot(i,i.return,qe)}ah&&(ah=!1,ZR(i));break;case 4:h=Ir,Ir=od(i.stateNode.containerInfo),gr(c,i),hr(i),Ir=h;break;case 12:gr(c,i),hr(i);break;case 13:gr(c,i),hr(i),i.child.flags&8192&&i.memoizedState!==null!=(f!==null&&f.memoizedState!==null)&&(gh=ye()),h&4&&(h=i.updateQueue,h!==null&&(i.updateQueue=null,oh(i,h)));break;case 22:if(h&512&&($t||f===null||Kn(f,f.return)),X=i.memoizedState!==null,re=f!==null&&f.memoizedState!==null,ve=ka,Ce=$t,ka=ve||X,$t=Ce||re,gr(c,i),$t=Ce,ka=ve,hr(i),c=i.stateNode,c._current=i,c._visibility&=-3,c._visibility|=c._pendingVisibility&2,h&8192&&(c._visibility=X?c._visibility&-2:c._visibility|1,X&&(c=ka||$t,f===null||re||c||Zi(i)),i.memoizedProps===null||i.memoizedProps.mode!=="manual"))e:for(f=null,c=i;;){if(c.tag===5||c.tag===26||c.tag===27){if(f===null){re=f=c;try{if(S=re.stateNode,X)T=S.style,typeof T.setProperty=="function"?T.setProperty("display","none","important"):T.display="none";else{F=re.stateNode,q=re.memoizedProps.style;var me=q!=null&&q.hasOwnProperty("display")?q.display:null;F.style.display=me==null||typeof me=="boolean"?"":(""+me).trim()}}catch(qe){Ot(re,re.return,qe)}}}else if(c.tag===6){if(f===null){re=c;try{re.stateNode.nodeValue=X?"":re.memoizedProps}catch(qe){Ot(re,re.return,qe)}}}else if((c.tag!==22&&c.tag!==23||c.memoizedState===null||c===i)&&c.child!==null){c.child.return=c,c=c.child;continue}if(c===i)break e;for(;c.sibling===null;){if(c.return===null||c.return===i)break e;f===c&&(f=null),c=c.return}f===c&&(f=null),c.sibling.return=c.return,c=c.sibling}h&4&&(h=i.updateQueue,h!==null&&(f=h.retryQueue,f!==null&&(h.retryQueue=null,oh(i,f))));break;case 19:gr(c,i),hr(i),h&4&&(h=i.updateQueue,h!==null&&(i.updateQueue=null,oh(i,h)));break;case 21:break;default:gr(c,i),hr(i)}}function hr(i){var c=i.flags;if(c&2){try{if(i.tag!==27){e:{for(var f=i.return;f!==null;){if(HR(f)){var h=f;break e}f=f.return}throw Error(r(160))}switch(h.tag){case 27:var S=h.stateNode,T=nh(i);$u(i,T,S);break;case 5:var F=h.stateNode;h.flags&32&&(Li(F,""),h.flags&=-33);var q=nh(i);$u(i,q,F);break;case 3:case 4:var X=h.stateNode.containerInfo,re=nh(i);rh(i,re,X);break;default:throw Error(r(161))}}}catch(ve){Ot(i,i.return,ve)}i.flags&=-3}c&4096&&(i.flags&=-4097)}function ZR(i){if(i.subtreeFlags&1024)for(i=i.child;i!==null;){var c=i;ZR(c),c.tag===5&&c.flags&1024&&c.stateNode.reset(),i=i.sibling}}function Aa(i,c){if(c.subtreeFlags&8772)for(c=c.child;c!==null;)VR(i,c.alternate,c),c=c.sibling}function Zi(i){for(i=i.child;i!==null;){var c=i;switch(c.tag){case 0:case 11:case 14:case 15:ao(4,c,c.return),Zi(c);break;case 1:Kn(c,c.return);var f=c.stateNode;typeof f.componentWillUnmount=="function"&&jR(c,c.return,f),Zi(c);break;case 26:case 27:case 5:Kn(c,c.return),Zi(c);break;case 22:Kn(c,c.return),c.memoizedState===null&&Zi(c);break;default:Zi(c)}i=i.sibling}}function oo(i,c,f){for(f=f&&(c.subtreeFlags&8772)!==0,c=c.child;c!==null;){var h=c.alternate,S=i,T=c,F=T.flags;switch(T.tag){case 0:case 11:case 15:oo(S,T,f),Il(4,T);break;case 1:if(oo(S,T,f),h=T,S=h.stateNode,typeof S.componentDidMount=="function")try{S.componentDidMount()}catch(re){Ot(h,h.return,re)}if(h=T,S=h.updateQueue,S!==null){var q=h.stateNode;try{var X=S.shared.hiddenCallbacks;if(X!==null)for(S.shared.hiddenCallbacks=null,S=0;S<X.length;S++)FR(X[S],q)}catch(re){Ot(h,h.return,re)}}f&&F&64&&BR(T),Qo(T,T.return);break;case 26:case 27:case 5:oo(S,T,f),f&&h===null&&F&4&&UR(T),Qo(T,T.return);break;case 12:oo(S,T,f);break;case 13:oo(S,T,f),f&&F&4&&KR(S,T);break;case 22:T.memoizedState===null&&oo(S,T,f),Qo(T,T.return);break;default:oo(S,T,f)}c=c.sibling}}function ih(i,c){var f=null;i!==null&&i.memoizedState!==null&&i.memoizedState.cachePool!==null&&(f=i.memoizedState.cachePool.pool),i=null,c.memoizedState!==null&&c.memoizedState.cachePool!==null&&(i=c.memoizedState.cachePool.pool),i!==f&&(i!=null&&i.refCount++,f!=null&&wl(f))}function sh(i,c){i=null,c.alternate!==null&&(i=c.alternate.memoizedState.cache),c=c.memoizedState.cache,c!==i&&(c.refCount++,i!=null&&wl(i))}function io(i,c,f,h){if(c.subtreeFlags&10256)for(c=c.child;c!==null;)QR(i,c,f,h),c=c.sibling}function QR(i,c,f,h){var S=c.flags;switch(c.tag){case 0:case 11:case 15:io(i,c,f,h),S&2048&&Il(9,c);break;case 3:io(i,c,f,h),S&2048&&(i=null,c.alternate!==null&&(i=c.alternate.memoizedState.cache),c=c.memoizedState.cache,c!==i&&(c.refCount++,i!=null&&wl(i)));break;case 12:if(S&2048){io(i,c,f,h),i=c.stateNode;try{var T=c.memoizedProps,F=T.id,q=T.onPostCommit;typeof q=="function"&&q(F,c.alternate===null?"mount":"update",i.passiveEffectDuration,-0)}catch(X){Ot(c,c.return,X)}}else io(i,c,f,h);break;case 23:break;case 22:T=c.stateNode,c.memoizedState!==null?T._visibility&4?io(i,c,f,h):Dl(i,c):T._visibility&4?io(i,c,f,h):(T._visibility|=4,Qi(i,c,f,h,(c.subtreeFlags&10256)!==0)),S&2048&&ih(c.alternate,c);break;case 24:io(i,c,f,h),S&2048&&sh(c.alternate,c);break;default:io(i,c,f,h)}}function Qi(i,c,f,h,S){for(S=S&&(c.subtreeFlags&10256)!==0,c=c.child;c!==null;){var T=i,F=c,q=f,X=h,re=F.flags;switch(F.tag){case 0:case 11:case 15:Qi(T,F,q,X,S),Il(8,F);break;case 23:break;case 22:var ve=F.stateNode;F.memoizedState!==null?ve._visibility&4?Qi(T,F,q,X,S):Dl(T,F):(ve._visibility|=4,Qi(T,F,q,X,S)),S&&re&2048&&ih(F.alternate,F);break;case 24:Qi(T,F,q,X,S),S&&re&2048&&sh(F.alternate,F);break;default:Qi(T,F,q,X,S)}c=c.sibling}}function Dl(i,c){if(c.subtreeFlags&10256)for(c=c.child;c!==null;){var f=i,h=c,S=h.flags;switch(h.tag){case 22:Dl(f,h),S&2048&&ih(h.alternate,h);break;case 24:Dl(f,h),S&2048&&sh(h.alternate,h);break;default:Dl(f,h)}c=c.sibling}}var Ll=8192;function Ji(i){if(i.subtreeFlags&Ll)for(i=i.child;i!==null;)JR(i),i=i.sibling}function JR(i){switch(i.tag){case 26:Ji(i),i.flags&Ll&&i.memoizedState!==null&&K$(Ir,i.memoizedState,i.memoizedProps);break;case 5:Ji(i);break;case 3:case 4:var c=Ir;Ir=od(i.stateNode.containerInfo),Ji(i),Ir=c;break;case 22:i.memoizedState===null&&(c=i.alternate,c!==null&&c.memoizedState!==null?(c=Ll,Ll=16777216,Ji(i),Ll=c):Ji(i));break;default:Ji(i)}}function eC(i){var c=i.alternate;if(c!==null&&(i=c.child,i!==null)){c.child=null;do c=i.sibling,i.sibling=null,i=c;while(i!==null)}}function Ml(i){var c=i.deletions;if(i.flags&16){if(c!==null)for(var f=0;f<c.length;f++){var h=c[f];sn=h,nC(h,i)}eC(i)}if(i.subtreeFlags&10256)for(i=i.child;i!==null;)tC(i),i=i.sibling}function tC(i){switch(i.tag){case 0:case 11:case 15:Ml(i),i.flags&2048&&ao(9,i,i.return);break;case 3:Ml(i);break;case 12:Ml(i);break;case 22:var c=i.stateNode;i.memoizedState!==null&&c._visibility&4&&(i.return===null||i.return.tag!==13)?(c._visibility&=-5,qu(i)):Ml(i);break;default:Ml(i)}}function qu(i){var c=i.deletions;if(i.flags&16){if(c!==null)for(var f=0;f<c.length;f++){var h=c[f];sn=h,nC(h,i)}eC(i)}for(i=i.child;i!==null;){switch(c=i,c.tag){case 0:case 11:case 15:ao(8,c,c.return),qu(c);break;case 22:f=c.stateNode,f._visibility&4&&(f._visibility&=-5,qu(c));break;default:qu(c)}i=i.sibling}}function nC(i,c){for(;sn!==null;){var f=sn;switch(f.tag){case 0:case 11:case 15:ao(8,f,c);break;case 23:case 22:if(f.memoizedState!==null&&f.memoizedState.cachePool!==null){var h=f.memoizedState.cachePool.pool;h!=null&&h.refCount++}break;case 24:wl(f.memoizedState.cache)}if(h=f.child,h!==null)h.return=f,sn=h;else e:for(f=i;sn!==null;){h=sn;var S=h.sibling,T=h.return;if(WR(h),h===f){sn=null;break e}if(S!==null){S.return=T,sn=S;break e}sn=T}}}function l$(i,c,f,h){this.tag=i,this.key=f,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=c,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=h,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function mr(i,c,f,h){return new l$(i,c,f,h)}function lh(i){return i=i.prototype,!(!i||!i.isReactComponent)}function so(i,c){var f=i.alternate;return f===null?(f=mr(i.tag,c,i.key,i.mode),f.elementType=i.elementType,f.type=i.type,f.stateNode=i.stateNode,f.alternate=i,i.alternate=f):(f.pendingProps=c,f.type=i.type,f.flags=0,f.subtreeFlags=0,f.deletions=null),f.flags=i.flags&31457280,f.childLanes=i.childLanes,f.lanes=i.lanes,f.child=i.child,f.memoizedProps=i.memoizedProps,f.memoizedState=i.memoizedState,f.updateQueue=i.updateQueue,c=i.dependencies,f.dependencies=c===null?null:{lanes:c.lanes,firstContext:c.firstContext},f.sibling=i.sibling,f.index=i.index,f.ref=i.ref,f.refCleanup=i.refCleanup,f}function rC(i,c){i.flags&=31457282;var f=i.alternate;return f===null?(i.childLanes=0,i.lanes=c,i.child=null,i.subtreeFlags=0,i.memoizedProps=null,i.memoizedState=null,i.updateQueue=null,i.dependencies=null,i.stateNode=null):(i.childLanes=f.childLanes,i.lanes=f.lanes,i.child=f.child,i.subtreeFlags=0,i.deletions=null,i.memoizedProps=f.memoizedProps,i.memoizedState=f.memoizedState,i.updateQueue=f.updateQueue,i.type=f.type,c=f.dependencies,i.dependencies=c===null?null:{lanes:c.lanes,firstContext:c.firstContext}),i}function Vu(i,c,f,h,S,T){var F=0;if(h=i,typeof i=="function")lh(i)&&(F=1);else if(typeof i=="string")F=W$(i,f,Te.current)?26:i==="html"||i==="head"||i==="body"?27:5;else e:switch(i){case u:return Jo(f.children,S,T,c);case d:F=8,S|=24;break;case p:return i=mr(12,f,c,S|2),i.elementType=p,i.lanes=T,i;case y:return i=mr(13,f,c,S),i.elementType=y,i.lanes=T,i;case k:return i=mr(19,f,c,S),i.elementType=k,i.lanes=T,i;case R:return aC(f,S,T,c);default:if(typeof i=="object"&&i!==null)switch(i.$$typeof){case g:case b:F=10;break e;case m:F=9;break e;case v:F=11;break e;case A:F=14;break e;case x:F=16,h=null;break e}F=29,f=Error(r(130,i===null?"null":typeof i,"")),h=null}return c=mr(F,f,c,S),c.elementType=i,c.type=h,c.lanes=T,c}function Jo(i,c,f,h){return i=mr(7,i,h,c),i.lanes=f,i}function aC(i,c,f,h){i=mr(22,i,h,c),i.elementType=R,i.lanes=f;var S={_visibility:1,_pendingVisibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null,_current:null,detach:function(){var T=S._current;if(T===null)throw Error(r(456));if(!(S._pendingVisibility&2)){var F=Ka(T,2);F!==null&&(S._pendingVisibility|=2,On(F,T,2))}},attach:function(){var T=S._current;if(T===null)throw Error(r(456));if(S._pendingVisibility&2){var F=Ka(T,2);F!==null&&(S._pendingVisibility&=-3,On(F,T,2))}}};return i.stateNode=S,i}function ch(i,c,f){return i=mr(6,i,null,c),i.lanes=f,i}function uh(i,c,f){return c=mr(4,i.children!==null?i.children:[],i.key,c),c.lanes=f,c.stateNode={containerInfo:i.containerInfo,pendingChildren:null,implementation:i.implementation},c}function Ra(i){i.flags|=4}function oC(i,c){if(c.type!=="stylesheet"||c.state.loading&4)i.flags&=-16777217;else if(i.flags|=16777216,!HC(c)){if(c=pr.current,c!==null&&((vt&4194176)===vt?Yr!==null:(vt&62914560)!==vt&&!(vt&536870912)||c!==Yr))throw vl=hg,w1;i.flags|=8192}}function Wu(i,c){c!==null&&(i.flags|=4),i.flags&16384&&(c=i.tag!==22?Ln():536870912,i.lanes|=c,ts|=c)}function Pl(i,c){if(!xt)switch(i.tailMode){case"hidden":c=i.tail;for(var f=null;c!==null;)c.alternate!==null&&(f=c),c=c.sibling;f===null?i.tail=null:f.sibling=null;break;case"collapsed":f=i.tail;for(var h=null;f!==null;)f.alternate!==null&&(h=f),f=f.sibling;h===null?c||i.tail===null?i.tail=null:i.tail.sibling=null:h.sibling=null}}function Bt(i){var c=i.alternate!==null&&i.alternate.child===i.child,f=0,h=0;if(c)for(var S=i.child;S!==null;)f|=S.lanes|S.childLanes,h|=S.subtreeFlags&31457280,h|=S.flags&31457280,S.return=i,S=S.sibling;else for(S=i.child;S!==null;)f|=S.lanes|S.childLanes,h|=S.subtreeFlags,h|=S.flags,S.return=i,S=S.sibling;return i.subtreeFlags|=h,i.childLanes=f,c}function c$(i,c,f){var h=c.pendingProps;switch(pg(c),c.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Bt(c),null;case 1:return Bt(c),null;case 3:return f=c.stateNode,h=null,i!==null&&(h=i.memoizedState.cache),c.memoizedState.cache!==h&&(c.flags|=2048),xa(tn),J(),f.pendingContext&&(f.context=f.pendingContext,f.pendingContext=null),(i===null||i.child===null)&&(hl(c)?Ra(c):i===null||i.memoizedState.isDehydrated&&!(c.flags&256)||(c.flags|=1024,Or!==null&&(yh(Or),Or=null))),Bt(c),null;case 26:return f=c.memoizedState,i===null?(Ra(c),f!==null?(Bt(c),oC(c,f)):(Bt(c),c.flags&=-16777217)):f?f!==i.memoizedState?(Ra(c),Bt(c),oC(c,f)):(Bt(c),c.flags&=-16777217):(i.memoizedProps!==h&&Ra(c),Bt(c),c.flags&=-16777217),null;case 27:ke(c),f=xe.current;var S=c.type;if(i!==null&&c.stateNode!=null)i.memoizedProps!==h&&Ra(c);else{if(!h){if(c.stateNode===null)throw Error(r(166));return Bt(c),null}i=Te.current,hl(c)?S1(c):(i=MC(S,h,f),c.stateNode=i,Ra(c))}return Bt(c),null;case 5:if(ke(c),f=c.type,i!==null&&c.stateNode!=null)i.memoizedProps!==h&&Ra(c);else{if(!h){if(c.stateNode===null)throw Error(r(166));return Bt(c),null}if(i=Te.current,hl(c))S1(c);else{switch(S=ad(xe.current),i){case 1:i=S.createElementNS("http://www.w3.org/2000/svg",f);break;case 2:i=S.createElementNS("http://www.w3.org/1998/Math/MathML",f);break;default:switch(f){case"svg":i=S.createElementNS("http://www.w3.org/2000/svg",f);break;case"math":i=S.createElementNS("http://www.w3.org/1998/Math/MathML",f);break;case"script":i=S.createElement("div"),i.innerHTML="<script><\/script>",i=i.removeChild(i.firstChild);break;case"select":i=typeof h.is=="string"?S.createElement("select",{is:h.is}):S.createElement("select"),h.multiple?i.multiple=!0:h.size&&(i.size=h.size);break;default:i=typeof h.is=="string"?S.createElement(f,{is:h.is}):S.createElement(f)}}i[Sn]=c,i[Fn]=h;e:for(S=c.child;S!==null;){if(S.tag===5||S.tag===6)i.appendChild(S.stateNode);else if(S.tag!==4&&S.tag!==27&&S.child!==null){S.child.return=S,S=S.child;continue}if(S===c)break e;for(;S.sibling===null;){if(S.return===null||S.return===c)break e;S=S.return}S.sibling.return=S.return,S=S.sibling}c.stateNode=i;e:switch(mn(i,f,h),f){case"button":case"input":case"select":case"textarea":i=!!h.autoFocus;break e;case"img":i=!0;break e;default:i=!1}i&&Ra(c)}}return Bt(c),c.flags&=-16777217,null;case 6:if(i&&c.stateNode!=null)i.memoizedProps!==h&&Ra(c);else{if(typeof h!="string"&&c.stateNode===null)throw Error(r(166));if(i=xe.current,hl(c)){if(i=c.stateNode,f=c.memoizedProps,h=null,S=Nn,S!==null)switch(S.tag){case 27:case 5:h=S.memoizedProps}i[Sn]=c,i=!!(i.nodeValue===f||h!==null&&h.suppressHydrationWarning===!0||_C(i.nodeValue,f)),i||Ho(c)}else i=ad(i).createTextNode(h),i[Sn]=c,c.stateNode=i}return Bt(c),null;case 13:if(h=c.memoizedState,i===null||i.memoizedState!==null&&i.memoizedState.dehydrated!==null){if(S=hl(c),h!==null&&h.dehydrated!==null){if(i===null){if(!S)throw Error(r(318));if(S=c.memoizedState,S=S!==null?S.dehydrated:null,!S)throw Error(r(317));S[Sn]=c}else ml(),!(c.flags&128)&&(c.memoizedState=null),c.flags|=4;Bt(c),S=!1}else Or!==null&&(yh(Or),Or=null),S=!0;if(!S)return c.flags&256?(va(c),c):(va(c),null)}if(va(c),c.flags&128)return c.lanes=f,c;if(f=h!==null,i=i!==null&&i.memoizedState!==null,f){h=c.child,S=null,h.alternate!==null&&h.alternate.memoizedState!==null&&h.alternate.memoizedState.cachePool!==null&&(S=h.alternate.memoizedState.cachePool.pool);var T=null;h.memoizedState!==null&&h.memoizedState.cachePool!==null&&(T=h.memoizedState.cachePool.pool),T!==S&&(h.flags|=2048)}return f!==i&&f&&(c.child.flags|=8192),Wu(c,c.updateQueue),Bt(c),null;case 4:return J(),i===null&&_h(c.stateNode.containerInfo),Bt(c),null;case 10:return xa(c.type),Bt(c),null;case 19:if(Re(en),S=c.memoizedState,S===null)return Bt(c),null;if(h=(c.flags&128)!==0,T=S.rendering,T===null)if(h)Pl(S,!1);else{if(qt!==0||i!==null&&i.flags&128)for(i=c.child;i!==null;){if(T=Nu(i),T!==null){for(c.flags|=128,Pl(S,!1),i=T.updateQueue,c.updateQueue=i,Wu(c,i),c.subtreeFlags=0,i=f,f=c.child;f!==null;)rC(f,i),f=f.sibling;return ie(en,en.current&1|2),c.child}i=i.sibling}S.tail!==null&&ye()>Yu&&(c.flags|=128,h=!0,Pl(S,!1),c.lanes=4194304)}else{if(!h)if(i=Nu(T),i!==null){if(c.flags|=128,h=!0,i=i.updateQueue,c.updateQueue=i,Wu(c,i),Pl(S,!0),S.tail===null&&S.tailMode==="hidden"&&!T.alternate&&!xt)return Bt(c),null}else 2*ye()-S.renderingStartTime>Yu&&f!==536870912&&(c.flags|=128,h=!0,Pl(S,!1),c.lanes=4194304);S.isBackwards?(T.sibling=c.child,c.child=T):(i=S.last,i!==null?i.sibling=T:c.child=T,S.last=T)}return S.tail!==null?(c=S.tail,S.rendering=c,S.tail=c.sibling,S.renderingStartTime=ye(),c.sibling=null,i=en.current,ie(en,h?i&1|2:i&1),c):(Bt(c),null);case 22:case 23:return va(c),bg(),h=c.memoizedState!==null,i!==null?i.memoizedState!==null!==h&&(c.flags|=8192):h&&(c.flags|=8192),h?f&536870912&&!(c.flags&128)&&(Bt(c),c.subtreeFlags&6&&(c.flags|=8192)):Bt(c),f=c.updateQueue,f!==null&&Wu(c,f.retryQueue),f=null,i!==null&&i.memoizedState!==null&&i.memoizedState.cachePool!==null&&(f=i.memoizedState.cachePool.pool),h=null,c.memoizedState!==null&&c.memoizedState.cachePool!==null&&(h=c.memoizedState.cachePool.pool),h!==f&&(c.flags|=2048),i!==null&&Re(qo),null;case 24:return f=null,i!==null&&(f=i.memoizedState.cache),c.memoizedState.cache!==f&&(c.flags|=2048),xa(tn),Bt(c),null;case 25:return null}throw Error(r(156,c.tag))}function u$(i,c){switch(pg(c),c.tag){case 1:return i=c.flags,i&65536?(c.flags=i&-65537|128,c):null;case 3:return xa(tn),J(),i=c.flags,i&65536&&!(i&128)?(c.flags=i&-65537|128,c):null;case 26:case 27:case 5:return ke(c),null;case 13:if(va(c),i=c.memoizedState,i!==null&&i.dehydrated!==null){if(c.alternate===null)throw Error(r(340));ml()}return i=c.flags,i&65536?(c.flags=i&-65537|128,c):null;case 19:return Re(en),null;case 4:return J(),null;case 10:return xa(c.type),null;case 22:case 23:return va(c),bg(),i!==null&&Re(qo),i=c.flags,i&65536?(c.flags=i&-65537|128,c):null;case 24:return xa(tn),null;case 25:return null;default:return null}}function iC(i,c){switch(pg(c),c.tag){case 3:xa(tn),J();break;case 26:case 27:case 5:ke(c);break;case 4:J();break;case 13:va(c);break;case 19:Re(en);break;case 10:xa(c.type);break;case 22:case 23:va(c),bg(),i!==null&&Re(qo);break;case 24:xa(tn)}}var d$={getCacheForType:function(i){var c=En(tn),f=c.data.get(i);return f===void 0&&(f=i(),c.data.set(i,f)),f}},f$=typeof WeakMap=="function"?WeakMap:Map,jt=0,Lt=null,ft=null,vt=0,Mt=0,Zn=null,Ca=!1,es=!1,dh=!1,_a=0,qt=0,lo=0,ei=0,fh=0,br=0,ts=0,Fl=null,Xr=null,ph=!1,gh=0,Yu=1/0,Ku=null,co=null,Xu=!1,ti=null,zl=0,hh=0,mh=null,Bl=0,bh=null;function Qn(){if(jt&2&&vt!==0)return vt&-vt;if(I.T!==null){var i=Vi;return i!==0?i:Th()}return RA()}function sC(){br===0&&(br=!(vt&536870912)||xt?Nt():536870912);var i=pr.current;return i!==null&&(i.flags|=32),br}function On(i,c,f){(i===Lt&&Mt===2||i.cancelPendingCommit!==null)&&(ns(i,0),Na(i,vt,br,!1)),Mn(i,f),(!(jt&2)||i!==Lt)&&(i===Lt&&(!(jt&2)&&(ei|=f),qt===4&&Na(i,vt,br,!1)),Zr(i))}function lC(i,c,f){if(jt&6)throw Error(r(327));var h=!f&&(c&60)===0&&(c&i.expiredLanes)===0||Xe(i,c),S=h?h$(i,c):Eh(i,c,!0),T=h;do{if(S===0){es&&!h&&Na(i,c,0,!1);break}else if(S===6)Na(i,c,0,!Ca);else{if(f=i.current.alternate,T&&!p$(f)){S=Eh(i,c,!1),T=!1;continue}if(S===2){if(T=c,i.errorRecoveryDisabledLanes&T)var F=0;else F=i.pendingLanes&-536870913,F=F!==0?F:F&536870912?536870912:0;if(F!==0){c=F;e:{var q=i;S=Fl;var X=q.current.memoizedState.isDehydrated;if(X&&(ns(q,F).flags|=256),F=Eh(q,F,!1),F!==2){if(dh&&!X){q.errorRecoveryDisabledLanes|=T,ei|=T,S=4;break e}T=Xr,Xr=S,T!==null&&yh(T)}S=F}if(T=!1,S!==2)continue}}if(S===1){ns(i,0),Na(i,c,0,!0);break}e:{switch(h=i,S){case 0:case 1:throw Error(r(345));case 4:if((c&4194176)===c){Na(h,c,br,!Ca);break e}break;case 2:Xr=null;break;case 3:case 5:break;default:throw Error(r(329))}if(h.finishedWork=f,h.finishedLanes=c,(c&62914560)===c&&(T=gh+300-ye(),10<T)){if(Na(h,c,br,!Ca),pa(h,0)!==0)break e;h.timeoutHandle=IC(cC.bind(null,h,f,Xr,Ku,ph,c,br,ei,ts,Ca,2,-0,0),T);break e}cC(h,f,Xr,Ku,ph,c,br,ei,ts,Ca,0,-0,0)}}break}while(!0);Zr(i)}function yh(i){Xr===null?Xr=i:Xr.push.apply(Xr,i)}function cC(i,c,f,h,S,T,F,q,X,re,ve,Ce,fe){var me=c.subtreeFlags;if((me&8192||(me&16785408)===16785408)&&(ql={stylesheets:null,count:0,unsuspend:Y$},JR(c),c=X$(),c!==null)){i.cancelPendingCommit=c(mC.bind(null,i,f,h,S,F,q,X,1,Ce,fe)),Na(i,T,F,!re);return}mC(i,f,h,S,F,q,X,ve,Ce,fe)}function p$(i){for(var c=i;;){var f=c.tag;if((f===0||f===11||f===15)&&c.flags&16384&&(f=c.updateQueue,f!==null&&(f=f.stores,f!==null)))for(var h=0;h<f.length;h++){var S=f[h],T=S.getSnapshot;S=S.value;try{if(!Yn(T(),S))return!1}catch{return!1}}if(f=c.child,c.subtreeFlags&16384&&f!==null)f.return=c,c=f;else{if(c===i)break;for(;c.sibling===null;){if(c.return===null||c.return===i)return!0;c=c.return}c.sibling.return=c.return,c=c.sibling}}return!0}function Na(i,c,f,h){c&=~fh,c&=~ei,i.suspendedLanes|=c,i.pingedLanes&=~c,h&&(i.warmLanes|=c),h=i.expirationTimes;for(var S=c;0<S;){var T=31-wt(S),F=1<<T;h[T]=-1,S&=~F}f!==0&&Pn(i,f,c)}function Zu(){return jt&6?!0:(jl(0),!1)}function vh(){if(ft!==null){if(Mt===0)var i=ft.return;else i=ft,wa=Xo=null,Tg(i),$i=null,Sl=0,i=ft;for(;i!==null;)iC(i.alternate,i),i=i.return;ft=null}}function ns(i,c){i.finishedWork=null,i.finishedLanes=0;var f=i.timeoutHandle;f!==-1&&(i.timeoutHandle=-1,I$(f)),f=i.cancelPendingCommit,f!==null&&(i.cancelPendingCommit=null,f()),vh(),Lt=i,ft=f=so(i.current,null),vt=c,Mt=0,Zn=null,Ca=!1,es=Xe(i,c),dh=!1,ts=br=fh=ei=lo=qt=0,Xr=Fl=null,ph=!1,c&8&&(c|=c&32);var h=i.entangledLanes;if(h!==0)for(i=i.entanglements,h&=c;0<h;){var S=31-wt(h),T=1<<S;c|=i[S],h&=~T}return _a=c,Eu(),f}function uC(i,c){ct=null,I.H=Kr,c===yl?(c=T1(),Mt=3):c===w1?(c=T1(),Mt=4):Mt=c===xR?8:c!==null&&typeof c=="object"&&typeof c.then=="function"?6:1,Zn=c,ft===null&&(qt=1,Uu(i,ur(c,i.current)))}function dC(){var i=I.H;return I.H=Kr,i===null?Kr:i}function fC(){var i=I.A;return I.A=d$,i}function Sh(){qt=4,Ca||(vt&4194176)!==vt&&pr.current!==null||(es=!0),!(lo&134217727)&&!(ei&134217727)||Lt===null||Na(Lt,vt,br,!1)}function Eh(i,c,f){var h=jt;jt|=2;var S=dC(),T=fC();(Lt!==i||vt!==c)&&(Ku=null,ns(i,c)),c=!1;var F=qt;e:do try{if(Mt!==0&&ft!==null){var q=ft,X=Zn;switch(Mt){case 8:vh(),F=6;break e;case 3:case 2:case 6:pr.current===null&&(c=!0);var re=Mt;if(Mt=0,Zn=null,rs(i,q,X,re),f&&es){F=0;break e}break;default:re=Mt,Mt=0,Zn=null,rs(i,q,X,re)}}g$(),F=qt;break}catch(ve){uC(i,ve)}while(!0);return c&&i.shellSuspendCounter++,wa=Xo=null,jt=h,I.H=S,I.A=T,ft===null&&(Lt=null,vt=0,Eu()),F}function g$(){for(;ft!==null;)pC(ft)}function h$(i,c){var f=jt;jt|=2;var h=dC(),S=fC();Lt!==i||vt!==c?(Ku=null,Yu=ye()+500,ns(i,c)):es=Xe(i,c);e:do try{if(Mt!==0&&ft!==null){c=ft;var T=Zn;t:switch(Mt){case 1:Mt=0,Zn=null,rs(i,c,T,1);break;case 2:if(x1(T)){Mt=0,Zn=null,gC(c);break}c=function(){Mt===2&&Lt===i&&(Mt=7),Zr(i)},T.then(c,c);break e;case 3:Mt=7;break e;case 4:Mt=5;break e;case 7:x1(T)?(Mt=0,Zn=null,gC(c)):(Mt=0,Zn=null,rs(i,c,T,7));break;case 5:var F=null;switch(ft.tag){case 26:F=ft.memoizedState;case 5:case 27:var q=ft;if(!F||HC(F)){Mt=0,Zn=null;var X=q.sibling;if(X!==null)ft=X;else{var re=q.return;re!==null?(ft=re,Qu(re)):ft=null}break t}}Mt=0,Zn=null,rs(i,c,T,5);break;case 6:Mt=0,Zn=null,rs(i,c,T,6);break;case 8:vh(),qt=6;break e;default:throw Error(r(462))}}m$();break}catch(ve){uC(i,ve)}while(!0);return wa=Xo=null,I.H=h,I.A=S,jt=f,ft!==null?0:(Lt=null,vt=0,Eu(),qt)}function m$(){for(;ft!==null&&!Be();)pC(ft)}function pC(i){var c=MR(i.alternate,i,_a);i.memoizedProps=i.pendingProps,c===null?Qu(i):ft=c}function gC(i){var c=i,f=c.alternate;switch(c.tag){case 15:case 0:c=_R(f,c,c.pendingProps,c.type,void 0,vt);break;case 11:c=_R(f,c,c.pendingProps,c.type.render,c.ref,vt);break;case 5:Tg(c);default:iC(f,c),c=ft=rC(c,_a),c=MR(f,c,_a)}i.memoizedProps=i.pendingProps,c===null?Qu(i):ft=c}function rs(i,c,f,h){wa=Xo=null,Tg(c),$i=null,Sl=0;var S=c.return;try{if(a$(i,S,c,f,vt)){qt=1,Uu(i,ur(f,i.current)),ft=null;return}}catch(T){if(S!==null)throw ft=S,T;qt=1,Uu(i,ur(f,i.current)),ft=null;return}c.flags&32768?(xt||h===1?i=!0:es||vt&536870912?i=!1:(Ca=i=!0,(h===2||h===3||h===6)&&(h=pr.current,h!==null&&h.tag===13&&(h.flags|=16384))),hC(c,i)):Qu(c)}function Qu(i){var c=i;do{if(c.flags&32768){hC(c,Ca);return}i=c.return;var f=c$(c.alternate,c,_a);if(f!==null){ft=f;return}if(c=c.sibling,c!==null){ft=c;return}ft=c=i}while(c!==null);qt===0&&(qt=5)}function hC(i,c){do{var f=u$(i.alternate,i);if(f!==null){f.flags&=32767,ft=f;return}if(f=i.return,f!==null&&(f.flags|=32768,f.subtreeFlags=0,f.deletions=null),!c&&(i=i.sibling,i!==null)){ft=i;return}ft=i=f}while(i!==null);qt=6,ft=null}function mC(i,c,f,h,S,T,F,q,X,re){var ve=I.T,Ce=Z.p;try{Z.p=2,I.T=null,b$(i,c,f,h,Ce,S,T,F,q,X,re)}finally{I.T=ve,Z.p=Ce}}function b$(i,c,f,h,S,T,F,q){do as();while(ti!==null);if(jt&6)throw Error(r(327));var X=i.finishedWork;if(h=i.finishedLanes,X===null)return null;if(i.finishedWork=null,i.finishedLanes=0,X===i.current)throw Error(r(177));i.callbackNode=null,i.callbackPriority=0,i.cancelPendingCommit=null;var re=X.lanes|X.childLanes;if(re|=ug,ga(i,h,re,T,F,q),i===Lt&&(ft=Lt=null,vt=0),!(X.subtreeFlags&10256)&&!(X.flags&10256)||Xu||(Xu=!0,hh=re,mh=f,E$(Ne,function(){return as(),null})),f=(X.flags&15990)!==0,X.subtreeFlags&15990||f?(f=I.T,I.T=null,T=Z.p,Z.p=2,F=jt,jt|=4,i$(i,X),XR(X,i),U6(Dh,i.containerInfo),ud=!!Ih,Dh=Ih=null,i.current=X,VR(i,X.alternate,X),je(),jt=F,Z.p=T,I.T=f):i.current=X,Xu?(Xu=!1,ti=i,zl=h):bC(i,re),re=i.pendingLanes,re===0&&(co=null),At(X.stateNode),Zr(i),c!==null)for(S=i.onRecoverableError,X=0;X<c.length;X++)re=c[X],S(re.value,{componentStack:re.stack});return zl&3&&as(),re=i.pendingLanes,h&4194218&&re&42?i===bh?Bl++:(Bl=0,bh=i):Bl=0,jl(0),null}function bC(i,c){(i.pooledCacheLanes&=c)===0&&(c=i.pooledCache,c!=null&&(i.pooledCache=null,wl(c)))}function as(){if(ti!==null){var i=ti,c=hh;hh=0;var f=AA(zl),h=I.T,S=Z.p;try{if(Z.p=32>f?32:f,I.T=null,ti===null)var T=!1;else{f=mh,mh=null;var F=ti,q=zl;if(ti=null,zl=0,jt&6)throw Error(r(331));var X=jt;if(jt|=4,tC(F.current),QR(F,F.current,q,f),jt=X,jl(0,!1),et&&typeof et.onPostCommitFiberRoot=="function")try{et.onPostCommitFiberRoot(bt,F)}catch{}T=!0}return T}finally{Z.p=S,I.T=h,bC(i,c)}}return!1}function yC(i,c,f){c=ur(f,c),c=Bg(i.stateNode,c,2),i=ro(i,c,2),i!==null&&(Mn(i,2),Zr(i))}function Ot(i,c,f){if(i.tag===3)yC(i,i,f);else for(;c!==null;){if(c.tag===3){yC(c,i,f);break}else if(c.tag===1){var h=c.stateNode;if(typeof c.type.getDerivedStateFromError=="function"||typeof h.componentDidCatch=="function"&&(co===null||!co.has(h))){i=ur(f,i),f=ER(2),h=ro(c,f,2),h!==null&&(wR(f,h,c,i),Mn(h,2),Zr(h));break}}c=c.return}}function wh(i,c,f){var h=i.pingCache;if(h===null){h=i.pingCache=new f$;var S=new Set;h.set(c,S)}else S=h.get(c),S===void 0&&(S=new Set,h.set(c,S));S.has(f)||(dh=!0,S.add(f),i=y$.bind(null,i,c,f),c.then(i,i))}function y$(i,c,f){var h=i.pingCache;h!==null&&h.delete(c),i.pingedLanes|=i.suspendedLanes&f,i.warmLanes&=~f,Lt===i&&(vt&f)===f&&(qt===4||qt===3&&(vt&62914560)===vt&&300>ye()-gh?!(jt&2)&&ns(i,0):fh|=f,ts===vt&&(ts=0)),Zr(i)}function vC(i,c){c===0&&(c=Ln()),i=Ka(i,c),i!==null&&(Mn(i,c),Zr(i))}function v$(i){var c=i.memoizedState,f=0;c!==null&&(f=c.retryLane),vC(i,f)}function S$(i,c){var f=0;switch(i.tag){case 13:var h=i.stateNode,S=i.memoizedState;S!==null&&(f=S.retryLane);break;case 19:h=i.stateNode;break;case 22:h=i.stateNode._retryCache;break;default:throw Error(r(314))}h!==null&&h.delete(c),vC(i,f)}function E$(i,c){return Ee(i,c)}var Ju=null,os=null,xh=!1,ed=!1,kh=!1,ni=0;function Zr(i){i!==os&&i.next===null&&(os===null?Ju=os=i:os=os.next=i),ed=!0,xh||(xh=!0,x$(w$))}function jl(i,c){if(!kh&&ed){kh=!0;do for(var f=!1,h=Ju;h!==null;){if(i!==0){var S=h.pendingLanes;if(S===0)var T=0;else{var F=h.suspendedLanes,q=h.pingedLanes;T=(1<<31-wt(42|i)+1)-1,T&=S&~(F&~q),T=T&201326677?T&201326677|1:T?T|2:0}T!==0&&(f=!0,wC(h,T))}else T=vt,T=pa(h,h===Lt?T:0),!(T&3)||Xe(h,T)||(f=!0,wC(h,T));h=h.next}while(f);kh=!1}}function w$(){ed=xh=!1;var i=0;ni!==0&&(O$()&&(i=ni),ni=0);for(var c=ye(),f=null,h=Ju;h!==null;){var S=h.next,T=SC(h,c);T===0?(h.next=null,f===null?Ju=S:f.next=S,S===null&&(os=f)):(f=h,(i!==0||T&3)&&(ed=!0)),h=S}jl(i)}function SC(i,c){for(var f=i.suspendedLanes,h=i.pingedLanes,S=i.expirationTimes,T=i.pendingLanes&-62914561;0<T;){var F=31-wt(T),q=1<<F,X=S[F];X===-1?(!(q&f)||q&h)&&(S[F]=yt(q,c)):X<=c&&(i.expiredLanes|=q),T&=~q}if(c=Lt,f=vt,f=pa(i,i===c?f:0),h=i.callbackNode,f===0||i===c&&Mt===2||i.cancelPendingCommit!==null)return h!==null&&h!==null&&se(h),i.callbackNode=null,i.callbackPriority=0;if(!(f&3)||Xe(i,f)){if(c=f&-f,c===i.callbackPriority)return c;switch(h!==null&&se(h),AA(f)){case 2:case 8:f=de;break;case 32:f=Ne;break;case 268435456:f=We;break;default:f=Ne}return h=EC.bind(null,i),f=Ee(f,h),i.callbackPriority=c,i.callbackNode=f,c}return h!==null&&h!==null&&se(h),i.callbackPriority=2,i.callbackNode=null,2}function EC(i,c){var f=i.callbackNode;if(as()&&i.callbackNode!==f)return null;var h=vt;return h=pa(i,i===Lt?h:0),h===0?null:(lC(i,h,c),SC(i,ye()),i.callbackNode!=null&&i.callbackNode===f?EC.bind(null,i):null)}function wC(i,c){if(as())return null;lC(i,c,!0)}function x$(i){D$(function(){jt&6?Ee(ee,i):i()})}function Th(){return ni===0&&(ni=Nt()),ni}function xC(i){return i==null||typeof i=="symbol"||typeof i=="boolean"?null:typeof i=="function"?i:gu(""+i)}function kC(i,c){var f=c.ownerDocument.createElement("input");return f.name=c.name,f.value=c.value,i.id&&f.setAttribute("form",i.id),c.parentNode.insertBefore(f,c),i=new FormData(i),f.parentNode.removeChild(f),i}function k$(i,c,f,h,S){if(c==="submit"&&f&&f.stateNode===S){var T=xC((S[Fn]||null).action),F=h.submitter;F&&(c=(c=F[Fn]||null)?xC(c.formAction):F.getAttribute("formAction"),c!==null&&(T=c,F=null));var q=new yu("action","action",null,h,S);i.push({event:q,listeners:[{instance:null,listener:function(){if(h.defaultPrevented){if(ni!==0){var X=F?kC(S,F):new FormData(S);Lg(f,{pending:!0,data:X,method:S.method,action:T},null,X)}}else typeof T=="function"&&(q.preventDefault(),X=F?kC(S,F):new FormData(S),Lg(f,{pending:!0,data:X,method:S.method,action:T},T,X))},currentTarget:S}]})}}for(var Ah=0;Ah<m1.length;Ah++){var Rh=m1[Ah],T$=Rh.toLowerCase(),A$=Rh[0].toUpperCase()+Rh.slice(1);Nr(T$,"on"+A$)}Nr(d1,"onAnimationEnd"),Nr(f1,"onAnimationIteration"),Nr(p1,"onAnimationStart"),Nr("dblclick","onDoubleClick"),Nr("focusin","onFocus"),Nr("focusout","onBlur"),Nr(H6,"onTransitionRun"),Nr($6,"onTransitionStart"),Nr(q6,"onTransitionCancel"),Nr(g1,"onTransitionEnd"),Ii("onMouseEnter",["mouseout","mouseover"]),Ii("onMouseLeave",["mouseout","mouseover"]),Ii("onPointerEnter",["pointerout","pointerover"]),Ii("onPointerLeave",["pointerout","pointerover"]),Fo("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Fo("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Fo("onBeforeInput",["compositionend","keypress","textInput","paste"]),Fo("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Fo("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Fo("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Ul="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),R$=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Ul));function TC(i,c){c=(c&4)!==0;for(var f=0;f<i.length;f++){var h=i[f],S=h.event;h=h.listeners;e:{var T=void 0;if(c)for(var F=h.length-1;0<=F;F--){var q=h[F],X=q.instance,re=q.currentTarget;if(q=q.listener,X!==T&&S.isPropagationStopped())break e;T=q,S.currentTarget=re;try{T(S)}catch(ve){ju(ve)}S.currentTarget=null,T=X}else for(F=0;F<h.length;F++){if(q=h[F],X=q.instance,re=q.currentTarget,q=q.listener,X!==T&&S.isPropagationStopped())break e;T=q,S.currentTarget=re;try{T(S)}catch(ve){ju(ve)}S.currentTarget=null,T=X}}}}function ht(i,c){var f=c[Hp];f===void 0&&(f=c[Hp]=new Set);var h=i+"__bubble";f.has(h)||(AC(c,i,2,!1),f.add(h))}function Ch(i,c,f){var h=0;c&&(h|=4),AC(f,i,h,c)}var td="_reactListening"+Math.random().toString(36).slice(2);function _h(i){if(!i[td]){i[td]=!0,_A.forEach(function(f){f!=="selectionchange"&&(R$.has(f)||Ch(f,!1,i),Ch(f,!0,i))});var c=i.nodeType===9?i:i.ownerDocument;c===null||c[td]||(c[td]=!0,Ch("selectionchange",!1,c))}}function AC(i,c,f,h){switch(KC(c)){case 2:var S=J$;break;case 8:S=eq;break;default:S=Gh}f=S.bind(null,c,f,i),S=void 0,!Zp||c!=="touchstart"&&c!=="touchmove"&&c!=="wheel"||(S=!0),h?S!==void 0?i.addEventListener(c,f,{capture:!0,passive:S}):i.addEventListener(c,f,!0):S!==void 0?i.addEventListener(c,f,{passive:S}):i.addEventListener(c,f,!1)}function Nh(i,c,f,h,S){var T=h;if(!(c&1)&&!(c&2)&&h!==null)e:for(;;){if(h===null)return;var F=h.tag;if(F===3||F===4){var q=h.stateNode.containerInfo;if(q===S||q.nodeType===8&&q.parentNode===S)break;if(F===4)for(F=h.return;F!==null;){var X=F.tag;if((X===3||X===4)&&(X=F.stateNode.containerInfo,X===S||X.nodeType===8&&X.parentNode===S))return;F=F.return}for(;q!==null;){if(F=Po(q),F===null)return;if(X=F.tag,X===5||X===6||X===26||X===27){h=T=F;continue e}q=q.parentNode}}h=h.return}UA(function(){var re=T,ve=Kp(f),Ce=[];e:{var fe=h1.get(i);if(fe!==void 0){var me=yu,qe=i;switch(i){case"keypress":if(mu(f)===0)break e;case"keydown":case"keyup":me=S6;break;case"focusin":qe="focus",me=tg;break;case"focusout":qe="blur",me=tg;break;case"beforeblur":case"afterblur":me=tg;break;case"click":if(f.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":me=$A;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":me=l6;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":me=x6;break;case d1:case f1:case p1:me=d6;break;case g1:me=T6;break;case"scroll":case"scrollend":me=i6;break;case"wheel":me=R6;break;case"copy":case"cut":case"paste":me=p6;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":me=VA;break;case"toggle":case"beforetoggle":me=_6}var rt=(c&4)!==0,Vt=!rt&&(i==="scroll"||i==="scrollend"),le=rt?fe!==null?fe+"Capture":null:fe;rt=[];for(var te=re,ue;te!==null;){var Ae=te;if(ue=Ae.stateNode,Ae=Ae.tag,Ae!==5&&Ae!==26&&Ae!==27||ue===null||le===null||(Ae=il(te,le),Ae!=null&&rt.push(Gl(te,Ae,ue))),Vt)break;te=te.return}0<rt.length&&(fe=new me(fe,qe,null,f,ve),Ce.push({event:fe,listeners:rt}))}}if(!(c&7)){e:{if(fe=i==="mouseover"||i==="pointerover",me=i==="mouseout"||i==="pointerout",fe&&f!==Yp&&(qe=f.relatedTarget||f.fromElement)&&(Po(qe)||qe[_i]))break e;if((me||fe)&&(fe=ve.window===ve?ve:(fe=ve.ownerDocument)?fe.defaultView||fe.parentWindow:window,me?(qe=f.relatedTarget||f.toElement,me=re,qe=qe?Po(qe):null,qe!==null&&(Vt=z(qe),rt=qe.tag,qe!==Vt||rt!==5&&rt!==27&&rt!==6)&&(qe=null)):(me=null,qe=re),me!==qe)){if(rt=$A,Ae="onMouseLeave",le="onMouseEnter",te="mouse",(i==="pointerout"||i==="pointerover")&&(rt=VA,Ae="onPointerLeave",le="onPointerEnter",te="pointer"),Vt=me==null?fe:ol(me),ue=qe==null?fe:ol(qe),fe=new rt(Ae,te+"leave",me,f,ve),fe.target=Vt,fe.relatedTarget=ue,Ae=null,Po(ve)===re&&(rt=new rt(le,te+"enter",qe,f,ve),rt.target=ue,rt.relatedTarget=Vt,Ae=rt),Vt=Ae,me&&qe)t:{for(rt=me,le=qe,te=0,ue=rt;ue;ue=is(ue))te++;for(ue=0,Ae=le;Ae;Ae=is(Ae))ue++;for(;0<te-ue;)rt=is(rt),te--;for(;0<ue-te;)le=is(le),ue--;for(;te--;){if(rt===le||le!==null&&rt===le.alternate)break t;rt=is(rt),le=is(le)}rt=null}else rt=null;me!==null&&RC(Ce,fe,me,rt,!1),qe!==null&&Vt!==null&&RC(Ce,Vt,qe,rt,!0)}}e:{if(fe=re?ol(re):window,me=fe.nodeName&&fe.nodeName.toLowerCase(),me==="select"||me==="input"&&fe.type==="file")var Ge=e1;else if(QA(fe))if(t1)Ge=B6;else{Ge=F6;var ut=P6}else me=fe.nodeName,!me||me.toLowerCase()!=="input"||fe.type!=="checkbox"&&fe.type!=="radio"?re&&Wp(re.elementType)&&(Ge=e1):Ge=z6;if(Ge&&(Ge=Ge(i,re))){JA(Ce,Ge,f,ve);break e}ut&&ut(i,fe,re),i==="focusout"&&re&&fe.type==="number"&&re.memoizedProps.value!=null&&Vp(fe,"number",fe.value)}switch(ut=re?ol(re):window,i){case"focusin":(QA(ut)||ut.contentEditable==="true")&&(zi=ut,sg=re,gl=null);break;case"focusout":gl=sg=zi=null;break;case"mousedown":lg=!0;break;case"contextmenu":case"mouseup":case"dragend":lg=!1,c1(Ce,f,ve);break;case"selectionchange":if(G6)break;case"keydown":case"keyup":c1(Ce,f,ve)}var Ye;if(rg)e:{switch(i){case"compositionstart":var Qe="onCompositionStart";break e;case"compositionend":Qe="onCompositionEnd";break e;case"compositionupdate":Qe="onCompositionUpdate";break e}Qe=void 0}else Fi?XA(i,f)&&(Qe="onCompositionEnd"):i==="keydown"&&f.keyCode===229&&(Qe="onCompositionStart");Qe&&(WA&&f.locale!=="ko"&&(Fi||Qe!=="onCompositionStart"?Qe==="onCompositionEnd"&&Fi&&(Ye=GA()):(Ya=ve,Qp="value"in Ya?Ya.value:Ya.textContent,Fi=!0)),ut=nd(re,Qe),0<ut.length&&(Qe=new qA(Qe,i,null,f,ve),Ce.push({event:Qe,listeners:ut}),Ye?Qe.data=Ye:(Ye=ZA(f),Ye!==null&&(Qe.data=Ye)))),(Ye=O6?I6(i,f):D6(i,f))&&(Qe=nd(re,"onBeforeInput"),0<Qe.length&&(ut=new qA("onBeforeInput","beforeinput",null,f,ve),Ce.push({event:ut,listeners:Qe}),ut.data=Ye)),k$(Ce,i,re,f,ve)}TC(Ce,c)})}function Gl(i,c,f){return{instance:i,listener:c,currentTarget:f}}function nd(i,c){for(var f=c+"Capture",h=[];i!==null;){var S=i,T=S.stateNode;S=S.tag,S!==5&&S!==26&&S!==27||T===null||(S=il(i,f),S!=null&&h.unshift(Gl(i,S,T)),S=il(i,c),S!=null&&h.push(Gl(i,S,T))),i=i.return}return h}function is(i){if(i===null)return null;do i=i.return;while(i&&i.tag!==5&&i.tag!==27);return i||null}function RC(i,c,f,h,S){for(var T=c._reactName,F=[];f!==null&&f!==h;){var q=f,X=q.alternate,re=q.stateNode;if(q=q.tag,X!==null&&X===h)break;q!==5&&q!==26&&q!==27||re===null||(X=re,S?(re=il(f,T),re!=null&&F.unshift(Gl(f,re,X))):S||(re=il(f,T),re!=null&&F.push(Gl(f,re,X)))),f=f.return}F.length!==0&&i.push({event:c,listeners:F})}var C$=/\r\n?/g,_$=/\u0000|\uFFFD/g;function CC(i){return(typeof i=="string"?i:""+i).replace(C$,`
`).replace(_$,"")}function _C(i,c){return c=CC(c),CC(i)===c}function rd(){}function Ct(i,c,f,h,S,T){switch(f){case"children":typeof h=="string"?c==="body"||c==="textarea"&&h===""||Li(i,h):(typeof h=="number"||typeof h=="bigint")&&c!=="body"&&Li(i,""+h);break;case"className":du(i,"class",h);break;case"tabIndex":du(i,"tabindex",h);break;case"dir":case"role":case"viewBox":case"width":case"height":du(i,f,h);break;case"style":BA(i,h,T);break;case"data":if(c!=="object"){du(i,"data",h);break}case"src":case"href":if(h===""&&(c!=="a"||f!=="href")){i.removeAttribute(f);break}if(h==null||typeof h=="function"||typeof h=="symbol"||typeof h=="boolean"){i.removeAttribute(f);break}h=gu(""+h),i.setAttribute(f,h);break;case"action":case"formAction":if(typeof h=="function"){i.setAttribute(f,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof T=="function"&&(f==="formAction"?(c!=="input"&&Ct(i,c,"name",S.name,S,null),Ct(i,c,"formEncType",S.formEncType,S,null),Ct(i,c,"formMethod",S.formMethod,S,null),Ct(i,c,"formTarget",S.formTarget,S,null)):(Ct(i,c,"encType",S.encType,S,null),Ct(i,c,"method",S.method,S,null),Ct(i,c,"target",S.target,S,null)));if(h==null||typeof h=="symbol"||typeof h=="boolean"){i.removeAttribute(f);break}h=gu(""+h),i.setAttribute(f,h);break;case"onClick":h!=null&&(i.onclick=rd);break;case"onScroll":h!=null&&ht("scroll",i);break;case"onScrollEnd":h!=null&&ht("scrollend",i);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(f=h.__html,f!=null){if(S.children!=null)throw Error(r(60));i.innerHTML=f}}break;case"multiple":i.multiple=h&&typeof h!="function"&&typeof h!="symbol";break;case"muted":i.muted=h&&typeof h!="function"&&typeof h!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(h==null||typeof h=="function"||typeof h=="boolean"||typeof h=="symbol"){i.removeAttribute("xlink:href");break}f=gu(""+h),i.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",f);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":h!=null&&typeof h!="function"&&typeof h!="symbol"?i.setAttribute(f,""+h):i.removeAttribute(f);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":h&&typeof h!="function"&&typeof h!="symbol"?i.setAttribute(f,""):i.removeAttribute(f);break;case"capture":case"download":h===!0?i.setAttribute(f,""):h!==!1&&h!=null&&typeof h!="function"&&typeof h!="symbol"?i.setAttribute(f,h):i.removeAttribute(f);break;case"cols":case"rows":case"size":case"span":h!=null&&typeof h!="function"&&typeof h!="symbol"&&!isNaN(h)&&1<=h?i.setAttribute(f,h):i.removeAttribute(f);break;case"rowSpan":case"start":h==null||typeof h=="function"||typeof h=="symbol"||isNaN(h)?i.removeAttribute(f):i.setAttribute(f,h);break;case"popover":ht("beforetoggle",i),ht("toggle",i),uu(i,"popover",h);break;case"xlinkActuate":ma(i,"http://www.w3.org/1999/xlink","xlink:actuate",h);break;case"xlinkArcrole":ma(i,"http://www.w3.org/1999/xlink","xlink:arcrole",h);break;case"xlinkRole":ma(i,"http://www.w3.org/1999/xlink","xlink:role",h);break;case"xlinkShow":ma(i,"http://www.w3.org/1999/xlink","xlink:show",h);break;case"xlinkTitle":ma(i,"http://www.w3.org/1999/xlink","xlink:title",h);break;case"xlinkType":ma(i,"http://www.w3.org/1999/xlink","xlink:type",h);break;case"xmlBase":ma(i,"http://www.w3.org/XML/1998/namespace","xml:base",h);break;case"xmlLang":ma(i,"http://www.w3.org/XML/1998/namespace","xml:lang",h);break;case"xmlSpace":ma(i,"http://www.w3.org/XML/1998/namespace","xml:space",h);break;case"is":uu(i,"is",h);break;case"innerText":case"textContent":break;default:(!(2<f.length)||f[0]!=="o"&&f[0]!=="O"||f[1]!=="n"&&f[1]!=="N")&&(f=a6.get(f)||f,uu(i,f,h))}}function Oh(i,c,f,h,S,T){switch(f){case"style":BA(i,h,T);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(f=h.__html,f!=null){if(S.children!=null)throw Error(r(60));i.innerHTML=f}}break;case"children":typeof h=="string"?Li(i,h):(typeof h=="number"||typeof h=="bigint")&&Li(i,""+h);break;case"onScroll":h!=null&&ht("scroll",i);break;case"onScrollEnd":h!=null&&ht("scrollend",i);break;case"onClick":h!=null&&(i.onclick=rd);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!NA.hasOwnProperty(f))e:{if(f[0]==="o"&&f[1]==="n"&&(S=f.endsWith("Capture"),c=f.slice(2,S?f.length-7:void 0),T=i[Fn]||null,T=T!=null?T[f]:null,typeof T=="function"&&i.removeEventListener(c,T,S),typeof h=="function")){typeof T!="function"&&T!==null&&(f in i?i[f]=null:i.hasAttribute(f)&&i.removeAttribute(f)),i.addEventListener(c,h,S);break e}f in i?i[f]=h:h===!0?i.setAttribute(f,""):uu(i,f,h)}}}function mn(i,c,f){switch(c){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":ht("error",i),ht("load",i);var h=!1,S=!1,T;for(T in f)if(f.hasOwnProperty(T)){var F=f[T];if(F!=null)switch(T){case"src":h=!0;break;case"srcSet":S=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,c));default:Ct(i,c,T,F,f,null)}}S&&Ct(i,c,"srcSet",f.srcSet,f,null),h&&Ct(i,c,"src",f.src,f,null);return;case"input":ht("invalid",i);var q=T=F=S=null,X=null,re=null;for(h in f)if(f.hasOwnProperty(h)){var ve=f[h];if(ve!=null)switch(h){case"name":S=ve;break;case"type":F=ve;break;case"checked":X=ve;break;case"defaultChecked":re=ve;break;case"value":T=ve;break;case"defaultValue":q=ve;break;case"children":case"dangerouslySetInnerHTML":if(ve!=null)throw Error(r(137,c));break;default:Ct(i,c,h,ve,f,null)}}MA(i,T,q,X,re,F,S,!1),fu(i);return;case"select":ht("invalid",i),h=F=T=null;for(S in f)if(f.hasOwnProperty(S)&&(q=f[S],q!=null))switch(S){case"value":T=q;break;case"defaultValue":F=q;break;case"multiple":h=q;default:Ct(i,c,S,q,f,null)}c=T,f=F,i.multiple=!!h,c!=null?Di(i,!!h,c,!1):f!=null&&Di(i,!!h,f,!0);return;case"textarea":ht("invalid",i),T=S=h=null;for(F in f)if(f.hasOwnProperty(F)&&(q=f[F],q!=null))switch(F){case"value":h=q;break;case"defaultValue":S=q;break;case"children":T=q;break;case"dangerouslySetInnerHTML":if(q!=null)throw Error(r(91));break;default:Ct(i,c,F,q,f,null)}FA(i,h,S,T),fu(i);return;case"option":for(X in f)if(f.hasOwnProperty(X)&&(h=f[X],h!=null))switch(X){case"selected":i.selected=h&&typeof h!="function"&&typeof h!="symbol";break;default:Ct(i,c,X,h,f,null)}return;case"dialog":ht("cancel",i),ht("close",i);break;case"iframe":case"object":ht("load",i);break;case"video":case"audio":for(h=0;h<Ul.length;h++)ht(Ul[h],i);break;case"image":ht("error",i),ht("load",i);break;case"details":ht("toggle",i);break;case"embed":case"source":case"link":ht("error",i),ht("load",i);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(re in f)if(f.hasOwnProperty(re)&&(h=f[re],h!=null))switch(re){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,c));default:Ct(i,c,re,h,f,null)}return;default:if(Wp(c)){for(ve in f)f.hasOwnProperty(ve)&&(h=f[ve],h!==void 0&&Oh(i,c,ve,h,f,void 0));return}}for(q in f)f.hasOwnProperty(q)&&(h=f[q],h!=null&&Ct(i,c,q,h,f,null))}function N$(i,c,f,h){switch(c){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var S=null,T=null,F=null,q=null,X=null,re=null,ve=null;for(me in f){var Ce=f[me];if(f.hasOwnProperty(me)&&Ce!=null)switch(me){case"checked":break;case"value":break;case"defaultValue":X=Ce;default:h.hasOwnProperty(me)||Ct(i,c,me,null,h,Ce)}}for(var fe in h){var me=h[fe];if(Ce=f[fe],h.hasOwnProperty(fe)&&(me!=null||Ce!=null))switch(fe){case"type":T=me;break;case"name":S=me;break;case"checked":re=me;break;case"defaultChecked":ve=me;break;case"value":F=me;break;case"defaultValue":q=me;break;case"children":case"dangerouslySetInnerHTML":if(me!=null)throw Error(r(137,c));break;default:me!==Ce&&Ct(i,c,fe,me,h,Ce)}}qp(i,F,q,X,re,ve,T,S);return;case"select":me=F=q=fe=null;for(T in f)if(X=f[T],f.hasOwnProperty(T)&&X!=null)switch(T){case"value":break;case"multiple":me=X;default:h.hasOwnProperty(T)||Ct(i,c,T,null,h,X)}for(S in h)if(T=h[S],X=f[S],h.hasOwnProperty(S)&&(T!=null||X!=null))switch(S){case"value":fe=T;break;case"defaultValue":q=T;break;case"multiple":F=T;default:T!==X&&Ct(i,c,S,T,h,X)}c=q,f=F,h=me,fe!=null?Di(i,!!f,fe,!1):!!h!=!!f&&(c!=null?Di(i,!!f,c,!0):Di(i,!!f,f?[]:"",!1));return;case"textarea":me=fe=null;for(q in f)if(S=f[q],f.hasOwnProperty(q)&&S!=null&&!h.hasOwnProperty(q))switch(q){case"value":break;case"children":break;default:Ct(i,c,q,null,h,S)}for(F in h)if(S=h[F],T=f[F],h.hasOwnProperty(F)&&(S!=null||T!=null))switch(F){case"value":fe=S;break;case"defaultValue":me=S;break;case"children":break;case"dangerouslySetInnerHTML":if(S!=null)throw Error(r(91));break;default:S!==T&&Ct(i,c,F,S,h,T)}PA(i,fe,me);return;case"option":for(var qe in f)if(fe=f[qe],f.hasOwnProperty(qe)&&fe!=null&&!h.hasOwnProperty(qe))switch(qe){case"selected":i.selected=!1;break;default:Ct(i,c,qe,null,h,fe)}for(X in h)if(fe=h[X],me=f[X],h.hasOwnProperty(X)&&fe!==me&&(fe!=null||me!=null))switch(X){case"selected":i.selected=fe&&typeof fe!="function"&&typeof fe!="symbol";break;default:Ct(i,c,X,fe,h,me)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var rt in f)fe=f[rt],f.hasOwnProperty(rt)&&fe!=null&&!h.hasOwnProperty(rt)&&Ct(i,c,rt,null,h,fe);for(re in h)if(fe=h[re],me=f[re],h.hasOwnProperty(re)&&fe!==me&&(fe!=null||me!=null))switch(re){case"children":case"dangerouslySetInnerHTML":if(fe!=null)throw Error(r(137,c));break;default:Ct(i,c,re,fe,h,me)}return;default:if(Wp(c)){for(var Vt in f)fe=f[Vt],f.hasOwnProperty(Vt)&&fe!==void 0&&!h.hasOwnProperty(Vt)&&Oh(i,c,Vt,void 0,h,fe);for(ve in h)fe=h[ve],me=f[ve],!h.hasOwnProperty(ve)||fe===me||fe===void 0&&me===void 0||Oh(i,c,ve,fe,h,me);return}}for(var le in f)fe=f[le],f.hasOwnProperty(le)&&fe!=null&&!h.hasOwnProperty(le)&&Ct(i,c,le,null,h,fe);for(Ce in h)fe=h[Ce],me=f[Ce],!h.hasOwnProperty(Ce)||fe===me||fe==null&&me==null||Ct(i,c,Ce,fe,h,me)}var Ih=null,Dh=null;function ad(i){return i.nodeType===9?i:i.ownerDocument}function NC(i){switch(i){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function OC(i,c){if(i===0)switch(c){case"svg":return 1;case"math":return 2;default:return 0}return i===1&&c==="foreignObject"?0:i}function Lh(i,c){return i==="textarea"||i==="noscript"||typeof c.children=="string"||typeof c.children=="number"||typeof c.children=="bigint"||typeof c.dangerouslySetInnerHTML=="object"&&c.dangerouslySetInnerHTML!==null&&c.dangerouslySetInnerHTML.__html!=null}var Mh=null;function O$(){var i=window.event;return i&&i.type==="popstate"?i===Mh?!1:(Mh=i,!0):(Mh=null,!1)}var IC=typeof setTimeout=="function"?setTimeout:void 0,I$=typeof clearTimeout=="function"?clearTimeout:void 0,DC=typeof Promise=="function"?Promise:void 0,D$=typeof queueMicrotask=="function"?queueMicrotask:typeof DC<"u"?function(i){return DC.resolve(null).then(i).catch(L$)}:IC;function L$(i){setTimeout(function(){throw i})}function Ph(i,c){var f=c,h=0;do{var S=f.nextSibling;if(i.removeChild(f),S&&S.nodeType===8)if(f=S.data,f==="/$"){if(h===0){i.removeChild(S),Xl(c);return}h--}else f!=="$"&&f!=="$?"&&f!=="$!"||h++;f=S}while(f);Xl(c)}function Fh(i){var c=i.firstChild;for(c&&c.nodeType===10&&(c=c.nextSibling);c;){var f=c;switch(c=c.nextSibling,f.nodeName){case"HTML":case"HEAD":case"BODY":Fh(f),$p(f);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(f.rel.toLowerCase()==="stylesheet")continue}i.removeChild(f)}}function M$(i,c,f,h){for(;i.nodeType===1;){var S=f;if(i.nodeName.toLowerCase()!==c.toLowerCase()){if(!h&&(i.nodeName!=="INPUT"||i.type!=="hidden"))break}else if(h){if(!i[al])switch(c){case"meta":if(!i.hasAttribute("itemprop"))break;return i;case"link":if(T=i.getAttribute("rel"),T==="stylesheet"&&i.hasAttribute("data-precedence"))break;if(T!==S.rel||i.getAttribute("href")!==(S.href==null?null:S.href)||i.getAttribute("crossorigin")!==(S.crossOrigin==null?null:S.crossOrigin)||i.getAttribute("title")!==(S.title==null?null:S.title))break;return i;case"style":if(i.hasAttribute("data-precedence"))break;return i;case"script":if(T=i.getAttribute("src"),(T!==(S.src==null?null:S.src)||i.getAttribute("type")!==(S.type==null?null:S.type)||i.getAttribute("crossorigin")!==(S.crossOrigin==null?null:S.crossOrigin))&&T&&i.hasAttribute("async")&&!i.hasAttribute("itemprop"))break;return i;default:return i}}else if(c==="input"&&i.type==="hidden"){var T=S.name==null?null:""+S.name;if(S.type==="hidden"&&i.getAttribute("name")===T)return i}else return i;if(i=Dr(i.nextSibling),i===null)break}return null}function P$(i,c,f){if(c==="")return null;for(;i.nodeType!==3;)if((i.nodeType!==1||i.nodeName!=="INPUT"||i.type!=="hidden")&&!f||(i=Dr(i.nextSibling),i===null))return null;return i}function Dr(i){for(;i!=null;i=i.nextSibling){var c=i.nodeType;if(c===1||c===3)break;if(c===8){if(c=i.data,c==="$"||c==="$!"||c==="$?"||c==="F!"||c==="F")break;if(c==="/$")return null}}return i}function LC(i){i=i.previousSibling;for(var c=0;i;){if(i.nodeType===8){var f=i.data;if(f==="$"||f==="$!"||f==="$?"){if(c===0)return i;c--}else f==="/$"&&c++}i=i.previousSibling}return null}function MC(i,c,f){switch(c=ad(f),i){case"html":if(i=c.documentElement,!i)throw Error(r(452));return i;case"head":if(i=c.head,!i)throw Error(r(453));return i;case"body":if(i=c.body,!i)throw Error(r(454));return i;default:throw Error(r(451))}}var yr=new Map,PC=new Set;function od(i){return typeof i.getRootNode=="function"?i.getRootNode():i.ownerDocument}var Oa=Z.d;Z.d={f:F$,r:z$,D:B$,C:j$,L:U$,m:G$,X:$$,S:H$,M:q$};function F$(){var i=Oa.f(),c=Zu();return i||c}function z$(i){var c=Ni(i);c!==null&&c.tag===5&&c.type==="form"?cR(c):Oa.r(i)}var ss=typeof document>"u"?null:document;function FC(i,c,f){var h=ss;if(h&&typeof c=="string"&&c){var S=lr(c);S='link[rel="'+i+'"][href="'+S+'"]',typeof f=="string"&&(S+='[crossorigin="'+f+'"]'),PC.has(S)||(PC.add(S),i={rel:i,crossOrigin:f,href:c},h.querySelector(S)===null&&(c=h.createElement("link"),mn(c,"link",i),an(c),h.head.appendChild(c)))}}function B$(i){Oa.D(i),FC("dns-prefetch",i,null)}function j$(i,c){Oa.C(i,c),FC("preconnect",i,c)}function U$(i,c,f){Oa.L(i,c,f);var h=ss;if(h&&i&&c){var S='link[rel="preload"][as="'+lr(c)+'"]';c==="image"&&f&&f.imageSrcSet?(S+='[imagesrcset="'+lr(f.imageSrcSet)+'"]',typeof f.imageSizes=="string"&&(S+='[imagesizes="'+lr(f.imageSizes)+'"]')):S+='[href="'+lr(i)+'"]';var T=S;switch(c){case"style":T=ls(i);break;case"script":T=cs(i)}yr.has(T)||(i=D({rel:"preload",href:c==="image"&&f&&f.imageSrcSet?void 0:i,as:c},f),yr.set(T,i),h.querySelector(S)!==null||c==="style"&&h.querySelector(Hl(T))||c==="script"&&h.querySelector($l(T))||(c=h.createElement("link"),mn(c,"link",i),an(c),h.head.appendChild(c)))}}function G$(i,c){Oa.m(i,c);var f=ss;if(f&&i){var h=c&&typeof c.as=="string"?c.as:"script",S='link[rel="modulepreload"][as="'+lr(h)+'"][href="'+lr(i)+'"]',T=S;switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":T=cs(i)}if(!yr.has(T)&&(i=D({rel:"modulepreload",href:i},c),yr.set(T,i),f.querySelector(S)===null)){switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(f.querySelector($l(T)))return}h=f.createElement("link"),mn(h,"link",i),an(h),f.head.appendChild(h)}}}function H$(i,c,f){Oa.S(i,c,f);var h=ss;if(h&&i){var S=Oi(h).hoistableStyles,T=ls(i);c=c||"default";var F=S.get(T);if(!F){var q={loading:0,preload:null};if(F=h.querySelector(Hl(T)))q.loading=5;else{i=D({rel:"stylesheet",href:i,"data-precedence":c},f),(f=yr.get(T))&&zh(i,f);var X=F=h.createElement("link");an(X),mn(X,"link",i),X._p=new Promise(function(re,ve){X.onload=re,X.onerror=ve}),X.addEventListener("load",function(){q.loading|=1}),X.addEventListener("error",function(){q.loading|=2}),q.loading|=4,id(F,c,h)}F={type:"stylesheet",instance:F,count:1,state:q},S.set(T,F)}}}function $$(i,c){Oa.X(i,c);var f=ss;if(f&&i){var h=Oi(f).hoistableScripts,S=cs(i),T=h.get(S);T||(T=f.querySelector($l(S)),T||(i=D({src:i,async:!0},c),(c=yr.get(S))&&Bh(i,c),T=f.createElement("script"),an(T),mn(T,"link",i),f.head.appendChild(T)),T={type:"script",instance:T,count:1,state:null},h.set(S,T))}}function q$(i,c){Oa.M(i,c);var f=ss;if(f&&i){var h=Oi(f).hoistableScripts,S=cs(i),T=h.get(S);T||(T=f.querySelector($l(S)),T||(i=D({src:i,async:!0,type:"module"},c),(c=yr.get(S))&&Bh(i,c),T=f.createElement("script"),an(T),mn(T,"link",i),f.head.appendChild(T)),T={type:"script",instance:T,count:1,state:null},h.set(S,T))}}function zC(i,c,f,h){var S=(S=xe.current)?od(S):null;if(!S)throw Error(r(446));switch(i){case"meta":case"title":return null;case"style":return typeof f.precedence=="string"&&typeof f.href=="string"?(c=ls(f.href),f=Oi(S).hoistableStyles,h=f.get(c),h||(h={type:"style",instance:null,count:0,state:null},f.set(c,h)),h):{type:"void",instance:null,count:0,state:null};case"link":if(f.rel==="stylesheet"&&typeof f.href=="string"&&typeof f.precedence=="string"){i=ls(f.href);var T=Oi(S).hoistableStyles,F=T.get(i);if(F||(S=S.ownerDocument||S,F={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},T.set(i,F),(T=S.querySelector(Hl(i)))&&!T._p&&(F.instance=T,F.state.loading=5),yr.has(i)||(f={rel:"preload",as:"style",href:f.href,crossOrigin:f.crossOrigin,integrity:f.integrity,media:f.media,hrefLang:f.hrefLang,referrerPolicy:f.referrerPolicy},yr.set(i,f),T||V$(S,i,f,F.state))),c&&h===null)throw Error(r(528,""));return F}if(c&&h!==null)throw Error(r(529,""));return null;case"script":return c=f.async,f=f.src,typeof f=="string"&&c&&typeof c!="function"&&typeof c!="symbol"?(c=cs(f),f=Oi(S).hoistableScripts,h=f.get(c),h||(h={type:"script",instance:null,count:0,state:null},f.set(c,h)),h):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,i))}}function ls(i){return'href="'+lr(i)+'"'}function Hl(i){return'link[rel="stylesheet"]['+i+"]"}function BC(i){return D({},i,{"data-precedence":i.precedence,precedence:null})}function V$(i,c,f,h){i.querySelector('link[rel="preload"][as="style"]['+c+"]")?h.loading=1:(c=i.createElement("link"),h.preload=c,c.addEventListener("load",function(){return h.loading|=1}),c.addEventListener("error",function(){return h.loading|=2}),mn(c,"link",f),an(c),i.head.appendChild(c))}function cs(i){return'[src="'+lr(i)+'"]'}function $l(i){return"script[async]"+i}function jC(i,c,f){if(c.count++,c.instance===null)switch(c.type){case"style":var h=i.querySelector('style[data-href~="'+lr(f.href)+'"]');if(h)return c.instance=h,an(h),h;var S=D({},f,{"data-href":f.href,"data-precedence":f.precedence,href:null,precedence:null});return h=(i.ownerDocument||i).createElement("style"),an(h),mn(h,"style",S),id(h,f.precedence,i),c.instance=h;case"stylesheet":S=ls(f.href);var T=i.querySelector(Hl(S));if(T)return c.state.loading|=4,c.instance=T,an(T),T;h=BC(f),(S=yr.get(S))&&zh(h,S),T=(i.ownerDocument||i).createElement("link"),an(T);var F=T;return F._p=new Promise(function(q,X){F.onload=q,F.onerror=X}),mn(T,"link",h),c.state.loading|=4,id(T,f.precedence,i),c.instance=T;case"script":return T=cs(f.src),(S=i.querySelector($l(T)))?(c.instance=S,an(S),S):(h=f,(S=yr.get(T))&&(h=D({},f),Bh(h,S)),i=i.ownerDocument||i,S=i.createElement("script"),an(S),mn(S,"link",h),i.head.appendChild(S),c.instance=S);case"void":return null;default:throw Error(r(443,c.type))}else c.type==="stylesheet"&&!(c.state.loading&4)&&(h=c.instance,c.state.loading|=4,id(h,f.precedence,i));return c.instance}function id(i,c,f){for(var h=f.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),S=h.length?h[h.length-1]:null,T=S,F=0;F<h.length;F++){var q=h[F];if(q.dataset.precedence===c)T=q;else if(T!==S)break}T?T.parentNode.insertBefore(i,T.nextSibling):(c=f.nodeType===9?f.head:f,c.insertBefore(i,c.firstChild))}function zh(i,c){i.crossOrigin==null&&(i.crossOrigin=c.crossOrigin),i.referrerPolicy==null&&(i.referrerPolicy=c.referrerPolicy),i.title==null&&(i.title=c.title)}function Bh(i,c){i.crossOrigin==null&&(i.crossOrigin=c.crossOrigin),i.referrerPolicy==null&&(i.referrerPolicy=c.referrerPolicy),i.integrity==null&&(i.integrity=c.integrity)}var sd=null;function UC(i,c,f){if(sd===null){var h=new Map,S=sd=new Map;S.set(f,h)}else S=sd,h=S.get(f),h||(h=new Map,S.set(f,h));if(h.has(i))return h;for(h.set(i,null),f=f.getElementsByTagName(i),S=0;S<f.length;S++){var T=f[S];if(!(T[al]||T[Sn]||i==="link"&&T.getAttribute("rel")==="stylesheet")&&T.namespaceURI!=="http://www.w3.org/2000/svg"){var F=T.getAttribute(c)||"";F=i+F;var q=h.get(F);q?q.push(T):h.set(F,[T])}}return h}function GC(i,c,f){i=i.ownerDocument||i,i.head.insertBefore(f,c==="title"?i.querySelector("head > title"):null)}function W$(i,c,f){if(f===1||c.itemProp!=null)return!1;switch(i){case"meta":case"title":return!0;case"style":if(typeof c.precedence!="string"||typeof c.href!="string"||c.href==="")break;return!0;case"link":if(typeof c.rel!="string"||typeof c.href!="string"||c.href===""||c.onLoad||c.onError)break;switch(c.rel){case"stylesheet":return i=c.disabled,typeof c.precedence=="string"&&i==null;default:return!0}case"script":if(c.async&&typeof c.async!="function"&&typeof c.async!="symbol"&&!c.onLoad&&!c.onError&&c.src&&typeof c.src=="string")return!0}return!1}function HC(i){return!(i.type==="stylesheet"&&!(i.state.loading&3))}var ql=null;function Y$(){}function K$(i,c,f){if(ql===null)throw Error(r(475));var h=ql;if(c.type==="stylesheet"&&(typeof f.media!="string"||matchMedia(f.media).matches!==!1)&&!(c.state.loading&4)){if(c.instance===null){var S=ls(f.href),T=i.querySelector(Hl(S));if(T){i=T._p,i!==null&&typeof i=="object"&&typeof i.then=="function"&&(h.count++,h=ld.bind(h),i.then(h,h)),c.state.loading|=4,c.instance=T,an(T);return}T=i.ownerDocument||i,f=BC(f),(S=yr.get(S))&&zh(f,S),T=T.createElement("link"),an(T);var F=T;F._p=new Promise(function(q,X){F.onload=q,F.onerror=X}),mn(T,"link",f),c.instance=T}h.stylesheets===null&&(h.stylesheets=new Map),h.stylesheets.set(c,i),(i=c.state.preload)&&!(c.state.loading&3)&&(h.count++,c=ld.bind(h),i.addEventListener("load",c),i.addEventListener("error",c))}}function X$(){if(ql===null)throw Error(r(475));var i=ql;return i.stylesheets&&i.count===0&&jh(i,i.stylesheets),0<i.count?function(c){var f=setTimeout(function(){if(i.stylesheets&&jh(i,i.stylesheets),i.unsuspend){var h=i.unsuspend;i.unsuspend=null,h()}},6e4);return i.unsuspend=c,function(){i.unsuspend=null,clearTimeout(f)}}:null}function ld(){if(this.count--,this.count===0){if(this.stylesheets)jh(this,this.stylesheets);else if(this.unsuspend){var i=this.unsuspend;this.unsuspend=null,i()}}}var cd=null;function jh(i,c){i.stylesheets=null,i.unsuspend!==null&&(i.count++,cd=new Map,c.forEach(Z$,i),cd=null,ld.call(i))}function Z$(i,c){if(!(c.state.loading&4)){var f=cd.get(i);if(f)var h=f.get(null);else{f=new Map,cd.set(i,f);for(var S=i.querySelectorAll("link[data-precedence],style[data-precedence]"),T=0;T<S.length;T++){var F=S[T];(F.nodeName==="LINK"||F.getAttribute("media")!=="not all")&&(f.set(F.dataset.precedence,F),h=F)}h&&f.set(null,h)}S=c.instance,F=S.getAttribute("data-precedence"),T=f.get(F)||h,T===h&&f.set(null,S),f.set(F,S),this.count++,h=ld.bind(this),S.addEventListener("load",h),S.addEventListener("error",h),T?T.parentNode.insertBefore(S,T.nextSibling):(i=i.nodeType===9?i.head:i,i.insertBefore(S,i.firstChild)),c.state.loading|=4}}var Vl={$$typeof:b,Provider:null,Consumer:null,_currentValue:Q,_currentValue2:Q,_threadCount:0};function Q$(i,c,f,h,S,T,F,q){this.tag=1,this.containerInfo=i,this.finishedWork=this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=_n(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.finishedLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=_n(0),this.hiddenUpdates=_n(null),this.identifierPrefix=h,this.onUncaughtError=S,this.onCaughtError=T,this.onRecoverableError=F,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=q,this.incompleteTransitions=new Map}function $C(i,c,f,h,S,T,F,q,X,re,ve,Ce){return i=new Q$(i,c,f,F,q,X,re,Ce),c=1,T===!0&&(c|=24),T=mr(3,null,null,c),i.current=T,T.stateNode=i,c=yg(),c.refCount++,i.pooledCache=c,c.refCount++,T.memoizedState={element:h,isDehydrated:f,cache:c},Qg(T),i}function qC(i){return i?(i=Ui,i):Ui}function VC(i,c,f,h,S,T){S=qC(S),h.context===null?h.context=S:h.pendingContext=S,h=no(c),h.payload={element:f},T=T===void 0?null:T,T!==null&&(h.callback=T),f=ro(i,h,c),f!==null&&(On(f,i,c),_l(f,i,c))}function WC(i,c){if(i=i.memoizedState,i!==null&&i.dehydrated!==null){var f=i.retryLane;i.retryLane=f!==0&&f<c?f:c}}function Uh(i,c){WC(i,c),(i=i.alternate)&&WC(i,c)}function YC(i){if(i.tag===13){var c=Ka(i,67108864);c!==null&&On(c,i,67108864),Uh(i,67108864)}}var ud=!0;function J$(i,c,f,h){var S=I.T;I.T=null;var T=Z.p;try{Z.p=2,Gh(i,c,f,h)}finally{Z.p=T,I.T=S}}function eq(i,c,f,h){var S=I.T;I.T=null;var T=Z.p;try{Z.p=8,Gh(i,c,f,h)}finally{Z.p=T,I.T=S}}function Gh(i,c,f,h){if(ud){var S=Hh(h);if(S===null)Nh(i,c,h,dd,f),XC(i,h);else if(nq(S,i,c,f,h))h.stopPropagation();else if(XC(i,h),c&4&&-1<tq.indexOf(i)){for(;S!==null;){var T=Ni(S);if(T!==null)switch(T.tag){case 3:if(T=T.stateNode,T.current.memoizedState.isDehydrated){var F=Jt(T.pendingLanes);if(F!==0){var q=T;for(q.pendingLanes|=2,q.entangledLanes|=2;F;){var X=1<<31-wt(F);q.entanglements[1]|=X,F&=~X}Zr(T),!(jt&6)&&(Yu=ye()+500,jl(0))}}break;case 13:q=Ka(T,2),q!==null&&On(q,T,2),Zu(),Uh(T,2)}if(T=Hh(h),T===null&&Nh(i,c,h,dd,f),T===S)break;S=T}S!==null&&h.stopPropagation()}else Nh(i,c,h,null,f)}}function Hh(i){return i=Kp(i),$h(i)}var dd=null;function $h(i){if(dd=null,i=Po(i),i!==null){var c=z(i);if(c===null)i=null;else{var f=c.tag;if(f===13){if(i=Y(c),i!==null)return i;i=null}else if(f===3){if(c.stateNode.current.memoizedState.isDehydrated)return c.tag===3?c.stateNode.containerInfo:null;i=null}else c!==i&&(i=null)}}return dd=i,null}function KC(i){switch(i){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Oe()){case ee:return 2;case de:return 8;case Ne:case Fe:return 32;case We:return 268435456;default:return 32}default:return 32}}var qh=!1,uo=null,fo=null,po=null,Wl=new Map,Yl=new Map,go=[],tq="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function XC(i,c){switch(i){case"focusin":case"focusout":uo=null;break;case"dragenter":case"dragleave":fo=null;break;case"mouseover":case"mouseout":po=null;break;case"pointerover":case"pointerout":Wl.delete(c.pointerId);break;case"gotpointercapture":case"lostpointercapture":Yl.delete(c.pointerId)}}function Kl(i,c,f,h,S,T){return i===null||i.nativeEvent!==T?(i={blockedOn:c,domEventName:f,eventSystemFlags:h,nativeEvent:T,targetContainers:[S]},c!==null&&(c=Ni(c),c!==null&&YC(c)),i):(i.eventSystemFlags|=h,c=i.targetContainers,S!==null&&c.indexOf(S)===-1&&c.push(S),i)}function nq(i,c,f,h,S){switch(c){case"focusin":return uo=Kl(uo,i,c,f,h,S),!0;case"dragenter":return fo=Kl(fo,i,c,f,h,S),!0;case"mouseover":return po=Kl(po,i,c,f,h,S),!0;case"pointerover":var T=S.pointerId;return Wl.set(T,Kl(Wl.get(T)||null,i,c,f,h,S)),!0;case"gotpointercapture":return T=S.pointerId,Yl.set(T,Kl(Yl.get(T)||null,i,c,f,h,S)),!0}return!1}function ZC(i){var c=Po(i.target);if(c!==null){var f=z(c);if(f!==null){if(c=f.tag,c===13){if(c=Y(f),c!==null){i.blockedOn=c,XH(i.priority,function(){if(f.tag===13){var h=Qn(),S=Ka(f,h);S!==null&&On(S,f,h),Uh(f,h)}});return}}else if(c===3&&f.stateNode.current.memoizedState.isDehydrated){i.blockedOn=f.tag===3?f.stateNode.containerInfo:null;return}}}i.blockedOn=null}function fd(i){if(i.blockedOn!==null)return!1;for(var c=i.targetContainers;0<c.length;){var f=Hh(i.nativeEvent);if(f===null){f=i.nativeEvent;var h=new f.constructor(f.type,f);Yp=h,f.target.dispatchEvent(h),Yp=null}else return c=Ni(f),c!==null&&YC(c),i.blockedOn=f,!1;c.shift()}return!0}function QC(i,c,f){fd(i)&&f.delete(c)}function rq(){qh=!1,uo!==null&&fd(uo)&&(uo=null),fo!==null&&fd(fo)&&(fo=null),po!==null&&fd(po)&&(po=null),Wl.forEach(QC),Yl.forEach(QC)}function pd(i,c){i.blockedOn===c&&(i.blockedOn=null,qh||(qh=!0,e.unstable_scheduleCallback(e.unstable_NormalPriority,rq)))}var gd=null;function JC(i){gd!==i&&(gd=i,e.unstable_scheduleCallback(e.unstable_NormalPriority,function(){gd===i&&(gd=null);for(var c=0;c<i.length;c+=3){var f=i[c],h=i[c+1],S=i[c+2];if(typeof h!="function"){if($h(h||f)===null)continue;break}var T=Ni(f);T!==null&&(i.splice(c,3),c-=3,Lg(T,{pending:!0,data:S,method:f.method,action:h},h,S))}}))}function Xl(i){function c(X){return pd(X,i)}uo!==null&&pd(uo,i),fo!==null&&pd(fo,i),po!==null&&pd(po,i),Wl.forEach(c),Yl.forEach(c);for(var f=0;f<go.length;f++){var h=go[f];h.blockedOn===i&&(h.blockedOn=null)}for(;0<go.length&&(f=go[0],f.blockedOn===null);)ZC(f),f.blockedOn===null&&go.shift();if(f=(i.ownerDocument||i).$$reactFormReplay,f!=null)for(h=0;h<f.length;h+=3){var S=f[h],T=f[h+1],F=S[Fn]||null;if(typeof T=="function")F||JC(f);else if(F){var q=null;if(T&&T.hasAttribute("formAction")){if(S=T,F=T[Fn]||null)q=F.formAction;else if($h(S)!==null)continue}else q=F.action;typeof q=="function"?f[h+1]=q:(f.splice(h,3),h-=3),JC(f)}}}function Vh(i){this._internalRoot=i}hd.prototype.render=Vh.prototype.render=function(i){var c=this._internalRoot;if(c===null)throw Error(r(409));var f=c.current,h=Qn();VC(f,h,i,c,null,null)},hd.prototype.unmount=Vh.prototype.unmount=function(){var i=this._internalRoot;if(i!==null){this._internalRoot=null;var c=i.containerInfo;i.tag===0&&as(),VC(i.current,2,null,i,null,null),Zu(),c[_i]=null}};function hd(i){this._internalRoot=i}hd.prototype.unstable_scheduleHydration=function(i){if(i){var c=RA();i={blockedOn:null,target:i,priority:c};for(var f=0;f<go.length&&c!==0&&c<go[f].priority;f++);go.splice(f,0,i),f===0&&ZC(i)}};var e_=t.version;if(e_!=="19.0.0")throw Error(r(527,e_,"19.0.0"));Z.findDOMNode=function(i){var c=i._reactInternals;if(c===void 0)throw typeof i.render=="function"?Error(r(188)):(i=Object.keys(i).join(","),Error(r(268,i)));return i=V(c),i=i!==null?j(i):null,i=i===null?null:i.stateNode,i};var aq={bundleType:0,version:"19.0.0",rendererPackageName:"react-dom",currentDispatcherRef:I,findFiberByHostInstance:Po,reconcilerVersion:"19.0.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var md=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!md.isDisabled&&md.supportsFiber)try{bt=md.inject(aq),et=md}catch{}}return Ql.createRoot=function(i,c){if(!a(i))throw Error(r(299));var f=!1,h="",S=bR,T=yR,F=vR,q=null;return c!=null&&(c.unstable_strictMode===!0&&(f=!0),c.identifierPrefix!==void 0&&(h=c.identifierPrefix),c.onUncaughtError!==void 0&&(S=c.onUncaughtError),c.onCaughtError!==void 0&&(T=c.onCaughtError),c.onRecoverableError!==void 0&&(F=c.onRecoverableError),c.unstable_transitionCallbacks!==void 0&&(q=c.unstable_transitionCallbacks)),c=$C(i,1,!1,null,null,f,h,S,T,F,q,null),i[_i]=c.current,_h(i.nodeType===8?i.parentNode:i),new Vh(c)},Ql.hydrateRoot=function(i,c,f){if(!a(i))throw Error(r(299));var h=!1,S="",T=bR,F=yR,q=vR,X=null,re=null;return f!=null&&(f.unstable_strictMode===!0&&(h=!0),f.identifierPrefix!==void 0&&(S=f.identifierPrefix),f.onUncaughtError!==void 0&&(T=f.onUncaughtError),f.onCaughtError!==void 0&&(F=f.onCaughtError),f.onRecoverableError!==void 0&&(q=f.onRecoverableError),f.unstable_transitionCallbacks!==void 0&&(X=f.unstable_transitionCallbacks),f.formState!==void 0&&(re=f.formState)),c=$C(i,1,!0,c,f??null,h,S,T,F,q,X,re),c.context=qC(null),f=c.current,h=Qn(),S=no(h),S.callback=null,ro(f,S,h),c.current.lanes=h,Mn(c,h),Zr(c),i[_i]=c.current,_h(i),new hd(c)},Ql.version="19.0.0",Ql}var u_;function yq(){if(u_)return Kh.exports;u_=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),Kh.exports=bq(),Kh.exports}var vq=yq(),Jl={},d_;function Sq(){if(d_)return Jl;d_=1,Object.defineProperty(Jl,"__esModule",{value:!0}),Jl.parse=s,Jl.serialize=d;const e=/^[\u0021-\u003A\u003C\u003E-\u007E]+$/,t=/^[\u0021-\u003A\u003C-\u007E]*$/,n=/^([.]?[a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?)([.][a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?)*$/i,r=/^[\u0020-\u003A\u003D-\u007E]*$/,a=Object.prototype.toString,o=(()=>{const m=function(){};return m.prototype=Object.create(null),m})();function s(m,b){const v=new o,y=m.length;if(y<2)return v;const k=(b==null?void 0:b.decode)||p;let A=0;do{const x=m.indexOf("=",A);if(x===-1)break;const R=m.indexOf(";",A),O=R===-1?y:R;if(x>O){A=m.lastIndexOf(";",x-1)+1;continue}const N=l(m,A,x),C=u(m,x,N),_=m.slice(N,C);if(v[_]===void 0){let M=l(m,x+1,O),I=u(m,O,M);const D=k(m.slice(M,I));v[_]=D}A=O+1}while(A<y);return v}function l(m,b,v){do{const y=m.charCodeAt(b);if(y!==32&&y!==9)return b}while(++b<v);return v}function u(m,b,v){for(;b>v;){const y=m.charCodeAt(--b);if(y!==32&&y!==9)return b+1}return v}function d(m,b,v){const y=(v==null?void 0:v.encode)||encodeURIComponent;if(!e.test(m))throw new TypeError(`argument name is invalid: ${m}`);const k=y(b);if(!t.test(k))throw new TypeError(`argument val is invalid: ${b}`);let A=m+"="+k;if(!v)return A;if(v.maxAge!==void 0){if(!Number.isInteger(v.maxAge))throw new TypeError(`option maxAge is invalid: ${v.maxAge}`);A+="; Max-Age="+v.maxAge}if(v.domain){if(!n.test(v.domain))throw new TypeError(`option domain is invalid: ${v.domain}`);A+="; Domain="+v.domain}if(v.path){if(!r.test(v.path))throw new TypeError(`option path is invalid: ${v.path}`);A+="; Path="+v.path}if(v.expires){if(!g(v.expires)||!Number.isFinite(v.expires.valueOf()))throw new TypeError(`option expires is invalid: ${v.expires}`);A+="; Expires="+v.expires.toUTCString()}if(v.httpOnly&&(A+="; HttpOnly"),v.secure&&(A+="; Secure"),v.partitioned&&(A+="; Partitioned"),v.priority)switch(typeof v.priority=="string"?v.priority.toLowerCase():void 0){case"low":A+="; Priority=Low";break;case"medium":A+="; Priority=Medium";break;case"high":A+="; Priority=High";break;default:throw new TypeError(`option priority is invalid: ${v.priority}`)}if(v.sameSite)switch(typeof v.sameSite=="string"?v.sameSite.toLowerCase():v.sameSite){case!0:case"strict":A+="; SameSite=Strict";break;case"lax":A+="; SameSite=Lax";break;case"none":A+="; SameSite=None";break;default:throw new TypeError(`option sameSite is invalid: ${v.sameSite}`)}return A}function p(m){if(m.indexOf("%")===-1)return m;try{return decodeURIComponent(m)}catch{return m}}function g(m){return a.call(m)==="[object Date]"}return Jl}Sq();/**
 * react-router v7.3.0
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */var f_="popstate";function Eq(e={}){function t(a,o){let{pathname:s="/",search:l="",hash:u=""}=xi(a.location.hash.substring(1));return!s.startsWith("/")&&!s.startsWith(".")&&(s="/"+s),c0("",{pathname:s,search:l,hash:u},o.state&&o.state.usr||null,o.state&&o.state.key||"default")}function n(a,o){let s=a.document.querySelector("base"),l="";if(s&&s.getAttribute("href")){let u=a.location.href,d=u.indexOf("#");l=d===-1?u:u.slice(0,d)}return l+"#"+(typeof o=="string"?o:Ec(o))}function r(a,o){jr(a.pathname.charAt(0)==="/",`relative pathnames are not supported in hash history.push(${JSON.stringify(o)})`)}return xq(t,n,r,e)}function Gt(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}function jr(e,t){if(!e){typeof console<"u"&&console.warn(t);try{throw new Error(t)}catch{}}}function wq(){return Math.random().toString(36).substring(2,10)}function p_(e,t){return{usr:e.state,key:e.key,idx:t}}function c0(e,t,n=null,r){return{pathname:typeof e=="string"?e:e.pathname,search:"",hash:"",...typeof t=="string"?xi(t):t,state:n,key:t&&t.key||r||wq()}}function Ec({pathname:e="/",search:t="",hash:n=""}){return t&&t!=="?"&&(e+=t.charAt(0)==="?"?t:"?"+t),n&&n!=="#"&&(e+=n.charAt(0)==="#"?n:"#"+n),e}function xi(e){let t={};if(e){let n=e.indexOf("#");n>=0&&(t.hash=e.substring(n),e=e.substring(0,n));let r=e.indexOf("?");r>=0&&(t.search=e.substring(r),e=e.substring(0,r)),e&&(t.pathname=e)}return t}function xq(e,t,n,r={}){let{window:a=document.defaultView,v5Compat:o=!1}=r,s=a.history,l="POP",u=null,d=p();d==null&&(d=0,s.replaceState({...s.state,idx:d},""));function p(){return(s.state||{idx:null}).idx}function g(){l="POP";let k=p(),A=k==null?null:k-d;d=k,u&&u({action:l,location:y.location,delta:A})}function m(k,A){l="PUSH";let x=c0(y.location,k,A);n&&n(x,k),d=p()+1;let R=p_(x,d),O=y.createHref(x);try{s.pushState(R,"",O)}catch(N){if(N instanceof DOMException&&N.name==="DataCloneError")throw N;a.location.assign(O)}o&&u&&u({action:l,location:y.location,delta:1})}function b(k,A){l="REPLACE";let x=c0(y.location,k,A);n&&n(x,k),d=p();let R=p_(x,d),O=y.createHref(x);s.replaceState(R,"",O),o&&u&&u({action:l,location:y.location,delta:0})}function v(k){let A=a.location.origin!=="null"?a.location.origin:a.location.href,x=typeof k=="string"?k:Ec(k);return x=x.replace(/ $/,"%20"),Gt(A,`No window.location.(origin|href) available to create URL for href: ${x}`),new URL(x,A)}let y={get action(){return l},get location(){return e(a,s)},listen(k){if(u)throw new Error("A history only accepts one active listener");return a.addEventListener(f_,g),u=k,()=>{a.removeEventListener(f_,g),u=null}},createHref(k){return t(a,k)},createURL:v,encodeLocation(k){let A=v(k);return{pathname:A.pathname,search:A.search,hash:A.hash}},push:m,replace:b,go(k){return s.go(k)}};return y}function Yz(e,t,n="/"){return kq(e,t,n,!1)}function kq(e,t,n,r){let a=typeof t=="string"?xi(t):t,o=Ba(a.pathname||"/",n);if(o==null)return null;let s=Kz(e);Tq(s);let l=null;for(let u=0;l==null&&u<s.length;++u){let d=Pq(o);l=Lq(s[u],d,r)}return l}function Kz(e,t=[],n=[],r=""){let a=(o,s,l)=>{let u={relativePath:l===void 0?o.path||"":l,caseSensitive:o.caseSensitive===!0,childrenIndex:s,route:o};u.relativePath.startsWith("/")&&(Gt(u.relativePath.startsWith(r),`Absolute route path "${u.relativePath}" nested under path "${r}" is not valid. An absolute child route path must start with the combined path of all its parent routes.`),u.relativePath=u.relativePath.slice(r.length));let d=Fa([r,u.relativePath]),p=n.concat(u);o.children&&o.children.length>0&&(Gt(o.index!==!0,`Index routes must not have child routes. Please remove all child routes from route path "${d}".`),Kz(o.children,t,p,d)),!(o.path==null&&!o.index)&&t.push({path:d,score:Iq(d,o.index),routesMeta:p})};return e.forEach((o,s)=>{var l;if(o.path===""||!((l=o.path)!=null&&l.includes("?")))a(o,s);else for(let u of Xz(o.path))a(o,s,u)}),t}function Xz(e){let t=e.split("/");if(t.length===0)return[];let[n,...r]=t,a=n.endsWith("?"),o=n.replace(/\?$/,"");if(r.length===0)return a?[o,""]:[o];let s=Xz(r.join("/")),l=[];return l.push(...s.map(u=>u===""?o:[o,u].join("/"))),a&&l.push(...s),l.map(u=>e.startsWith("/")&&u===""?"/":u)}function Tq(e){e.sort((t,n)=>t.score!==n.score?n.score-t.score:Dq(t.routesMeta.map(r=>r.childrenIndex),n.routesMeta.map(r=>r.childrenIndex)))}var Aq=/^:[\w-]+$/,Rq=3,Cq=2,_q=1,Nq=10,Oq=-2,g_=e=>e==="*";function Iq(e,t){let n=e.split("/"),r=n.length;return n.some(g_)&&(r+=Oq),t&&(r+=Cq),n.filter(a=>!g_(a)).reduce((a,o)=>a+(Aq.test(o)?Rq:o===""?_q:Nq),r)}function Dq(e,t){return e.length===t.length&&e.slice(0,-1).every((r,a)=>r===t[a])?e[e.length-1]-t[t.length-1]:0}function Lq(e,t,n=!1){let{routesMeta:r}=e,a={},o="/",s=[];for(let l=0;l<r.length;++l){let u=r[l],d=l===r.length-1,p=o==="/"?t:t.slice(o.length)||"/",g=hf({path:u.relativePath,caseSensitive:u.caseSensitive,end:d},p),m=u.route;if(!g&&d&&n&&!r[r.length-1].route.index&&(g=hf({path:u.relativePath,caseSensitive:u.caseSensitive,end:!1},p)),!g)return null;Object.assign(a,g.params),s.push({params:a,pathname:Fa([o,g.pathname]),pathnameBase:jq(Fa([o,g.pathnameBase])),route:m}),g.pathnameBase!=="/"&&(o=Fa([o,g.pathnameBase]))}return s}function hf(e,t){typeof e=="string"&&(e={path:e,caseSensitive:!1,end:!0});let[n,r]=Mq(e.path,e.caseSensitive,e.end),a=t.match(n);if(!a)return null;let o=a[0],s=o.replace(/(.)\/+$/,"$1"),l=a.slice(1);return{params:r.reduce((d,{paramName:p,isOptional:g},m)=>{if(p==="*"){let v=l[m]||"";s=o.slice(0,o.length-v.length).replace(/(.)\/+$/,"$1")}const b=l[m];return g&&!b?d[p]=void 0:d[p]=(b||"").replace(/%2F/g,"/"),d},{}),pathname:o,pathnameBase:s,pattern:e}}function Mq(e,t=!1,n=!0){jr(e==="*"||!e.endsWith("*")||e.endsWith("/*"),`Route path "${e}" will be treated as if it were "${e.replace(/\*$/,"/*")}" because the \`*\` character must always follow a \`/\` in the pattern. To get rid of this warning, please change the route path to "${e.replace(/\*$/,"/*")}".`);let r=[],a="^"+e.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(s,l,u)=>(r.push({paramName:l,isOptional:u!=null}),u?"/?([^\\/]+)?":"/([^\\/]+)"));return e.endsWith("*")?(r.push({paramName:"*"}),a+=e==="*"||e==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):n?a+="\\/*$":e!==""&&e!=="/"&&(a+="(?:(?=\\/|$))"),[new RegExp(a,t?void 0:"i"),r]}function Pq(e){try{return e.split("/").map(t=>decodeURIComponent(t).replace(/\//g,"%2F")).join("/")}catch(t){return jr(!1,`The URL path "${e}" could not be decoded because it is a malformed URL segment. This is probably due to a bad percent encoding (${t}).`),e}}function Ba(e,t){if(t==="/")return e;if(!e.toLowerCase().startsWith(t.toLowerCase()))return null;let n=t.endsWith("/")?t.length-1:t.length,r=e.charAt(n);return r&&r!=="/"?null:e.slice(n)||"/"}function Fq(e,t="/"){let{pathname:n,search:r="",hash:a=""}=typeof e=="string"?xi(e):e;return{pathname:n?n.startsWith("/")?n:zq(n,t):t,search:Uq(r),hash:Gq(a)}}function zq(e,t){let n=t.replace(/\/+$/,"").split("/");return e.split("/").forEach(a=>{a===".."?n.length>1&&n.pop():a!=="."&&n.push(a)}),n.length>1?n.join("/"):"/"}function Jh(e,t,n,r){return`Cannot include a '${e}' character in a manually specified \`to.${t}\` field [${JSON.stringify(r)}].  Please separate it out to the \`to.${n}\` field. Alternatively you may provide the full path as a string in <Link to="..."> and the router will parse it for you.`}function Bq(e){return e.filter((t,n)=>n===0||t.route.path&&t.route.path.length>0)}function Zz(e){let t=Bq(e);return t.map((n,r)=>r===t.length-1?n.pathname:n.pathnameBase)}function Qz(e,t,n,r=!1){let a;typeof e=="string"?a=xi(e):(a={...e},Gt(!a.pathname||!a.pathname.includes("?"),Jh("?","pathname","search",a)),Gt(!a.pathname||!a.pathname.includes("#"),Jh("#","pathname","hash",a)),Gt(!a.search||!a.search.includes("#"),Jh("#","search","hash",a)));let o=e===""||a.pathname==="",s=o?"/":a.pathname,l;if(s==null)l=n;else{let g=t.length-1;if(!r&&s.startsWith("..")){let m=s.split("/");for(;m[0]==="..";)m.shift(),g-=1;a.pathname=m.join("/")}l=g>=0?t[g]:"/"}let u=Fq(a,l),d=s&&s!=="/"&&s.endsWith("/"),p=(o||s===".")&&n.endsWith("/");return!u.pathname.endsWith("/")&&(d||p)&&(u.pathname+="/"),u}var Fa=e=>e.join("/").replace(/\/\/+/g,"/"),jq=e=>e.replace(/\/+$/,"").replace(/^\/*/,"/"),Uq=e=>!e||e==="?"?"":e.startsWith("?")?e:"?"+e,Gq=e=>!e||e==="#"?"":e.startsWith("#")?e:"#"+e;function Hq(e){return e!=null&&typeof e.status=="number"&&typeof e.statusText=="string"&&typeof e.internal=="boolean"&&"data"in e}var Jz=["POST","PUT","PATCH","DELETE"];new Set(Jz);var $q=["GET",...Jz];new Set($q);var Us=w.createContext(null);Us.displayName="DataRouter";var Vf=w.createContext(null);Vf.displayName="DataRouterState";var eB=w.createContext({isTransitioning:!1});eB.displayName="ViewTransition";var qq=w.createContext(new Map);qq.displayName="Fetchers";var Vq=w.createContext(null);Vq.displayName="Await";var sa=w.createContext(null);sa.displayName="Navigation";var Bc=w.createContext(null);Bc.displayName="Location";var Ha=w.createContext({outlet:null,matches:[],isDataRoute:!1});Ha.displayName="Route";var Nk=w.createContext(null);Nk.displayName="RouteError";function Wq(e,{relative:t}={}){Gt(jc(),"useHref() may be used only in the context of a <Router> component.");let{basename:n,navigator:r}=w.useContext(sa),{hash:a,pathname:o,search:s}=Uc(e,{relative:t}),l=o;return n!=="/"&&(l=o==="/"?n:Fa([n,o])),r.createHref({pathname:l,search:s,hash:a})}function jc(){return w.useContext(Bc)!=null}function ki(){return Gt(jc(),"useLocation() may be used only in the context of a <Router> component."),w.useContext(Bc).location}var tB="You should call navigate() in a React.useEffect(), not when your component is first rendered.";function nB(e){w.useContext(sa).static||w.useLayoutEffect(e)}function Ok(){let{isDataRoute:e}=w.useContext(Ha);return e?i9():Yq()}function Yq(){Gt(jc(),"useNavigate() may be used only in the context of a <Router> component.");let e=w.useContext(Us),{basename:t,navigator:n}=w.useContext(sa),{matches:r}=w.useContext(Ha),{pathname:a}=ki(),o=JSON.stringify(Zz(r)),s=w.useRef(!1);return nB(()=>{s.current=!0}),w.useCallback((u,d={})=>{if(jr(s.current,tB),!s.current)return;if(typeof u=="number"){n.go(u);return}let p=Qz(u,JSON.parse(o),a,d.relative==="path");e==null&&t!=="/"&&(p.pathname=p.pathname==="/"?t:Fa([t,p.pathname])),(d.replace?n.replace:n.push)(p,d.state,d)},[t,n,o,a,e])}w.createContext(null);function Uc(e,{relative:t}={}){let{matches:n}=w.useContext(Ha),{pathname:r}=ki(),a=JSON.stringify(Zz(n));return w.useMemo(()=>Qz(e,JSON.parse(a),r,t==="path"),[e,a,r,t])}function Kq(e,t){return rB(e,t)}function rB(e,t,n,r){var x;Gt(jc(),"useRoutes() may be used only in the context of a <Router> component.");let{navigator:a,static:o}=w.useContext(sa),{matches:s}=w.useContext(Ha),l=s[s.length-1],u=l?l.params:{},d=l?l.pathname:"/",p=l?l.pathnameBase:"/",g=l&&l.route;{let R=g&&g.path||"";aB(d,!g||R.endsWith("*")||R.endsWith("*?"),`You rendered descendant <Routes> (or called \`useRoutes()\`) at "${d}" (under <Route path="${R}">) but the parent route path has no trailing "*". This means if you navigate deeper, the parent won't match anymore and therefore the child routes will never render.

Please change the parent <Route path="${R}"> to <Route path="${R==="/"?"*":`${R}/*`}">.`)}let m=ki(),b;if(t){let R=typeof t=="string"?xi(t):t;Gt(p==="/"||((x=R.pathname)==null?void 0:x.startsWith(p)),`When overriding the location using \`<Routes location>\` or \`useRoutes(routes, location)\`, the location pathname must begin with the portion of the URL pathname that was matched by all parent routes. The current pathname base is "${p}" but pathname "${R.pathname}" was given in the \`location\` prop.`),b=R}else b=m;let v=b.pathname||"/",y=v;if(p!=="/"){let R=p.replace(/^\//,"").split("/");y="/"+v.replace(/^\//,"").split("/").slice(R.length).join("/")}let k=!o&&n&&n.matches&&n.matches.length>0?n.matches:Yz(e,{pathname:y});jr(g||k!=null,`No routes matched location "${b.pathname}${b.search}${b.hash}" `),jr(k==null||k[k.length-1].route.element!==void 0||k[k.length-1].route.Component!==void 0||k[k.length-1].route.lazy!==void 0,`Matched leaf route at location "${b.pathname}${b.search}${b.hash}" does not have an element or Component. This means it will render an <Outlet /> with a null value by default resulting in an "empty" page.`);let A=e9(k&&k.map(R=>Object.assign({},R,{params:Object.assign({},u,R.params),pathname:Fa([p,a.encodeLocation?a.encodeLocation(R.pathname).pathname:R.pathname]),pathnameBase:R.pathnameBase==="/"?p:Fa([p,a.encodeLocation?a.encodeLocation(R.pathnameBase).pathname:R.pathnameBase])})),s,n,r);return t&&A?w.createElement(Bc.Provider,{value:{location:{pathname:"/",search:"",hash:"",state:null,key:"default",...b},navigationType:"POP"}},A):A}function Xq(){let e=o9(),t=Hq(e)?`${e.status} ${e.statusText}`:e instanceof Error?e.message:JSON.stringify(e),n=e instanceof Error?e.stack:null,r="rgba(200,200,200, 0.5)",a={padding:"0.5rem",backgroundColor:r},o={padding:"2px 4px",backgroundColor:r},s=null;return console.error("Error handled by React Router default ErrorBoundary:",e),s=w.createElement(w.Fragment,null,w.createElement("p",null,"💿 Hey developer 👋"),w.createElement("p",null,"You can provide a way better UX than this when your app throws errors by providing your own ",w.createElement("code",{style:o},"ErrorBoundary")," or"," ",w.createElement("code",{style:o},"errorElement")," prop on your route.")),w.createElement(w.Fragment,null,w.createElement("h2",null,"Unexpected Application Error!"),w.createElement("h3",{style:{fontStyle:"italic"}},t),n?w.createElement("pre",{style:a},n):null,s)}var Zq=w.createElement(Xq,null),Qq=class extends w.Component{constructor(e){super(e),this.state={location:e.location,revalidation:e.revalidation,error:e.error}}static getDerivedStateFromError(e){return{error:e}}static getDerivedStateFromProps(e,t){return t.location!==e.location||t.revalidation!=="idle"&&e.revalidation==="idle"?{error:e.error,location:e.location,revalidation:e.revalidation}:{error:e.error!==void 0?e.error:t.error,location:t.location,revalidation:e.revalidation||t.revalidation}}componentDidCatch(e,t){console.error("React Router caught the following error during render",e,t)}render(){return this.state.error!==void 0?w.createElement(Ha.Provider,{value:this.props.routeContext},w.createElement(Nk.Provider,{value:this.state.error,children:this.props.component})):this.props.children}};function Jq({routeContext:e,match:t,children:n}){let r=w.useContext(Us);return r&&r.static&&r.staticContext&&(t.route.errorElement||t.route.ErrorBoundary)&&(r.staticContext._deepestRenderedBoundaryId=t.route.id),w.createElement(Ha.Provider,{value:e},n)}function e9(e,t=[],n=null,r=null){if(e==null){if(!n)return null;if(n.errors)e=n.matches;else if(t.length===0&&!n.initialized&&n.matches.length>0)e=n.matches;else return null}let a=e,o=n==null?void 0:n.errors;if(o!=null){let u=a.findIndex(d=>d.route.id&&(o==null?void 0:o[d.route.id])!==void 0);Gt(u>=0,`Could not find a matching route for errors on route IDs: ${Object.keys(o).join(",")}`),a=a.slice(0,Math.min(a.length,u+1))}let s=!1,l=-1;if(n)for(let u=0;u<a.length;u++){let d=a[u];if((d.route.HydrateFallback||d.route.hydrateFallbackElement)&&(l=u),d.route.id){let{loaderData:p,errors:g}=n,m=d.route.loader&&!p.hasOwnProperty(d.route.id)&&(!g||g[d.route.id]===void 0);if(d.route.lazy||m){s=!0,l>=0?a=a.slice(0,l+1):a=[a[0]];break}}}return a.reduceRight((u,d,p)=>{let g,m=!1,b=null,v=null;n&&(g=o&&d.route.id?o[d.route.id]:void 0,b=d.route.errorElement||Zq,s&&(l<0&&p===0?(aB("route-fallback",!1,"No `HydrateFallback` element provided to render during initial hydration"),m=!0,v=null):l===p&&(m=!0,v=d.route.hydrateFallbackElement||null)));let y=t.concat(a.slice(0,p+1)),k=()=>{let A;return g?A=b:m?A=v:d.route.Component?A=w.createElement(d.route.Component,null):d.route.element?A=d.route.element:A=u,w.createElement(Jq,{match:d,routeContext:{outlet:u,matches:y,isDataRoute:n!=null},children:A})};return n&&(d.route.ErrorBoundary||d.route.errorElement||p===0)?w.createElement(Qq,{location:n.location,revalidation:n.revalidation,component:b,error:g,children:k(),routeContext:{outlet:null,matches:y,isDataRoute:!0}}):k()},null)}function Ik(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function t9(e){let t=w.useContext(Us);return Gt(t,Ik(e)),t}function n9(e){let t=w.useContext(Vf);return Gt(t,Ik(e)),t}function r9(e){let t=w.useContext(Ha);return Gt(t,Ik(e)),t}function Dk(e){let t=r9(e),n=t.matches[t.matches.length-1];return Gt(n.route.id,`${e} can only be used on routes that contain a unique "id"`),n.route.id}function a9(){return Dk("useRouteId")}function o9(){var r;let e=w.useContext(Nk),t=n9("useRouteError"),n=Dk("useRouteError");return e!==void 0?e:(r=t.errors)==null?void 0:r[n]}function i9(){let{router:e}=t9("useNavigate"),t=Dk("useNavigate"),n=w.useRef(!1);return nB(()=>{n.current=!0}),w.useCallback(async(a,o={})=>{jr(n.current,tB),n.current&&(typeof a=="number"?e.navigate(a):await e.navigate(a,{fromRouteId:t,...o}))},[e,t])}var h_={};function aB(e,t,n){!t&&!h_[e]&&(h_[e]=!0,jr(!1,n))}w.memo(s9);function s9({routes:e,future:t,state:n}){return rB(e,void 0,n,t)}function u0(e){Gt(!1,"A <Route> is only ever to be used as the child of <Routes> element, never rendered directly. Please wrap your <Route> in a <Routes>.")}function l9({basename:e="/",children:t=null,location:n,navigationType:r="POP",navigator:a,static:o=!1}){Gt(!jc(),"You cannot render a <Router> inside another <Router>. You should never have more than one in your app.");let s=e.replace(/^\/*/,"/"),l=w.useMemo(()=>({basename:s,navigator:a,static:o,future:{}}),[s,a,o]);typeof n=="string"&&(n=xi(n));let{pathname:u="/",search:d="",hash:p="",state:g=null,key:m="default"}=n,b=w.useMemo(()=>{let v=Ba(u,s);return v==null?null:{location:{pathname:v,search:d,hash:p,state:g,key:m},navigationType:r}},[s,u,d,p,g,m,r]);return jr(b!=null,`<Router basename="${s}"> is not able to match the URL "${u}${d}${p}" because it does not start with the basename, so the <Router> won't render anything.`),b==null?null:w.createElement(sa.Provider,{value:l},w.createElement(Bc.Provider,{children:t,value:b}))}function c9({children:e,location:t}){return Kq(d0(e),t)}function d0(e,t=[]){let n=[];return w.Children.forEach(e,(r,a)=>{if(!w.isValidElement(r))return;let o=[...t,a];if(r.type===w.Fragment){n.push.apply(n,d0(r.props.children,o));return}Gt(r.type===u0,`[${typeof r.type=="string"?r.type:r.type.name}] is not a <Route> component. All component children of <Routes> must be a <Route> or <React.Fragment>`),Gt(!r.props.index||!r.props.children,"An index route cannot have child routes.");let s={id:r.props.id||o.join("-"),caseSensitive:r.props.caseSensitive,element:r.props.element,Component:r.props.Component,index:r.props.index,path:r.props.path,loader:r.props.loader,action:r.props.action,hydrateFallbackElement:r.props.hydrateFallbackElement,HydrateFallback:r.props.HydrateFallback,errorElement:r.props.errorElement,ErrorBoundary:r.props.ErrorBoundary,hasErrorBoundary:r.props.hasErrorBoundary===!0||r.props.ErrorBoundary!=null||r.props.errorElement!=null,shouldRevalidate:r.props.shouldRevalidate,handle:r.props.handle,lazy:r.props.lazy};r.props.children&&(s.children=d0(r.props.children,o)),n.push(s)}),n}var Yd="get",Kd="application/x-www-form-urlencoded";function Wf(e){return e!=null&&typeof e.tagName=="string"}function u9(e){return Wf(e)&&e.tagName.toLowerCase()==="button"}function d9(e){return Wf(e)&&e.tagName.toLowerCase()==="form"}function f9(e){return Wf(e)&&e.tagName.toLowerCase()==="input"}function p9(e){return!!(e.metaKey||e.altKey||e.ctrlKey||e.shiftKey)}function g9(e,t){return e.button===0&&(!t||t==="_self")&&!p9(e)}var bd=null;function h9(){if(bd===null)try{new FormData(document.createElement("form"),0),bd=!1}catch{bd=!0}return bd}var m9=new Set(["application/x-www-form-urlencoded","multipart/form-data","text/plain"]);function em(e){return e!=null&&!m9.has(e)?(jr(!1,`"${e}" is not a valid \`encType\` for \`<Form>\`/\`<fetcher.Form>\` and will default to "${Kd}"`),null):e}function b9(e,t){let n,r,a,o,s;if(d9(e)){let l=e.getAttribute("action");r=l?Ba(l,t):null,n=e.getAttribute("method")||Yd,a=em(e.getAttribute("enctype"))||Kd,o=new FormData(e)}else if(u9(e)||f9(e)&&(e.type==="submit"||e.type==="image")){let l=e.form;if(l==null)throw new Error('Cannot submit a <button> or <input type="submit"> without a <form>');let u=e.getAttribute("formaction")||l.getAttribute("action");if(r=u?Ba(u,t):null,n=e.getAttribute("formmethod")||l.getAttribute("method")||Yd,a=em(e.getAttribute("formenctype"))||em(l.getAttribute("enctype"))||Kd,o=new FormData(l,e),!h9()){let{name:d,type:p,value:g}=e;if(p==="image"){let m=d?`${d}.`:"";o.append(`${m}x`,"0"),o.append(`${m}y`,"0")}else d&&o.append(d,g)}}else{if(Wf(e))throw new Error('Cannot submit element that is not <form>, <button>, or <input type="submit|image">');n=Yd,r=null,a=Kd,s=e}return o&&a==="text/plain"&&(s=o,o=void 0),{action:r,method:n.toLowerCase(),encType:a,formData:o,body:s}}function Lk(e,t){if(e===!1||e===null||typeof e>"u")throw new Error(t)}async function y9(e,t){if(e.id in t)return t[e.id];try{let n=await import(e.module);return t[e.id]=n,n}catch(n){return console.error(`Error loading route module \`${e.module}\`, reloading page...`),console.error(n),window.__reactRouterContext&&window.__reactRouterContext.isSpaMode,window.location.reload(),new Promise(()=>{})}}function v9(e){return e==null?!1:e.href==null?e.rel==="preload"&&typeof e.imageSrcSet=="string"&&typeof e.imageSizes=="string":typeof e.rel=="string"&&typeof e.href=="string"}async function S9(e,t,n){let r=await Promise.all(e.map(async a=>{let o=t.routes[a.route.id];if(o){let s=await y9(o,n);return s.links?s.links():[]}return[]}));return k9(r.flat(1).filter(v9).filter(a=>a.rel==="stylesheet"||a.rel==="preload").map(a=>a.rel==="stylesheet"?{...a,rel:"prefetch",as:"style"}:{...a,rel:"prefetch"}))}function m_(e,t,n,r,a,o){let s=(u,d)=>n[d]?u.route.id!==n[d].route.id:!0,l=(u,d)=>{var p;return n[d].pathname!==u.pathname||((p=n[d].route.path)==null?void 0:p.endsWith("*"))&&n[d].params["*"]!==u.params["*"]};return o==="assets"?t.filter((u,d)=>s(u,d)||l(u,d)):o==="data"?t.filter((u,d)=>{var g;let p=r.routes[u.route.id];if(!p||!p.hasLoader)return!1;if(s(u,d)||l(u,d))return!0;if(u.route.shouldRevalidate){let m=u.route.shouldRevalidate({currentUrl:new URL(a.pathname+a.search+a.hash,window.origin),currentParams:((g=n[0])==null?void 0:g.params)||{},nextUrl:new URL(e,window.origin),nextParams:u.params,defaultShouldRevalidate:!0});if(typeof m=="boolean")return m}return!0}):[]}function E9(e,t,{includeHydrateFallback:n}={}){return w9(e.map(r=>{let a=t.routes[r.route.id];if(!a)return[];let o=[a.module];return a.clientActionModule&&(o=o.concat(a.clientActionModule)),a.clientLoaderModule&&(o=o.concat(a.clientLoaderModule)),n&&a.hydrateFallbackModule&&(o=o.concat(a.hydrateFallbackModule)),a.imports&&(o=o.concat(a.imports)),o}).flat(1))}function w9(e){return[...new Set(e)]}function x9(e){let t={},n=Object.keys(e).sort();for(let r of n)t[r]=e[r];return t}function k9(e,t){let n=new Set;return new Set(t),e.reduce((r,a)=>{let o=JSON.stringify(x9(a));return n.has(o)||(n.add(o),r.push({key:o,link:a})),r},[])}function T9(e,t){let n=typeof e=="string"?new URL(e,typeof window>"u"?"server://singlefetch/":window.location.origin):e;return n.pathname==="/"?n.pathname="_root.data":t&&Ba(n.pathname,t)==="/"?n.pathname=`${t.replace(/\/$/,"")}/_root.data`:n.pathname=`${n.pathname.replace(/\/$/,"")}.data`,n}function oB(){let e=w.useContext(Us);return Lk(e,"You must render this element inside a <DataRouterContext.Provider> element"),e}function A9(){let e=w.useContext(Vf);return Lk(e,"You must render this element inside a <DataRouterStateContext.Provider> element"),e}var Mk=w.createContext(void 0);Mk.displayName="FrameworkContext";function iB(){let e=w.useContext(Mk);return Lk(e,"You must render this element inside a <HydratedRouter> element"),e}function R9(e,t){let n=w.useContext(Mk),[r,a]=w.useState(!1),[o,s]=w.useState(!1),{onFocus:l,onBlur:u,onMouseEnter:d,onMouseLeave:p,onTouchStart:g}=t,m=w.useRef(null);w.useEffect(()=>{if(e==="render"&&s(!0),e==="viewport"){let y=A=>{A.forEach(x=>{s(x.isIntersecting)})},k=new IntersectionObserver(y,{threshold:.5});return m.current&&k.observe(m.current),()=>{k.disconnect()}}},[e]),w.useEffect(()=>{if(r){let y=setTimeout(()=>{s(!0)},100);return()=>{clearTimeout(y)}}},[r]);let b=()=>{a(!0)},v=()=>{a(!1),s(!1)};return n?e!=="intent"?[o,m,{}]:[o,m,{onFocus:ec(l,b),onBlur:ec(u,v),onMouseEnter:ec(d,b),onMouseLeave:ec(p,v),onTouchStart:ec(g,b)}]:[!1,m,{}]}function ec(e,t){return n=>{e&&e(n),n.defaultPrevented||t(n)}}function C9({page:e,...t}){let{router:n}=oB(),r=w.useMemo(()=>Yz(n.routes,e,n.basename),[n.routes,e,n.basename]);return r?w.createElement(N9,{page:e,matches:r,...t}):null}function _9(e){let{manifest:t,routeModules:n}=iB(),[r,a]=w.useState([]);return w.useEffect(()=>{let o=!1;return S9(e,t,n).then(s=>{o||a(s)}),()=>{o=!0}},[e,t,n]),r}function N9({page:e,matches:t,...n}){let r=ki(),{manifest:a,routeModules:o}=iB(),{basename:s}=oB(),{loaderData:l,matches:u}=A9(),d=w.useMemo(()=>m_(e,t,u,a,r,"data"),[e,t,u,a,r]),p=w.useMemo(()=>m_(e,t,u,a,r,"assets"),[e,t,u,a,r]),g=w.useMemo(()=>{if(e===r.pathname+r.search+r.hash)return[];let v=new Set,y=!1;if(t.forEach(A=>{var R;let x=a.routes[A.route.id];!x||!x.hasLoader||(!d.some(O=>O.route.id===A.route.id)&&A.route.id in l&&((R=o[A.route.id])!=null&&R.shouldRevalidate)||x.hasClientLoader?y=!0:v.add(A.route.id))}),v.size===0)return[];let k=T9(e,s);return y&&v.size>0&&k.searchParams.set("_routes",t.filter(A=>v.has(A.route.id)).map(A=>A.route.id).join(",")),[k.pathname+k.search]},[s,l,r,a,d,t,e,o]),m=w.useMemo(()=>E9(p,a),[p,a]),b=_9(p);return w.createElement(w.Fragment,null,g.map(v=>w.createElement("link",{key:v,rel:"prefetch",as:"fetch",href:v,...n})),m.map(v=>w.createElement("link",{key:v,rel:"modulepreload",href:v,...n})),b.map(({key:v,link:y})=>w.createElement("link",{key:v,...y})))}function O9(...e){return t=>{e.forEach(n=>{typeof n=="function"?n(t):n!=null&&(n.current=t)})}}var sB=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";try{sB&&(window.__reactRouterVersion="7.3.0")}catch{}function I9({basename:e,children:t,window:n}){let r=w.useRef();r.current==null&&(r.current=Eq({window:n,v5Compat:!0}));let a=r.current,[o,s]=w.useState({action:a.action,location:a.location}),l=w.useCallback(u=>{w.startTransition(()=>s(u))},[s]);return w.useLayoutEffect(()=>a.listen(l),[a,l]),w.createElement(l9,{basename:e,children:t,location:o.location,navigationType:o.action,navigator:a})}var lB=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,cB=w.forwardRef(function({onClick:t,discover:n="render",prefetch:r="none",relative:a,reloadDocument:o,replace:s,state:l,target:u,to:d,preventScrollReset:p,viewTransition:g,...m},b){let{basename:v}=w.useContext(sa),y=typeof d=="string"&&lB.test(d),k,A=!1;if(typeof d=="string"&&y&&(k=d,sB))try{let I=new URL(window.location.href),D=d.startsWith("//")?new URL(I.protocol+d):new URL(d),U=Ba(D.pathname,v);D.origin===I.origin&&U!=null?d=U+D.search+D.hash:A=!0}catch{jr(!1,`<Link to="${d}"> contains an invalid URL which will probably break when clicked - please update to a valid URL path.`)}let x=Wq(d,{relative:a}),[R,O,N]=R9(r,m),C=P9(d,{replace:s,state:l,target:u,preventScrollReset:p,relative:a,viewTransition:g});function _(I){t&&t(I),I.defaultPrevented||C(I)}let M=w.createElement("a",{...m,...N,href:k||x,onClick:A||o?t:_,ref:O9(b,O),target:u,"data-discover":!y&&n==="render"?"true":void 0});return R&&!y?w.createElement(w.Fragment,null,M,w.createElement(C9,{page:x})):M});cB.displayName="Link";var D9=w.forwardRef(function({"aria-current":t="page",caseSensitive:n=!1,className:r="",end:a=!1,style:o,to:s,viewTransition:l,children:u,...d},p){let g=Uc(s,{relative:d.relative}),m=ki(),b=w.useContext(Vf),{navigator:v,basename:y}=w.useContext(sa),k=b!=null&&U9(g)&&l===!0,A=v.encodeLocation?v.encodeLocation(g).pathname:g.pathname,x=m.pathname,R=b&&b.navigation&&b.navigation.location?b.navigation.location.pathname:null;n||(x=x.toLowerCase(),R=R?R.toLowerCase():null,A=A.toLowerCase()),R&&y&&(R=Ba(R,y)||R);const O=A!=="/"&&A.endsWith("/")?A.length-1:A.length;let N=x===A||!a&&x.startsWith(A)&&x.charAt(O)==="/",C=R!=null&&(R===A||!a&&R.startsWith(A)&&R.charAt(A.length)==="/"),_={isActive:N,isPending:C,isTransitioning:k},M=N?t:void 0,I;typeof r=="function"?I=r(_):I=[r,N?"active":null,C?"pending":null,k?"transitioning":null].filter(Boolean).join(" ");let D=typeof o=="function"?o(_):o;return w.createElement(cB,{...d,"aria-current":M,className:I,ref:p,style:D,to:s,viewTransition:l},typeof u=="function"?u(_):u)});D9.displayName="NavLink";var L9=w.forwardRef(({discover:e="render",fetcherKey:t,navigate:n,reloadDocument:r,replace:a,state:o,method:s=Yd,action:l,onSubmit:u,relative:d,preventScrollReset:p,viewTransition:g,...m},b)=>{let v=B9(),y=j9(l,{relative:d}),k=s.toLowerCase()==="get"?"get":"post",A=typeof l=="string"&&lB.test(l),x=R=>{if(u&&u(R),R.defaultPrevented)return;R.preventDefault();let O=R.nativeEvent.submitter,N=(O==null?void 0:O.getAttribute("formmethod"))||s;v(O||R.currentTarget,{fetcherKey:t,method:N,navigate:n,replace:a,state:o,relative:d,preventScrollReset:p,viewTransition:g})};return w.createElement("form",{ref:b,method:k,action:y,onSubmit:r?u:x,...m,"data-discover":!A&&e==="render"?"true":void 0})});L9.displayName="Form";function M9(e){return`${e} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function uB(e){let t=w.useContext(Us);return Gt(t,M9(e)),t}function P9(e,{target:t,replace:n,state:r,preventScrollReset:a,relative:o,viewTransition:s}={}){let l=Ok(),u=ki(),d=Uc(e,{relative:o});return w.useCallback(p=>{if(g9(p,t)){p.preventDefault();let g=n!==void 0?n:Ec(u)===Ec(d);l(e,{replace:g,state:r,preventScrollReset:a,relative:o,viewTransition:s})}},[u,l,d,n,r,t,e,a,o,s])}var F9=0,z9=()=>`__${String(++F9)}__`;function B9(){let{router:e}=uB("useSubmit"),{basename:t}=w.useContext(sa),n=a9();return w.useCallback(async(r,a={})=>{let{action:o,method:s,encType:l,formData:u,body:d}=b9(r,t);if(a.navigate===!1){let p=a.fetcherKey||z9();await e.fetch(p,n,a.action||o,{preventScrollReset:a.preventScrollReset,formData:u,body:d,formMethod:a.method||s,formEncType:a.encType||l,flushSync:a.flushSync})}else await e.navigate(a.action||o,{preventScrollReset:a.preventScrollReset,formData:u,body:d,formMethod:a.method||s,formEncType:a.encType||l,replace:a.replace,state:a.state,fromRouteId:n,flushSync:a.flushSync,viewTransition:a.viewTransition})},[e,t,n])}function j9(e,{relative:t}={}){let{basename:n}=w.useContext(sa),r=w.useContext(Ha);Gt(r,"useFormAction must be used inside a RouteContext");let[a]=r.matches.slice(-1),o={...Uc(e||".",{relative:t})},s=ki();if(e==null){o.search=s.search;let l=new URLSearchParams(o.search),u=l.getAll("index");if(u.some(p=>p==="")){l.delete("index"),u.filter(g=>g).forEach(g=>l.append("index",g));let p=l.toString();o.search=p?`?${p}`:""}}return(!e||e===".")&&a.route.index&&(o.search=o.search?o.search.replace(/^\?/,"?index&"):"?index"),n!=="/"&&(o.pathname=o.pathname==="/"?n:Fa([n,o.pathname])),Ec(o)}function U9(e,t={}){let n=w.useContext(eB);Gt(n!=null,"`useViewTransitionState` must be used within `react-router-dom`'s `RouterProvider`.  Did you accidentally import `RouterProvider` from `react-router`?");let{basename:r}=uB("useViewTransitionState"),a=Uc(e,{relative:t.relative});if(!n.isTransitioning)return!1;let o=Ba(n.currentLocation.pathname,r)||n.currentLocation.pathname,s=Ba(n.nextLocation.pathname,r)||n.nextLocation.pathname;return hf(a.pathname,s)!=null||hf(a.pathname,o)!=null}new TextEncoder;var Gc=Wz();const dB=un(Gc),b_=e=>{let t;const n=new Set,r=(d,p)=>{const g=typeof d=="function"?d(t):d;if(!Object.is(g,t)){const m=t;t=p??(typeof g!="object"||g===null)?g:Object.assign({},t,g),n.forEach(b=>b(t,m))}},a=()=>t,l={setState:r,getState:a,getInitialState:()=>u,subscribe:d=>(n.add(d),()=>n.delete(d))},u=t=e(r,a,l);return l},G9=e=>e?b_(e):b_,H9=e=>e;function $9(e,t=H9){const n=we.useSyncExternalStore(e.subscribe,()=>t(e.getState()),()=>t(e.getInitialState()));return we.useDebugValue(n),n}const y_=e=>{const t=G9(e),n=r=>$9(t,r);return Object.assign(n,t),n},Yf=e=>e?y_(e):y_;function fB(e){var t,n,r="";if(typeof e=="string"||typeof e=="number")r+=e;else if(typeof e=="object")if(Array.isArray(e)){var a=e.length;for(t=0;t<a;t++)e[t]&&(n=fB(e[t]))&&(r&&(r+=" "),r+=n)}else for(n in e)e[n]&&(r&&(r+=" "),r+=n);return r}function pB(){for(var e,t,n=0,r="",a=arguments.length;n<a;n++)(e=arguments[n])&&(t=fB(e))&&(r&&(r+=" "),r+=t);return r}const Pk="-",q9=e=>{const t=W9(e),{conflictingClassGroups:n,conflictingClassGroupModifiers:r}=e;return{getClassGroupId:s=>{const l=s.split(Pk);return l[0]===""&&l.length!==1&&l.shift(),gB(l,t)||V9(s)},getConflictingClassGroupIds:(s,l)=>{const u=n[s]||[];return l&&r[s]?[...u,...r[s]]:u}}},gB=(e,t)=>{var s;if(e.length===0)return t.classGroupId;const n=e[0],r=t.nextPart.get(n),a=r?gB(e.slice(1),r):void 0;if(a)return a;if(t.validators.length===0)return;const o=e.join(Pk);return(s=t.validators.find(({validator:l})=>l(o)))==null?void 0:s.classGroupId},v_=/^\[(.+)\]$/,V9=e=>{if(v_.test(e)){const t=v_.exec(e)[1],n=t==null?void 0:t.substring(0,t.indexOf(":"));if(n)return"arbitrary.."+n}},W9=e=>{const{theme:t,classGroups:n}=e,r={nextPart:new Map,validators:[]};for(const a in n)f0(n[a],r,a,t);return r},f0=(e,t,n,r)=>{e.forEach(a=>{if(typeof a=="string"){const o=a===""?t:S_(t,a);o.classGroupId=n;return}if(typeof a=="function"){if(Y9(a)){f0(a(r),t,n,r);return}t.validators.push({validator:a,classGroupId:n});return}Object.entries(a).forEach(([o,s])=>{f0(s,S_(t,o),n,r)})})},S_=(e,t)=>{let n=e;return t.split(Pk).forEach(r=>{n.nextPart.has(r)||n.nextPart.set(r,{nextPart:new Map,validators:[]}),n=n.nextPart.get(r)}),n},Y9=e=>e.isThemeGetter,K9=e=>{if(e<1)return{get:()=>{},set:()=>{}};let t=0,n=new Map,r=new Map;const a=(o,s)=>{n.set(o,s),t++,t>e&&(t=0,r=n,n=new Map)};return{get(o){let s=n.get(o);if(s!==void 0)return s;if((s=r.get(o))!==void 0)return a(o,s),s},set(o,s){n.has(o)?n.set(o,s):a(o,s)}}},p0="!",g0=":",X9=g0.length,Z9=e=>{const{prefix:t,experimentalParseClassName:n}=e;let r=a=>{const o=[];let s=0,l=0,u=0,d;for(let v=0;v<a.length;v++){let y=a[v];if(s===0&&l===0){if(y===g0){o.push(a.slice(u,v)),u=v+X9;continue}if(y==="/"){d=v;continue}}y==="["?s++:y==="]"?s--:y==="("?l++:y===")"&&l--}const p=o.length===0?a:a.substring(u),g=Q9(p),m=g!==p,b=d&&d>u?d-u:void 0;return{modifiers:o,hasImportantModifier:m,baseClassName:g,maybePostfixModifierPosition:b}};if(t){const a=t+g0,o=r;r=s=>s.startsWith(a)?o(s.substring(a.length)):{isExternal:!0,modifiers:[],hasImportantModifier:!1,baseClassName:s,maybePostfixModifierPosition:void 0}}if(n){const a=r;r=o=>n({className:o,parseClassName:a})}return r},Q9=e=>e.endsWith(p0)?e.substring(0,e.length-1):e.startsWith(p0)?e.substring(1):e,J9=e=>{const t=Object.fromEntries(e.orderSensitiveModifiers.map(r=>[r,!0]));return r=>{if(r.length<=1)return r;const a=[];let o=[];return r.forEach(s=>{s[0]==="["||t[s]?(a.push(...o.sort(),s),o=[]):o.push(s)}),a.push(...o.sort()),a}},e8=e=>({cache:K9(e.cacheSize),parseClassName:Z9(e),sortModifiers:J9(e),...q9(e)}),t8=/\s+/,n8=(e,t)=>{const{parseClassName:n,getClassGroupId:r,getConflictingClassGroupIds:a,sortModifiers:o}=t,s=[],l=e.trim().split(t8);let u="";for(let d=l.length-1;d>=0;d-=1){const p=l[d],{isExternal:g,modifiers:m,hasImportantModifier:b,baseClassName:v,maybePostfixModifierPosition:y}=n(p);if(g){u=p+(u.length>0?" "+u:u);continue}let k=!!y,A=r(k?v.substring(0,y):v);if(!A){if(!k){u=p+(u.length>0?" "+u:u);continue}if(A=r(v),!A){u=p+(u.length>0?" "+u:u);continue}k=!1}const x=o(m).join(":"),R=b?x+p0:x,O=R+A;if(s.includes(O))continue;s.push(O);const N=a(A,k);for(let C=0;C<N.length;++C){const _=N[C];s.push(R+_)}u=p+(u.length>0?" "+u:u)}return u};function r8(){let e=0,t,n,r="";for(;e<arguments.length;)(t=arguments[e++])&&(n=hB(t))&&(r&&(r+=" "),r+=n);return r}const hB=e=>{if(typeof e=="string")return e;let t,n="";for(let r=0;r<e.length;r++)e[r]&&(t=hB(e[r]))&&(n&&(n+=" "),n+=t);return n};function a8(e,...t){let n,r,a,o=s;function s(u){const d=t.reduce((p,g)=>g(p),e());return n=e8(d),r=n.cache.get,a=n.cache.set,o=l,l(u)}function l(u){const d=r(u);if(d)return d;const p=n8(u,n);return a(u,p),p}return function(){return o(r8.apply(null,arguments))}}const cn=e=>{const t=n=>n[e]||[];return t.isThemeGetter=!0,t},mB=/^\[(?:(\w[\w-]*):)?(.+)\]$/i,bB=/^\((?:(\w[\w-]*):)?(.+)\)$/i,o8=/^\d+\/\d+$/,i8=/^(\d+(\.\d+)?)?(xs|sm|md|lg|xl)$/,s8=/\d+(%|px|r?em|[sdl]?v([hwib]|min|max)|pt|pc|in|cm|mm|cap|ch|ex|r?lh|cq(w|h|i|b|min|max))|\b(calc|min|max|clamp)\(.+\)|^0$/,l8=/^(rgba?|hsla?|hwb|(ok)?(lab|lch))\(.+\)$/,c8=/^(inset_)?-?((\d+)?\.?(\d+)[a-z]+|0)_-?((\d+)?\.?(\d+)[a-z]+|0)/,u8=/^(url|image|image-set|cross-fade|element|(repeating-)?(linear|radial|conic)-gradient)\(.+\)$/,us=e=>o8.test(e),gt=e=>!!e&&!Number.isNaN(Number(e)),ri=e=>!!e&&Number.isInteger(Number(e)),E_=e=>e.endsWith("%")&&gt(e.slice(0,-1)),mo=e=>i8.test(e),d8=()=>!0,f8=e=>s8.test(e)&&!l8.test(e),Fk=()=>!1,p8=e=>c8.test(e),g8=e=>u8.test(e),h8=e=>!He(e)&&!$e(e),m8=e=>Gs(e,SB,Fk),He=e=>mB.test(e),ai=e=>Gs(e,EB,f8),tm=e=>Gs(e,R8,gt),b8=e=>Gs(e,yB,Fk),y8=e=>Gs(e,vB,g8),v8=e=>Gs(e,Fk,p8),$e=e=>bB.test(e),yd=e=>Hs(e,EB),S8=e=>Hs(e,C8),E8=e=>Hs(e,yB),w8=e=>Hs(e,SB),x8=e=>Hs(e,vB),k8=e=>Hs(e,_8,!0),Gs=(e,t,n)=>{const r=mB.exec(e);return r?r[1]?t(r[1]):n(r[2]):!1},Hs=(e,t,n=!1)=>{const r=bB.exec(e);return r?r[1]?t(r[1]):n:!1},yB=e=>e==="position",T8=new Set(["image","url"]),vB=e=>T8.has(e),A8=new Set(["length","size","percentage"]),SB=e=>A8.has(e),EB=e=>e==="length",R8=e=>e==="number",C8=e=>e==="family-name",_8=e=>e==="shadow",N8=()=>{const e=cn("color"),t=cn("font"),n=cn("text"),r=cn("font-weight"),a=cn("tracking"),o=cn("leading"),s=cn("breakpoint"),l=cn("container"),u=cn("spacing"),d=cn("radius"),p=cn("shadow"),g=cn("inset-shadow"),m=cn("drop-shadow"),b=cn("blur"),v=cn("perspective"),y=cn("aspect"),k=cn("ease"),A=cn("animate"),x=()=>["auto","avoid","all","avoid-page","page","left","right","column"],R=()=>["bottom","center","left","left-bottom","left-top","right","right-bottom","right-top","top"],O=()=>["auto","hidden","clip","visible","scroll"],N=()=>["auto","contain","none"],C=()=>[$e,He,u],_=()=>[us,"full","auto",...C()],M=()=>[ri,"none","subgrid",$e,He],I=()=>["auto",{span:["full",ri,$e,He]},$e,He],D=()=>[ri,"auto",$e,He],U=()=>["auto","min","max","fr",$e,He],$=()=>["start","end","center","between","around","evenly","stretch","baseline"],B=()=>["start","end","center","stretch"],W=()=>["auto",...C()],K=()=>[us,"auto","full","dvw","dvh","lvw","lvh","svw","svh","min","max","fit",...C()],H=()=>[e,$e,He],G=()=>[E_,ai],z=()=>["","none","full",d,$e,He],Y=()=>["",gt,yd,ai],L=()=>["solid","dashed","dotted","double"],V=()=>["normal","multiply","screen","overlay","darken","lighten","color-dodge","color-burn","hard-light","soft-light","difference","exclusion","hue","saturation","color","luminosity"],j=()=>["","none",b,$e,He],P=()=>["center","top","top-right","right","bottom-right","bottom","bottom-left","left","top-left",$e,He],Z=()=>["none",gt,$e,He],Q=()=>["none",gt,$e,He],oe=()=>[gt,$e,He],ae=()=>[us,"full",...C()];return{cacheSize:500,theme:{animate:["spin","ping","pulse","bounce"],aspect:["video"],blur:[mo],breakpoint:[mo],color:[d8],container:[mo],"drop-shadow":[mo],ease:["in","out","in-out"],font:[h8],"font-weight":["thin","extralight","light","normal","medium","semibold","bold","extrabold","black"],"inset-shadow":[mo],leading:["none","tight","snug","normal","relaxed","loose"],perspective:["dramatic","near","normal","midrange","distant","none"],radius:[mo],shadow:[mo],spacing:["px",gt],text:[mo],tracking:["tighter","tight","normal","wide","wider","widest"]},classGroups:{aspect:[{aspect:["auto","square",us,He,$e,y]}],container:["container"],columns:[{columns:[gt,He,$e,l]}],"break-after":[{"break-after":x()}],"break-before":[{"break-before":x()}],"break-inside":[{"break-inside":["auto","avoid","avoid-page","avoid-column"]}],"box-decoration":[{"box-decoration":["slice","clone"]}],box:[{box:["border","content"]}],display:["block","inline-block","inline","flex","inline-flex","table","inline-table","table-caption","table-cell","table-column","table-column-group","table-footer-group","table-header-group","table-row-group","table-row","flow-root","grid","inline-grid","contents","list-item","hidden"],sr:["sr-only","not-sr-only"],float:[{float:["right","left","none","start","end"]}],clear:[{clear:["left","right","both","none","start","end"]}],isolation:["isolate","isolation-auto"],"object-fit":[{object:["contain","cover","fill","none","scale-down"]}],"object-position":[{object:[...R(),He,$e]}],overflow:[{overflow:O()}],"overflow-x":[{"overflow-x":O()}],"overflow-y":[{"overflow-y":O()}],overscroll:[{overscroll:N()}],"overscroll-x":[{"overscroll-x":N()}],"overscroll-y":[{"overscroll-y":N()}],position:["static","fixed","absolute","relative","sticky"],inset:[{inset:_()}],"inset-x":[{"inset-x":_()}],"inset-y":[{"inset-y":_()}],start:[{start:_()}],end:[{end:_()}],top:[{top:_()}],right:[{right:_()}],bottom:[{bottom:_()}],left:[{left:_()}],visibility:["visible","invisible","collapse"],z:[{z:[ri,"auto",$e,He]}],basis:[{basis:[us,"full","auto",l,...C()]}],"flex-direction":[{flex:["row","row-reverse","col","col-reverse"]}],"flex-wrap":[{flex:["nowrap","wrap","wrap-reverse"]}],flex:[{flex:[gt,us,"auto","initial","none",He]}],grow:[{grow:["",gt,$e,He]}],shrink:[{shrink:["",gt,$e,He]}],order:[{order:[ri,"first","last","none",$e,He]}],"grid-cols":[{"grid-cols":M()}],"col-start-end":[{col:I()}],"col-start":[{"col-start":D()}],"col-end":[{"col-end":D()}],"grid-rows":[{"grid-rows":M()}],"row-start-end":[{row:I()}],"row-start":[{"row-start":D()}],"row-end":[{"row-end":D()}],"grid-flow":[{"grid-flow":["row","col","dense","row-dense","col-dense"]}],"auto-cols":[{"auto-cols":U()}],"auto-rows":[{"auto-rows":U()}],gap:[{gap:C()}],"gap-x":[{"gap-x":C()}],"gap-y":[{"gap-y":C()}],"justify-content":[{justify:[...$(),"normal"]}],"justify-items":[{"justify-items":[...B(),"normal"]}],"justify-self":[{"justify-self":["auto",...B()]}],"align-content":[{content:["normal",...$()]}],"align-items":[{items:[...B(),"baseline"]}],"align-self":[{self:["auto",...B(),"baseline"]}],"place-content":[{"place-content":$()}],"place-items":[{"place-items":[...B(),"baseline"]}],"place-self":[{"place-self":["auto",...B()]}],p:[{p:C()}],px:[{px:C()}],py:[{py:C()}],ps:[{ps:C()}],pe:[{pe:C()}],pt:[{pt:C()}],pr:[{pr:C()}],pb:[{pb:C()}],pl:[{pl:C()}],m:[{m:W()}],mx:[{mx:W()}],my:[{my:W()}],ms:[{ms:W()}],me:[{me:W()}],mt:[{mt:W()}],mr:[{mr:W()}],mb:[{mb:W()}],ml:[{ml:W()}],"space-x":[{"space-x":C()}],"space-x-reverse":["space-x-reverse"],"space-y":[{"space-y":C()}],"space-y-reverse":["space-y-reverse"],size:[{size:K()}],w:[{w:[l,"screen",...K()]}],"min-w":[{"min-w":[l,"screen","none",...K()]}],"max-w":[{"max-w":[l,"screen","none","prose",{screen:[s]},...K()]}],h:[{h:["screen",...K()]}],"min-h":[{"min-h":["screen","none",...K()]}],"max-h":[{"max-h":["screen",...K()]}],"font-size":[{text:["base",n,yd,ai]}],"font-smoothing":["antialiased","subpixel-antialiased"],"font-style":["italic","not-italic"],"font-weight":[{font:[r,$e,tm]}],"font-stretch":[{"font-stretch":["ultra-condensed","extra-condensed","condensed","semi-condensed","normal","semi-expanded","expanded","extra-expanded","ultra-expanded",E_,He]}],"font-family":[{font:[S8,He,t]}],"fvn-normal":["normal-nums"],"fvn-ordinal":["ordinal"],"fvn-slashed-zero":["slashed-zero"],"fvn-figure":["lining-nums","oldstyle-nums"],"fvn-spacing":["proportional-nums","tabular-nums"],"fvn-fraction":["diagonal-fractions","stacked-fractions"],tracking:[{tracking:[a,$e,He]}],"line-clamp":[{"line-clamp":[gt,"none",$e,tm]}],leading:[{leading:[o,...C()]}],"list-image":[{"list-image":["none",$e,He]}],"list-style-position":[{list:["inside","outside"]}],"list-style-type":[{list:["disc","decimal","none",$e,He]}],"text-alignment":[{text:["left","center","right","justify","start","end"]}],"placeholder-color":[{placeholder:H()}],"text-color":[{text:H()}],"text-decoration":["underline","overline","line-through","no-underline"],"text-decoration-style":[{decoration:[...L(),"wavy"]}],"text-decoration-thickness":[{decoration:[gt,"from-font","auto",$e,ai]}],"text-decoration-color":[{decoration:H()}],"underline-offset":[{"underline-offset":[gt,"auto",$e,He]}],"text-transform":["uppercase","lowercase","capitalize","normal-case"],"text-overflow":["truncate","text-ellipsis","text-clip"],"text-wrap":[{text:["wrap","nowrap","balance","pretty"]}],indent:[{indent:C()}],"vertical-align":[{align:["baseline","top","middle","bottom","text-top","text-bottom","sub","super",$e,He]}],whitespace:[{whitespace:["normal","nowrap","pre","pre-line","pre-wrap","break-spaces"]}],break:[{break:["normal","words","all","keep"]}],hyphens:[{hyphens:["none","manual","auto"]}],content:[{content:["none",$e,He]}],"bg-attachment":[{bg:["fixed","local","scroll"]}],"bg-clip":[{"bg-clip":["border","padding","content","text"]}],"bg-origin":[{"bg-origin":["border","padding","content"]}],"bg-position":[{bg:[...R(),E8,b8]}],"bg-repeat":[{bg:["no-repeat",{repeat:["","x","y","space","round"]}]}],"bg-size":[{bg:["auto","cover","contain",w8,m8]}],"bg-image":[{bg:["none",{linear:[{to:["t","tr","r","br","b","bl","l","tl"]},ri,$e,He],radial:["",$e,He],conic:[ri,$e,He]},x8,y8]}],"bg-color":[{bg:H()}],"gradient-from-pos":[{from:G()}],"gradient-via-pos":[{via:G()}],"gradient-to-pos":[{to:G()}],"gradient-from":[{from:H()}],"gradient-via":[{via:H()}],"gradient-to":[{to:H()}],rounded:[{rounded:z()}],"rounded-s":[{"rounded-s":z()}],"rounded-e":[{"rounded-e":z()}],"rounded-t":[{"rounded-t":z()}],"rounded-r":[{"rounded-r":z()}],"rounded-b":[{"rounded-b":z()}],"rounded-l":[{"rounded-l":z()}],"rounded-ss":[{"rounded-ss":z()}],"rounded-se":[{"rounded-se":z()}],"rounded-ee":[{"rounded-ee":z()}],"rounded-es":[{"rounded-es":z()}],"rounded-tl":[{"rounded-tl":z()}],"rounded-tr":[{"rounded-tr":z()}],"rounded-br":[{"rounded-br":z()}],"rounded-bl":[{"rounded-bl":z()}],"border-w":[{border:Y()}],"border-w-x":[{"border-x":Y()}],"border-w-y":[{"border-y":Y()}],"border-w-s":[{"border-s":Y()}],"border-w-e":[{"border-e":Y()}],"border-w-t":[{"border-t":Y()}],"border-w-r":[{"border-r":Y()}],"border-w-b":[{"border-b":Y()}],"border-w-l":[{"border-l":Y()}],"divide-x":[{"divide-x":Y()}],"divide-x-reverse":["divide-x-reverse"],"divide-y":[{"divide-y":Y()}],"divide-y-reverse":["divide-y-reverse"],"border-style":[{border:[...L(),"hidden","none"]}],"divide-style":[{divide:[...L(),"hidden","none"]}],"border-color":[{border:H()}],"border-color-x":[{"border-x":H()}],"border-color-y":[{"border-y":H()}],"border-color-s":[{"border-s":H()}],"border-color-e":[{"border-e":H()}],"border-color-t":[{"border-t":H()}],"border-color-r":[{"border-r":H()}],"border-color-b":[{"border-b":H()}],"border-color-l":[{"border-l":H()}],"divide-color":[{divide:H()}],"outline-style":[{outline:[...L(),"none","hidden"]}],"outline-offset":[{"outline-offset":[gt,$e,He]}],"outline-w":[{outline:["",gt,yd,ai]}],"outline-color":[{outline:[e]}],shadow:[{shadow:["","none",p,k8,v8]}],"shadow-color":[{shadow:H()}],"inset-shadow":[{"inset-shadow":["none",$e,He,g]}],"inset-shadow-color":[{"inset-shadow":H()}],"ring-w":[{ring:Y()}],"ring-w-inset":["ring-inset"],"ring-color":[{ring:H()}],"ring-offset-w":[{"ring-offset":[gt,ai]}],"ring-offset-color":[{"ring-offset":H()}],"inset-ring-w":[{"inset-ring":Y()}],"inset-ring-color":[{"inset-ring":H()}],opacity:[{opacity:[gt,$e,He]}],"mix-blend":[{"mix-blend":[...V(),"plus-darker","plus-lighter"]}],"bg-blend":[{"bg-blend":V()}],filter:[{filter:["","none",$e,He]}],blur:[{blur:j()}],brightness:[{brightness:[gt,$e,He]}],contrast:[{contrast:[gt,$e,He]}],"drop-shadow":[{"drop-shadow":["","none",m,$e,He]}],grayscale:[{grayscale:["",gt,$e,He]}],"hue-rotate":[{"hue-rotate":[gt,$e,He]}],invert:[{invert:["",gt,$e,He]}],saturate:[{saturate:[gt,$e,He]}],sepia:[{sepia:["",gt,$e,He]}],"backdrop-filter":[{"backdrop-filter":["","none",$e,He]}],"backdrop-blur":[{"backdrop-blur":j()}],"backdrop-brightness":[{"backdrop-brightness":[gt,$e,He]}],"backdrop-contrast":[{"backdrop-contrast":[gt,$e,He]}],"backdrop-grayscale":[{"backdrop-grayscale":["",gt,$e,He]}],"backdrop-hue-rotate":[{"backdrop-hue-rotate":[gt,$e,He]}],"backdrop-invert":[{"backdrop-invert":["",gt,$e,He]}],"backdrop-opacity":[{"backdrop-opacity":[gt,$e,He]}],"backdrop-saturate":[{"backdrop-saturate":[gt,$e,He]}],"backdrop-sepia":[{"backdrop-sepia":["",gt,$e,He]}],"border-collapse":[{border:["collapse","separate"]}],"border-spacing":[{"border-spacing":C()}],"border-spacing-x":[{"border-spacing-x":C()}],"border-spacing-y":[{"border-spacing-y":C()}],"table-layout":[{table:["auto","fixed"]}],caption:[{caption:["top","bottom"]}],transition:[{transition:["","all","colors","opacity","shadow","transform","none",$e,He]}],"transition-behavior":[{transition:["normal","discrete"]}],duration:[{duration:[gt,"initial",$e,He]}],ease:[{ease:["linear","initial",k,$e,He]}],delay:[{delay:[gt,$e,He]}],animate:[{animate:["none",A,$e,He]}],backface:[{backface:["hidden","visible"]}],perspective:[{perspective:[v,$e,He]}],"perspective-origin":[{"perspective-origin":P()}],rotate:[{rotate:Z()}],"rotate-x":[{"rotate-x":Z()}],"rotate-y":[{"rotate-y":Z()}],"rotate-z":[{"rotate-z":Z()}],scale:[{scale:Q()}],"scale-x":[{"scale-x":Q()}],"scale-y":[{"scale-y":Q()}],"scale-z":[{"scale-z":Q()}],"scale-3d":["scale-3d"],skew:[{skew:oe()}],"skew-x":[{"skew-x":oe()}],"skew-y":[{"skew-y":oe()}],transform:[{transform:[$e,He,"","none","gpu","cpu"]}],"transform-origin":[{origin:P()}],"transform-style":[{transform:["3d","flat"]}],translate:[{translate:ae()}],"translate-x":[{"translate-x":ae()}],"translate-y":[{"translate-y":ae()}],"translate-z":[{"translate-z":ae()}],"translate-none":["translate-none"],accent:[{accent:H()}],appearance:[{appearance:["none","auto"]}],"caret-color":[{caret:H()}],"color-scheme":[{scheme:["normal","dark","light","light-dark","only-dark","only-light"]}],cursor:[{cursor:["auto","default","pointer","wait","text","move","help","not-allowed","none","context-menu","progress","cell","crosshair","vertical-text","alias","copy","no-drop","grab","grabbing","all-scroll","col-resize","row-resize","n-resize","e-resize","s-resize","w-resize","ne-resize","nw-resize","se-resize","sw-resize","ew-resize","ns-resize","nesw-resize","nwse-resize","zoom-in","zoom-out",$e,He]}],"field-sizing":[{"field-sizing":["fixed","content"]}],"pointer-events":[{"pointer-events":["auto","none"]}],resize:[{resize:["none","","y","x"]}],"scroll-behavior":[{scroll:["auto","smooth"]}],"scroll-m":[{"scroll-m":C()}],"scroll-mx":[{"scroll-mx":C()}],"scroll-my":[{"scroll-my":C()}],"scroll-ms":[{"scroll-ms":C()}],"scroll-me":[{"scroll-me":C()}],"scroll-mt":[{"scroll-mt":C()}],"scroll-mr":[{"scroll-mr":C()}],"scroll-mb":[{"scroll-mb":C()}],"scroll-ml":[{"scroll-ml":C()}],"scroll-p":[{"scroll-p":C()}],"scroll-px":[{"scroll-px":C()}],"scroll-py":[{"scroll-py":C()}],"scroll-ps":[{"scroll-ps":C()}],"scroll-pe":[{"scroll-pe":C()}],"scroll-pt":[{"scroll-pt":C()}],"scroll-pr":[{"scroll-pr":C()}],"scroll-pb":[{"scroll-pb":C()}],"scroll-pl":[{"scroll-pl":C()}],"snap-align":[{snap:["start","end","center","align-none"]}],"snap-stop":[{snap:["normal","always"]}],"snap-type":[{snap:["none","x","y","both"]}],"snap-strictness":[{snap:["mandatory","proximity"]}],touch:[{touch:["auto","none","manipulation"]}],"touch-x":[{"touch-pan":["x","left","right"]}],"touch-y":[{"touch-pan":["y","up","down"]}],"touch-pz":["touch-pinch-zoom"],select:[{select:["none","text","all","auto"]}],"will-change":[{"will-change":["auto","scroll","contents","transform",$e,He]}],fill:[{fill:["none",...H()]}],"stroke-w":[{stroke:[gt,yd,ai,tm]}],stroke:[{stroke:["none",...H()]}],"forced-color-adjust":[{"forced-color-adjust":["auto","none"]}]},conflictingClassGroups:{overflow:["overflow-x","overflow-y"],overscroll:["overscroll-x","overscroll-y"],inset:["inset-x","inset-y","start","end","top","right","bottom","left"],"inset-x":["right","left"],"inset-y":["top","bottom"],flex:["basis","grow","shrink"],gap:["gap-x","gap-y"],p:["px","py","ps","pe","pt","pr","pb","pl"],px:["pr","pl"],py:["pt","pb"],m:["mx","my","ms","me","mt","mr","mb","ml"],mx:["mr","ml"],my:["mt","mb"],size:["w","h"],"font-size":["leading"],"fvn-normal":["fvn-ordinal","fvn-slashed-zero","fvn-figure","fvn-spacing","fvn-fraction"],"fvn-ordinal":["fvn-normal"],"fvn-slashed-zero":["fvn-normal"],"fvn-figure":["fvn-normal"],"fvn-spacing":["fvn-normal"],"fvn-fraction":["fvn-normal"],"line-clamp":["display","overflow"],rounded:["rounded-s","rounded-e","rounded-t","rounded-r","rounded-b","rounded-l","rounded-ss","rounded-se","rounded-ee","rounded-es","rounded-tl","rounded-tr","rounded-br","rounded-bl"],"rounded-s":["rounded-ss","rounded-es"],"rounded-e":["rounded-se","rounded-ee"],"rounded-t":["rounded-tl","rounded-tr"],"rounded-r":["rounded-tr","rounded-br"],"rounded-b":["rounded-br","rounded-bl"],"rounded-l":["rounded-tl","rounded-bl"],"border-spacing":["border-spacing-x","border-spacing-y"],"border-w":["border-w-s","border-w-e","border-w-t","border-w-r","border-w-b","border-w-l"],"border-w-x":["border-w-r","border-w-l"],"border-w-y":["border-w-t","border-w-b"],"border-color":["border-color-s","border-color-e","border-color-t","border-color-r","border-color-b","border-color-l"],"border-color-x":["border-color-r","border-color-l"],"border-color-y":["border-color-t","border-color-b"],translate:["translate-x","translate-y","translate-none"],"translate-none":["translate","translate-x","translate-y","translate-z"],"scroll-m":["scroll-mx","scroll-my","scroll-ms","scroll-me","scroll-mt","scroll-mr","scroll-mb","scroll-ml"],"scroll-mx":["scroll-mr","scroll-ml"],"scroll-my":["scroll-mt","scroll-mb"],"scroll-p":["scroll-px","scroll-py","scroll-ps","scroll-pe","scroll-pt","scroll-pr","scroll-pb","scroll-pl"],"scroll-px":["scroll-pr","scroll-pl"],"scroll-py":["scroll-pt","scroll-pb"],touch:["touch-x","touch-y","touch-pz"],"touch-x":["touch"],"touch-y":["touch"],"touch-pz":["touch"]},conflictingClassGroupModifiers:{"font-size":["leading"]},orderSensitiveModifiers:["before","after","placeholder","file","marker","selection","first-line","first-letter","backdrop","*","**"]}},O8=a8(N8);function Me(...e){return O8(pB(e))}function Gn(e){return e instanceof Error?e.message:`${e}`}const zk=e=>{const t=e;t.use={};for(const n of Object.keys(t.getState()))t.use[n]=()=>t(r=>r[n]);return t};function wB(e,t){return function(){return e.apply(t,arguments)}}const{toString:I8}=Object.prototype,{getPrototypeOf:Bk}=Object,Kf=(e=>t=>{const n=I8.call(t);return e[n]||(e[n]=n.slice(8,-1).toLowerCase())})(Object.create(null)),Hr=e=>(e=e.toLowerCase(),t=>Kf(t)===e),Xf=e=>t=>typeof t===e,{isArray:$s}=Array,wc=Xf("undefined");function D8(e){return e!==null&&!wc(e)&&e.constructor!==null&&!wc(e.constructor)&&nr(e.constructor.isBuffer)&&e.constructor.isBuffer(e)}const xB=Hr("ArrayBuffer");function L8(e){let t;return typeof ArrayBuffer<"u"&&ArrayBuffer.isView?t=ArrayBuffer.isView(e):t=e&&e.buffer&&xB(e.buffer),t}const M8=Xf("string"),nr=Xf("function"),kB=Xf("number"),Zf=e=>e!==null&&typeof e=="object",P8=e=>e===!0||e===!1,Xd=e=>{if(Kf(e)!=="object")return!1;const t=Bk(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)},F8=Hr("Date"),z8=Hr("File"),B8=Hr("Blob"),j8=Hr("FileList"),U8=e=>Zf(e)&&nr(e.pipe),G8=e=>{let t;return e&&(typeof FormData=="function"&&e instanceof FormData||nr(e.append)&&((t=Kf(e))==="formdata"||t==="object"&&nr(e.toString)&&e.toString()==="[object FormData]"))},H8=Hr("URLSearchParams"),[$8,q8,V8,W8]=["ReadableStream","Request","Response","Headers"].map(Hr),Y8=e=>e.trim?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"");function Hc(e,t,{allOwnKeys:n=!1}={}){if(e===null||typeof e>"u")return;let r,a;if(typeof e!="object"&&(e=[e]),$s(e))for(r=0,a=e.length;r<a;r++)t.call(null,e[r],r,e);else{const o=n?Object.getOwnPropertyNames(e):Object.keys(e),s=o.length;let l;for(r=0;r<s;r++)l=o[r],t.call(null,e[l],l,e)}}function TB(e,t){t=t.toLowerCase();const n=Object.keys(e);let r=n.length,a;for(;r-- >0;)if(a=n[r],t===a.toLowerCase())return a;return null}const fi=typeof globalThis<"u"?globalThis:typeof self<"u"?self:typeof window<"u"?window:global,AB=e=>!wc(e)&&e!==fi;function h0(){const{caseless:e}=AB(this)&&this||{},t={},n=(r,a)=>{const o=e&&TB(t,a)||a;Xd(t[o])&&Xd(r)?t[o]=h0(t[o],r):Xd(r)?t[o]=h0({},r):$s(r)?t[o]=r.slice():t[o]=r};for(let r=0,a=arguments.length;r<a;r++)arguments[r]&&Hc(arguments[r],n);return t}const K8=(e,t,n,{allOwnKeys:r}={})=>(Hc(t,(a,o)=>{n&&nr(a)?e[o]=wB(a,n):e[o]=a},{allOwnKeys:r}),e),X8=e=>(e.charCodeAt(0)===65279&&(e=e.slice(1)),e),Z8=(e,t,n,r)=>{e.prototype=Object.create(t.prototype,r),e.prototype.constructor=e,Object.defineProperty(e,"super",{value:t.prototype}),n&&Object.assign(e.prototype,n)},Q8=(e,t,n,r)=>{let a,o,s;const l={};if(t=t||{},e==null)return t;do{for(a=Object.getOwnPropertyNames(e),o=a.length;o-- >0;)s=a[o],(!r||r(s,e,t))&&!l[s]&&(t[s]=e[s],l[s]=!0);e=n!==!1&&Bk(e)}while(e&&(!n||n(e,t))&&e!==Object.prototype);return t},J8=(e,t,n)=>{e=String(e),(n===void 0||n>e.length)&&(n=e.length),n-=t.length;const r=e.indexOf(t,n);return r!==-1&&r===n},e7=e=>{if(!e)return null;if($s(e))return e;let t=e.length;if(!kB(t))return null;const n=new Array(t);for(;t-- >0;)n[t]=e[t];return n},t7=(e=>t=>e&&t instanceof e)(typeof Uint8Array<"u"&&Bk(Uint8Array)),n7=(e,t)=>{const r=(e&&e[Symbol.iterator]).call(e);let a;for(;(a=r.next())&&!a.done;){const o=a.value;t.call(e,o[0],o[1])}},r7=(e,t)=>{let n;const r=[];for(;(n=e.exec(t))!==null;)r.push(n);return r},a7=Hr("HTMLFormElement"),o7=e=>e.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,function(n,r,a){return r.toUpperCase()+a}),w_=(({hasOwnProperty:e})=>(t,n)=>e.call(t,n))(Object.prototype),i7=Hr("RegExp"),RB=(e,t)=>{const n=Object.getOwnPropertyDescriptors(e),r={};Hc(n,(a,o)=>{let s;(s=t(a,o,e))!==!1&&(r[o]=s||a)}),Object.defineProperties(e,r)},s7=e=>{RB(e,(t,n)=>{if(nr(e)&&["arguments","caller","callee"].indexOf(n)!==-1)return!1;const r=e[n];if(nr(r)){if(t.enumerable=!1,"writable"in t){t.writable=!1;return}t.set||(t.set=()=>{throw Error("Can not rewrite read-only method '"+n+"'")})}})},l7=(e,t)=>{const n={},r=a=>{a.forEach(o=>{n[o]=!0})};return $s(e)?r(e):r(String(e).split(t)),n},c7=()=>{},u7=(e,t)=>e!=null&&Number.isFinite(e=+e)?e:t,nm="abcdefghijklmnopqrstuvwxyz",x_="0123456789",CB={DIGIT:x_,ALPHA:nm,ALPHA_DIGIT:nm+nm.toUpperCase()+x_},d7=(e=16,t=CB.ALPHA_DIGIT)=>{let n="";const{length:r}=t;for(;e--;)n+=t[Math.random()*r|0];return n};function f7(e){return!!(e&&nr(e.append)&&e[Symbol.toStringTag]==="FormData"&&e[Symbol.iterator])}const p7=e=>{const t=new Array(10),n=(r,a)=>{if(Zf(r)){if(t.indexOf(r)>=0)return;if(!("toJSON"in r)){t[a]=r;const o=$s(r)?[]:{};return Hc(r,(s,l)=>{const u=n(s,a+1);!wc(u)&&(o[l]=u)}),t[a]=void 0,o}}return r};return n(e,0)},g7=Hr("AsyncFunction"),h7=e=>e&&(Zf(e)||nr(e))&&nr(e.then)&&nr(e.catch),_B=((e,t)=>e?setImmediate:t?((n,r)=>(fi.addEventListener("message",({source:a,data:o})=>{a===fi&&o===n&&r.length&&r.shift()()},!1),a=>{r.push(a),fi.postMessage(n,"*")}))(`axios@${Math.random()}`,[]):n=>setTimeout(n))(typeof setImmediate=="function",nr(fi.postMessage)),m7=typeof queueMicrotask<"u"?queueMicrotask.bind(fi):typeof process<"u"&&process.nextTick||_B,ge={isArray:$s,isArrayBuffer:xB,isBuffer:D8,isFormData:G8,isArrayBufferView:L8,isString:M8,isNumber:kB,isBoolean:P8,isObject:Zf,isPlainObject:Xd,isReadableStream:$8,isRequest:q8,isResponse:V8,isHeaders:W8,isUndefined:wc,isDate:F8,isFile:z8,isBlob:B8,isRegExp:i7,isFunction:nr,isStream:U8,isURLSearchParams:H8,isTypedArray:t7,isFileList:j8,forEach:Hc,merge:h0,extend:K8,trim:Y8,stripBOM:X8,inherits:Z8,toFlatObject:Q8,kindOf:Kf,kindOfTest:Hr,endsWith:J8,toArray:e7,forEachEntry:n7,matchAll:r7,isHTMLForm:a7,hasOwnProperty:w_,hasOwnProp:w_,reduceDescriptors:RB,freezeMethods:s7,toObjectSet:l7,toCamelCase:o7,noop:c7,toFiniteNumber:u7,findKey:TB,global:fi,isContextDefined:AB,ALPHABET:CB,generateString:d7,isSpecCompliantForm:f7,toJSONObject:p7,isAsyncFn:g7,isThenable:h7,setImmediate:_B,asap:m7};function ot(e,t,n,r,a){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=new Error().stack,this.message=e,this.name="AxiosError",t&&(this.code=t),n&&(this.config=n),r&&(this.request=r),a&&(this.response=a,this.status=a.status?a.status:null)}ge.inherits(ot,Error,{toJSON:function(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:ge.toJSONObject(this.config),code:this.code,status:this.status}}});const NB=ot.prototype,OB={};["ERR_BAD_OPTION_VALUE","ERR_BAD_OPTION","ECONNABORTED","ETIMEDOUT","ERR_NETWORK","ERR_FR_TOO_MANY_REDIRECTS","ERR_DEPRECATED","ERR_BAD_RESPONSE","ERR_BAD_REQUEST","ERR_CANCELED","ERR_NOT_SUPPORT","ERR_INVALID_URL"].forEach(e=>{OB[e]={value:e}});Object.defineProperties(ot,OB);Object.defineProperty(NB,"isAxiosError",{value:!0});ot.from=(e,t,n,r,a,o)=>{const s=Object.create(NB);return ge.toFlatObject(e,s,function(u){return u!==Error.prototype},l=>l!=="isAxiosError"),ot.call(s,e.message,t,n,r,a),s.cause=e,s.name=e.name,o&&Object.assign(s,o),s};const b7=null;function m0(e){return ge.isPlainObject(e)||ge.isArray(e)}function IB(e){return ge.endsWith(e,"[]")?e.slice(0,-2):e}function k_(e,t,n){return e?e.concat(t).map(function(a,o){return a=IB(a),!n&&o?"["+a+"]":a}).join(n?".":""):t}function y7(e){return ge.isArray(e)&&!e.some(m0)}const v7=ge.toFlatObject(ge,{},null,function(t){return/^is[A-Z]/.test(t)});function Qf(e,t,n){if(!ge.isObject(e))throw new TypeError("target must be an object");t=t||new FormData,n=ge.toFlatObject(n,{metaTokens:!0,dots:!1,indexes:!1},!1,function(y,k){return!ge.isUndefined(k[y])});const r=n.metaTokens,a=n.visitor||p,o=n.dots,s=n.indexes,u=(n.Blob||typeof Blob<"u"&&Blob)&&ge.isSpecCompliantForm(t);if(!ge.isFunction(a))throw new TypeError("visitor must be a function");function d(v){if(v===null)return"";if(ge.isDate(v))return v.toISOString();if(!u&&ge.isBlob(v))throw new ot("Blob is not supported. Use a Buffer instead.");return ge.isArrayBuffer(v)||ge.isTypedArray(v)?u&&typeof Blob=="function"?new Blob([v]):Buffer.from(v):v}function p(v,y,k){let A=v;if(v&&!k&&typeof v=="object"){if(ge.endsWith(y,"{}"))y=r?y:y.slice(0,-2),v=JSON.stringify(v);else if(ge.isArray(v)&&y7(v)||(ge.isFileList(v)||ge.endsWith(y,"[]"))&&(A=ge.toArray(v)))return y=IB(y),A.forEach(function(R,O){!(ge.isUndefined(R)||R===null)&&t.append(s===!0?k_([y],O,o):s===null?y:y+"[]",d(R))}),!1}return m0(v)?!0:(t.append(k_(k,y,o),d(v)),!1)}const g=[],m=Object.assign(v7,{defaultVisitor:p,convertValue:d,isVisitable:m0});function b(v,y){if(!ge.isUndefined(v)){if(g.indexOf(v)!==-1)throw Error("Circular reference detected in "+y.join("."));g.push(v),ge.forEach(v,function(A,x){(!(ge.isUndefined(A)||A===null)&&a.call(t,A,ge.isString(x)?x.trim():x,y,m))===!0&&b(A,y?y.concat(x):[x])}),g.pop()}}if(!ge.isObject(e))throw new TypeError("data must be an object");return b(e),t}function T_(e){const t={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(e).replace(/[!'()~]|%20|%00/g,function(r){return t[r]})}function jk(e,t){this._pairs=[],e&&Qf(e,this,t)}const DB=jk.prototype;DB.append=function(t,n){this._pairs.push([t,n])};DB.toString=function(t){const n=t?function(r){return t.call(this,r,T_)}:T_;return this._pairs.map(function(a){return n(a[0])+"="+n(a[1])},"").join("&")};function S7(e){return encodeURIComponent(e).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}function LB(e,t,n){if(!t)return e;const r=n&&n.encode||S7;ge.isFunction(n)&&(n={serialize:n});const a=n&&n.serialize;let o;if(a?o=a(t,n):o=ge.isURLSearchParams(t)?t.toString():new jk(t,n).toString(r),o){const s=e.indexOf("#");s!==-1&&(e=e.slice(0,s)),e+=(e.indexOf("?")===-1?"?":"&")+o}return e}class A_{constructor(){this.handlers=[]}use(t,n,r){return this.handlers.push({fulfilled:t,rejected:n,synchronous:r?r.synchronous:!1,runWhen:r?r.runWhen:null}),this.handlers.length-1}eject(t){this.handlers[t]&&(this.handlers[t]=null)}clear(){this.handlers&&(this.handlers=[])}forEach(t){ge.forEach(this.handlers,function(r){r!==null&&t(r)})}}const MB={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1},E7=typeof URLSearchParams<"u"?URLSearchParams:jk,w7=typeof FormData<"u"?FormData:null,x7=typeof Blob<"u"?Blob:null,k7={isBrowser:!0,classes:{URLSearchParams:E7,FormData:w7,Blob:x7},protocols:["http","https","file","blob","url","data"]},Uk=typeof window<"u"&&typeof document<"u",b0=typeof navigator=="object"&&navigator||void 0,T7=Uk&&(!b0||["ReactNative","NativeScript","NS"].indexOf(b0.product)<0),A7=typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope&&typeof self.importScripts=="function",R7=Uk&&window.location.href||"http://localhost",C7=Object.freeze(Object.defineProperty({__proto__:null,hasBrowserEnv:Uk,hasStandardBrowserEnv:T7,hasStandardBrowserWebWorkerEnv:A7,navigator:b0,origin:R7},Symbol.toStringTag,{value:"Module"})),kn={...C7,...k7};function _7(e,t){return Qf(e,new kn.classes.URLSearchParams,Object.assign({visitor:function(n,r,a,o){return kn.isNode&&ge.isBuffer(n)?(this.append(r,n.toString("base64")),!1):o.defaultVisitor.apply(this,arguments)}},t))}function N7(e){return ge.matchAll(/\w+|\[(\w*)]/g,e).map(t=>t[0]==="[]"?"":t[1]||t[0])}function O7(e){const t={},n=Object.keys(e);let r;const a=n.length;let o;for(r=0;r<a;r++)o=n[r],t[o]=e[o];return t}function PB(e){function t(n,r,a,o){let s=n[o++];if(s==="__proto__")return!0;const l=Number.isFinite(+s),u=o>=n.length;return s=!s&&ge.isArray(a)?a.length:s,u?(ge.hasOwnProp(a,s)?a[s]=[a[s],r]:a[s]=r,!l):((!a[s]||!ge.isObject(a[s]))&&(a[s]=[]),t(n,r,a[s],o)&&ge.isArray(a[s])&&(a[s]=O7(a[s])),!l)}if(ge.isFormData(e)&&ge.isFunction(e.entries)){const n={};return ge.forEachEntry(e,(r,a)=>{t(N7(r),a,n,0)}),n}return null}function I7(e,t,n){if(ge.isString(e))try{return(t||JSON.parse)(e),ge.trim(e)}catch(r){if(r.name!=="SyntaxError")throw r}return(n||JSON.stringify)(e)}const $c={transitional:MB,adapter:["xhr","http","fetch"],transformRequest:[function(t,n){const r=n.getContentType()||"",a=r.indexOf("application/json")>-1,o=ge.isObject(t);if(o&&ge.isHTMLForm(t)&&(t=new FormData(t)),ge.isFormData(t))return a?JSON.stringify(PB(t)):t;if(ge.isArrayBuffer(t)||ge.isBuffer(t)||ge.isStream(t)||ge.isFile(t)||ge.isBlob(t)||ge.isReadableStream(t))return t;if(ge.isArrayBufferView(t))return t.buffer;if(ge.isURLSearchParams(t))return n.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),t.toString();let l;if(o){if(r.indexOf("application/x-www-form-urlencoded")>-1)return _7(t,this.formSerializer).toString();if((l=ge.isFileList(t))||r.indexOf("multipart/form-data")>-1){const u=this.env&&this.env.FormData;return Qf(l?{"files[]":t}:t,u&&new u,this.formSerializer)}}return o||a?(n.setContentType("application/json",!1),I7(t)):t}],transformResponse:[function(t){const n=this.transitional||$c.transitional,r=n&&n.forcedJSONParsing,a=this.responseType==="json";if(ge.isResponse(t)||ge.isReadableStream(t))return t;if(t&&ge.isString(t)&&(r&&!this.responseType||a)){const s=!(n&&n.silentJSONParsing)&&a;try{return JSON.parse(t)}catch(l){if(s)throw l.name==="SyntaxError"?ot.from(l,ot.ERR_BAD_RESPONSE,this,null,this.response):l}}return t}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:kn.classes.FormData,Blob:kn.classes.Blob},validateStatus:function(t){return t>=200&&t<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};ge.forEach(["delete","get","head","post","put","patch"],e=>{$c.headers[e]={}});const D7=ge.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),L7=e=>{const t={};let n,r,a;return e&&e.split(`
`).forEach(function(s){a=s.indexOf(":"),n=s.substring(0,a).trim().toLowerCase(),r=s.substring(a+1).trim(),!(!n||t[n]&&D7[n])&&(n==="set-cookie"?t[n]?t[n].push(r):t[n]=[r]:t[n]=t[n]?t[n]+", "+r:r)}),t},R_=Symbol("internals");function tc(e){return e&&String(e).trim().toLowerCase()}function Zd(e){return e===!1||e==null?e:ge.isArray(e)?e.map(Zd):String(e)}function M7(e){const t=Object.create(null),n=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;let r;for(;r=n.exec(e);)t[r[1]]=r[2];return t}const P7=e=>/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim());function rm(e,t,n,r,a){if(ge.isFunction(r))return r.call(this,t,n);if(a&&(t=n),!!ge.isString(t)){if(ge.isString(r))return t.indexOf(r)!==-1;if(ge.isRegExp(r))return r.test(t)}}function F7(e){return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(t,n,r)=>n.toUpperCase()+r)}function z7(e,t){const n=ge.toCamelCase(" "+t);["get","set","has"].forEach(r=>{Object.defineProperty(e,r+n,{value:function(a,o,s){return this[r].call(this,t,a,o,s)},configurable:!0})})}let Hn=class{constructor(t){t&&this.set(t)}set(t,n,r){const a=this;function o(l,u,d){const p=tc(u);if(!p)throw new Error("header name must be a non-empty string");const g=ge.findKey(a,p);(!g||a[g]===void 0||d===!0||d===void 0&&a[g]!==!1)&&(a[g||u]=Zd(l))}const s=(l,u)=>ge.forEach(l,(d,p)=>o(d,p,u));if(ge.isPlainObject(t)||t instanceof this.constructor)s(t,n);else if(ge.isString(t)&&(t=t.trim())&&!P7(t))s(L7(t),n);else if(ge.isHeaders(t))for(const[l,u]of t.entries())o(u,l,r);else t!=null&&o(n,t,r);return this}get(t,n){if(t=tc(t),t){const r=ge.findKey(this,t);if(r){const a=this[r];if(!n)return a;if(n===!0)return M7(a);if(ge.isFunction(n))return n.call(this,a,r);if(ge.isRegExp(n))return n.exec(a);throw new TypeError("parser must be boolean|regexp|function")}}}has(t,n){if(t=tc(t),t){const r=ge.findKey(this,t);return!!(r&&this[r]!==void 0&&(!n||rm(this,this[r],r,n)))}return!1}delete(t,n){const r=this;let a=!1;function o(s){if(s=tc(s),s){const l=ge.findKey(r,s);l&&(!n||rm(r,r[l],l,n))&&(delete r[l],a=!0)}}return ge.isArray(t)?t.forEach(o):o(t),a}clear(t){const n=Object.keys(this);let r=n.length,a=!1;for(;r--;){const o=n[r];(!t||rm(this,this[o],o,t,!0))&&(delete this[o],a=!0)}return a}normalize(t){const n=this,r={};return ge.forEach(this,(a,o)=>{const s=ge.findKey(r,o);if(s){n[s]=Zd(a),delete n[o];return}const l=t?F7(o):String(o).trim();l!==o&&delete n[o],n[l]=Zd(a),r[l]=!0}),this}concat(...t){return this.constructor.concat(this,...t)}toJSON(t){const n=Object.create(null);return ge.forEach(this,(r,a)=>{r!=null&&r!==!1&&(n[a]=t&&ge.isArray(r)?r.join(", "):r)}),n}[Symbol.iterator](){return Object.entries(this.toJSON())[Symbol.iterator]()}toString(){return Object.entries(this.toJSON()).map(([t,n])=>t+": "+n).join(`
`)}get[Symbol.toStringTag](){return"AxiosHeaders"}static from(t){return t instanceof this?t:new this(t)}static concat(t,...n){const r=new this(t);return n.forEach(a=>r.set(a)),r}static accessor(t){const r=(this[R_]=this[R_]={accessors:{}}).accessors,a=this.prototype;function o(s){const l=tc(s);r[l]||(z7(a,s),r[l]=!0)}return ge.isArray(t)?t.forEach(o):o(t),this}};Hn.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]);ge.reduceDescriptors(Hn.prototype,({value:e},t)=>{let n=t[0].toUpperCase()+t.slice(1);return{get:()=>e,set(r){this[n]=r}}});ge.freezeMethods(Hn);function am(e,t){const n=this||$c,r=t||n,a=Hn.from(r.headers);let o=r.data;return ge.forEach(e,function(l){o=l.call(n,o,a.normalize(),t?t.status:void 0)}),a.normalize(),o}function FB(e){return!!(e&&e.__CANCEL__)}function qs(e,t,n){ot.call(this,e??"canceled",ot.ERR_CANCELED,t,n),this.name="CanceledError"}ge.inherits(qs,ot,{__CANCEL__:!0});function zB(e,t,n){const r=n.config.validateStatus;!n.status||!r||r(n.status)?e(n):t(new ot("Request failed with status code "+n.status,[ot.ERR_BAD_REQUEST,ot.ERR_BAD_RESPONSE][Math.floor(n.status/100)-4],n.config,n.request,n))}function B7(e){const t=/^([-+\w]{1,25})(:?\/\/|:)/.exec(e);return t&&t[1]||""}function j7(e,t){e=e||10;const n=new Array(e),r=new Array(e);let a=0,o=0,s;return t=t!==void 0?t:1e3,function(u){const d=Date.now(),p=r[o];s||(s=d),n[a]=u,r[a]=d;let g=o,m=0;for(;g!==a;)m+=n[g++],g=g%e;if(a=(a+1)%e,a===o&&(o=(o+1)%e),d-s<t)return;const b=p&&d-p;return b?Math.round(m*1e3/b):void 0}}function U7(e,t){let n=0,r=1e3/t,a,o;const s=(d,p=Date.now())=>{n=p,a=null,o&&(clearTimeout(o),o=null),e.apply(null,d)};return[(...d)=>{const p=Date.now(),g=p-n;g>=r?s(d,p):(a=d,o||(o=setTimeout(()=>{o=null,s(a)},r-g)))},()=>a&&s(a)]}const mf=(e,t,n=3)=>{let r=0;const a=j7(50,250);return U7(o=>{const s=o.loaded,l=o.lengthComputable?o.total:void 0,u=s-r,d=a(u),p=s<=l;r=s;const g={loaded:s,total:l,progress:l?s/l:void 0,bytes:u,rate:d||void 0,estimated:d&&l&&p?(l-s)/d:void 0,event:o,lengthComputable:l!=null,[t?"download":"upload"]:!0};e(g)},n)},C_=(e,t)=>{const n=e!=null;return[r=>t[0]({lengthComputable:n,total:e,loaded:r}),t[1]]},__=e=>(...t)=>ge.asap(()=>e(...t)),G7=kn.hasStandardBrowserEnv?((e,t)=>n=>(n=new URL(n,kn.origin),e.protocol===n.protocol&&e.host===n.host&&(t||e.port===n.port)))(new URL(kn.origin),kn.navigator&&/(msie|trident)/i.test(kn.navigator.userAgent)):()=>!0,H7=kn.hasStandardBrowserEnv?{write(e,t,n,r,a,o){const s=[e+"="+encodeURIComponent(t)];ge.isNumber(n)&&s.push("expires="+new Date(n).toGMTString()),ge.isString(r)&&s.push("path="+r),ge.isString(a)&&s.push("domain="+a),o===!0&&s.push("secure"),document.cookie=s.join("; ")},read(e){const t=document.cookie.match(new RegExp("(^|;\\s*)("+e+")=([^;]*)"));return t?decodeURIComponent(t[3]):null},remove(e){this.write(e,"",Date.now()-864e5)}}:{write(){},read(){return null},remove(){}};function $7(e){return/^([a-z][a-z\d+\-.]*:)?\/\//i.test(e)}function q7(e,t){return t?e.replace(/\/?\/$/,"")+"/"+t.replace(/^\/+/,""):e}function BB(e,t){return e&&!$7(t)?q7(e,t):t}const N_=e=>e instanceof Hn?{...e}:e;function hi(e,t){t=t||{};const n={};function r(d,p,g,m){return ge.isPlainObject(d)&&ge.isPlainObject(p)?ge.merge.call({caseless:m},d,p):ge.isPlainObject(p)?ge.merge({},p):ge.isArray(p)?p.slice():p}function a(d,p,g,m){if(ge.isUndefined(p)){if(!ge.isUndefined(d))return r(void 0,d,g,m)}else return r(d,p,g,m)}function o(d,p){if(!ge.isUndefined(p))return r(void 0,p)}function s(d,p){if(ge.isUndefined(p)){if(!ge.isUndefined(d))return r(void 0,d)}else return r(void 0,p)}function l(d,p,g){if(g in t)return r(d,p);if(g in e)return r(void 0,d)}const u={url:o,method:o,data:o,baseURL:s,transformRequest:s,transformResponse:s,paramsSerializer:s,timeout:s,timeoutMessage:s,withCredentials:s,withXSRFToken:s,adapter:s,responseType:s,xsrfCookieName:s,xsrfHeaderName:s,onUploadProgress:s,onDownloadProgress:s,decompress:s,maxContentLength:s,maxBodyLength:s,beforeRedirect:s,transport:s,httpAgent:s,httpsAgent:s,cancelToken:s,socketPath:s,responseEncoding:s,validateStatus:l,headers:(d,p,g)=>a(N_(d),N_(p),g,!0)};return ge.forEach(Object.keys(Object.assign({},e,t)),function(p){const g=u[p]||a,m=g(e[p],t[p],p);ge.isUndefined(m)&&g!==l||(n[p]=m)}),n}const jB=e=>{const t=hi({},e);let{data:n,withXSRFToken:r,xsrfHeaderName:a,xsrfCookieName:o,headers:s,auth:l}=t;t.headers=s=Hn.from(s),t.url=LB(BB(t.baseURL,t.url),e.params,e.paramsSerializer),l&&s.set("Authorization","Basic "+btoa((l.username||"")+":"+(l.password?unescape(encodeURIComponent(l.password)):"")));let u;if(ge.isFormData(n)){if(kn.hasStandardBrowserEnv||kn.hasStandardBrowserWebWorkerEnv)s.setContentType(void 0);else if((u=s.getContentType())!==!1){const[d,...p]=u?u.split(";").map(g=>g.trim()).filter(Boolean):[];s.setContentType([d||"multipart/form-data",...p].join("; "))}}if(kn.hasStandardBrowserEnv&&(r&&ge.isFunction(r)&&(r=r(t)),r||r!==!1&&G7(t.url))){const d=a&&o&&H7.read(o);d&&s.set(a,d)}return t},V7=typeof XMLHttpRequest<"u",W7=V7&&function(e){return new Promise(function(n,r){const a=jB(e);let o=a.data;const s=Hn.from(a.headers).normalize();let{responseType:l,onUploadProgress:u,onDownloadProgress:d}=a,p,g,m,b,v;function y(){b&&b(),v&&v(),a.cancelToken&&a.cancelToken.unsubscribe(p),a.signal&&a.signal.removeEventListener("abort",p)}let k=new XMLHttpRequest;k.open(a.method.toUpperCase(),a.url,!0),k.timeout=a.timeout;function A(){if(!k)return;const R=Hn.from("getAllResponseHeaders"in k&&k.getAllResponseHeaders()),N={data:!l||l==="text"||l==="json"?k.responseText:k.response,status:k.status,statusText:k.statusText,headers:R,config:e,request:k};zB(function(_){n(_),y()},function(_){r(_),y()},N),k=null}"onloadend"in k?k.onloadend=A:k.onreadystatechange=function(){!k||k.readyState!==4||k.status===0&&!(k.responseURL&&k.responseURL.indexOf("file:")===0)||setTimeout(A)},k.onabort=function(){k&&(r(new ot("Request aborted",ot.ECONNABORTED,e,k)),k=null)},k.onerror=function(){r(new ot("Network Error",ot.ERR_NETWORK,e,k)),k=null},k.ontimeout=function(){let O=a.timeout?"timeout of "+a.timeout+"ms exceeded":"timeout exceeded";const N=a.transitional||MB;a.timeoutErrorMessage&&(O=a.timeoutErrorMessage),r(new ot(O,N.clarifyTimeoutError?ot.ETIMEDOUT:ot.ECONNABORTED,e,k)),k=null},o===void 0&&s.setContentType(null),"setRequestHeader"in k&&ge.forEach(s.toJSON(),function(O,N){k.setRequestHeader(N,O)}),ge.isUndefined(a.withCredentials)||(k.withCredentials=!!a.withCredentials),l&&l!=="json"&&(k.responseType=a.responseType),d&&([m,v]=mf(d,!0),k.addEventListener("progress",m)),u&&k.upload&&([g,b]=mf(u),k.upload.addEventListener("progress",g),k.upload.addEventListener("loadend",b)),(a.cancelToken||a.signal)&&(p=R=>{k&&(r(!R||R.type?new qs(null,e,k):R),k.abort(),k=null)},a.cancelToken&&a.cancelToken.subscribe(p),a.signal&&(a.signal.aborted?p():a.signal.addEventListener("abort",p)));const x=B7(a.url);if(x&&kn.protocols.indexOf(x)===-1){r(new ot("Unsupported protocol "+x+":",ot.ERR_BAD_REQUEST,e));return}k.send(o||null)})},Y7=(e,t)=>{const{length:n}=e=e?e.filter(Boolean):[];if(t||n){let r=new AbortController,a;const o=function(d){if(!a){a=!0,l();const p=d instanceof Error?d:this.reason;r.abort(p instanceof ot?p:new qs(p instanceof Error?p.message:p))}};let s=t&&setTimeout(()=>{s=null,o(new ot(`timeout ${t} of ms exceeded`,ot.ETIMEDOUT))},t);const l=()=>{e&&(s&&clearTimeout(s),s=null,e.forEach(d=>{d.unsubscribe?d.unsubscribe(o):d.removeEventListener("abort",o)}),e=null)};e.forEach(d=>d.addEventListener("abort",o));const{signal:u}=r;return u.unsubscribe=()=>ge.asap(l),u}},K7=function*(e,t){let n=e.byteLength;if(n<t){yield e;return}let r=0,a;for(;r<n;)a=r+t,yield e.slice(r,a),r=a},X7=async function*(e,t){for await(const n of Z7(e))yield*K7(n,t)},Z7=async function*(e){if(e[Symbol.asyncIterator]){yield*e;return}const t=e.getReader();try{for(;;){const{done:n,value:r}=await t.read();if(n)break;yield r}}finally{await t.cancel()}},O_=(e,t,n,r)=>{const a=X7(e,t);let o=0,s,l=u=>{s||(s=!0,r&&r(u))};return new ReadableStream({async pull(u){try{const{done:d,value:p}=await a.next();if(d){l(),u.close();return}let g=p.byteLength;if(n){let m=o+=g;n(m)}u.enqueue(new Uint8Array(p))}catch(d){throw l(d),d}},cancel(u){return l(u),a.return()}},{highWaterMark:2})},Jf=typeof fetch=="function"&&typeof Request=="function"&&typeof Response=="function",UB=Jf&&typeof ReadableStream=="function",Q7=Jf&&(typeof TextEncoder=="function"?(e=>t=>e.encode(t))(new TextEncoder):async e=>new Uint8Array(await new Response(e).arrayBuffer())),GB=(e,...t)=>{try{return!!e(...t)}catch{return!1}},J7=UB&&GB(()=>{let e=!1;const t=new Request(kn.origin,{body:new ReadableStream,method:"POST",get duplex(){return e=!0,"half"}}).headers.has("Content-Type");return e&&!t}),I_=64*1024,y0=UB&&GB(()=>ge.isReadableStream(new Response("").body)),bf={stream:y0&&(e=>e.body)};Jf&&(e=>{["text","arrayBuffer","blob","formData","stream"].forEach(t=>{!bf[t]&&(bf[t]=ge.isFunction(e[t])?n=>n[t]():(n,r)=>{throw new ot(`Response type '${t}' is not supported`,ot.ERR_NOT_SUPPORT,r)})})})(new Response);const eV=async e=>{if(e==null)return 0;if(ge.isBlob(e))return e.size;if(ge.isSpecCompliantForm(e))return(await new Request(kn.origin,{method:"POST",body:e}).arrayBuffer()).byteLength;if(ge.isArrayBufferView(e)||ge.isArrayBuffer(e))return e.byteLength;if(ge.isURLSearchParams(e)&&(e=e+""),ge.isString(e))return(await Q7(e)).byteLength},tV=async(e,t)=>{const n=ge.toFiniteNumber(e.getContentLength());return n??eV(t)},nV=Jf&&(async e=>{let{url:t,method:n,data:r,signal:a,cancelToken:o,timeout:s,onDownloadProgress:l,onUploadProgress:u,responseType:d,headers:p,withCredentials:g="same-origin",fetchOptions:m}=jB(e);d=d?(d+"").toLowerCase():"text";let b=Y7([a,o&&o.toAbortSignal()],s),v;const y=b&&b.unsubscribe&&(()=>{b.unsubscribe()});let k;try{if(u&&J7&&n!=="get"&&n!=="head"&&(k=await tV(p,r))!==0){let N=new Request(t,{method:"POST",body:r,duplex:"half"}),C;if(ge.isFormData(r)&&(C=N.headers.get("content-type"))&&p.setContentType(C),N.body){const[_,M]=C_(k,mf(__(u)));r=O_(N.body,I_,_,M)}}ge.isString(g)||(g=g?"include":"omit");const A="credentials"in Request.prototype;v=new Request(t,{...m,signal:b,method:n.toUpperCase(),headers:p.normalize().toJSON(),body:r,duplex:"half",credentials:A?g:void 0});let x=await fetch(v);const R=y0&&(d==="stream"||d==="response");if(y0&&(l||R&&y)){const N={};["status","statusText","headers"].forEach(I=>{N[I]=x[I]});const C=ge.toFiniteNumber(x.headers.get("content-length")),[_,M]=l&&C_(C,mf(__(l),!0))||[];x=new Response(O_(x.body,I_,_,()=>{M&&M(),y&&y()}),N)}d=d||"text";let O=await bf[ge.findKey(bf,d)||"text"](x,e);return!R&&y&&y(),await new Promise((N,C)=>{zB(N,C,{data:O,headers:Hn.from(x.headers),status:x.status,statusText:x.statusText,config:e,request:v})})}catch(A){throw y&&y(),A&&A.name==="TypeError"&&/fetch/i.test(A.message)?Object.assign(new ot("Network Error",ot.ERR_NETWORK,e,v),{cause:A.cause||A}):ot.from(A,A&&A.code,e,v)}}),v0={http:b7,xhr:W7,fetch:nV};ge.forEach(v0,(e,t)=>{if(e){try{Object.defineProperty(e,"name",{value:t})}catch{}Object.defineProperty(e,"adapterName",{value:t})}});const D_=e=>`- ${e}`,rV=e=>ge.isFunction(e)||e===null||e===!1,HB={getAdapter:e=>{e=ge.isArray(e)?e:[e];const{length:t}=e;let n,r;const a={};for(let o=0;o<t;o++){n=e[o];let s;if(r=n,!rV(n)&&(r=v0[(s=String(n)).toLowerCase()],r===void 0))throw new ot(`Unknown adapter '${s}'`);if(r)break;a[s||"#"+o]=r}if(!r){const o=Object.entries(a).map(([l,u])=>`adapter ${l} `+(u===!1?"is not supported by the environment":"is not available in the build"));let s=t?o.length>1?`since :
`+o.map(D_).join(`
`):" "+D_(o[0]):"as no adapter specified";throw new ot("There is no suitable adapter to dispatch the request "+s,"ERR_NOT_SUPPORT")}return r},adapters:v0};function om(e){if(e.cancelToken&&e.cancelToken.throwIfRequested(),e.signal&&e.signal.aborted)throw new qs(null,e)}function L_(e){return om(e),e.headers=Hn.from(e.headers),e.data=am.call(e,e.transformRequest),["post","put","patch"].indexOf(e.method)!==-1&&e.headers.setContentType("application/x-www-form-urlencoded",!1),HB.getAdapter(e.adapter||$c.adapter)(e).then(function(r){return om(e),r.data=am.call(e,e.transformResponse,r),r.headers=Hn.from(r.headers),r},function(r){return FB(r)||(om(e),r&&r.response&&(r.response.data=am.call(e,e.transformResponse,r.response),r.response.headers=Hn.from(r.response.headers))),Promise.reject(r)})}const $B="1.7.9",ep={};["object","boolean","number","function","string","symbol"].forEach((e,t)=>{ep[e]=function(r){return typeof r===e||"a"+(t<1?"n ":" ")+e}});const M_={};ep.transitional=function(t,n,r){function a(o,s){return"[Axios v"+$B+"] Transitional option '"+o+"'"+s+(r?". "+r:"")}return(o,s,l)=>{if(t===!1)throw new ot(a(s," has been removed"+(n?" in "+n:"")),ot.ERR_DEPRECATED);return n&&!M_[s]&&(M_[s]=!0,console.warn(a(s," has been deprecated since v"+n+" and will be removed in the near future"))),t?t(o,s,l):!0}};ep.spelling=function(t){return(n,r)=>(console.warn(`${r} is likely a misspelling of ${t}`),!0)};function aV(e,t,n){if(typeof e!="object")throw new ot("options must be an object",ot.ERR_BAD_OPTION_VALUE);const r=Object.keys(e);let a=r.length;for(;a-- >0;){const o=r[a],s=t[o];if(s){const l=e[o],u=l===void 0||s(l,o,e);if(u!==!0)throw new ot("option "+o+" must be "+u,ot.ERR_BAD_OPTION_VALUE);continue}if(n!==!0)throw new ot("Unknown option "+o,ot.ERR_BAD_OPTION)}}const Qd={assertOptions:aV,validators:ep},Jr=Qd.validators;let pi=class{constructor(t){this.defaults=t,this.interceptors={request:new A_,response:new A_}}async request(t,n){try{return await this._request(t,n)}catch(r){if(r instanceof Error){let a={};Error.captureStackTrace?Error.captureStackTrace(a):a=new Error;const o=a.stack?a.stack.replace(/^.+\n/,""):"";try{r.stack?o&&!String(r.stack).endsWith(o.replace(/^.+\n.+\n/,""))&&(r.stack+=`
`+o):r.stack=o}catch{}}throw r}}_request(t,n){typeof t=="string"?(n=n||{},n.url=t):n=t||{},n=hi(this.defaults,n);const{transitional:r,paramsSerializer:a,headers:o}=n;r!==void 0&&Qd.assertOptions(r,{silentJSONParsing:Jr.transitional(Jr.boolean),forcedJSONParsing:Jr.transitional(Jr.boolean),clarifyTimeoutError:Jr.transitional(Jr.boolean)},!1),a!=null&&(ge.isFunction(a)?n.paramsSerializer={serialize:a}:Qd.assertOptions(a,{encode:Jr.function,serialize:Jr.function},!0)),Qd.assertOptions(n,{baseUrl:Jr.spelling("baseURL"),withXsrfToken:Jr.spelling("withXSRFToken")},!0),n.method=(n.method||this.defaults.method||"get").toLowerCase();let s=o&&ge.merge(o.common,o[n.method]);o&&ge.forEach(["delete","get","head","post","put","patch","common"],v=>{delete o[v]}),n.headers=Hn.concat(s,o);const l=[];let u=!0;this.interceptors.request.forEach(function(y){typeof y.runWhen=="function"&&y.runWhen(n)===!1||(u=u&&y.synchronous,l.unshift(y.fulfilled,y.rejected))});const d=[];this.interceptors.response.forEach(function(y){d.push(y.fulfilled,y.rejected)});let p,g=0,m;if(!u){const v=[L_.bind(this),void 0];for(v.unshift.apply(v,l),v.push.apply(v,d),m=v.length,p=Promise.resolve(n);g<m;)p=p.then(v[g++],v[g++]);return p}m=l.length;let b=n;for(g=0;g<m;){const v=l[g++],y=l[g++];try{b=v(b)}catch(k){y.call(this,k);break}}try{p=L_.call(this,b)}catch(v){return Promise.reject(v)}for(g=0,m=d.length;g<m;)p=p.then(d[g++],d[g++]);return p}getUri(t){t=hi(this.defaults,t);const n=BB(t.baseURL,t.url);return LB(n,t.params,t.paramsSerializer)}};ge.forEach(["delete","get","head","options"],function(t){pi.prototype[t]=function(n,r){return this.request(hi(r||{},{method:t,url:n,data:(r||{}).data}))}});ge.forEach(["post","put","patch"],function(t){function n(r){return function(o,s,l){return this.request(hi(l||{},{method:t,headers:r?{"Content-Type":"multipart/form-data"}:{},url:o,data:s}))}}pi.prototype[t]=n(),pi.prototype[t+"Form"]=n(!0)});let oV=class qB{constructor(t){if(typeof t!="function")throw new TypeError("executor must be a function.");let n;this.promise=new Promise(function(o){n=o});const r=this;this.promise.then(a=>{if(!r._listeners)return;let o=r._listeners.length;for(;o-- >0;)r._listeners[o](a);r._listeners=null}),this.promise.then=a=>{let o;const s=new Promise(l=>{r.subscribe(l),o=l}).then(a);return s.cancel=function(){r.unsubscribe(o)},s},t(function(o,s,l){r.reason||(r.reason=new qs(o,s,l),n(r.reason))})}throwIfRequested(){if(this.reason)throw this.reason}subscribe(t){if(this.reason){t(this.reason);return}this._listeners?this._listeners.push(t):this._listeners=[t]}unsubscribe(t){if(!this._listeners)return;const n=this._listeners.indexOf(t);n!==-1&&this._listeners.splice(n,1)}toAbortSignal(){const t=new AbortController,n=r=>{t.abort(r)};return this.subscribe(n),t.signal.unsubscribe=()=>this.unsubscribe(n),t.signal}static source(){let t;return{token:new qB(function(a){t=a}),cancel:t}}};function iV(e){return function(n){return e.apply(null,n)}}function sV(e){return ge.isObject(e)&&e.isAxiosError===!0}const S0={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511};Object.entries(S0).forEach(([e,t])=>{S0[t]=e});function VB(e){const t=new pi(e),n=wB(pi.prototype.request,t);return ge.extend(n,pi.prototype,t,{allOwnKeys:!0}),ge.extend(n,t,null,{allOwnKeys:!0}),n.create=function(a){return VB(hi(e,a))},n}const Yt=VB($c);Yt.Axios=pi;Yt.CanceledError=qs;Yt.CancelToken=oV;Yt.isCancel=FB;Yt.VERSION=$B;Yt.toFormData=Qf;Yt.AxiosError=ot;Yt.Cancel=Yt.CanceledError;Yt.all=function(t){return Promise.all(t)};Yt.spread=iV;Yt.isAxiosError=sV;Yt.mergeConfig=hi;Yt.AxiosHeaders=Hn;Yt.formToJSON=e=>PB(ge.isHTMLForm(e)?new FormData(e):e);Yt.getAdapter=HB.getAdapter;Yt.HttpStatusCode=S0;Yt.default=Yt;const{Axios:Yxe,AxiosError:Kxe,CanceledError:Xxe,isCancel:Zxe,CancelToken:Qxe,VERSION:Jxe,all:e0e,Cancel:t0e,isAxiosError:n0e,spread:r0e,toFormData:a0e,AxiosHeaders:o0e,HttpStatusCode:i0e,formToJSON:s0e,getAdapter:l0e,mergeConfig:c0e}=Yt,WB="",YB="/webui/",Er="ghost",lV="#B2EBF2",cV="#000",uV="#E2E2E2",E0="#EEEEEE",dV="#F57F17",fV="#969696",pV="#F57F17",P_="#B2EBF2",vd=50,F_=100,li=4,w0=20,gV=15,z_="*",hV={"text/plain":[".txt",".md",".html",".htm",".tex",".json",".xml",".yaml",".yml",".rtf",".odt",".epub",".csv",".log",".conf",".ini",".properties",".sql",".bat",".sh",".c",".cpp",".py",".java",".js",".ts",".swift",".go",".rb",".php",".css",".scss",".less"],"application/pdf":[".pdf"],"application/msword":[".doc"],"application/vnd.openxmlformats-officedocument.wordprocessingml.document":[".docx"],"application/vnd.openxmlformats-officedocument.presentationml.presentation":[".pptx"]},x0={name:"LightRAG",github:"https://github.com/HKUDS/LightRAG"},mV="modulepreload",bV=function(e){return"/webui/"+e},B_={},yV=function(t,n,r){let a=Promise.resolve();if(n&&n.length>0){document.getElementsByTagName("link");const s=document.querySelector("meta[property=csp-nonce]"),l=(s==null?void 0:s.nonce)||(s==null?void 0:s.getAttribute("nonce"));a=Promise.allSettled(n.map(u=>{if(u=bV(u),u in B_)return;B_[u]=!0;const d=u.endsWith(".css"),p=d?'[rel="stylesheet"]':"";if(document.querySelector(`link[href="${u}"]${p}`))return;const g=document.createElement("link");if(g.rel=d?"stylesheet":mV,d||(g.as="script"),g.crossOrigin="",g.href=u,l&&g.setAttribute("nonce",l),document.head.appendChild(g),d)return new Promise((m,b)=>{g.addEventListener("load",m),g.addEventListener("error",()=>b(new Error(`Unable to preload CSS for ${u}`)))})}))}function o(s){const l=new Event("vite:preloadError",{cancelable:!0});if(l.payload=s,window.dispatchEvent(l),!l.defaultPrevented)throw s}return a.then(s=>{for(const l of s||[])l.status==="rejected"&&o(l.reason);return t().catch(o)})};function KB(e,t){let n;try{n=e()}catch{return}return{getItem:a=>{var o;const s=u=>u===null?null:JSON.parse(u,void 0),l=(o=n.getItem(a))!=null?o:null;return l instanceof Promise?l.then(s):s(l)},setItem:(a,o)=>n.setItem(a,JSON.stringify(o,void 0)),removeItem:a=>n.removeItem(a)}}const k0=e=>t=>{try{const n=e(t);return n instanceof Promise?n:{then(r){return k0(r)(n)},catch(r){return this}}}catch(n){return{then(r){return this},catch(r){return k0(r)(n)}}}},vV=(e,t)=>(n,r,a)=>{let o={storage:KB(()=>localStorage),partialize:y=>y,version:0,merge:(y,k)=>({...k,...y}),...t},s=!1;const l=new Set,u=new Set;let d=o.storage;if(!d)return e((...y)=>{console.warn(`[zustand persist middleware] Unable to update item '${o.name}', the given storage is currently unavailable.`),n(...y)},r,a);const p=()=>{const y=o.partialize({...r()});return d.setItem(o.name,{state:y,version:o.version})},g=a.setState;a.setState=(y,k)=>{g(y,k),p()};const m=e((...y)=>{n(...y),p()},r,a);a.getInitialState=()=>m;let b;const v=()=>{var y,k;if(!d)return;s=!1,l.forEach(x=>{var R;return x((R=r())!=null?R:m)});const A=((k=o.onRehydrateStorage)==null?void 0:k.call(o,(y=r())!=null?y:m))||void 0;return k0(d.getItem.bind(d))(o.name).then(x=>{if(x)if(typeof x.version=="number"&&x.version!==o.version){if(o.migrate){const R=o.migrate(x.state,x.version);return R instanceof Promise?R.then(O=>[!0,O]):[!0,R]}console.error("State loaded from storage couldn't be migrated since no migrate function was provided")}else return[!1,x.state];return[!1,void 0]}).then(x=>{var R;const[O,N]=x;if(b=o.merge(N,(R=r())!=null?R:m),n(b,!0),O)return p()}).then(()=>{A==null||A(b,void 0),b=r(),s=!0,u.forEach(x=>x(b))}).catch(x=>{A==null||A(void 0,x)})};return a.persist={setOptions:y=>{o={...o,...y},y.storage&&(d=y.storage)},clearStorage:()=>{d==null||d.removeItem(o.name)},getOptions:()=>o,rehydrate:()=>v(),hasHydrated:()=>s,onHydrate:y=>(l.add(y),()=>{l.delete(y)}),onFinishHydration:y=>(u.add(y),()=>{u.delete(y)})},o.skipHydration||v(),b||m},SV=vV,EV=Yf()(SV(e=>({theme:"system",language:"en",showPropertyPanel:!0,showNodeSearchBar:!0,showLegend:!1,showNodeLabel:!0,enableNodeDrag:!0,showEdgeLabel:!1,enableHideUnselectedEdges:!0,enableEdgeEvents:!1,minEdgeSize:1,maxEdgeSize:1,graphQueryMaxDepth:3,graphMaxNodes:1e3,graphLayoutMaxIterations:15,queryLabel:z_,enableHealthCheck:!0,apiKey:null,currentTab:"documents",showFileName:!1,retrievalHistory:[],querySettings:{mode:"global",response_type:"Multiple Paragraphs",top_k:10,max_token_for_text_unit:4e3,max_token_for_global_context:4e3,max_token_for_local_context:4e3,only_need_context:!1,only_need_prompt:!1,stream:!0,history_turns:3,hl_keywords:[],ll_keywords:[]},setTheme:t=>e({theme:t}),setLanguage:t=>{e({language:t}),yV(async()=>{const{default:n}=await Promise.resolve().then(()=>rxe);return{default:n}},[]).then(({default:n})=>{n.language!==t&&n.changeLanguage(t)})},setGraphLayoutMaxIterations:t=>e({graphLayoutMaxIterations:t}),setQueryLabel:t=>e({queryLabel:t}),setGraphQueryMaxDepth:t=>e({graphQueryMaxDepth:t}),setGraphMaxNodes:t=>e({graphMaxNodes:t}),setMinEdgeSize:t=>e({minEdgeSize:t}),setMaxEdgeSize:t=>e({maxEdgeSize:t}),setEnableHealthCheck:t=>e({enableHealthCheck:t}),setApiKey:t=>e({apiKey:t}),setCurrentTab:t=>e({currentTab:t}),setRetrievalHistory:t=>e({retrievalHistory:t}),updateQuerySettings:t=>e(n=>({querySettings:{...n.querySettings,...t}})),setShowFileName:t=>e({showFileName:t}),setShowLegend:t=>e({showLegend:t})}),{name:"settings-storage",storage:KB(()=>localStorage),version:11,migrate:(e,t)=>(t<2&&(e.showEdgeLabel=!1),t<3&&(e.queryLabel=z_),t<4&&(e.showPropertyPanel=!0,e.showNodeSearchBar=!0,e.showNodeLabel=!0,e.enableHealthCheck=!0,e.apiKey=null),t<5&&(e.currentTab="documents"),t<6&&(e.querySettings={mode:"global",response_type:"Multiple Paragraphs",top_k:10,max_token_for_text_unit:4e3,max_token_for_global_context:4e3,max_token_for_local_context:4e3,only_need_context:!1,only_need_prompt:!1,stream:!0,history_turns:3,hl_keywords:[],ll_keywords:[]},e.retrievalHistory=[]),t<7&&(e.graphQueryMaxDepth=3,e.graphLayoutMaxIterations=15),t<8&&(e.graphMinDegree=0,e.language="en"),t<9&&(e.showFileName=!1),t<10&&(delete e.graphMinDegree,e.graphMaxNodes=1e3),t<11&&(e.minEdgeSize=1,e.maxEdgeSize=1),e)})),De=zk(EV);class wV{constructor(){Qr(this,"nodes",[]);Qr(this,"edges",[]);Qr(this,"nodeIdMap",{});Qr(this,"edgeIdMap",{});Qr(this,"edgeDynamicIdMap",{});Qr(this,"getNode",t=>{const n=this.nodeIdMap[t];if(n!==void 0)return this.nodes[n]});Qr(this,"getEdge",(t,n=!0)=>{const r=n?this.edgeDynamicIdMap[t]:this.edgeIdMap[t];if(r!==void 0)return this.edges[r]});Qr(this,"buildDynamicMap",()=>{this.edgeDynamicIdMap={};for(let t=0;t<this.edges.length;t++){const n=this.edges[t];this.edgeDynamicIdMap[n.dynamicId]=t}})}}const xV=Yf()(e=>({selectedNode:null,focusedNode:null,selectedEdge:null,focusedEdge:null,moveToSelectedNode:!1,isFetching:!1,graphIsEmpty:!1,lastSuccessfulQueryLabel:"",graphDataFetchAttempted:!1,labelsFetchAttempted:!1,rawGraph:null,sigmaGraph:null,sigmaInstance:null,allDatabaseLabels:["*"],typeColorMap:new Map,searchEngine:null,setGraphIsEmpty:t=>e({graphIsEmpty:t}),setLastSuccessfulQueryLabel:t=>e({lastSuccessfulQueryLabel:t}),setIsFetching:t=>e({isFetching:t}),setSelectedNode:(t,n)=>e({selectedNode:t,moveToSelectedNode:n}),setFocusedNode:t=>e({focusedNode:t}),setSelectedEdge:t=>e({selectedEdge:t}),setFocusedEdge:t=>e({focusedEdge:t}),clearSelection:()=>e({selectedNode:null,focusedNode:null,selectedEdge:null,focusedEdge:null}),reset:()=>{e({selectedNode:null,focusedNode:null,selectedEdge:null,focusedEdge:null,rawGraph:null,sigmaGraph:null,searchEngine:null,moveToSelectedNode:!1,graphIsEmpty:!1})},setRawGraph:t=>e({rawGraph:t}),setSigmaGraph:t=>{e({sigmaGraph:t})},setAllDatabaseLabels:t=>e({allDatabaseLabels:t}),fetchAllDatabaseLabels:async()=>{try{console.log("Fetching all database labels...");const t=await TV();e({allDatabaseLabels:["*",...t]});return}catch(t){throw console.error("Failed to fetch all database labels:",t),e({allDatabaseLabels:["*"]}),t}},setMoveToSelectedNode:t=>e({moveToSelectedNode:t}),setSigmaInstance:t=>e({sigmaInstance:t}),setTypeColorMap:t=>e({typeColorMap:t}),setSearchEngine:t=>e({searchEngine:t}),resetSearchEngine:()=>e({searchEngine:null}),setGraphDataFetchAttempted:t=>e({graphDataFetchAttempted:t}),setLabelsFetchAttempted:t=>e({labelsFetchAttempted:t}),nodeToExpand:null,nodeToPrune:null,triggerNodeExpand:t=>e({nodeToExpand:t}),triggerNodePrune:t=>e({nodeToPrune:t})})),ze=zk(xV);class kV{constructor(){Qr(this,"navigate",null)}setNavigate(t){this.navigate=t}resetAllApplicationState(){console.log("Resetting all application state...");const t=ze.getState(),n=t.sigmaInstance;t.reset(),t.setGraphDataFetchAttempted(!1),t.setLabelsFetchAttempted(!1),t.setSigmaInstance(null),t.setIsFetching(!1),rr.getState().clear(),De.getState().setRetrievalHistory([]),sessionStorage.clear(),n&&(n.getGraph().clear(),n.kill(),ze.getState().setSigmaInstance(null))}handleDirectLoginAccess(){const t=!document.referrer;return t&&this.resetAllApplicationState(),t}navigateToLogin(){if(!this.navigate){console.error("Navigation function not set");return}this.resetAllApplicationState(),wr.getState().logout(),this.navigate("/login")}navigateToHome(){if(!this.navigate){console.error("Navigation function not set");return}this.navigate("/")}}const Gk=new kV,XB="Invalid API Key",ZB="API Key required",Dn=Yt.create({baseURL:WB,headers:{"Content-Type":"application/json"}});Dn.interceptors.request.use(e=>{const t=De.getState().apiKey,n=localStorage.getItem("LIGHTRAG-API-TOKEN");return n&&(e.headers.Authorization=`Bearer ${n}`),t&&(e.headers["X-API-Key"]=t),e});Dn.interceptors.response.use(e=>e,e=>{var t,n,r,a;if(e.response){if(((t=e.response)==null?void 0:t.status)===401){if((r=(n=e.config)==null?void 0:n.url)!=null&&r.includes("/login"))throw e;return Gk.navigateToLogin(),Promise.reject(new Error("Authentication required"))}throw new Error(`${e.response.status} ${e.response.statusText}
${JSON.stringify(e.response.data)}
${(a=e.config)==null?void 0:a.url}`)}throw e});const QB=async(e,t,n)=>(await Dn.get(`/graphs?label=${encodeURIComponent(e)}&max_depth=${t}&max_nodes=${n}`)).data,TV=async()=>(await Dn.get("/graph/label/list")).data,AV=async()=>{try{return(await Dn.get("/health")).data}catch(e){return{status:"error",message:Gn(e)}}},RV=async()=>(await Dn.get("/documents")).data,CV=async()=>(await Dn.post("/documents/scan")).data,_V=async e=>(await Dn.post("/query",e)).data,NV=async(e,t,n)=>{try{let r="";if(await Dn.post("/query/stream",e,{responseType:"text",headers:{Accept:"application/x-ndjson"},transformResponse:[a=>{r+=a;const o=r.split(`
`);r=o.pop()||"";for(const s of o)if(s.trim())try{const l=JSON.parse(s);l.response?t(l.response):l.error&&n&&n(l.error)}catch(l){console.error("Error parsing stream chunk:",l),n&&n("Error parsing server response")}return a}]}).catch(a=>{n&&n(Gn(a))}),r.trim())try{const a=JSON.parse(r);a.response?t(a.response):a.error&&n&&n(a.error)}catch(a){console.error("Error parsing final chunk:",a),n&&n("Error parsing server response")}}catch(r){const a=Gn(r);console.error("Stream request failed:",a),n&&n(a)}},OV=async(e,t)=>{const n=new FormData;return n.append("file",e),(await Dn.post("/documents/upload",n,{headers:{"Content-Type":"multipart/form-data"},onUploadProgress:t!==void 0?a=>{const o=Math.round(a.loaded*100/a.total);t(o)}:void 0})).data},IV=async()=>(await Dn.delete("/documents")).data,DV=async e=>(await Dn.post("/documents/clear_cache",{modes:e})).data,JB=async()=>{try{const e=await Dn.get("/auth-status",{timeout:5e3,headers:{Accept:"application/json"}});if((e.headers["content-type"]||"").includes("text/html"))return console.warn("Received HTML response instead of JSON for auth-status endpoint"),{auth_configured:!0,auth_mode:"enabled"};if(e.data&&typeof e.data=="object"&&"auth_configured"in e.data&&typeof e.data.auth_configured=="boolean"){if(e.data.auth_configured)return e.data;if(e.data.access_token&&typeof e.data.access_token=="string")return e.data;console.warn("Auth not configured but no valid access token provided")}return console.warn("Received invalid auth status response:",e.data),{auth_configured:!0,auth_mode:"enabled"}}catch(e){return console.error("Failed to get auth status:",Gn(e)),{auth_configured:!0,auth_mode:"enabled"}}},LV=async()=>(await Dn.get("/documents/pipeline_status")).data,MV=async(e,t)=>{const n=new FormData;return n.append("username",e),n.append("password",t),(await Dn.post("/login",n,{headers:{"Content-Type":"multipart/form-data"}})).data},PV=Yf()(e=>({health:!0,message:null,messageTitle:null,lastCheckTime:Date.now(),status:null,pipelineBusy:!1,check:async()=>{const t=await AV();return t.status==="healthy"?((t.core_version||t.api_version)&&wr.getState().setVersion(t.core_version||null,t.api_version||null),("webui_title"in t||"webui_description"in t)&&wr.getState().setCustomTitle("webui_title"in t?t.webui_title??null:null,"webui_description"in t?t.webui_description??null:null),e({health:!0,message:null,messageTitle:null,lastCheckTime:Date.now(),status:t,pipelineBusy:t.pipeline_busy}),!0):(e({health:!1,message:t.message,messageTitle:"Backend Health Check Error!",lastCheckTime:Date.now(),status:null}),!1)},clear:()=>{e({health:!0,message:null,messageTitle:null})},setErrorMessage:(t,n)=>{e({health:!1,message:t,messageTitle:n})},setPipelineBusy:t=>{e({pipelineBusy:t})}})),rr=zk(PV),ej=e=>{try{const t=e.split(".");return t.length!==3?{}:JSON.parse(atob(t[1]))}catch(t){return console.error("Error parsing token payload:",t),{}}},tj=e=>ej(e).sub||null,FV=e=>ej(e).role==="guest",zV=()=>{const e=localStorage.getItem("LIGHTRAG-API-TOKEN"),t=localStorage.getItem("LIGHTRAG-CORE-VERSION"),n=localStorage.getItem("LIGHTRAG-API-VERSION"),r=localStorage.getItem("LIGHTRAG-WEBUI-TITLE"),a=localStorage.getItem("LIGHTRAG-WEBUI-DESCRIPTION"),o=e?tj(e):null;return e?{isAuthenticated:!0,isGuestMode:FV(e),coreVersion:t,apiVersion:n,username:o,webuiTitle:r,webuiDescription:a}:{isAuthenticated:!1,isGuestMode:!1,coreVersion:t,apiVersion:n,username:null,webuiTitle:r,webuiDescription:a}},wr=Yf(e=>{const t=zV();return{isAuthenticated:t.isAuthenticated,isGuestMode:t.isGuestMode,coreVersion:t.coreVersion,apiVersion:t.apiVersion,username:t.username,webuiTitle:t.webuiTitle,webuiDescription:t.webuiDescription,login:(n,r=!1,a=null,o=null,s=null,l=null)=>{localStorage.setItem("LIGHTRAG-API-TOKEN",n),a&&localStorage.setItem("LIGHTRAG-CORE-VERSION",a),o&&localStorage.setItem("LIGHTRAG-API-VERSION",o),s?localStorage.setItem("LIGHTRAG-WEBUI-TITLE",s):localStorage.removeItem("LIGHTRAG-WEBUI-TITLE"),l?localStorage.setItem("LIGHTRAG-WEBUI-DESCRIPTION",l):localStorage.removeItem("LIGHTRAG-WEBUI-DESCRIPTION");const u=tj(n);e({isAuthenticated:!0,isGuestMode:r,username:u,coreVersion:a,apiVersion:o,webuiTitle:s,webuiDescription:l})},logout:()=>{localStorage.removeItem("LIGHTRAG-API-TOKEN");const n=localStorage.getItem("LIGHTRAG-CORE-VERSION"),r=localStorage.getItem("LIGHTRAG-API-VERSION"),a=localStorage.getItem("LIGHTRAG-WEBUI-TITLE"),o=localStorage.getItem("LIGHTRAG-WEBUI-DESCRIPTION");e({isAuthenticated:!1,isGuestMode:!1,username:null,coreVersion:n,apiVersion:r,webuiTitle:a,webuiDescription:o})},setVersion:(n,r)=>{n&&localStorage.setItem("LIGHTRAG-CORE-VERSION",n),r&&localStorage.setItem("LIGHTRAG-API-VERSION",r),e({coreVersion:n,apiVersion:r})},setCustomTitle:(n,r)=>{n?localStorage.setItem("LIGHTRAG-WEBUI-TITLE",n):localStorage.removeItem("LIGHTRAG-WEBUI-TITLE"),r?localStorage.setItem("LIGHTRAG-WEBUI-DESCRIPTION",r):localStorage.removeItem("LIGHTRAG-WEBUI-DESCRIPTION"),e({webuiTitle:n,webuiDescription:r})}}});var BV=e=>{switch(e){case"success":return GV;case"info":return $V;case"warning":return HV;case"error":return qV;default:return null}},jV=Array(12).fill(0),UV=({visible:e,className:t})=>we.createElement("div",{className:["sonner-loading-wrapper",t].filter(Boolean).join(" "),"data-visible":e},we.createElement("div",{className:"sonner-spinner"},jV.map((n,r)=>we.createElement("div",{className:"sonner-loading-bar",key:`spinner-bar-${r}`})))),GV=we.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},we.createElement("path",{fillRule:"evenodd",d:"M10 18a8 8 0 100-16 8 8 0 000 16zm3.857-9.809a.75.75 0 00-1.214-.882l-3.483 4.79-1.88-1.88a.75.75 0 10-1.06 1.061l2.5 2.5a.75.75 0 001.137-.089l4-5.5z",clipRule:"evenodd"})),HV=we.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",fill:"currentColor",height:"20",width:"20"},we.createElement("path",{fillRule:"evenodd",d:"M9.401 3.003c1.155-2 4.043-2 5.197 0l7.355 12.748c1.154 2-.29 4.5-2.599 4.5H4.645c-2.309 0-3.752-2.5-2.598-4.5L9.4 3.003zM12 8.25a.75.75 0 01.75.75v3.75a.75.75 0 01-1.5 0V9a.75.75 0 01.75-.75zm0 8.25a.75.75 0 100-1.5.75.75 0 000 1.5z",clipRule:"evenodd"})),$V=we.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},we.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7-4a1 1 0 11-2 0 1 1 0 012 0zM9 9a.75.75 0 000 1.5h.253a.25.25 0 01.244.304l-.459 2.066A1.75 1.75 0 0010.747 15H11a.75.75 0 000-1.5h-.253a.25.25 0 01-.244-.304l.459-2.066A1.75 1.75 0 009.253 9H9z",clipRule:"evenodd"})),qV=we.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},we.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-5a.75.75 0 01.75.75v4.5a.75.75 0 01-1.5 0v-4.5A.75.75 0 0110 5zm0 10a1 1 0 100-2 1 1 0 000 2z",clipRule:"evenodd"})),VV=we.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"12",height:"12",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round"},we.createElement("line",{x1:"18",y1:"6",x2:"6",y2:"18"}),we.createElement("line",{x1:"6",y1:"6",x2:"18",y2:"18"})),WV=()=>{let[e,t]=we.useState(document.hidden);return we.useEffect(()=>{let n=()=>{t(document.hidden)};return document.addEventListener("visibilitychange",n),()=>window.removeEventListener("visibilitychange",n)},[]),e},T0=1,YV=class{constructor(){this.subscribe=e=>(this.subscribers.push(e),()=>{let t=this.subscribers.indexOf(e);this.subscribers.splice(t,1)}),this.publish=e=>{this.subscribers.forEach(t=>t(e))},this.addToast=e=>{this.publish(e),this.toasts=[...this.toasts,e]},this.create=e=>{var t;let{message:n,...r}=e,a=typeof(e==null?void 0:e.id)=="number"||((t=e.id)==null?void 0:t.length)>0?e.id:T0++,o=this.toasts.find(l=>l.id===a),s=e.dismissible===void 0?!0:e.dismissible;return this.dismissedToasts.has(a)&&this.dismissedToasts.delete(a),o?this.toasts=this.toasts.map(l=>l.id===a?(this.publish({...l,...e,id:a,title:n}),{...l,...e,id:a,dismissible:s,title:n}):l):this.addToast({title:n,...r,dismissible:s,id:a}),a},this.dismiss=e=>(this.dismissedToasts.add(e),e||this.toasts.forEach(t=>{this.subscribers.forEach(n=>n({id:t.id,dismiss:!0}))}),this.subscribers.forEach(t=>t({id:e,dismiss:!0})),e),this.message=(e,t)=>this.create({...t,message:e}),this.error=(e,t)=>this.create({...t,message:e,type:"error"}),this.success=(e,t)=>this.create({...t,type:"success",message:e}),this.info=(e,t)=>this.create({...t,type:"info",message:e}),this.warning=(e,t)=>this.create({...t,type:"warning",message:e}),this.loading=(e,t)=>this.create({...t,type:"loading",message:e}),this.promise=(e,t)=>{if(!t)return;let n;t.loading!==void 0&&(n=this.create({...t,promise:e,type:"loading",message:t.loading,description:typeof t.description!="function"?t.description:void 0}));let r=e instanceof Promise?e:e(),a=n!==void 0,o,s=r.then(async u=>{if(o=["resolve",u],we.isValidElement(u))a=!1,this.create({id:n,type:"default",message:u});else if(XV(u)&&!u.ok){a=!1;let d=typeof t.error=="function"?await t.error(`HTTP error! status: ${u.status}`):t.error,p=typeof t.description=="function"?await t.description(`HTTP error! status: ${u.status}`):t.description;this.create({id:n,type:"error",message:d,description:p})}else if(t.success!==void 0){a=!1;let d=typeof t.success=="function"?await t.success(u):t.success,p=typeof t.description=="function"?await t.description(u):t.description;this.create({id:n,type:"success",message:d,description:p})}}).catch(async u=>{if(o=["reject",u],t.error!==void 0){a=!1;let d=typeof t.error=="function"?await t.error(u):t.error,p=typeof t.description=="function"?await t.description(u):t.description;this.create({id:n,type:"error",message:d,description:p})}}).finally(()=>{var u;a&&(this.dismiss(n),n=void 0),(u=t.finally)==null||u.call(t)}),l=()=>new Promise((u,d)=>s.then(()=>o[0]==="reject"?d(o[1]):u(o[1])).catch(d));return typeof n!="string"&&typeof n!="number"?{unwrap:l}:Object.assign(n,{unwrap:l})},this.custom=(e,t)=>{let n=(t==null?void 0:t.id)||T0++;return this.create({jsx:e(n),id:n,...t}),n},this.getActiveToasts=()=>this.toasts.filter(e=>!this.dismissedToasts.has(e.id)),this.subscribers=[],this.toasts=[],this.dismissedToasts=new Set}},Un=new YV,KV=(e,t)=>{let n=(t==null?void 0:t.id)||T0++;return Un.addToast({title:e,...t,id:n}),n},XV=e=>e&&typeof e=="object"&&"ok"in e&&typeof e.ok=="boolean"&&"status"in e&&typeof e.status=="number",ZV=KV,QV=()=>Un.toasts,JV=()=>Un.getActiveToasts(),Ft=Object.assign(ZV,{success:Un.success,info:Un.info,warning:Un.warning,error:Un.error,custom:Un.custom,message:Un.message,promise:Un.promise,dismiss:Un.dismiss,loading:Un.loading},{getHistory:QV,getToasts:JV});function eW(e,{insertAt:t}={}){if(typeof document>"u")return;let n=document.head||document.getElementsByTagName("head")[0],r=document.createElement("style");r.type="text/css",t==="top"&&n.firstChild?n.insertBefore(r,n.firstChild):n.appendChild(r),r.styleSheet?r.styleSheet.cssText=e:r.appendChild(document.createTextNode(e))}eW(`:where(html[dir="ltr"]),:where([data-sonner-toaster][dir="ltr"]){--toast-icon-margin-start: -3px;--toast-icon-margin-end: 4px;--toast-svg-margin-start: -1px;--toast-svg-margin-end: 0px;--toast-button-margin-start: auto;--toast-button-margin-end: 0;--toast-close-button-start: 0;--toast-close-button-end: unset;--toast-close-button-transform: translate(-35%, -35%)}:where(html[dir="rtl"]),:where([data-sonner-toaster][dir="rtl"]){--toast-icon-margin-start: 4px;--toast-icon-margin-end: -3px;--toast-svg-margin-start: 0px;--toast-svg-margin-end: -1px;--toast-button-margin-start: 0;--toast-button-margin-end: auto;--toast-close-button-start: unset;--toast-close-button-end: 0;--toast-close-button-transform: translate(35%, -35%)}:where([data-sonner-toaster]){position:fixed;width:var(--width);font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol,Noto Color Emoji;--gray1: hsl(0, 0%, 99%);--gray2: hsl(0, 0%, 97.3%);--gray3: hsl(0, 0%, 95.1%);--gray4: hsl(0, 0%, 93%);--gray5: hsl(0, 0%, 90.9%);--gray6: hsl(0, 0%, 88.7%);--gray7: hsl(0, 0%, 85.8%);--gray8: hsl(0, 0%, 78%);--gray9: hsl(0, 0%, 56.1%);--gray10: hsl(0, 0%, 52.3%);--gray11: hsl(0, 0%, 43.5%);--gray12: hsl(0, 0%, 9%);--border-radius: 8px;box-sizing:border-box;padding:0;margin:0;list-style:none;outline:none;z-index:999999999;transition:transform .4s ease}:where([data-sonner-toaster][data-lifted="true"]){transform:translateY(-10px)}@media (hover: none) and (pointer: coarse){:where([data-sonner-toaster][data-lifted="true"]){transform:none}}:where([data-sonner-toaster][data-x-position="right"]){right:var(--offset-right)}:where([data-sonner-toaster][data-x-position="left"]){left:var(--offset-left)}:where([data-sonner-toaster][data-x-position="center"]){left:50%;transform:translate(-50%)}:where([data-sonner-toaster][data-y-position="top"]){top:var(--offset-top)}:where([data-sonner-toaster][data-y-position="bottom"]){bottom:var(--offset-bottom)}:where([data-sonner-toast]){--y: translateY(100%);--lift-amount: calc(var(--lift) * var(--gap));z-index:var(--z-index);position:absolute;opacity:0;transform:var(--y);filter:blur(0);touch-action:none;transition:transform .4s,opacity .4s,height .4s,box-shadow .2s;box-sizing:border-box;outline:none;overflow-wrap:anywhere}:where([data-sonner-toast][data-styled="true"]){padding:16px;background:var(--normal-bg);border:1px solid var(--normal-border);color:var(--normal-text);border-radius:var(--border-radius);box-shadow:0 4px 12px #0000001a;width:var(--width);font-size:13px;display:flex;align-items:center;gap:6px}:where([data-sonner-toast]:focus-visible){box-shadow:0 4px 12px #0000001a,0 0 0 2px #0003}:where([data-sonner-toast][data-y-position="top"]){top:0;--y: translateY(-100%);--lift: 1;--lift-amount: calc(1 * var(--gap))}:where([data-sonner-toast][data-y-position="bottom"]){bottom:0;--y: translateY(100%);--lift: -1;--lift-amount: calc(var(--lift) * var(--gap))}:where([data-sonner-toast]) :where([data-description]){font-weight:400;line-height:1.4;color:inherit}:where([data-sonner-toast]) :where([data-title]){font-weight:500;line-height:1.5;color:inherit}:where([data-sonner-toast]) :where([data-icon]){display:flex;height:16px;width:16px;position:relative;justify-content:flex-start;align-items:center;flex-shrink:0;margin-left:var(--toast-icon-margin-start);margin-right:var(--toast-icon-margin-end)}:where([data-sonner-toast][data-promise="true"]) :where([data-icon])>svg{opacity:0;transform:scale(.8);transform-origin:center;animation:sonner-fade-in .3s ease forwards}:where([data-sonner-toast]) :where([data-icon])>*{flex-shrink:0}:where([data-sonner-toast]) :where([data-icon]) svg{margin-left:var(--toast-svg-margin-start);margin-right:var(--toast-svg-margin-end)}:where([data-sonner-toast]) :where([data-content]){display:flex;flex-direction:column;gap:2px}[data-sonner-toast][data-styled=true] [data-button]{border-radius:4px;padding-left:8px;padding-right:8px;height:24px;font-size:12px;color:var(--normal-bg);background:var(--normal-text);margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end);border:none;cursor:pointer;outline:none;display:flex;align-items:center;flex-shrink:0;transition:opacity .4s,box-shadow .2s}:where([data-sonner-toast]) :where([data-button]):focus-visible{box-shadow:0 0 0 2px #0006}:where([data-sonner-toast]) :where([data-button]):first-of-type{margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end)}:where([data-sonner-toast]) :where([data-cancel]){color:var(--normal-text);background:rgba(0,0,0,.08)}:where([data-sonner-toast][data-theme="dark"]) :where([data-cancel]){background:rgba(255,255,255,.3)}:where([data-sonner-toast]) :where([data-close-button]){position:absolute;left:var(--toast-close-button-start);right:var(--toast-close-button-end);top:0;height:20px;width:20px;display:flex;justify-content:center;align-items:center;padding:0;color:var(--gray12);border:1px solid var(--gray4);transform:var(--toast-close-button-transform);border-radius:50%;cursor:pointer;z-index:1;transition:opacity .1s,background .2s,border-color .2s}[data-sonner-toast] [data-close-button]{background:var(--gray1)}:where([data-sonner-toast]) :where([data-close-button]):focus-visible{box-shadow:0 4px 12px #0000001a,0 0 0 2px #0003}:where([data-sonner-toast]) :where([data-disabled="true"]){cursor:not-allowed}:where([data-sonner-toast]):hover :where([data-close-button]):hover{background:var(--gray2);border-color:var(--gray5)}:where([data-sonner-toast][data-swiping="true"]):before{content:"";position:absolute;left:-50%;right:-50%;height:100%;z-index:-1}:where([data-sonner-toast][data-y-position="top"][data-swiping="true"]):before{bottom:50%;transform:scaleY(3) translateY(50%)}:where([data-sonner-toast][data-y-position="bottom"][data-swiping="true"]):before{top:50%;transform:scaleY(3) translateY(-50%)}:where([data-sonner-toast][data-swiping="false"][data-removed="true"]):before{content:"";position:absolute;inset:0;transform:scaleY(2)}:where([data-sonner-toast]):after{content:"";position:absolute;left:0;height:calc(var(--gap) + 1px);bottom:100%;width:100%}:where([data-sonner-toast][data-mounted="true"]){--y: translateY(0);opacity:1}:where([data-sonner-toast][data-expanded="false"][data-front="false"]){--scale: var(--toasts-before) * .05 + 1;--y: translateY(calc(var(--lift-amount) * var(--toasts-before))) scale(calc(-1 * var(--scale)));height:var(--front-toast-height)}:where([data-sonner-toast])>*{transition:opacity .4s}:where([data-sonner-toast][data-expanded="false"][data-front="false"][data-styled="true"])>*{opacity:0}:where([data-sonner-toast][data-visible="false"]){opacity:0;pointer-events:none}:where([data-sonner-toast][data-mounted="true"][data-expanded="true"]){--y: translateY(calc(var(--lift) * var(--offset)));height:var(--initial-height)}:where([data-sonner-toast][data-removed="true"][data-front="true"][data-swipe-out="false"]){--y: translateY(calc(var(--lift) * -100%));opacity:0}:where([data-sonner-toast][data-removed="true"][data-front="false"][data-swipe-out="false"][data-expanded="true"]){--y: translateY(calc(var(--lift) * var(--offset) + var(--lift) * -100%));opacity:0}:where([data-sonner-toast][data-removed="true"][data-front="false"][data-swipe-out="false"][data-expanded="false"]){--y: translateY(40%);opacity:0;transition:transform .5s,opacity .2s}:where([data-sonner-toast][data-removed="true"][data-front="false"]):before{height:calc(var(--initial-height) + 20%)}[data-sonner-toast][data-swiping=true]{transform:var(--y) translateY(var(--swipe-amount-y, 0px)) translate(var(--swipe-amount-x, 0px));transition:none}[data-sonner-toast][data-swiped=true]{user-select:none}[data-sonner-toast][data-swipe-out=true][data-y-position=bottom],[data-sonner-toast][data-swipe-out=true][data-y-position=top]{animation-duration:.2s;animation-timing-function:ease-out;animation-fill-mode:forwards}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=left]{animation-name:swipe-out-left}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=right]{animation-name:swipe-out-right}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=up]{animation-name:swipe-out-up}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=down]{animation-name:swipe-out-down}@keyframes swipe-out-left{0%{transform:var(--y) translate(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translate(calc(var(--swipe-amount-x) - 100%));opacity:0}}@keyframes swipe-out-right{0%{transform:var(--y) translate(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translate(calc(var(--swipe-amount-x) + 100%));opacity:0}}@keyframes swipe-out-up{0%{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) - 100%));opacity:0}}@keyframes swipe-out-down{0%{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) + 100%));opacity:0}}@media (max-width: 600px){[data-sonner-toaster]{position:fixed;right:var(--mobile-offset-right);left:var(--mobile-offset-left);width:100%}[data-sonner-toaster][dir=rtl]{left:calc(var(--mobile-offset-left) * -1)}[data-sonner-toaster] [data-sonner-toast]{left:0;right:0;width:calc(100% - var(--mobile-offset-left) * 2)}[data-sonner-toaster][data-x-position=left]{left:var(--mobile-offset-left)}[data-sonner-toaster][data-y-position=bottom]{bottom:var(--mobile-offset-bottom)}[data-sonner-toaster][data-y-position=top]{top:var(--mobile-offset-top)}[data-sonner-toaster][data-x-position=center]{left:var(--mobile-offset-left);right:var(--mobile-offset-right);transform:none}}[data-sonner-toaster][data-theme=light]{--normal-bg: #fff;--normal-border: var(--gray4);--normal-text: var(--gray12);--success-bg: hsl(143, 85%, 96%);--success-border: hsl(145, 92%, 91%);--success-text: hsl(140, 100%, 27%);--info-bg: hsl(208, 100%, 97%);--info-border: hsl(221, 91%, 91%);--info-text: hsl(210, 92%, 45%);--warning-bg: hsl(49, 100%, 97%);--warning-border: hsl(49, 91%, 91%);--warning-text: hsl(31, 92%, 45%);--error-bg: hsl(359, 100%, 97%);--error-border: hsl(359, 100%, 94%);--error-text: hsl(360, 100%, 45%)}[data-sonner-toaster][data-theme=light] [data-sonner-toast][data-invert=true]{--normal-bg: #000;--normal-border: hsl(0, 0%, 20%);--normal-text: var(--gray1)}[data-sonner-toaster][data-theme=dark] [data-sonner-toast][data-invert=true]{--normal-bg: #fff;--normal-border: var(--gray3);--normal-text: var(--gray12)}[data-sonner-toaster][data-theme=dark]{--normal-bg: #000;--normal-bg-hover: hsl(0, 0%, 12%);--normal-border: hsl(0, 0%, 20%);--normal-border-hover: hsl(0, 0%, 25%);--normal-text: var(--gray1);--success-bg: hsl(150, 100%, 6%);--success-border: hsl(147, 100%, 12%);--success-text: hsl(150, 86%, 65%);--info-bg: hsl(215, 100%, 6%);--info-border: hsl(223, 100%, 12%);--info-text: hsl(216, 87%, 65%);--warning-bg: hsl(64, 100%, 6%);--warning-border: hsl(60, 100%, 12%);--warning-text: hsl(46, 87%, 65%);--error-bg: hsl(358, 76%, 10%);--error-border: hsl(357, 89%, 16%);--error-text: hsl(358, 100%, 81%)}[data-sonner-toaster][data-theme=dark] [data-sonner-toast] [data-close-button]{background:var(--normal-bg);border-color:var(--normal-border);color:var(--normal-text)}[data-sonner-toaster][data-theme=dark] [data-sonner-toast] [data-close-button]:hover{background:var(--normal-bg-hover);border-color:var(--normal-border-hover)}[data-rich-colors=true][data-sonner-toast][data-type=success],[data-rich-colors=true][data-sonner-toast][data-type=success] [data-close-button]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true][data-sonner-toast][data-type=info],[data-rich-colors=true][data-sonner-toast][data-type=info] [data-close-button]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true][data-sonner-toast][data-type=warning],[data-rich-colors=true][data-sonner-toast][data-type=warning] [data-close-button]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true][data-sonner-toast][data-type=error],[data-rich-colors=true][data-sonner-toast][data-type=error] [data-close-button]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}.sonner-loading-wrapper{--size: 16px;height:var(--size);width:var(--size);position:absolute;inset:0;z-index:10}.sonner-loading-wrapper[data-visible=false]{transform-origin:center;animation:sonner-fade-out .2s ease forwards}.sonner-spinner{position:relative;top:50%;left:50%;height:var(--size);width:var(--size)}.sonner-loading-bar{animation:sonner-spin 1.2s linear infinite;background:var(--gray11);border-radius:6px;height:8%;left:-10%;position:absolute;top:-3.9%;width:24%}.sonner-loading-bar:nth-child(1){animation-delay:-1.2s;transform:rotate(.0001deg) translate(146%)}.sonner-loading-bar:nth-child(2){animation-delay:-1.1s;transform:rotate(30deg) translate(146%)}.sonner-loading-bar:nth-child(3){animation-delay:-1s;transform:rotate(60deg) translate(146%)}.sonner-loading-bar:nth-child(4){animation-delay:-.9s;transform:rotate(90deg) translate(146%)}.sonner-loading-bar:nth-child(5){animation-delay:-.8s;transform:rotate(120deg) translate(146%)}.sonner-loading-bar:nth-child(6){animation-delay:-.7s;transform:rotate(150deg) translate(146%)}.sonner-loading-bar:nth-child(7){animation-delay:-.6s;transform:rotate(180deg) translate(146%)}.sonner-loading-bar:nth-child(8){animation-delay:-.5s;transform:rotate(210deg) translate(146%)}.sonner-loading-bar:nth-child(9){animation-delay:-.4s;transform:rotate(240deg) translate(146%)}.sonner-loading-bar:nth-child(10){animation-delay:-.3s;transform:rotate(270deg) translate(146%)}.sonner-loading-bar:nth-child(11){animation-delay:-.2s;transform:rotate(300deg) translate(146%)}.sonner-loading-bar:nth-child(12){animation-delay:-.1s;transform:rotate(330deg) translate(146%)}@keyframes sonner-fade-in{0%{opacity:0;transform:scale(.8)}to{opacity:1;transform:scale(1)}}@keyframes sonner-fade-out{0%{opacity:1;transform:scale(1)}to{opacity:0;transform:scale(.8)}}@keyframes sonner-spin{0%{opacity:1}to{opacity:.15}}@media (prefers-reduced-motion){[data-sonner-toast],[data-sonner-toast]>*,.sonner-loading-bar{transition:none!important;animation:none!important}}.sonner-loader{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);transform-origin:center;transition:opacity .2s,transform .2s}.sonner-loader[data-visible=false]{opacity:0;transform:scale(.8) translate(-50%,-50%)}
`);function Sd(e){return e.label!==void 0}var tW=3,nW="32px",rW="16px",j_=4e3,aW=356,oW=14,iW=20,sW=200;function Lr(...e){return e.filter(Boolean).join(" ")}function lW(e){let[t,n]=e.split("-"),r=[];return t&&r.push(t),n&&r.push(n),r}var cW=e=>{var t,n,r,a,o,s,l,u,d,p,g;let{invert:m,toast:b,unstyled:v,interacting:y,setHeights:k,visibleToasts:A,heights:x,index:R,toasts:O,expanded:N,removeToast:C,defaultRichColors:_,closeButton:M,style:I,cancelButtonStyle:D,actionButtonStyle:U,className:$="",descriptionClassName:B="",duration:W,position:K,gap:H,loadingIcon:G,expandByDefault:z,classNames:Y,icons:L,closeButtonAriaLabel:V="Close toast",pauseWhenPageIsHidden:j}=e,[P,Z]=we.useState(null),[Q,oe]=we.useState(null),[ae,ce]=we.useState(!1),[Re,ie]=we.useState(!1),[Te,ne]=we.useState(!1),[xe,Se]=we.useState(!1),[be,J]=we.useState(!1),[pe,ke]=we.useState(0),[he,Ee]=we.useState(0),se=we.useRef(b.duration||W||j_),Be=we.useRef(null),je=we.useRef(null),ye=R===0,Oe=R+1<=A,ee=b.type,de=b.dismissible!==!1,Ne=b.className||"",Fe=b.descriptionClassName||"",We=we.useMemo(()=>x.findIndex(Xe=>Xe.toastId===b.id)||0,[x,b.id]),St=we.useMemo(()=>{var Xe;return(Xe=b.closeButton)!=null?Xe:M},[b.closeButton,M]),Tt=we.useMemo(()=>b.duration||W||j_,[b.duration,W]),bt=we.useRef(0),et=we.useRef(0),At=we.useRef(0),st=we.useRef(null),[wt,Ht]=K.split("-"),pn=we.useMemo(()=>x.reduce((Xe,yt,Nt)=>Nt>=We?Xe:Xe+yt.height,0),[x,We]),zt=WV(),ir=b.invert||m,Vr=ee==="loading";et.current=we.useMemo(()=>We*H+pn,[We,pn]),we.useEffect(()=>{se.current=Tt},[Tt]),we.useEffect(()=>{ce(!0)},[]),we.useEffect(()=>{let Xe=je.current;if(Xe){let yt=Xe.getBoundingClientRect().height;return Ee(yt),k(Nt=>[{toastId:b.id,height:yt,position:b.position},...Nt]),()=>k(Nt=>Nt.filter(Ln=>Ln.toastId!==b.id))}},[k,b.id]),we.useLayoutEffect(()=>{if(!ae)return;let Xe=je.current,yt=Xe.style.height;Xe.style.height="auto";let Nt=Xe.getBoundingClientRect().height;Xe.style.height=yt,Ee(Nt),k(Ln=>Ln.find(_n=>_n.toastId===b.id)?Ln.map(_n=>_n.toastId===b.id?{..._n,height:Nt}:_n):[{toastId:b.id,height:Nt,position:b.position},...Ln])},[ae,b.title,b.description,k,b.id]);let Jt=we.useCallback(()=>{ie(!0),ke(et.current),k(Xe=>Xe.filter(yt=>yt.toastId!==b.id)),setTimeout(()=>{C(b)},sW)},[b,C,k,et]);we.useEffect(()=>{if(b.promise&&ee==="loading"||b.duration===1/0||b.type==="loading")return;let Xe;return N||y||j&&zt?(()=>{if(At.current<bt.current){let yt=new Date().getTime()-bt.current;se.current=se.current-yt}At.current=new Date().getTime()})():se.current!==1/0&&(bt.current=new Date().getTime(),Xe=setTimeout(()=>{var yt;(yt=b.onAutoClose)==null||yt.call(b,b),Jt()},se.current)),()=>clearTimeout(Xe)},[N,y,b,ee,j,zt,Jt]),we.useEffect(()=>{b.delete&&Jt()},[Jt,b.delete]);function pa(){var Xe,yt,Nt;return L!=null&&L.loading?we.createElement("div",{className:Lr(Y==null?void 0:Y.loader,(Xe=b==null?void 0:b.classNames)==null?void 0:Xe.loader,"sonner-loader"),"data-visible":ee==="loading"},L.loading):G?we.createElement("div",{className:Lr(Y==null?void 0:Y.loader,(yt=b==null?void 0:b.classNames)==null?void 0:yt.loader,"sonner-loader"),"data-visible":ee==="loading"},G):we.createElement(UV,{className:Lr(Y==null?void 0:Y.loader,(Nt=b==null?void 0:b.classNames)==null?void 0:Nt.loader),visible:ee==="loading"})}return we.createElement("li",{tabIndex:0,ref:je,className:Lr($,Ne,Y==null?void 0:Y.toast,(t=b==null?void 0:b.classNames)==null?void 0:t.toast,Y==null?void 0:Y.default,Y==null?void 0:Y[ee],(n=b==null?void 0:b.classNames)==null?void 0:n[ee]),"data-sonner-toast":"","data-rich-colors":(r=b.richColors)!=null?r:_,"data-styled":!(b.jsx||b.unstyled||v),"data-mounted":ae,"data-promise":!!b.promise,"data-swiped":be,"data-removed":Re,"data-visible":Oe,"data-y-position":wt,"data-x-position":Ht,"data-index":R,"data-front":ye,"data-swiping":Te,"data-dismissible":de,"data-type":ee,"data-invert":ir,"data-swipe-out":xe,"data-swipe-direction":Q,"data-expanded":!!(N||z&&ae),style:{"--index":R,"--toasts-before":R,"--z-index":O.length-R,"--offset":`${Re?pe:et.current}px`,"--initial-height":z?"auto":`${he}px`,...I,...b.style},onDragEnd:()=>{ne(!1),Z(null),st.current=null},onPointerDown:Xe=>{Vr||!de||(Be.current=new Date,ke(et.current),Xe.target.setPointerCapture(Xe.pointerId),Xe.target.tagName!=="BUTTON"&&(ne(!0),st.current={x:Xe.clientX,y:Xe.clientY}))},onPointerUp:()=>{var Xe,yt,Nt,Ln;if(xe||!de)return;st.current=null;let _n=Number(((Xe=je.current)==null?void 0:Xe.style.getPropertyValue("--swipe-amount-x").replace("px",""))||0),Mn=Number(((yt=je.current)==null?void 0:yt.style.getPropertyValue("--swipe-amount-y").replace("px",""))||0),ga=new Date().getTime()-((Nt=Be.current)==null?void 0:Nt.getTime()),Pn=P==="x"?_n:Mn,_r=Math.abs(Pn)/ga;if(Math.abs(Pn)>=iW||_r>.11){ke(et.current),(Ln=b.onDismiss)==null||Ln.call(b,b),oe(P==="x"?_n>0?"right":"left":Mn>0?"down":"up"),Jt(),Se(!0),J(!1);return}ne(!1),Z(null)},onPointerMove:Xe=>{var yt,Nt,Ln,_n;if(!st.current||!de||((yt=window.getSelection())==null?void 0:yt.toString().length)>0)return;let Mn=Xe.clientY-st.current.y,ga=Xe.clientX-st.current.x,Pn=(Nt=e.swipeDirections)!=null?Nt:lW(K);!P&&(Math.abs(ga)>1||Math.abs(Mn)>1)&&Z(Math.abs(ga)>Math.abs(Mn)?"x":"y");let _r={x:0,y:0};P==="y"?(Pn.includes("top")||Pn.includes("bottom"))&&(Pn.includes("top")&&Mn<0||Pn.includes("bottom")&&Mn>0)&&(_r.y=Mn):P==="x"&&(Pn.includes("left")||Pn.includes("right"))&&(Pn.includes("left")&&ga<0||Pn.includes("right")&&ga>0)&&(_r.x=ga),(Math.abs(_r.x)>0||Math.abs(_r.y)>0)&&J(!0),(Ln=je.current)==null||Ln.style.setProperty("--swipe-amount-x",`${_r.x}px`),(_n=je.current)==null||_n.style.setProperty("--swipe-amount-y",`${_r.y}px`)}},St&&!b.jsx?we.createElement("button",{"aria-label":V,"data-disabled":Vr,"data-close-button":!0,onClick:Vr||!de?()=>{}:()=>{var Xe;Jt(),(Xe=b.onDismiss)==null||Xe.call(b,b)},className:Lr(Y==null?void 0:Y.closeButton,(a=b==null?void 0:b.classNames)==null?void 0:a.closeButton)},(o=L==null?void 0:L.close)!=null?o:VV):null,b.jsx||w.isValidElement(b.title)?b.jsx?b.jsx:typeof b.title=="function"?b.title():b.title:we.createElement(we.Fragment,null,ee||b.icon||b.promise?we.createElement("div",{"data-icon":"",className:Lr(Y==null?void 0:Y.icon,(s=b==null?void 0:b.classNames)==null?void 0:s.icon)},b.promise||b.type==="loading"&&!b.icon?b.icon||pa():null,b.type!=="loading"?b.icon||(L==null?void 0:L[ee])||BV(ee):null):null,we.createElement("div",{"data-content":"",className:Lr(Y==null?void 0:Y.content,(l=b==null?void 0:b.classNames)==null?void 0:l.content)},we.createElement("div",{"data-title":"",className:Lr(Y==null?void 0:Y.title,(u=b==null?void 0:b.classNames)==null?void 0:u.title)},typeof b.title=="function"?b.title():b.title),b.description?we.createElement("div",{"data-description":"",className:Lr(B,Fe,Y==null?void 0:Y.description,(d=b==null?void 0:b.classNames)==null?void 0:d.description)},typeof b.description=="function"?b.description():b.description):null),w.isValidElement(b.cancel)?b.cancel:b.cancel&&Sd(b.cancel)?we.createElement("button",{"data-button":!0,"data-cancel":!0,style:b.cancelButtonStyle||D,onClick:Xe=>{var yt,Nt;Sd(b.cancel)&&de&&((Nt=(yt=b.cancel).onClick)==null||Nt.call(yt,Xe),Jt())},className:Lr(Y==null?void 0:Y.cancelButton,(p=b==null?void 0:b.classNames)==null?void 0:p.cancelButton)},b.cancel.label):null,w.isValidElement(b.action)?b.action:b.action&&Sd(b.action)?we.createElement("button",{"data-button":!0,"data-action":!0,style:b.actionButtonStyle||U,onClick:Xe=>{var yt,Nt;Sd(b.action)&&((Nt=(yt=b.action).onClick)==null||Nt.call(yt,Xe),!Xe.defaultPrevented&&Jt())},className:Lr(Y==null?void 0:Y.actionButton,(g=b==null?void 0:b.classNames)==null?void 0:g.actionButton)},b.action.label):null))};function U_(){if(typeof window>"u"||typeof document>"u")return"ltr";let e=document.documentElement.getAttribute("dir");return e==="auto"||!e?window.getComputedStyle(document.documentElement).direction:e}function uW(e,t){let n={};return[e,t].forEach((r,a)=>{let o=a===1,s=o?"--mobile-offset":"--offset",l=o?rW:nW;function u(d){["top","right","bottom","left"].forEach(p=>{n[`${s}-${p}`]=typeof d=="number"?`${d}px`:d})}typeof r=="number"||typeof r=="string"?u(r):typeof r=="object"?["top","right","bottom","left"].forEach(d=>{r[d]===void 0?n[`${s}-${d}`]=l:n[`${s}-${d}`]=typeof r[d]=="number"?`${r[d]}px`:r[d]}):u(l)}),n}var dW=w.forwardRef(function(e,t){let{invert:n,position:r="bottom-right",hotkey:a=["altKey","KeyT"],expand:o,closeButton:s,className:l,offset:u,mobileOffset:d,theme:p="light",richColors:g,duration:m,style:b,visibleToasts:v=tW,toastOptions:y,dir:k=U_(),gap:A=oW,loadingIcon:x,icons:R,containerAriaLabel:O="Notifications",pauseWhenPageIsHidden:N}=e,[C,_]=we.useState([]),M=we.useMemo(()=>Array.from(new Set([r].concat(C.filter(j=>j.position).map(j=>j.position)))),[C,r]),[I,D]=we.useState([]),[U,$]=we.useState(!1),[B,W]=we.useState(!1),[K,H]=we.useState(p!=="system"?p:typeof window<"u"&&window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light"),G=we.useRef(null),z=a.join("+").replace(/Key/g,"").replace(/Digit/g,""),Y=we.useRef(null),L=we.useRef(!1),V=we.useCallback(j=>{_(P=>{var Z;return(Z=P.find(Q=>Q.id===j.id))!=null&&Z.delete||Un.dismiss(j.id),P.filter(({id:Q})=>Q!==j.id)})},[]);return we.useEffect(()=>Un.subscribe(j=>{if(j.dismiss){_(P=>P.map(Z=>Z.id===j.id?{...Z,delete:!0}:Z));return}setTimeout(()=>{dB.flushSync(()=>{_(P=>{let Z=P.findIndex(Q=>Q.id===j.id);return Z!==-1?[...P.slice(0,Z),{...P[Z],...j},...P.slice(Z+1)]:[j,...P]})})})}),[]),we.useEffect(()=>{if(p!=="system"){H(p);return}if(p==="system"&&(window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?H("dark"):H("light")),typeof window>"u")return;let j=window.matchMedia("(prefers-color-scheme: dark)");try{j.addEventListener("change",({matches:P})=>{H(P?"dark":"light")})}catch{j.addListener(({matches:Z})=>{try{H(Z?"dark":"light")}catch(Q){console.error(Q)}})}},[p]),we.useEffect(()=>{C.length<=1&&$(!1)},[C]),we.useEffect(()=>{let j=P=>{var Z,Q;a.every(oe=>P[oe]||P.code===oe)&&($(!0),(Z=G.current)==null||Z.focus()),P.code==="Escape"&&(document.activeElement===G.current||(Q=G.current)!=null&&Q.contains(document.activeElement))&&$(!1)};return document.addEventListener("keydown",j),()=>document.removeEventListener("keydown",j)},[a]),we.useEffect(()=>{if(G.current)return()=>{Y.current&&(Y.current.focus({preventScroll:!0}),Y.current=null,L.current=!1)}},[G.current]),we.createElement("section",{ref:t,"aria-label":`${O} ${z}`,tabIndex:-1,"aria-live":"polite","aria-relevant":"additions text","aria-atomic":"false",suppressHydrationWarning:!0},M.map((j,P)=>{var Z;let[Q,oe]=j.split("-");return C.length?we.createElement("ol",{key:j,dir:k==="auto"?U_():k,tabIndex:-1,ref:G,className:l,"data-sonner-toaster":!0,"data-theme":K,"data-y-position":Q,"data-lifted":U&&C.length>1&&!o,"data-x-position":oe,style:{"--front-toast-height":`${((Z=I[0])==null?void 0:Z.height)||0}px`,"--width":`${aW}px`,"--gap":`${A}px`,...b,...uW(u,d)},onBlur:ae=>{L.current&&!ae.currentTarget.contains(ae.relatedTarget)&&(L.current=!1,Y.current&&(Y.current.focus({preventScroll:!0}),Y.current=null))},onFocus:ae=>{ae.target instanceof HTMLElement&&ae.target.dataset.dismissible==="false"||L.current||(L.current=!0,Y.current=ae.relatedTarget)},onMouseEnter:()=>$(!0),onMouseMove:()=>$(!0),onMouseLeave:()=>{B||$(!1)},onDragEnd:()=>$(!1),onPointerDown:ae=>{ae.target instanceof HTMLElement&&ae.target.dataset.dismissible==="false"||W(!0)},onPointerUp:()=>W(!1)},C.filter(ae=>!ae.position&&P===0||ae.position===j).map((ae,ce)=>{var Re,ie;return we.createElement(cW,{key:ae.id,icons:R,index:ce,toast:ae,defaultRichColors:g,duration:(Re=y==null?void 0:y.duration)!=null?Re:m,className:y==null?void 0:y.className,descriptionClassName:y==null?void 0:y.descriptionClassName,invert:n,visibleToasts:v,closeButton:(ie=y==null?void 0:y.closeButton)!=null?ie:s,interacting:B,position:j,style:y==null?void 0:y.style,unstyled:y==null?void 0:y.unstyled,classNames:y==null?void 0:y.classNames,cancelButtonStyle:y==null?void 0:y.cancelButtonStyle,actionButtonStyle:y==null?void 0:y.actionButtonStyle,removeToast:V,toasts:C.filter(Te=>Te.position==ae.position),heights:I.filter(Te=>Te.position==ae.position),setHeights:D,expandByDefault:o,gap:A,loadingIcon:x,expanded:U,pauseWhenPageIsHidden:N,swipeDirections:e.swipeDirections})})):null}))});const fW={theme:"system",setTheme:()=>null},nj=w.createContext(fW);function rj({children:e,...t}){const n=De.use.theme(),r=De.use.setTheme();w.useEffect(()=>{const o=window.document.documentElement;if(o.classList.remove("light","dark"),n==="system"){const s=window.matchMedia("(prefers-color-scheme: dark)"),l=u=>{o.classList.remove("light","dark"),o.classList.add(u.matches?"dark":"light")};return o.classList.add(s.matches?"dark":"light"),s.addEventListener("change",l),()=>s.removeEventListener("change",l)}else o.classList.add(n)},[n]);const a={theme:n,setTheme:r};return E.jsx(nj.Provider,{...t,value:a,children:e})}const pW={visibleTabs:{},setTabVisibility:()=>{},isTabVisible:()=>!1},aj=w.createContext(pW),gW=({children:e})=>{const t=De.use.currentTab(),[n,r]=w.useState(()=>({documents:!0,"knowledge-graph":!0,retrieval:!0,api:!0}));w.useEffect(()=>{r(o=>({...o,documents:!0,"knowledge-graph":!0,retrieval:!0,api:!0}))},[t]);const a=w.useMemo(()=>({visibleTabs:n,setTabVisibility:(o,s)=>{r(l=>({...l,[o]:s}))},isTabVisible:o=>!!n[o]}),[n]);return E.jsx(aj.Provider,{value:a,children:e})},hW=(e,t,n,r)=>{var o,s,l,u;const a=[n,{code:t,...r||{}}];if((s=(o=e==null?void 0:e.services)==null?void 0:o.logger)!=null&&s.forward)return e.services.logger.forward(a,"warn","react-i18next::",!0);gi(a[0])&&(a[0]=`react-i18next:: ${a[0]}`),(u=(l=e==null?void 0:e.services)==null?void 0:l.logger)!=null&&u.warn?e.services.logger.warn(...a):console!=null&&console.warn&&console.warn(...a)},G_={},A0=(e,t,n,r)=>{gi(n)&&G_[n]||(gi(n)&&(G_[n]=new Date),hW(e,t,n,r))},oj=(e,t)=>()=>{if(e.isInitialized)t();else{const n=()=>{setTimeout(()=>{e.off("initialized",n)},0),t()};e.on("initialized",n)}},R0=(e,t,n)=>{e.loadNamespaces(t,oj(e,n))},H_=(e,t,n,r)=>{if(gi(n)&&(n=[n]),e.options.preload&&e.options.preload.indexOf(t)>-1)return R0(e,n,r);n.forEach(a=>{e.options.ns.indexOf(a)<0&&e.options.ns.push(a)}),e.loadLanguages(t,oj(e,r))},mW=(e,t,n={})=>!t.languages||!t.languages.length?(A0(t,"NO_LANGUAGES","i18n.languages were undefined or empty",{languages:t.languages}),!0):t.hasLoadedNamespace(e,{lng:n.lng,precheck:(r,a)=>{var o;if(((o=n.bindI18n)==null?void 0:o.indexOf("languageChanging"))>-1&&r.services.backendConnector.backend&&r.isLanguageChangingTo&&!a(r.isLanguageChangingTo,e))return!1}}),gi=e=>typeof e=="string",bW=e=>typeof e=="object"&&e!==null,yW=/&(?:amp|#38|lt|#60|gt|#62|apos|#39|quot|#34|nbsp|#160|copy|#169|reg|#174|hellip|#8230|#x2F|#47);/g,vW={"&amp;":"&","&#38;":"&","&lt;":"<","&#60;":"<","&gt;":">","&#62;":">","&apos;":"'","&#39;":"'","&quot;":'"',"&#34;":'"',"&nbsp;":" ","&#160;":" ","&copy;":"©","&#169;":"©","&reg;":"®","&#174;":"®","&hellip;":"…","&#8230;":"…","&#x2F;":"/","&#47;":"/"},SW=e=>vW[e],EW=e=>e.replace(yW,SW);let C0={bindI18n:"languageChanged",bindI18nStore:"",transEmptyNodeValue:"",transSupportBasicHtmlNodes:!0,transWrapTextNodes:"",transKeepBasicHtmlNodesFor:["br","strong","i","p"],useSuspense:!0,unescape:EW};const wW=(e={})=>{C0={...C0,...e}},xW=()=>C0;let ij;const kW=e=>{ij=e},TW=()=>ij,AW={type:"3rdParty",init(e){wW(e.options.react),kW(e)}},RW=w.createContext();class CW{constructor(){this.usedNamespaces={}}addUsedNamespaces(t){t.forEach(n=>{this.usedNamespaces[n]||(this.usedNamespaces[n]=!0)})}getUsedNamespaces(){return Object.keys(this.usedNamespaces)}}const _W=(e,t)=>{const n=w.useRef();return w.useEffect(()=>{n.current=e},[e,t]),n.current},sj=(e,t,n,r)=>e.getFixedT(t,n,r),NW=(e,t,n,r)=>w.useCallback(sj(e,t,n,r),[e,t,n,r]),Et=(e,t={})=>{var O,N,C,_;const{i18n:n}=t,{i18n:r,defaultNS:a}=w.useContext(RW)||{},o=n||r||TW();if(o&&!o.reportNamespaces&&(o.reportNamespaces=new CW),!o){A0(o,"NO_I18NEXT_INSTANCE","useTranslation: You will need to pass in an i18next instance by using initReactI18next");const M=(D,U)=>gi(U)?U:bW(U)&&gi(U.defaultValue)?U.defaultValue:Array.isArray(D)?D[D.length-1]:D,I=[M,{},!1];return I.t=M,I.i18n={},I.ready=!1,I}(O=o.options.react)!=null&&O.wait&&A0(o,"DEPRECATED_OPTION","useTranslation: It seems you are still using the old wait option, you may migrate to the new useSuspense behaviour.");const s={...xW(),...o.options.react,...t},{useSuspense:l,keyPrefix:u}=s;let d=a||((N=o.options)==null?void 0:N.defaultNS);d=gi(d)?[d]:d||["translation"],(_=(C=o.reportNamespaces).addUsedNamespaces)==null||_.call(C,d);const p=(o.isInitialized||o.initializedStoreOnce)&&d.every(M=>mW(M,o,s)),g=NW(o,t.lng||null,s.nsMode==="fallback"?d:d[0],u),m=()=>g,b=()=>sj(o,t.lng||null,s.nsMode==="fallback"?d:d[0],u),[v,y]=w.useState(m);let k=d.join();t.lng&&(k=`${t.lng}${k}`);const A=_W(k),x=w.useRef(!0);w.useEffect(()=>{const{bindI18n:M,bindI18nStore:I}=s;x.current=!0,!p&&!l&&(t.lng?H_(o,t.lng,d,()=>{x.current&&y(b)}):R0(o,d,()=>{x.current&&y(b)})),p&&A&&A!==k&&x.current&&y(b);const D=()=>{x.current&&y(b)};return M&&(o==null||o.on(M,D)),I&&(o==null||o.store.on(I,D)),()=>{x.current=!1,o&&(M==null||M.split(" ").forEach(U=>o.off(U,D))),I&&o&&I.split(" ").forEach(U=>o.store.off(U,D))}},[o,k]),w.useEffect(()=>{x.current&&p&&y(m)},[o,u,p]);const R=[v,o,p];if(R.t=v,R.i18n=o,R.ready=p,p||!p&&!l)return R;throw new Promise(M=>{t.lng?H_(o,t.lng,d,()=>M()):R0(o,d,()=>M())})};function OW(e,t){const n=w.createContext(t),r=o=>{const{children:s,...l}=o,u=w.useMemo(()=>l,Object.values(l));return E.jsx(n.Provider,{value:u,children:s})};r.displayName=e+"Provider";function a(o){const s=w.useContext(n);if(s)return s;if(t!==void 0)return t;throw new Error(`\`${o}\` must be used within \`${e}\``)}return[r,a]}function $r(e,t=[]){let n=[];function r(o,s){const l=w.createContext(s),u=n.length;n=[...n,s];const d=g=>{var A;const{scope:m,children:b,...v}=g,y=((A=m==null?void 0:m[e])==null?void 0:A[u])||l,k=w.useMemo(()=>v,Object.values(v));return E.jsx(y.Provider,{value:k,children:b})};d.displayName=o+"Provider";function p(g,m){var y;const b=((y=m==null?void 0:m[e])==null?void 0:y[u])||l,v=w.useContext(b);if(v)return v;if(s!==void 0)return s;throw new Error(`\`${g}\` must be used within \`${o}\``)}return[d,p]}const a=()=>{const o=n.map(s=>w.createContext(s));return function(l){const u=(l==null?void 0:l[e])||o;return w.useMemo(()=>({[`__scope${e}`]:{...l,[e]:u}}),[l,u])}};return a.scopeName=e,[r,IW(a,...t)]}function IW(...e){const t=e[0];if(e.length===1)return t;const n=()=>{const r=e.map(a=>({useScope:a(),scopeName:a.scopeName}));return function(o){const s=r.reduce((l,{useScope:u,scopeName:d})=>{const g=u(o)[`__scope${d}`];return{...l,...g}},{});return w.useMemo(()=>({[`__scope${t.scopeName}`]:s}),[s])}};return n.scopeName=t.scopeName,n}function $_(e,t){if(typeof e=="function")return e(t);e!=null&&(e.current=t)}function lj(...e){return t=>{let n=!1;const r=e.map(a=>{const o=$_(a,t);return!n&&typeof o=="function"&&(n=!0),o});if(n)return()=>{for(let a=0;a<r.length;a++){const o=r[a];typeof o=="function"?o():$_(e[a],null)}}}}function mt(...e){return w.useCallback(lj(...e),e)}function Ke(e,t,{checkForDefaultPrevented:n=!0}={}){return function(a){if(e==null||e(a),n===!1||!a.defaultPrevented)return t==null?void 0:t(a)}}var Rn=globalThis!=null&&globalThis.document?w.useLayoutEffect:()=>{},DW=pq.useId||(()=>{}),LW=0;function An(e){const[t,n]=w.useState(DW());return Rn(()=>{n(r=>r??String(LW++))},[e]),t?`radix-${t}`:""}function yn(e){const t=w.useRef(e);return w.useEffect(()=>{t.current=e}),w.useMemo(()=>(...n)=>{var r;return(r=t.current)==null?void 0:r.call(t,...n)},[])}function ja({prop:e,defaultProp:t,onChange:n=()=>{}}){const[r,a]=MW({defaultProp:t,onChange:n}),o=e!==void 0,s=o?e:r,l=yn(n),u=w.useCallback(d=>{if(o){const g=typeof d=="function"?d(e):d;g!==e&&l(g)}else a(d)},[o,e,a,l]);return[s,u]}function MW({defaultProp:e,onChange:t}){const n=w.useState(e),[r]=n,a=w.useRef(r),o=yn(t);return w.useEffect(()=>{a.current!==r&&(o(r),a.current=r)},[r,a,o]),n}var _o=w.forwardRef((e,t)=>{const{children:n,...r}=e,a=w.Children.toArray(n),o=a.find(PW);if(o){const s=o.props.children,l=a.map(u=>u===o?w.Children.count(s)>1?w.Children.only(null):w.isValidElement(s)?s.props.children:null:u);return E.jsx(_0,{...r,ref:t,children:w.isValidElement(s)?w.cloneElement(s,void 0,l):null})}return E.jsx(_0,{...r,ref:t,children:n})});_o.displayName="Slot";var _0=w.forwardRef((e,t)=>{const{children:n,...r}=e;if(w.isValidElement(n)){const a=zW(n),o=FW(r,n.props);return n.type!==w.Fragment&&(o.ref=t?lj(t,a):a),w.cloneElement(n,o)}return w.Children.count(n)>1?w.Children.only(null):null});_0.displayName="SlotClone";var Hk=({children:e})=>E.jsx(E.Fragment,{children:e});function PW(e){return w.isValidElement(e)&&e.type===Hk}function FW(e,t){const n={...t};for(const r in t){const a=e[r],o=t[r];/^on[A-Z]/.test(r)?a&&o?n[r]=(...l)=>{o(...l),a(...l)}:a&&(n[r]=a):r==="style"?n[r]={...a,...o}:r==="className"&&(n[r]=[a,o].filter(Boolean).join(" "))}return{...e,...n}}function zW(e){var r,a;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(a=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:a.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}var BW=["a","button","div","form","h2","h3","img","input","label","li","nav","ol","p","span","svg","ul"],Je=BW.reduce((e,t)=>{const n=w.forwardRef((r,a)=>{const{asChild:o,...s}=r,l=o?_o:t;return typeof window<"u"&&(window[Symbol.for("radix-ui")]=!0),E.jsx(l,{...s,ref:a})});return n.displayName=`Primitive.${t}`,{...e,[t]:n}},{});function jW(e,t){e&&Gc.flushSync(()=>e.dispatchEvent(t))}function UW(e,t=globalThis==null?void 0:globalThis.document){const n=yn(e);w.useEffect(()=>{const r=a=>{a.key==="Escape"&&n(a)};return t.addEventListener("keydown",r,{capture:!0}),()=>t.removeEventListener("keydown",r,{capture:!0})},[n,t])}var GW="DismissableLayer",N0="dismissableLayer.update",HW="dismissableLayer.pointerDownOutside",$W="dismissableLayer.focusOutside",q_,cj=w.createContext({layers:new Set,layersWithOutsidePointerEventsDisabled:new Set,branches:new Set}),qc=w.forwardRef((e,t)=>{const{disableOutsidePointerEvents:n=!1,onEscapeKeyDown:r,onPointerDownOutside:a,onFocusOutside:o,onInteractOutside:s,onDismiss:l,...u}=e,d=w.useContext(cj),[p,g]=w.useState(null),m=(p==null?void 0:p.ownerDocument)??(globalThis==null?void 0:globalThis.document),[,b]=w.useState({}),v=mt(t,_=>g(_)),y=Array.from(d.layers),[k]=[...d.layersWithOutsidePointerEventsDisabled].slice(-1),A=y.indexOf(k),x=p?y.indexOf(p):-1,R=d.layersWithOutsidePointerEventsDisabled.size>0,O=x>=A,N=WW(_=>{const M=_.target,I=[...d.branches].some(D=>D.contains(M));!O||I||(a==null||a(_),s==null||s(_),_.defaultPrevented||l==null||l())},m),C=YW(_=>{const M=_.target;[...d.branches].some(D=>D.contains(M))||(o==null||o(_),s==null||s(_),_.defaultPrevented||l==null||l())},m);return UW(_=>{x===d.layers.size-1&&(r==null||r(_),!_.defaultPrevented&&l&&(_.preventDefault(),l()))},m),w.useEffect(()=>{if(p)return n&&(d.layersWithOutsidePointerEventsDisabled.size===0&&(q_=m.body.style.pointerEvents,m.body.style.pointerEvents="none"),d.layersWithOutsidePointerEventsDisabled.add(p)),d.layers.add(p),V_(),()=>{n&&d.layersWithOutsidePointerEventsDisabled.size===1&&(m.body.style.pointerEvents=q_)}},[p,m,n,d]),w.useEffect(()=>()=>{p&&(d.layers.delete(p),d.layersWithOutsidePointerEventsDisabled.delete(p),V_())},[p,d]),w.useEffect(()=>{const _=()=>b({});return document.addEventListener(N0,_),()=>document.removeEventListener(N0,_)},[]),E.jsx(Je.div,{...u,ref:v,style:{pointerEvents:R?O?"auto":"none":void 0,...e.style},onFocusCapture:Ke(e.onFocusCapture,C.onFocusCapture),onBlurCapture:Ke(e.onBlurCapture,C.onBlurCapture),onPointerDownCapture:Ke(e.onPointerDownCapture,N.onPointerDownCapture)})});qc.displayName=GW;var qW="DismissableLayerBranch",VW=w.forwardRef((e,t)=>{const n=w.useContext(cj),r=w.useRef(null),a=mt(t,r);return w.useEffect(()=>{const o=r.current;if(o)return n.branches.add(o),()=>{n.branches.delete(o)}},[n.branches]),E.jsx(Je.div,{...e,ref:a})});VW.displayName=qW;function WW(e,t=globalThis==null?void 0:globalThis.document){const n=yn(e),r=w.useRef(!1),a=w.useRef(()=>{});return w.useEffect(()=>{const o=l=>{if(l.target&&!r.current){let u=function(){uj(HW,n,d,{discrete:!0})};const d={originalEvent:l};l.pointerType==="touch"?(t.removeEventListener("click",a.current),a.current=u,t.addEventListener("click",a.current,{once:!0})):u()}else t.removeEventListener("click",a.current);r.current=!1},s=window.setTimeout(()=>{t.addEventListener("pointerdown",o)},0);return()=>{window.clearTimeout(s),t.removeEventListener("pointerdown",o),t.removeEventListener("click",a.current)}},[t,n]),{onPointerDownCapture:()=>r.current=!0}}function YW(e,t=globalThis==null?void 0:globalThis.document){const n=yn(e),r=w.useRef(!1);return w.useEffect(()=>{const a=o=>{o.target&&!r.current&&uj($W,n,{originalEvent:o},{discrete:!1})};return t.addEventListener("focusin",a),()=>t.removeEventListener("focusin",a)},[t,n]),{onFocusCapture:()=>r.current=!0,onBlurCapture:()=>r.current=!1}}function V_(){const e=new CustomEvent(N0);document.dispatchEvent(e)}function uj(e,t,n,{discrete:r}){const a=n.originalEvent.target,o=new CustomEvent(e,{bubbles:!1,cancelable:!0,detail:n});t&&a.addEventListener(e,t,{once:!0}),r?jW(a,o):a.dispatchEvent(o)}var im="focusScope.autoFocusOnMount",sm="focusScope.autoFocusOnUnmount",W_={bubbles:!1,cancelable:!0},KW="FocusScope",tp=w.forwardRef((e,t)=>{const{loop:n=!1,trapped:r=!1,onMountAutoFocus:a,onUnmountAutoFocus:o,...s}=e,[l,u]=w.useState(null),d=yn(a),p=yn(o),g=w.useRef(null),m=mt(t,y=>u(y)),b=w.useRef({paused:!1,pause(){this.paused=!0},resume(){this.paused=!1}}).current;w.useEffect(()=>{if(r){let y=function(R){if(b.paused||!l)return;const O=R.target;l.contains(O)?g.current=O:Eo(g.current,{select:!0})},k=function(R){if(b.paused||!l)return;const O=R.relatedTarget;O!==null&&(l.contains(O)||Eo(g.current,{select:!0}))},A=function(R){if(document.activeElement===document.body)for(const N of R)N.removedNodes.length>0&&Eo(l)};document.addEventListener("focusin",y),document.addEventListener("focusout",k);const x=new MutationObserver(A);return l&&x.observe(l,{childList:!0,subtree:!0}),()=>{document.removeEventListener("focusin",y),document.removeEventListener("focusout",k),x.disconnect()}}},[r,l,b.paused]),w.useEffect(()=>{if(l){K_.add(b);const y=document.activeElement;if(!l.contains(y)){const A=new CustomEvent(im,W_);l.addEventListener(im,d),l.dispatchEvent(A),A.defaultPrevented||(XW(tY(dj(l)),{select:!0}),document.activeElement===y&&Eo(l))}return()=>{l.removeEventListener(im,d),setTimeout(()=>{const A=new CustomEvent(sm,W_);l.addEventListener(sm,p),l.dispatchEvent(A),A.defaultPrevented||Eo(y??document.body,{select:!0}),l.removeEventListener(sm,p),K_.remove(b)},0)}}},[l,d,p,b]);const v=w.useCallback(y=>{if(!n&&!r||b.paused)return;const k=y.key==="Tab"&&!y.altKey&&!y.ctrlKey&&!y.metaKey,A=document.activeElement;if(k&&A){const x=y.currentTarget,[R,O]=ZW(x);R&&O?!y.shiftKey&&A===O?(y.preventDefault(),n&&Eo(R,{select:!0})):y.shiftKey&&A===R&&(y.preventDefault(),n&&Eo(O,{select:!0})):A===x&&y.preventDefault()}},[n,r,b.paused]);return E.jsx(Je.div,{tabIndex:-1,...s,ref:m,onKeyDown:v})});tp.displayName=KW;function XW(e,{select:t=!1}={}){const n=document.activeElement;for(const r of e)if(Eo(r,{select:t}),document.activeElement!==n)return}function ZW(e){const t=dj(e),n=Y_(t,e),r=Y_(t.reverse(),e);return[n,r]}function dj(e){const t=[],n=document.createTreeWalker(e,NodeFilter.SHOW_ELEMENT,{acceptNode:r=>{const a=r.tagName==="INPUT"&&r.type==="hidden";return r.disabled||r.hidden||a?NodeFilter.FILTER_SKIP:r.tabIndex>=0?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP}});for(;n.nextNode();)t.push(n.currentNode);return t}function Y_(e,t){for(const n of e)if(!QW(n,{upTo:t}))return n}function QW(e,{upTo:t}){if(getComputedStyle(e).visibility==="hidden")return!0;for(;e;){if(t!==void 0&&e===t)return!1;if(getComputedStyle(e).display==="none")return!0;e=e.parentElement}return!1}function JW(e){return e instanceof HTMLInputElement&&"select"in e}function Eo(e,{select:t=!1}={}){if(e&&e.focus){const n=document.activeElement;e.focus({preventScroll:!0}),e!==n&&JW(e)&&t&&e.select()}}var K_=eY();function eY(){let e=[];return{add(t){const n=e[0];t!==n&&(n==null||n.pause()),e=X_(e,t),e.unshift(t)},remove(t){var n;e=X_(e,t),(n=e[0])==null||n.resume()}}}function X_(e,t){const n=[...e],r=n.indexOf(t);return r!==-1&&n.splice(r,1),n}function tY(e){return e.filter(t=>t.tagName!=="A")}var nY="Portal",$k=w.forwardRef((e,t)=>{var l;const{container:n,...r}=e,[a,o]=w.useState(!1);Rn(()=>o(!0),[]);const s=n||a&&((l=globalThis==null?void 0:globalThis.document)==null?void 0:l.body);return s?dB.createPortal(E.jsx(Je.div,{...r,ref:t}),s):null});$k.displayName=nY;function rY(e,t){return w.useReducer((n,r)=>t[n][r]??n,e)}var Tr=e=>{const{present:t,children:n}=e,r=aY(t),a=typeof n=="function"?n({present:r.isPresent}):w.Children.only(n),o=mt(r.ref,oY(a));return typeof n=="function"||r.isPresent?w.cloneElement(a,{ref:o}):null};Tr.displayName="Presence";function aY(e){const[t,n]=w.useState(),r=w.useRef({}),a=w.useRef(e),o=w.useRef("none"),s=e?"mounted":"unmounted",[l,u]=rY(s,{mounted:{UNMOUNT:"unmounted",ANIMATION_OUT:"unmountSuspended"},unmountSuspended:{MOUNT:"mounted",ANIMATION_END:"unmounted"},unmounted:{MOUNT:"mounted"}});return w.useEffect(()=>{const d=Ed(r.current);o.current=l==="mounted"?d:"none"},[l]),Rn(()=>{const d=r.current,p=a.current;if(p!==e){const m=o.current,b=Ed(d);e?u("MOUNT"):b==="none"||(d==null?void 0:d.display)==="none"?u("UNMOUNT"):u(p&&m!==b?"ANIMATION_OUT":"UNMOUNT"),a.current=e}},[e,u]),Rn(()=>{if(t){let d;const p=t.ownerDocument.defaultView??window,g=b=>{const y=Ed(r.current).includes(b.animationName);if(b.target===t&&y&&(u("ANIMATION_END"),!a.current)){const k=t.style.animationFillMode;t.style.animationFillMode="forwards",d=p.setTimeout(()=>{t.style.animationFillMode==="forwards"&&(t.style.animationFillMode=k)})}},m=b=>{b.target===t&&(o.current=Ed(r.current))};return t.addEventListener("animationstart",m),t.addEventListener("animationcancel",g),t.addEventListener("animationend",g),()=>{p.clearTimeout(d),t.removeEventListener("animationstart",m),t.removeEventListener("animationcancel",g),t.removeEventListener("animationend",g)}}else u("ANIMATION_END")},[t,u]),{isPresent:["mounted","unmountSuspended"].includes(l),ref:w.useCallback(d=>{d&&(r.current=getComputedStyle(d)),n(d)},[])}}function Ed(e){return(e==null?void 0:e.animationName)||"none"}function oY(e){var r,a;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(a=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:a.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}var lm=0;function qk(){w.useEffect(()=>{const e=document.querySelectorAll("[data-radix-focus-guard]");return document.body.insertAdjacentElement("afterbegin",e[0]??Z_()),document.body.insertAdjacentElement("beforeend",e[1]??Z_()),lm++,()=>{lm===1&&document.querySelectorAll("[data-radix-focus-guard]").forEach(t=>t.remove()),lm--}},[])}function Z_(){const e=document.createElement("span");return e.setAttribute("data-radix-focus-guard",""),e.tabIndex=0,e.style.outline="none",e.style.opacity="0",e.style.position="fixed",e.style.pointerEvents="none",e}var na=function(){return na=Object.assign||function(t){for(var n,r=1,a=arguments.length;r<a;r++){n=arguments[r];for(var o in n)Object.prototype.hasOwnProperty.call(n,o)&&(t[o]=n[o])}return t},na.apply(this,arguments)};function fj(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var a=0,r=Object.getOwnPropertySymbols(e);a<r.length;a++)t.indexOf(r[a])<0&&Object.prototype.propertyIsEnumerable.call(e,r[a])&&(n[r[a]]=e[r[a]]);return n}function Ti(e,t,n,r){function a(o){return o instanceof n?o:new n(function(s){s(o)})}return new(n||(n=Promise))(function(o,s){function l(p){try{d(r.next(p))}catch(g){s(g)}}function u(p){try{d(r.throw(p))}catch(g){s(g)}}function d(p){p.done?o(p.value):a(p.value).then(l,u)}d((r=r.apply(e,t||[])).next())})}function iY(e,t,n){if(n||arguments.length===2)for(var r=0,a=t.length,o;r<a;r++)(o||!(r in t))&&(o||(o=Array.prototype.slice.call(t,0,r)),o[r]=t[r]);return e.concat(o||Array.prototype.slice.call(t))}var Jd="right-scroll-bar-position",ef="width-before-scroll-bar",sY="with-scroll-bars-hidden",lY="--removed-body-scroll-bar-size";function cm(e,t){return typeof e=="function"?e(t):e&&(e.current=t),e}function cY(e,t){var n=w.useState(function(){return{value:e,callback:t,facade:{get current(){return n.value},set current(r){var a=n.value;a!==r&&(n.value=r,n.callback(r,a))}}}})[0];return n.callback=t,n.facade}var uY=typeof window<"u"?w.useLayoutEffect:w.useEffect,Q_=new WeakMap;function dY(e,t){var n=cY(null,function(r){return e.forEach(function(a){return cm(a,r)})});return uY(function(){var r=Q_.get(n);if(r){var a=new Set(r),o=new Set(e),s=n.current;a.forEach(function(l){o.has(l)||cm(l,null)}),o.forEach(function(l){a.has(l)||cm(l,s)})}Q_.set(n,e)},[e]),n}function fY(e){return e}function pY(e,t){t===void 0&&(t=fY);var n=[],r=!1,a={read:function(){if(r)throw new Error("Sidecar: could not `read` from an `assigned` medium. `read` could be used only with `useMedium`.");return n.length?n[n.length-1]:e},useMedium:function(o){var s=t(o,r);return n.push(s),function(){n=n.filter(function(l){return l!==s})}},assignSyncMedium:function(o){for(r=!0;n.length;){var s=n;n=[],s.forEach(o)}n={push:function(l){return o(l)},filter:function(){return n}}},assignMedium:function(o){r=!0;var s=[];if(n.length){var l=n;n=[],l.forEach(o),s=n}var u=function(){var p=s;s=[],p.forEach(o)},d=function(){return Promise.resolve().then(u)};d(),n={push:function(p){s.push(p),d()},filter:function(p){return s=s.filter(p),n}}}};return a}function gY(e){e===void 0&&(e={});var t=pY(null);return t.options=na({async:!0,ssr:!1},e),t}var pj=function(e){var t=e.sideCar,n=fj(e,["sideCar"]);if(!t)throw new Error("Sidecar: please provide `sideCar` property to import the right car");var r=t.read();if(!r)throw new Error("Sidecar medium not found");return w.createElement(r,na({},n))};pj.isSideCarExport=!0;function hY(e,t){return e.useMedium(t),pj}var gj=gY(),um=function(){},np=w.forwardRef(function(e,t){var n=w.useRef(null),r=w.useState({onScrollCapture:um,onWheelCapture:um,onTouchMoveCapture:um}),a=r[0],o=r[1],s=e.forwardProps,l=e.children,u=e.className,d=e.removeScrollBar,p=e.enabled,g=e.shards,m=e.sideCar,b=e.noIsolation,v=e.inert,y=e.allowPinchZoom,k=e.as,A=k===void 0?"div":k,x=e.gapMode,R=fj(e,["forwardProps","children","className","removeScrollBar","enabled","shards","sideCar","noIsolation","inert","allowPinchZoom","as","gapMode"]),O=m,N=dY([n,t]),C=na(na({},R),a);return w.createElement(w.Fragment,null,p&&w.createElement(O,{sideCar:gj,removeScrollBar:d,shards:g,noIsolation:b,inert:v,setCallbacks:o,allowPinchZoom:!!y,lockRef:n,gapMode:x}),s?w.cloneElement(w.Children.only(l),na(na({},C),{ref:N})):w.createElement(A,na({},C,{className:u,ref:N}),l))});np.defaultProps={enabled:!0,removeScrollBar:!0,inert:!1};np.classNames={fullWidth:ef,zeroRight:Jd};var mY=function(){if(typeof __webpack_nonce__<"u")return __webpack_nonce__};function bY(){if(!document)return null;var e=document.createElement("style");e.type="text/css";var t=mY();return t&&e.setAttribute("nonce",t),e}function yY(e,t){e.styleSheet?e.styleSheet.cssText=t:e.appendChild(document.createTextNode(t))}function vY(e){var t=document.head||document.getElementsByTagName("head")[0];t.appendChild(e)}var SY=function(){var e=0,t=null;return{add:function(n){e==0&&(t=bY())&&(yY(t,n),vY(t)),e++},remove:function(){e--,!e&&t&&(t.parentNode&&t.parentNode.removeChild(t),t=null)}}},EY=function(){var e=SY();return function(t,n){w.useEffect(function(){return e.add(t),function(){e.remove()}},[t&&n])}},hj=function(){var e=EY(),t=function(n){var r=n.styles,a=n.dynamic;return e(r,a),null};return t},wY={left:0,top:0,right:0,gap:0},dm=function(e){return parseInt(e||"",10)||0},xY=function(e){var t=window.getComputedStyle(document.body),n=t[e==="padding"?"paddingLeft":"marginLeft"],r=t[e==="padding"?"paddingTop":"marginTop"],a=t[e==="padding"?"paddingRight":"marginRight"];return[dm(n),dm(r),dm(a)]},kY=function(e){if(e===void 0&&(e="margin"),typeof window>"u")return wY;var t=xY(e),n=document.documentElement.clientWidth,r=window.innerWidth;return{left:t[0],top:t[1],right:t[2],gap:Math.max(0,r-n+t[2]-t[0])}},TY=hj(),As="data-scroll-locked",AY=function(e,t,n,r){var a=e.left,o=e.top,s=e.right,l=e.gap;return n===void 0&&(n="margin"),`
  .`.concat(sY,` {
   overflow: hidden `).concat(r,`;
   padding-right: `).concat(l,"px ").concat(r,`;
  }
  body[`).concat(As,`] {
    overflow: hidden `).concat(r,`;
    overscroll-behavior: contain;
    `).concat([t&&"position: relative ".concat(r,";"),n==="margin"&&`
    padding-left: `.concat(a,`px;
    padding-top: `).concat(o,`px;
    padding-right: `).concat(s,`px;
    margin-left:0;
    margin-top:0;
    margin-right: `).concat(l,"px ").concat(r,`;
    `),n==="padding"&&"padding-right: ".concat(l,"px ").concat(r,";")].filter(Boolean).join(""),`
  }
  
  .`).concat(Jd,` {
    right: `).concat(l,"px ").concat(r,`;
  }
  
  .`).concat(ef,` {
    margin-right: `).concat(l,"px ").concat(r,`;
  }
  
  .`).concat(Jd," .").concat(Jd,` {
    right: 0 `).concat(r,`;
  }
  
  .`).concat(ef," .").concat(ef,` {
    margin-right: 0 `).concat(r,`;
  }
  
  body[`).concat(As,`] {
    `).concat(lY,": ").concat(l,`px;
  }
`)},J_=function(){var e=parseInt(document.body.getAttribute(As)||"0",10);return isFinite(e)?e:0},RY=function(){w.useEffect(function(){return document.body.setAttribute(As,(J_()+1).toString()),function(){var e=J_()-1;e<=0?document.body.removeAttribute(As):document.body.setAttribute(As,e.toString())}},[])},CY=function(e){var t=e.noRelative,n=e.noImportant,r=e.gapMode,a=r===void 0?"margin":r;RY();var o=w.useMemo(function(){return kY(a)},[a]);return w.createElement(TY,{styles:AY(o,!t,a,n?"":"!important")})},O0=!1;if(typeof window<"u")try{var wd=Object.defineProperty({},"passive",{get:function(){return O0=!0,!0}});window.addEventListener("test",wd,wd),window.removeEventListener("test",wd,wd)}catch{O0=!1}var ds=O0?{passive:!1}:!1,_Y=function(e){return e.tagName==="TEXTAREA"},mj=function(e,t){if(!(e instanceof Element))return!1;var n=window.getComputedStyle(e);return n[t]!=="hidden"&&!(n.overflowY===n.overflowX&&!_Y(e)&&n[t]==="visible")},NY=function(e){return mj(e,"overflowY")},OY=function(e){return mj(e,"overflowX")},eN=function(e,t){var n=t.ownerDocument,r=t;do{typeof ShadowRoot<"u"&&r instanceof ShadowRoot&&(r=r.host);var a=bj(e,r);if(a){var o=yj(e,r),s=o[1],l=o[2];if(s>l)return!0}r=r.parentNode}while(r&&r!==n.body);return!1},IY=function(e){var t=e.scrollTop,n=e.scrollHeight,r=e.clientHeight;return[t,n,r]},DY=function(e){var t=e.scrollLeft,n=e.scrollWidth,r=e.clientWidth;return[t,n,r]},bj=function(e,t){return e==="v"?NY(t):OY(t)},yj=function(e,t){return e==="v"?IY(t):DY(t)},LY=function(e,t){return e==="h"&&t==="rtl"?-1:1},MY=function(e,t,n,r,a){var o=LY(e,window.getComputedStyle(t).direction),s=o*r,l=n.target,u=t.contains(l),d=!1,p=s>0,g=0,m=0;do{var b=yj(e,l),v=b[0],y=b[1],k=b[2],A=y-k-o*v;(v||A)&&bj(e,l)&&(g+=A,m+=v),l instanceof ShadowRoot?l=l.host:l=l.parentNode}while(!u&&l!==document.body||u&&(t.contains(l)||t===l));return(p&&Math.abs(g)<1||!p&&Math.abs(m)<1)&&(d=!0),d},xd=function(e){return"changedTouches"in e?[e.changedTouches[0].clientX,e.changedTouches[0].clientY]:[0,0]},tN=function(e){return[e.deltaX,e.deltaY]},nN=function(e){return e&&"current"in e?e.current:e},PY=function(e,t){return e[0]===t[0]&&e[1]===t[1]},FY=function(e){return`
  .block-interactivity-`.concat(e,` {pointer-events: none;}
  .allow-interactivity-`).concat(e,` {pointer-events: all;}
`)},zY=0,fs=[];function BY(e){var t=w.useRef([]),n=w.useRef([0,0]),r=w.useRef(),a=w.useState(zY++)[0],o=w.useState(hj)[0],s=w.useRef(e);w.useEffect(function(){s.current=e},[e]),w.useEffect(function(){if(e.inert){document.body.classList.add("block-interactivity-".concat(a));var y=iY([e.lockRef.current],(e.shards||[]).map(nN),!0).filter(Boolean);return y.forEach(function(k){return k.classList.add("allow-interactivity-".concat(a))}),function(){document.body.classList.remove("block-interactivity-".concat(a)),y.forEach(function(k){return k.classList.remove("allow-interactivity-".concat(a))})}}},[e.inert,e.lockRef.current,e.shards]);var l=w.useCallback(function(y,k){if("touches"in y&&y.touches.length===2||y.type==="wheel"&&y.ctrlKey)return!s.current.allowPinchZoom;var A=xd(y),x=n.current,R="deltaX"in y?y.deltaX:x[0]-A[0],O="deltaY"in y?y.deltaY:x[1]-A[1],N,C=y.target,_=Math.abs(R)>Math.abs(O)?"h":"v";if("touches"in y&&_==="h"&&C.type==="range")return!1;var M=eN(_,C);if(!M)return!0;if(M?N=_:(N=_==="v"?"h":"v",M=eN(_,C)),!M)return!1;if(!r.current&&"changedTouches"in y&&(R||O)&&(r.current=N),!N)return!0;var I=r.current||N;return MY(I,k,y,I==="h"?R:O)},[]),u=w.useCallback(function(y){var k=y;if(!(!fs.length||fs[fs.length-1]!==o)){var A="deltaY"in k?tN(k):xd(k),x=t.current.filter(function(N){return N.name===k.type&&(N.target===k.target||k.target===N.shadowParent)&&PY(N.delta,A)})[0];if(x&&x.should){k.cancelable&&k.preventDefault();return}if(!x){var R=(s.current.shards||[]).map(nN).filter(Boolean).filter(function(N){return N.contains(k.target)}),O=R.length>0?l(k,R[0]):!s.current.noIsolation;O&&k.cancelable&&k.preventDefault()}}},[]),d=w.useCallback(function(y,k,A,x){var R={name:y,delta:k,target:A,should:x,shadowParent:jY(A)};t.current.push(R),setTimeout(function(){t.current=t.current.filter(function(O){return O!==R})},1)},[]),p=w.useCallback(function(y){n.current=xd(y),r.current=void 0},[]),g=w.useCallback(function(y){d(y.type,tN(y),y.target,l(y,e.lockRef.current))},[]),m=w.useCallback(function(y){d(y.type,xd(y),y.target,l(y,e.lockRef.current))},[]);w.useEffect(function(){return fs.push(o),e.setCallbacks({onScrollCapture:g,onWheelCapture:g,onTouchMoveCapture:m}),document.addEventListener("wheel",u,ds),document.addEventListener("touchmove",u,ds),document.addEventListener("touchstart",p,ds),function(){fs=fs.filter(function(y){return y!==o}),document.removeEventListener("wheel",u,ds),document.removeEventListener("touchmove",u,ds),document.removeEventListener("touchstart",p,ds)}},[]);var b=e.removeScrollBar,v=e.inert;return w.createElement(w.Fragment,null,v?w.createElement(o,{styles:FY(a)}):null,b?w.createElement(CY,{gapMode:e.gapMode}):null)}function jY(e){for(var t=null;e!==null;)e instanceof ShadowRoot&&(t=e.host,e=e.host),e=e.parentNode;return t}const UY=hY(gj,BY);var rp=w.forwardRef(function(e,t){return w.createElement(np,na({},e,{ref:t,sideCar:UY}))});rp.classNames=np.classNames;var GY=function(e){if(typeof document>"u")return null;var t=Array.isArray(e)?e[0]:e;return t.ownerDocument.body},ps=new WeakMap,kd=new WeakMap,Td={},fm=0,vj=function(e){return e&&(e.host||vj(e.parentNode))},HY=function(e,t){return t.map(function(n){if(e.contains(n))return n;var r=vj(n);return r&&e.contains(r)?r:(console.error("aria-hidden",n,"in not contained inside",e,". Doing nothing"),null)}).filter(function(n){return!!n})},$Y=function(e,t,n,r){var a=HY(t,Array.isArray(e)?e:[e]);Td[n]||(Td[n]=new WeakMap);var o=Td[n],s=[],l=new Set,u=new Set(a),d=function(g){!g||l.has(g)||(l.add(g),d(g.parentNode))};a.forEach(d);var p=function(g){!g||u.has(g)||Array.prototype.forEach.call(g.children,function(m){if(l.has(m))p(m);else try{var b=m.getAttribute(r),v=b!==null&&b!=="false",y=(ps.get(m)||0)+1,k=(o.get(m)||0)+1;ps.set(m,y),o.set(m,k),s.push(m),y===1&&v&&kd.set(m,!0),k===1&&m.setAttribute(n,"true"),v||m.setAttribute(r,"true")}catch(A){console.error("aria-hidden: cannot operate on ",m,A)}})};return p(t),l.clear(),fm++,function(){s.forEach(function(g){var m=ps.get(g)-1,b=o.get(g)-1;ps.set(g,m),o.set(g,b),m||(kd.has(g)||g.removeAttribute(r),kd.delete(g)),b||g.removeAttribute(n)}),fm--,fm||(ps=new WeakMap,ps=new WeakMap,kd=new WeakMap,Td={})}},Vk=function(e,t,n){n===void 0&&(n="data-aria-hidden");var r=Array.from(Array.isArray(e)?e:[e]),a=GY(e);return a?(r.push.apply(r,Array.from(a.querySelectorAll("[aria-live]"))),$Y(r,a,n,"aria-hidden")):function(){return null}},Wk="Dialog",[Sj,Ej]=$r(Wk),[qY,qr]=Sj(Wk),wj=e=>{const{__scopeDialog:t,children:n,open:r,defaultOpen:a,onOpenChange:o,modal:s=!0}=e,l=w.useRef(null),u=w.useRef(null),[d=!1,p]=ja({prop:r,defaultProp:a,onChange:o});return E.jsx(qY,{scope:t,triggerRef:l,contentRef:u,contentId:An(),titleId:An(),descriptionId:An(),open:d,onOpenChange:p,onOpenToggle:w.useCallback(()=>p(g=>!g),[p]),modal:s,children:n})};wj.displayName=Wk;var xj="DialogTrigger",kj=w.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=qr(xj,n),o=mt(t,a.triggerRef);return E.jsx(Je.button,{type:"button","aria-haspopup":"dialog","aria-expanded":a.open,"aria-controls":a.contentId,"data-state":Xk(a.open),...r,ref:o,onClick:Ke(e.onClick,a.onOpenToggle)})});kj.displayName=xj;var Yk="DialogPortal",[VY,Tj]=Sj(Yk,{forceMount:void 0}),Aj=e=>{const{__scopeDialog:t,forceMount:n,children:r,container:a}=e,o=qr(Yk,t);return E.jsx(VY,{scope:t,forceMount:n,children:w.Children.map(r,s=>E.jsx(Tr,{present:n||o.open,children:E.jsx($k,{asChild:!0,container:a,children:s})}))})};Aj.displayName=Yk;var yf="DialogOverlay",Rj=w.forwardRef((e,t)=>{const n=Tj(yf,e.__scopeDialog),{forceMount:r=n.forceMount,...a}=e,o=qr(yf,e.__scopeDialog);return o.modal?E.jsx(Tr,{present:r||o.open,children:E.jsx(WY,{...a,ref:t})}):null});Rj.displayName=yf;var WY=w.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=qr(yf,n);return E.jsx(rp,{as:_o,allowPinchZoom:!0,shards:[a.contentRef],children:E.jsx(Je.div,{"data-state":Xk(a.open),...r,ref:t,style:{pointerEvents:"auto",...r.style}})})}),mi="DialogContent",Cj=w.forwardRef((e,t)=>{const n=Tj(mi,e.__scopeDialog),{forceMount:r=n.forceMount,...a}=e,o=qr(mi,e.__scopeDialog);return E.jsx(Tr,{present:r||o.open,children:o.modal?E.jsx(YY,{...a,ref:t}):E.jsx(KY,{...a,ref:t})})});Cj.displayName=mi;var YY=w.forwardRef((e,t)=>{const n=qr(mi,e.__scopeDialog),r=w.useRef(null),a=mt(t,n.contentRef,r);return w.useEffect(()=>{const o=r.current;if(o)return Vk(o)},[]),E.jsx(_j,{...e,ref:a,trapFocus:n.open,disableOutsidePointerEvents:!0,onCloseAutoFocus:Ke(e.onCloseAutoFocus,o=>{var s;o.preventDefault(),(s=n.triggerRef.current)==null||s.focus()}),onPointerDownOutside:Ke(e.onPointerDownOutside,o=>{const s=o.detail.originalEvent,l=s.button===0&&s.ctrlKey===!0;(s.button===2||l)&&o.preventDefault()}),onFocusOutside:Ke(e.onFocusOutside,o=>o.preventDefault())})}),KY=w.forwardRef((e,t)=>{const n=qr(mi,e.__scopeDialog),r=w.useRef(!1),a=w.useRef(!1);return E.jsx(_j,{...e,ref:t,trapFocus:!1,disableOutsidePointerEvents:!1,onCloseAutoFocus:o=>{var s,l;(s=e.onCloseAutoFocus)==null||s.call(e,o),o.defaultPrevented||(r.current||(l=n.triggerRef.current)==null||l.focus(),o.preventDefault()),r.current=!1,a.current=!1},onInteractOutside:o=>{var u,d;(u=e.onInteractOutside)==null||u.call(e,o),o.defaultPrevented||(r.current=!0,o.detail.originalEvent.type==="pointerdown"&&(a.current=!0));const s=o.target;((d=n.triggerRef.current)==null?void 0:d.contains(s))&&o.preventDefault(),o.detail.originalEvent.type==="focusin"&&a.current&&o.preventDefault()}})}),_j=w.forwardRef((e,t)=>{const{__scopeDialog:n,trapFocus:r,onOpenAutoFocus:a,onCloseAutoFocus:o,...s}=e,l=qr(mi,n),u=w.useRef(null),d=mt(t,u);return qk(),E.jsxs(E.Fragment,{children:[E.jsx(tp,{asChild:!0,loop:!0,trapped:r,onMountAutoFocus:a,onUnmountAutoFocus:o,children:E.jsx(qc,{role:"dialog",id:l.contentId,"aria-describedby":l.descriptionId,"aria-labelledby":l.titleId,"data-state":Xk(l.open),...s,ref:d,onDismiss:()=>l.onOpenChange(!1)})}),E.jsxs(E.Fragment,{children:[E.jsx(ZY,{titleId:l.titleId}),E.jsx(JY,{contentRef:u,descriptionId:l.descriptionId})]})]})}),Kk="DialogTitle",Nj=w.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=qr(Kk,n);return E.jsx(Je.h2,{id:a.titleId,...r,ref:t})});Nj.displayName=Kk;var Oj="DialogDescription",Ij=w.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=qr(Oj,n);return E.jsx(Je.p,{id:a.descriptionId,...r,ref:t})});Ij.displayName=Oj;var Dj="DialogClose",Lj=w.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=qr(Dj,n);return E.jsx(Je.button,{type:"button",...r,ref:t,onClick:Ke(e.onClick,()=>a.onOpenChange(!1))})});Lj.displayName=Dj;function Xk(e){return e?"open":"closed"}var Mj="DialogTitleWarning",[XY,Pj]=OW(Mj,{contentName:mi,titleName:Kk,docsSlug:"dialog"}),ZY=({titleId:e})=>{const t=Pj(Mj),n=`\`${t.contentName}\` requires a \`${t.titleName}\` for the component to be accessible for screen reader users.

If you want to hide the \`${t.titleName}\`, you can wrap it with our VisuallyHidden component.

For more information, see https://radix-ui.com/primitives/docs/components/${t.docsSlug}`;return w.useEffect(()=>{e&&(document.getElementById(e)||console.error(n))},[n,e]),null},QY="DialogDescriptionWarning",JY=({contentRef:e,descriptionId:t})=>{const r=`Warning: Missing \`Description\` or \`aria-describedby={undefined}\` for {${Pj(QY).contentName}}.`;return w.useEffect(()=>{var o;const a=(o=e.current)==null?void 0:o.getAttribute("aria-describedby");t&&a&&(document.getElementById(t)||console.warn(r))},[r,e,t]),null},Zk=wj,Fj=kj,Qk=Aj,ap=Rj,op=Cj,Jk=Nj,eT=Ij,tT=Lj,zj="AlertDialog",[eK,u0e]=$r(zj,[Ej]),$a=Ej(),Bj=e=>{const{__scopeAlertDialog:t,...n}=e,r=$a(t);return E.jsx(Zk,{...r,...n,modal:!0})};Bj.displayName=zj;var tK="AlertDialogTrigger",nK=w.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=$a(n);return E.jsx(Fj,{...a,...r,ref:t})});nK.displayName=tK;var rK="AlertDialogPortal",jj=e=>{const{__scopeAlertDialog:t,...n}=e,r=$a(t);return E.jsx(Qk,{...r,...n})};jj.displayName=rK;var aK="AlertDialogOverlay",Uj=w.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=$a(n);return E.jsx(ap,{...a,...r,ref:t})});Uj.displayName=aK;var Rs="AlertDialogContent",[oK,iK]=eK(Rs),Gj=w.forwardRef((e,t)=>{const{__scopeAlertDialog:n,children:r,...a}=e,o=$a(n),s=w.useRef(null),l=mt(t,s),u=w.useRef(null);return E.jsx(XY,{contentName:Rs,titleName:Hj,docsSlug:"alert-dialog",children:E.jsx(oK,{scope:n,cancelRef:u,children:E.jsxs(op,{role:"alertdialog",...o,...a,ref:l,onOpenAutoFocus:Ke(a.onOpenAutoFocus,d=>{var p;d.preventDefault(),(p=u.current)==null||p.focus({preventScroll:!0})}),onPointerDownOutside:d=>d.preventDefault(),onInteractOutside:d=>d.preventDefault(),children:[E.jsx(Hk,{children:r}),E.jsx(lK,{contentRef:s})]})})})});Gj.displayName=Rs;var Hj="AlertDialogTitle",$j=w.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=$a(n);return E.jsx(Jk,{...a,...r,ref:t})});$j.displayName=Hj;var qj="AlertDialogDescription",Vj=w.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=$a(n);return E.jsx(eT,{...a,...r,ref:t})});Vj.displayName=qj;var sK="AlertDialogAction",Wj=w.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=$a(n);return E.jsx(tT,{...a,...r,ref:t})});Wj.displayName=sK;var Yj="AlertDialogCancel",Kj=w.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,{cancelRef:a}=iK(Yj,n),o=$a(n),s=mt(t,a);return E.jsx(tT,{...o,...r,ref:s})});Kj.displayName=Yj;var lK=({contentRef:e})=>{const t=`\`${Rs}\` requires a description for the component to be accessible for screen reader users.

You can add a description to the \`${Rs}\` by passing a \`${qj}\` component as a child, which also benefits sighted users by adding visible context to the dialog.

Alternatively, you can use your own component as a description by assigning it an \`id\` and passing the same value to the \`aria-describedby\` prop in \`${Rs}\`. If the description is confusing or duplicative for sighted users, you can use the \`@radix-ui/react-visually-hidden\` primitive as a wrapper around your description component.

For more information, see https://radix-ui.com/primitives/docs/components/alert-dialog`;return w.useEffect(()=>{var r;document.getElementById((r=e.current)==null?void 0:r.getAttribute("aria-describedby"))||console.warn(t)},[t,e]),null},cK=Bj,uK=jj,Xj=Uj,Zj=Gj,Qj=Wj,Jj=Kj,eU=$j,tU=Vj;const rN=e=>typeof e=="boolean"?`${e}`:e===0?"0":e,aN=pB,dK=(e,t)=>n=>{var r;if((t==null?void 0:t.variants)==null)return aN(e,n==null?void 0:n.class,n==null?void 0:n.className);const{variants:a,defaultVariants:o}=t,s=Object.keys(a).map(d=>{const p=n==null?void 0:n[d],g=o==null?void 0:o[d];if(p===null)return null;const m=rN(p)||rN(g);return a[d][m]}),l=n&&Object.entries(n).reduce((d,p)=>{let[g,m]=p;return m===void 0||(d[g]=m),d},{}),u=t==null||(r=t.compoundVariants)===null||r===void 0?void 0:r.reduce((d,p)=>{let{class:g,className:m,...b}=p;return Object.entries(b).every(v=>{let[y,k]=v;return Array.isArray(k)?k.includes({...o,...l}[y]):{...o,...l}[y]===k})?[...d,g,m]:d},[]);return aN(e,s,u,n==null?void 0:n.class,n==null?void 0:n.className)},fK=["top","right","bottom","left"],No=Math.min,tr=Math.max,vf=Math.round,Ad=Math.floor,oa=e=>({x:e,y:e}),pK={left:"right",right:"left",bottom:"top",top:"bottom"},gK={start:"end",end:"start"};function I0(e,t,n){return tr(e,No(t,n))}function Ua(e,t){return typeof e=="function"?e(t):e}function Ga(e){return e.split("-")[0]}function Vs(e){return e.split("-")[1]}function nT(e){return e==="x"?"y":"x"}function rT(e){return e==="y"?"height":"width"}function Oo(e){return["top","bottom"].includes(Ga(e))?"y":"x"}function aT(e){return nT(Oo(e))}function hK(e,t,n){n===void 0&&(n=!1);const r=Vs(e),a=aT(e),o=rT(a);let s=a==="x"?r===(n?"end":"start")?"right":"left":r==="start"?"bottom":"top";return t.reference[o]>t.floating[o]&&(s=Sf(s)),[s,Sf(s)]}function mK(e){const t=Sf(e);return[D0(e),t,D0(t)]}function D0(e){return e.replace(/start|end/g,t=>gK[t])}function bK(e,t,n){const r=["left","right"],a=["right","left"],o=["top","bottom"],s=["bottom","top"];switch(e){case"top":case"bottom":return n?t?a:r:t?r:a;case"left":case"right":return t?o:s;default:return[]}}function yK(e,t,n,r){const a=Vs(e);let o=bK(Ga(e),n==="start",r);return a&&(o=o.map(s=>s+"-"+a),t&&(o=o.concat(o.map(D0)))),o}function Sf(e){return e.replace(/left|right|bottom|top/g,t=>pK[t])}function vK(e){return{top:0,right:0,bottom:0,left:0,...e}}function nU(e){return typeof e!="number"?vK(e):{top:e,right:e,bottom:e,left:e}}function Ef(e){const{x:t,y:n,width:r,height:a}=e;return{width:r,height:a,top:n,left:t,right:t+r,bottom:n+a,x:t,y:n}}function oN(e,t,n){let{reference:r,floating:a}=e;const o=Oo(t),s=aT(t),l=rT(s),u=Ga(t),d=o==="y",p=r.x+r.width/2-a.width/2,g=r.y+r.height/2-a.height/2,m=r[l]/2-a[l]/2;let b;switch(u){case"top":b={x:p,y:r.y-a.height};break;case"bottom":b={x:p,y:r.y+r.height};break;case"right":b={x:r.x+r.width,y:g};break;case"left":b={x:r.x-a.width,y:g};break;default:b={x:r.x,y:r.y}}switch(Vs(t)){case"start":b[s]-=m*(n&&d?-1:1);break;case"end":b[s]+=m*(n&&d?-1:1);break}return b}const SK=async(e,t,n)=>{const{placement:r="bottom",strategy:a="absolute",middleware:o=[],platform:s}=n,l=o.filter(Boolean),u=await(s.isRTL==null?void 0:s.isRTL(t));let d=await s.getElementRects({reference:e,floating:t,strategy:a}),{x:p,y:g}=oN(d,r,u),m=r,b={},v=0;for(let y=0;y<l.length;y++){const{name:k,fn:A}=l[y],{x,y:R,data:O,reset:N}=await A({x:p,y:g,initialPlacement:r,placement:m,strategy:a,middlewareData:b,rects:d,platform:s,elements:{reference:e,floating:t}});p=x??p,g=R??g,b={...b,[k]:{...b[k],...O}},N&&v<=50&&(v++,typeof N=="object"&&(N.placement&&(m=N.placement),N.rects&&(d=N.rects===!0?await s.getElementRects({reference:e,floating:t,strategy:a}):N.rects),{x:p,y:g}=oN(d,m,u)),y=-1)}return{x:p,y:g,placement:m,strategy:a,middlewareData:b}};async function xc(e,t){var n;t===void 0&&(t={});const{x:r,y:a,platform:o,rects:s,elements:l,strategy:u}=e,{boundary:d="clippingAncestors",rootBoundary:p="viewport",elementContext:g="floating",altBoundary:m=!1,padding:b=0}=Ua(t,e),v=nU(b),k=l[m?g==="floating"?"reference":"floating":g],A=Ef(await o.getClippingRect({element:(n=await(o.isElement==null?void 0:o.isElement(k)))==null||n?k:k.contextElement||await(o.getDocumentElement==null?void 0:o.getDocumentElement(l.floating)),boundary:d,rootBoundary:p,strategy:u})),x=g==="floating"?{x:r,y:a,width:s.floating.width,height:s.floating.height}:s.reference,R=await(o.getOffsetParent==null?void 0:o.getOffsetParent(l.floating)),O=await(o.isElement==null?void 0:o.isElement(R))?await(o.getScale==null?void 0:o.getScale(R))||{x:1,y:1}:{x:1,y:1},N=Ef(o.convertOffsetParentRelativeRectToViewportRelativeRect?await o.convertOffsetParentRelativeRectToViewportRelativeRect({elements:l,rect:x,offsetParent:R,strategy:u}):x);return{top:(A.top-N.top+v.top)/O.y,bottom:(N.bottom-A.bottom+v.bottom)/O.y,left:(A.left-N.left+v.left)/O.x,right:(N.right-A.right+v.right)/O.x}}const EK=e=>({name:"arrow",options:e,async fn(t){const{x:n,y:r,placement:a,rects:o,platform:s,elements:l,middlewareData:u}=t,{element:d,padding:p=0}=Ua(e,t)||{};if(d==null)return{};const g=nU(p),m={x:n,y:r},b=aT(a),v=rT(b),y=await s.getDimensions(d),k=b==="y",A=k?"top":"left",x=k?"bottom":"right",R=k?"clientHeight":"clientWidth",O=o.reference[v]+o.reference[b]-m[b]-o.floating[v],N=m[b]-o.reference[b],C=await(s.getOffsetParent==null?void 0:s.getOffsetParent(d));let _=C?C[R]:0;(!_||!await(s.isElement==null?void 0:s.isElement(C)))&&(_=l.floating[R]||o.floating[v]);const M=O/2-N/2,I=_/2-y[v]/2-1,D=No(g[A],I),U=No(g[x],I),$=D,B=_-y[v]-U,W=_/2-y[v]/2+M,K=I0($,W,B),H=!u.arrow&&Vs(a)!=null&&W!==K&&o.reference[v]/2-(W<$?D:U)-y[v]/2<0,G=H?W<$?W-$:W-B:0;return{[b]:m[b]+G,data:{[b]:K,centerOffset:W-K-G,...H&&{alignmentOffset:G}},reset:H}}}),wK=function(e){return e===void 0&&(e={}),{name:"flip",options:e,async fn(t){var n,r;const{placement:a,middlewareData:o,rects:s,initialPlacement:l,platform:u,elements:d}=t,{mainAxis:p=!0,crossAxis:g=!0,fallbackPlacements:m,fallbackStrategy:b="bestFit",fallbackAxisSideDirection:v="none",flipAlignment:y=!0,...k}=Ua(e,t);if((n=o.arrow)!=null&&n.alignmentOffset)return{};const A=Ga(a),x=Oo(l),R=Ga(l)===l,O=await(u.isRTL==null?void 0:u.isRTL(d.floating)),N=m||(R||!y?[Sf(l)]:mK(l)),C=v!=="none";!m&&C&&N.push(...yK(l,y,v,O));const _=[l,...N],M=await xc(t,k),I=[];let D=((r=o.flip)==null?void 0:r.overflows)||[];if(p&&I.push(M[A]),g){const W=hK(a,s,O);I.push(M[W[0]],M[W[1]])}if(D=[...D,{placement:a,overflows:I}],!I.every(W=>W<=0)){var U,$;const W=(((U=o.flip)==null?void 0:U.index)||0)+1,K=_[W];if(K)return{data:{index:W,overflows:D},reset:{placement:K}};let H=($=D.filter(G=>G.overflows[0]<=0).sort((G,z)=>G.overflows[1]-z.overflows[1])[0])==null?void 0:$.placement;if(!H)switch(b){case"bestFit":{var B;const G=(B=D.filter(z=>{if(C){const Y=Oo(z.placement);return Y===x||Y==="y"}return!0}).map(z=>[z.placement,z.overflows.filter(Y=>Y>0).reduce((Y,L)=>Y+L,0)]).sort((z,Y)=>z[1]-Y[1])[0])==null?void 0:B[0];G&&(H=G);break}case"initialPlacement":H=l;break}if(a!==H)return{reset:{placement:H}}}return{}}}};function iN(e,t){return{top:e.top-t.height,right:e.right-t.width,bottom:e.bottom-t.height,left:e.left-t.width}}function sN(e){return fK.some(t=>e[t]>=0)}const xK=function(e){return e===void 0&&(e={}),{name:"hide",options:e,async fn(t){const{rects:n}=t,{strategy:r="referenceHidden",...a}=Ua(e,t);switch(r){case"referenceHidden":{const o=await xc(t,{...a,elementContext:"reference"}),s=iN(o,n.reference);return{data:{referenceHiddenOffsets:s,referenceHidden:sN(s)}}}case"escaped":{const o=await xc(t,{...a,altBoundary:!0}),s=iN(o,n.floating);return{data:{escapedOffsets:s,escaped:sN(s)}}}default:return{}}}}};async function kK(e,t){const{placement:n,platform:r,elements:a}=e,o=await(r.isRTL==null?void 0:r.isRTL(a.floating)),s=Ga(n),l=Vs(n),u=Oo(n)==="y",d=["left","top"].includes(s)?-1:1,p=o&&u?-1:1,g=Ua(t,e);let{mainAxis:m,crossAxis:b,alignmentAxis:v}=typeof g=="number"?{mainAxis:g,crossAxis:0,alignmentAxis:null}:{mainAxis:g.mainAxis||0,crossAxis:g.crossAxis||0,alignmentAxis:g.alignmentAxis};return l&&typeof v=="number"&&(b=l==="end"?v*-1:v),u?{x:b*p,y:m*d}:{x:m*d,y:b*p}}const TK=function(e){return e===void 0&&(e=0),{name:"offset",options:e,async fn(t){var n,r;const{x:a,y:o,placement:s,middlewareData:l}=t,u=await kK(t,e);return s===((n=l.offset)==null?void 0:n.placement)&&(r=l.arrow)!=null&&r.alignmentOffset?{}:{x:a+u.x,y:o+u.y,data:{...u,placement:s}}}}},AK=function(e){return e===void 0&&(e={}),{name:"shift",options:e,async fn(t){const{x:n,y:r,placement:a}=t,{mainAxis:o=!0,crossAxis:s=!1,limiter:l={fn:k=>{let{x:A,y:x}=k;return{x:A,y:x}}},...u}=Ua(e,t),d={x:n,y:r},p=await xc(t,u),g=Oo(Ga(a)),m=nT(g);let b=d[m],v=d[g];if(o){const k=m==="y"?"top":"left",A=m==="y"?"bottom":"right",x=b+p[k],R=b-p[A];b=I0(x,b,R)}if(s){const k=g==="y"?"top":"left",A=g==="y"?"bottom":"right",x=v+p[k],R=v-p[A];v=I0(x,v,R)}const y=l.fn({...t,[m]:b,[g]:v});return{...y,data:{x:y.x-n,y:y.y-r,enabled:{[m]:o,[g]:s}}}}}},RK=function(e){return e===void 0&&(e={}),{options:e,fn(t){const{x:n,y:r,placement:a,rects:o,middlewareData:s}=t,{offset:l=0,mainAxis:u=!0,crossAxis:d=!0}=Ua(e,t),p={x:n,y:r},g=Oo(a),m=nT(g);let b=p[m],v=p[g];const y=Ua(l,t),k=typeof y=="number"?{mainAxis:y,crossAxis:0}:{mainAxis:0,crossAxis:0,...y};if(u){const R=m==="y"?"height":"width",O=o.reference[m]-o.floating[R]+k.mainAxis,N=o.reference[m]+o.reference[R]-k.mainAxis;b<O?b=O:b>N&&(b=N)}if(d){var A,x;const R=m==="y"?"width":"height",O=["top","left"].includes(Ga(a)),N=o.reference[g]-o.floating[R]+(O&&((A=s.offset)==null?void 0:A[g])||0)+(O?0:k.crossAxis),C=o.reference[g]+o.reference[R]+(O?0:((x=s.offset)==null?void 0:x[g])||0)-(O?k.crossAxis:0);v<N?v=N:v>C&&(v=C)}return{[m]:b,[g]:v}}}},CK=function(e){return e===void 0&&(e={}),{name:"size",options:e,async fn(t){var n,r;const{placement:a,rects:o,platform:s,elements:l}=t,{apply:u=()=>{},...d}=Ua(e,t),p=await xc(t,d),g=Ga(a),m=Vs(a),b=Oo(a)==="y",{width:v,height:y}=o.floating;let k,A;g==="top"||g==="bottom"?(k=g,A=m===(await(s.isRTL==null?void 0:s.isRTL(l.floating))?"start":"end")?"left":"right"):(A=g,k=m==="end"?"top":"bottom");const x=y-p.top-p.bottom,R=v-p.left-p.right,O=No(y-p[k],x),N=No(v-p[A],R),C=!t.middlewareData.shift;let _=O,M=N;if((n=t.middlewareData.shift)!=null&&n.enabled.x&&(M=R),(r=t.middlewareData.shift)!=null&&r.enabled.y&&(_=x),C&&!m){const D=tr(p.left,0),U=tr(p.right,0),$=tr(p.top,0),B=tr(p.bottom,0);b?M=v-2*(D!==0||U!==0?D+U:tr(p.left,p.right)):_=y-2*($!==0||B!==0?$+B:tr(p.top,p.bottom))}await u({...t,availableWidth:M,availableHeight:_});const I=await s.getDimensions(l.floating);return v!==I.width||y!==I.height?{reset:{rects:!0}}:{}}}};function ip(){return typeof window<"u"}function Ws(e){return rU(e)?(e.nodeName||"").toLowerCase():"#document"}function ar(e){var t;return(e==null||(t=e.ownerDocument)==null?void 0:t.defaultView)||window}function la(e){var t;return(t=(rU(e)?e.ownerDocument:e.document)||window.document)==null?void 0:t.documentElement}function rU(e){return ip()?e instanceof Node||e instanceof ar(e).Node:!1}function Ur(e){return ip()?e instanceof Element||e instanceof ar(e).Element:!1}function ia(e){return ip()?e instanceof HTMLElement||e instanceof ar(e).HTMLElement:!1}function lN(e){return!ip()||typeof ShadowRoot>"u"?!1:e instanceof ShadowRoot||e instanceof ar(e).ShadowRoot}function Vc(e){const{overflow:t,overflowX:n,overflowY:r,display:a}=Gr(e);return/auto|scroll|overlay|hidden|clip/.test(t+r+n)&&!["inline","contents"].includes(a)}function _K(e){return["table","td","th"].includes(Ws(e))}function sp(e){return[":popover-open",":modal"].some(t=>{try{return e.matches(t)}catch{return!1}})}function oT(e){const t=iT(),n=Ur(e)?Gr(e):e;return["transform","translate","scale","rotate","perspective"].some(r=>n[r]?n[r]!=="none":!1)||(n.containerType?n.containerType!=="normal":!1)||!t&&(n.backdropFilter?n.backdropFilter!=="none":!1)||!t&&(n.filter?n.filter!=="none":!1)||["transform","translate","scale","rotate","perspective","filter"].some(r=>(n.willChange||"").includes(r))||["paint","layout","strict","content"].some(r=>(n.contain||"").includes(r))}function NK(e){let t=Io(e);for(;ia(t)&&!Ds(t);){if(oT(t))return t;if(sp(t))return null;t=Io(t)}return null}function iT(){return typeof CSS>"u"||!CSS.supports?!1:CSS.supports("-webkit-backdrop-filter","none")}function Ds(e){return["html","body","#document"].includes(Ws(e))}function Gr(e){return ar(e).getComputedStyle(e)}function lp(e){return Ur(e)?{scrollLeft:e.scrollLeft,scrollTop:e.scrollTop}:{scrollLeft:e.scrollX,scrollTop:e.scrollY}}function Io(e){if(Ws(e)==="html")return e;const t=e.assignedSlot||e.parentNode||lN(e)&&e.host||la(e);return lN(t)?t.host:t}function aU(e){const t=Io(e);return Ds(t)?e.ownerDocument?e.ownerDocument.body:e.body:ia(t)&&Vc(t)?t:aU(t)}function kc(e,t,n){var r;t===void 0&&(t=[]),n===void 0&&(n=!0);const a=aU(e),o=a===((r=e.ownerDocument)==null?void 0:r.body),s=ar(a);if(o){const l=L0(s);return t.concat(s,s.visualViewport||[],Vc(a)?a:[],l&&n?kc(l):[])}return t.concat(a,kc(a,[],n))}function L0(e){return e.parent&&Object.getPrototypeOf(e.parent)?e.frameElement:null}function oU(e){const t=Gr(e);let n=parseFloat(t.width)||0,r=parseFloat(t.height)||0;const a=ia(e),o=a?e.offsetWidth:n,s=a?e.offsetHeight:r,l=vf(n)!==o||vf(r)!==s;return l&&(n=o,r=s),{width:n,height:r,$:l}}function sT(e){return Ur(e)?e:e.contextElement}function Cs(e){const t=sT(e);if(!ia(t))return oa(1);const n=t.getBoundingClientRect(),{width:r,height:a,$:o}=oU(t);let s=(o?vf(n.width):n.width)/r,l=(o?vf(n.height):n.height)/a;return(!s||!Number.isFinite(s))&&(s=1),(!l||!Number.isFinite(l))&&(l=1),{x:s,y:l}}const OK=oa(0);function iU(e){const t=ar(e);return!iT()||!t.visualViewport?OK:{x:t.visualViewport.offsetLeft,y:t.visualViewport.offsetTop}}function IK(e,t,n){return t===void 0&&(t=!1),!n||t&&n!==ar(e)?!1:t}function bi(e,t,n,r){t===void 0&&(t=!1),n===void 0&&(n=!1);const a=e.getBoundingClientRect(),o=sT(e);let s=oa(1);t&&(r?Ur(r)&&(s=Cs(r)):s=Cs(e));const l=IK(o,n,r)?iU(o):oa(0);let u=(a.left+l.x)/s.x,d=(a.top+l.y)/s.y,p=a.width/s.x,g=a.height/s.y;if(o){const m=ar(o),b=r&&Ur(r)?ar(r):r;let v=m,y=L0(v);for(;y&&r&&b!==v;){const k=Cs(y),A=y.getBoundingClientRect(),x=Gr(y),R=A.left+(y.clientLeft+parseFloat(x.paddingLeft))*k.x,O=A.top+(y.clientTop+parseFloat(x.paddingTop))*k.y;u*=k.x,d*=k.y,p*=k.x,g*=k.y,u+=R,d+=O,v=ar(y),y=L0(v)}}return Ef({width:p,height:g,x:u,y:d})}function lT(e,t){const n=lp(e).scrollLeft;return t?t.left+n:bi(la(e)).left+n}function sU(e,t,n){n===void 0&&(n=!1);const r=e.getBoundingClientRect(),a=r.left+t.scrollLeft-(n?0:lT(e,r)),o=r.top+t.scrollTop;return{x:a,y:o}}function DK(e){let{elements:t,rect:n,offsetParent:r,strategy:a}=e;const o=a==="fixed",s=la(r),l=t?sp(t.floating):!1;if(r===s||l&&o)return n;let u={scrollLeft:0,scrollTop:0},d=oa(1);const p=oa(0),g=ia(r);if((g||!g&&!o)&&((Ws(r)!=="body"||Vc(s))&&(u=lp(r)),ia(r))){const b=bi(r);d=Cs(r),p.x=b.x+r.clientLeft,p.y=b.y+r.clientTop}const m=s&&!g&&!o?sU(s,u,!0):oa(0);return{width:n.width*d.x,height:n.height*d.y,x:n.x*d.x-u.scrollLeft*d.x+p.x+m.x,y:n.y*d.y-u.scrollTop*d.y+p.y+m.y}}function LK(e){return Array.from(e.getClientRects())}function MK(e){const t=la(e),n=lp(e),r=e.ownerDocument.body,a=tr(t.scrollWidth,t.clientWidth,r.scrollWidth,r.clientWidth),o=tr(t.scrollHeight,t.clientHeight,r.scrollHeight,r.clientHeight);let s=-n.scrollLeft+lT(e);const l=-n.scrollTop;return Gr(r).direction==="rtl"&&(s+=tr(t.clientWidth,r.clientWidth)-a),{width:a,height:o,x:s,y:l}}function PK(e,t){const n=ar(e),r=la(e),a=n.visualViewport;let o=r.clientWidth,s=r.clientHeight,l=0,u=0;if(a){o=a.width,s=a.height;const d=iT();(!d||d&&t==="fixed")&&(l=a.offsetLeft,u=a.offsetTop)}return{width:o,height:s,x:l,y:u}}function FK(e,t){const n=bi(e,!0,t==="fixed"),r=n.top+e.clientTop,a=n.left+e.clientLeft,o=ia(e)?Cs(e):oa(1),s=e.clientWidth*o.x,l=e.clientHeight*o.y,u=a*o.x,d=r*o.y;return{width:s,height:l,x:u,y:d}}function cN(e,t,n){let r;if(t==="viewport")r=PK(e,n);else if(t==="document")r=MK(la(e));else if(Ur(t))r=FK(t,n);else{const a=iU(e);r={x:t.x-a.x,y:t.y-a.y,width:t.width,height:t.height}}return Ef(r)}function lU(e,t){const n=Io(e);return n===t||!Ur(n)||Ds(n)?!1:Gr(n).position==="fixed"||lU(n,t)}function zK(e,t){const n=t.get(e);if(n)return n;let r=kc(e,[],!1).filter(l=>Ur(l)&&Ws(l)!=="body"),a=null;const o=Gr(e).position==="fixed";let s=o?Io(e):e;for(;Ur(s)&&!Ds(s);){const l=Gr(s),u=oT(s);!u&&l.position==="fixed"&&(a=null),(o?!u&&!a:!u&&l.position==="static"&&!!a&&["absolute","fixed"].includes(a.position)||Vc(s)&&!u&&lU(e,s))?r=r.filter(p=>p!==s):a=l,s=Io(s)}return t.set(e,r),r}function BK(e){let{element:t,boundary:n,rootBoundary:r,strategy:a}=e;const s=[...n==="clippingAncestors"?sp(t)?[]:zK(t,this._c):[].concat(n),r],l=s[0],u=s.reduce((d,p)=>{const g=cN(t,p,a);return d.top=tr(g.top,d.top),d.right=No(g.right,d.right),d.bottom=No(g.bottom,d.bottom),d.left=tr(g.left,d.left),d},cN(t,l,a));return{width:u.right-u.left,height:u.bottom-u.top,x:u.left,y:u.top}}function jK(e){const{width:t,height:n}=oU(e);return{width:t,height:n}}function UK(e,t,n){const r=ia(t),a=la(t),o=n==="fixed",s=bi(e,!0,o,t);let l={scrollLeft:0,scrollTop:0};const u=oa(0);if(r||!r&&!o)if((Ws(t)!=="body"||Vc(a))&&(l=lp(t)),r){const m=bi(t,!0,o,t);u.x=m.x+t.clientLeft,u.y=m.y+t.clientTop}else a&&(u.x=lT(a));const d=a&&!r&&!o?sU(a,l):oa(0),p=s.left+l.scrollLeft-u.x-d.x,g=s.top+l.scrollTop-u.y-d.y;return{x:p,y:g,width:s.width,height:s.height}}function pm(e){return Gr(e).position==="static"}function uN(e,t){if(!ia(e)||Gr(e).position==="fixed")return null;if(t)return t(e);let n=e.offsetParent;return la(e)===n&&(n=n.ownerDocument.body),n}function cU(e,t){const n=ar(e);if(sp(e))return n;if(!ia(e)){let a=Io(e);for(;a&&!Ds(a);){if(Ur(a)&&!pm(a))return a;a=Io(a)}return n}let r=uN(e,t);for(;r&&_K(r)&&pm(r);)r=uN(r,t);return r&&Ds(r)&&pm(r)&&!oT(r)?n:r||NK(e)||n}const GK=async function(e){const t=this.getOffsetParent||cU,n=this.getDimensions,r=await n(e.floating);return{reference:UK(e.reference,await t(e.floating),e.strategy),floating:{x:0,y:0,width:r.width,height:r.height}}};function HK(e){return Gr(e).direction==="rtl"}const $K={convertOffsetParentRelativeRectToViewportRelativeRect:DK,getDocumentElement:la,getClippingRect:BK,getOffsetParent:cU,getElementRects:GK,getClientRects:LK,getDimensions:jK,getScale:Cs,isElement:Ur,isRTL:HK};function uU(e,t){return e.x===t.x&&e.y===t.y&&e.width===t.width&&e.height===t.height}function qK(e,t){let n=null,r;const a=la(e);function o(){var l;clearTimeout(r),(l=n)==null||l.disconnect(),n=null}function s(l,u){l===void 0&&(l=!1),u===void 0&&(u=1),o();const d=e.getBoundingClientRect(),{left:p,top:g,width:m,height:b}=d;if(l||t(),!m||!b)return;const v=Ad(g),y=Ad(a.clientWidth-(p+m)),k=Ad(a.clientHeight-(g+b)),A=Ad(p),R={rootMargin:-v+"px "+-y+"px "+-k+"px "+-A+"px",threshold:tr(0,No(1,u))||1};let O=!0;function N(C){const _=C[0].intersectionRatio;if(_!==u){if(!O)return s();_?s(!1,_):r=setTimeout(()=>{s(!1,1e-7)},1e3)}_===1&&!uU(d,e.getBoundingClientRect())&&s(),O=!1}try{n=new IntersectionObserver(N,{...R,root:a.ownerDocument})}catch{n=new IntersectionObserver(N,R)}n.observe(e)}return s(!0),o}function VK(e,t,n,r){r===void 0&&(r={});const{ancestorScroll:a=!0,ancestorResize:o=!0,elementResize:s=typeof ResizeObserver=="function",layoutShift:l=typeof IntersectionObserver=="function",animationFrame:u=!1}=r,d=sT(e),p=a||o?[...d?kc(d):[],...kc(t)]:[];p.forEach(A=>{a&&A.addEventListener("scroll",n,{passive:!0}),o&&A.addEventListener("resize",n)});const g=d&&l?qK(d,n):null;let m=-1,b=null;s&&(b=new ResizeObserver(A=>{let[x]=A;x&&x.target===d&&b&&(b.unobserve(t),cancelAnimationFrame(m),m=requestAnimationFrame(()=>{var R;(R=b)==null||R.observe(t)})),n()}),d&&!u&&b.observe(d),b.observe(t));let v,y=u?bi(e):null;u&&k();function k(){const A=bi(e);y&&!uU(y,A)&&n(),y=A,v=requestAnimationFrame(k)}return n(),()=>{var A;p.forEach(x=>{a&&x.removeEventListener("scroll",n),o&&x.removeEventListener("resize",n)}),g==null||g(),(A=b)==null||A.disconnect(),b=null,u&&cancelAnimationFrame(v)}}const WK=TK,YK=AK,KK=wK,XK=CK,ZK=xK,dN=EK,QK=RK,JK=(e,t,n)=>{const r=new Map,a={platform:$K,...n},o={...a.platform,_c:r};return SK(e,t,{...a,platform:o})};var tf=typeof document<"u"?w.useLayoutEffect:w.useEffect;function wf(e,t){if(e===t)return!0;if(typeof e!=typeof t)return!1;if(typeof e=="function"&&e.toString()===t.toString())return!0;let n,r,a;if(e&&t&&typeof e=="object"){if(Array.isArray(e)){if(n=e.length,n!==t.length)return!1;for(r=n;r--!==0;)if(!wf(e[r],t[r]))return!1;return!0}if(a=Object.keys(e),n=a.length,n!==Object.keys(t).length)return!1;for(r=n;r--!==0;)if(!{}.hasOwnProperty.call(t,a[r]))return!1;for(r=n;r--!==0;){const o=a[r];if(!(o==="_owner"&&e.$$typeof)&&!wf(e[o],t[o]))return!1}return!0}return e!==e&&t!==t}function dU(e){return typeof window>"u"?1:(e.ownerDocument.defaultView||window).devicePixelRatio||1}function fN(e,t){const n=dU(e);return Math.round(t*n)/n}function gm(e){const t=w.useRef(e);return tf(()=>{t.current=e}),t}function eX(e){e===void 0&&(e={});const{placement:t="bottom",strategy:n="absolute",middleware:r=[],platform:a,elements:{reference:o,floating:s}={},transform:l=!0,whileElementsMounted:u,open:d}=e,[p,g]=w.useState({x:0,y:0,strategy:n,placement:t,middlewareData:{},isPositioned:!1}),[m,b]=w.useState(r);wf(m,r)||b(r);const[v,y]=w.useState(null),[k,A]=w.useState(null),x=w.useCallback(z=>{z!==C.current&&(C.current=z,y(z))},[]),R=w.useCallback(z=>{z!==_.current&&(_.current=z,A(z))},[]),O=o||v,N=s||k,C=w.useRef(null),_=w.useRef(null),M=w.useRef(p),I=u!=null,D=gm(u),U=gm(a),$=gm(d),B=w.useCallback(()=>{if(!C.current||!_.current)return;const z={placement:t,strategy:n,middleware:m};U.current&&(z.platform=U.current),JK(C.current,_.current,z).then(Y=>{const L={...Y,isPositioned:$.current!==!1};W.current&&!wf(M.current,L)&&(M.current=L,Gc.flushSync(()=>{g(L)}))})},[m,t,n,U,$]);tf(()=>{d===!1&&M.current.isPositioned&&(M.current.isPositioned=!1,g(z=>({...z,isPositioned:!1})))},[d]);const W=w.useRef(!1);tf(()=>(W.current=!0,()=>{W.current=!1}),[]),tf(()=>{if(O&&(C.current=O),N&&(_.current=N),O&&N){if(D.current)return D.current(O,N,B);B()}},[O,N,B,D,I]);const K=w.useMemo(()=>({reference:C,floating:_,setReference:x,setFloating:R}),[x,R]),H=w.useMemo(()=>({reference:O,floating:N}),[O,N]),G=w.useMemo(()=>{const z={position:n,left:0,top:0};if(!H.floating)return z;const Y=fN(H.floating,p.x),L=fN(H.floating,p.y);return l?{...z,transform:"translate("+Y+"px, "+L+"px)",...dU(H.floating)>=1.5&&{willChange:"transform"}}:{position:n,left:Y,top:L}},[n,l,H.floating,p.x,p.y]);return w.useMemo(()=>({...p,update:B,refs:K,elements:H,floatingStyles:G}),[p,B,K,H,G])}const tX=e=>{function t(n){return{}.hasOwnProperty.call(n,"current")}return{name:"arrow",options:e,fn(n){const{element:r,padding:a}=typeof e=="function"?e(n):e;return r&&t(r)?r.current!=null?dN({element:r.current,padding:a}).fn(n):{}:r?dN({element:r,padding:a}).fn(n):{}}}},nX=(e,t)=>({...WK(e),options:[e,t]}),rX=(e,t)=>({...YK(e),options:[e,t]}),aX=(e,t)=>({...QK(e),options:[e,t]}),oX=(e,t)=>({...KK(e),options:[e,t]}),iX=(e,t)=>({...XK(e),options:[e,t]}),sX=(e,t)=>({...ZK(e),options:[e,t]}),lX=(e,t)=>({...tX(e),options:[e,t]});var cX="Arrow",fU=w.forwardRef((e,t)=>{const{children:n,width:r=10,height:a=5,...o}=e;return E.jsx(Je.svg,{...o,ref:t,width:r,height:a,viewBox:"0 0 30 10",preserveAspectRatio:"none",children:e.asChild?n:E.jsx("polygon",{points:"0,0 30,0 15,10"})})});fU.displayName=cX;var uX=fU;function pU(e){const[t,n]=w.useState(void 0);return Rn(()=>{if(e){n({width:e.offsetWidth,height:e.offsetHeight});const r=new ResizeObserver(a=>{if(!Array.isArray(a)||!a.length)return;const o=a[0];let s,l;if("borderBoxSize"in o){const u=o.borderBoxSize,d=Array.isArray(u)?u[0]:u;s=d.inlineSize,l=d.blockSize}else s=e.offsetWidth,l=e.offsetHeight;n({width:s,height:l})});return r.observe(e,{box:"border-box"}),()=>r.unobserve(e)}else n(void 0)},[e]),t}var cT="Popper",[gU,Ys]=$r(cT),[dX,hU]=gU(cT),mU=e=>{const{__scopePopper:t,children:n}=e,[r,a]=w.useState(null);return E.jsx(dX,{scope:t,anchor:r,onAnchorChange:a,children:n})};mU.displayName=cT;var bU="PopperAnchor",yU=w.forwardRef((e,t)=>{const{__scopePopper:n,virtualRef:r,...a}=e,o=hU(bU,n),s=w.useRef(null),l=mt(t,s);return w.useEffect(()=>{o.onAnchorChange((r==null?void 0:r.current)||s.current)}),r?null:E.jsx(Je.div,{...a,ref:l})});yU.displayName=bU;var uT="PopperContent",[fX,pX]=gU(uT),vU=w.forwardRef((e,t)=>{var ae,ce,Re,ie,Te,ne;const{__scopePopper:n,side:r="bottom",sideOffset:a=0,align:o="center",alignOffset:s=0,arrowPadding:l=0,avoidCollisions:u=!0,collisionBoundary:d=[],collisionPadding:p=0,sticky:g="partial",hideWhenDetached:m=!1,updatePositionStrategy:b="optimized",onPlaced:v,...y}=e,k=hU(uT,n),[A,x]=w.useState(null),R=mt(t,xe=>x(xe)),[O,N]=w.useState(null),C=pU(O),_=(C==null?void 0:C.width)??0,M=(C==null?void 0:C.height)??0,I=r+(o!=="center"?"-"+o:""),D=typeof p=="number"?p:{top:0,right:0,bottom:0,left:0,...p},U=Array.isArray(d)?d:[d],$=U.length>0,B={padding:D,boundary:U.filter(hX),altBoundary:$},{refs:W,floatingStyles:K,placement:H,isPositioned:G,middlewareData:z}=eX({strategy:"fixed",placement:I,whileElementsMounted:(...xe)=>VK(...xe,{animationFrame:b==="always"}),elements:{reference:k.anchor},middleware:[nX({mainAxis:a+M,alignmentAxis:s}),u&&rX({mainAxis:!0,crossAxis:!1,limiter:g==="partial"?aX():void 0,...B}),u&&oX({...B}),iX({...B,apply:({elements:xe,rects:Se,availableWidth:be,availableHeight:J})=>{const{width:pe,height:ke}=Se.reference,he=xe.floating.style;he.setProperty("--radix-popper-available-width",`${be}px`),he.setProperty("--radix-popper-available-height",`${J}px`),he.setProperty("--radix-popper-anchor-width",`${pe}px`),he.setProperty("--radix-popper-anchor-height",`${ke}px`)}}),O&&lX({element:O,padding:l}),mX({arrowWidth:_,arrowHeight:M}),m&&sX({strategy:"referenceHidden",...B})]}),[Y,L]=wU(H),V=yn(v);Rn(()=>{G&&(V==null||V())},[G,V]);const j=(ae=z.arrow)==null?void 0:ae.x,P=(ce=z.arrow)==null?void 0:ce.y,Z=((Re=z.arrow)==null?void 0:Re.centerOffset)!==0,[Q,oe]=w.useState();return Rn(()=>{A&&oe(window.getComputedStyle(A).zIndex)},[A]),E.jsx("div",{ref:W.setFloating,"data-radix-popper-content-wrapper":"",style:{...K,transform:G?K.transform:"translate(0, -200%)",minWidth:"max-content",zIndex:Q,"--radix-popper-transform-origin":[(ie=z.transformOrigin)==null?void 0:ie.x,(Te=z.transformOrigin)==null?void 0:Te.y].join(" "),...((ne=z.hide)==null?void 0:ne.referenceHidden)&&{visibility:"hidden",pointerEvents:"none"}},dir:e.dir,children:E.jsx(fX,{scope:n,placedSide:Y,onArrowChange:N,arrowX:j,arrowY:P,shouldHideArrow:Z,children:E.jsx(Je.div,{"data-side":Y,"data-align":L,...y,ref:R,style:{...y.style,animation:G?void 0:"none"}})})})});vU.displayName=uT;var SU="PopperArrow",gX={top:"bottom",right:"left",bottom:"top",left:"right"},EU=w.forwardRef(function(t,n){const{__scopePopper:r,...a}=t,o=pX(SU,r),s=gX[o.placedSide];return E.jsx("span",{ref:o.onArrowChange,style:{position:"absolute",left:o.arrowX,top:o.arrowY,[s]:0,transformOrigin:{top:"",right:"0 0",bottom:"center 0",left:"100% 0"}[o.placedSide],transform:{top:"translateY(100%)",right:"translateY(50%) rotate(90deg) translateX(-50%)",bottom:"rotate(180deg)",left:"translateY(50%) rotate(-90deg) translateX(50%)"}[o.placedSide],visibility:o.shouldHideArrow?"hidden":void 0},children:E.jsx(uX,{...a,ref:n,style:{...a.style,display:"block"}})})});EU.displayName=SU;function hX(e){return e!==null}var mX=e=>({name:"transformOrigin",options:e,fn(t){var k,A,x;const{placement:n,rects:r,middlewareData:a}=t,s=((k=a.arrow)==null?void 0:k.centerOffset)!==0,l=s?0:e.arrowWidth,u=s?0:e.arrowHeight,[d,p]=wU(n),g={start:"0%",center:"50%",end:"100%"}[p],m=(((A=a.arrow)==null?void 0:A.x)??0)+l/2,b=(((x=a.arrow)==null?void 0:x.y)??0)+u/2;let v="",y="";return d==="bottom"?(v=s?g:`${m}px`,y=`${-u}px`):d==="top"?(v=s?g:`${m}px`,y=`${r.floating.height+u}px`):d==="right"?(v=`${-u}px`,y=s?g:`${b}px`):d==="left"&&(v=`${r.floating.width+u}px`,y=s?g:`${b}px`),{data:{x:v,y}}}});function wU(e){const[t,n="center"]=e.split("-");return[t,n]}var dT=mU,cp=yU,fT=vU,pT=EU,bX="VisuallyHidden",gT=w.forwardRef((e,t)=>E.jsx(Je.span,{...e,ref:t,style:{position:"absolute",border:0,width:1,height:1,padding:0,margin:-1,overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",wordWrap:"normal",...e.style}}));gT.displayName=bX;var yX=gT,[up,d0e]=$r("Tooltip",[Ys]),dp=Ys(),xU="TooltipProvider",vX=700,M0="tooltip.open",[SX,hT]=up(xU),kU=e=>{const{__scopeTooltip:t,delayDuration:n=vX,skipDelayDuration:r=300,disableHoverableContent:a=!1,children:o}=e,[s,l]=w.useState(!0),u=w.useRef(!1),d=w.useRef(0);return w.useEffect(()=>{const p=d.current;return()=>window.clearTimeout(p)},[]),E.jsx(SX,{scope:t,isOpenDelayed:s,delayDuration:n,onOpen:w.useCallback(()=>{window.clearTimeout(d.current),l(!1)},[]),onClose:w.useCallback(()=>{window.clearTimeout(d.current),d.current=window.setTimeout(()=>l(!0),r)},[r]),isPointerInTransitRef:u,onPointerInTransitChange:w.useCallback(p=>{u.current=p},[]),disableHoverableContent:a,children:o})};kU.displayName=xU;var fp="Tooltip",[EX,pp]=up(fp),TU=e=>{const{__scopeTooltip:t,children:n,open:r,defaultOpen:a=!1,onOpenChange:o,disableHoverableContent:s,delayDuration:l}=e,u=hT(fp,e.__scopeTooltip),d=dp(t),[p,g]=w.useState(null),m=An(),b=w.useRef(0),v=s??u.disableHoverableContent,y=l??u.delayDuration,k=w.useRef(!1),[A=!1,x]=ja({prop:r,defaultProp:a,onChange:_=>{_?(u.onOpen(),document.dispatchEvent(new CustomEvent(M0))):u.onClose(),o==null||o(_)}}),R=w.useMemo(()=>A?k.current?"delayed-open":"instant-open":"closed",[A]),O=w.useCallback(()=>{window.clearTimeout(b.current),b.current=0,k.current=!1,x(!0)},[x]),N=w.useCallback(()=>{window.clearTimeout(b.current),b.current=0,x(!1)},[x]),C=w.useCallback(()=>{window.clearTimeout(b.current),b.current=window.setTimeout(()=>{k.current=!0,x(!0),b.current=0},y)},[y,x]);return w.useEffect(()=>()=>{b.current&&(window.clearTimeout(b.current),b.current=0)},[]),E.jsx(dT,{...d,children:E.jsx(EX,{scope:t,contentId:m,open:A,stateAttribute:R,trigger:p,onTriggerChange:g,onTriggerEnter:w.useCallback(()=>{u.isOpenDelayed?C():O()},[u.isOpenDelayed,C,O]),onTriggerLeave:w.useCallback(()=>{v?N():(window.clearTimeout(b.current),b.current=0)},[N,v]),onOpen:O,onClose:N,disableHoverableContent:v,children:n})})};TU.displayName=fp;var P0="TooltipTrigger",AU=w.forwardRef((e,t)=>{const{__scopeTooltip:n,...r}=e,a=pp(P0,n),o=hT(P0,n),s=dp(n),l=w.useRef(null),u=mt(t,l,a.onTriggerChange),d=w.useRef(!1),p=w.useRef(!1),g=w.useCallback(()=>d.current=!1,[]);return w.useEffect(()=>()=>document.removeEventListener("pointerup",g),[g]),E.jsx(cp,{asChild:!0,...s,children:E.jsx(Je.button,{"aria-describedby":a.open?a.contentId:void 0,"data-state":a.stateAttribute,...r,ref:u,onPointerMove:Ke(e.onPointerMove,m=>{m.pointerType!=="touch"&&!p.current&&!o.isPointerInTransitRef.current&&(a.onTriggerEnter(),p.current=!0)}),onPointerLeave:Ke(e.onPointerLeave,()=>{a.onTriggerLeave(),p.current=!1}),onPointerDown:Ke(e.onPointerDown,()=>{d.current=!0,document.addEventListener("pointerup",g,{once:!0})}),onFocus:Ke(e.onFocus,()=>{d.current||a.onOpen()}),onBlur:Ke(e.onBlur,a.onClose),onClick:Ke(e.onClick,a.onClose)})})});AU.displayName=P0;var wX="TooltipPortal",[f0e,xX]=up(wX,{forceMount:void 0}),Ls="TooltipContent",RU=w.forwardRef((e,t)=>{const n=xX(Ls,e.__scopeTooltip),{forceMount:r=n.forceMount,side:a="top",...o}=e,s=pp(Ls,e.__scopeTooltip);return E.jsx(Tr,{present:r||s.open,children:s.disableHoverableContent?E.jsx(CU,{side:a,...o,ref:t}):E.jsx(kX,{side:a,...o,ref:t})})}),kX=w.forwardRef((e,t)=>{const n=pp(Ls,e.__scopeTooltip),r=hT(Ls,e.__scopeTooltip),a=w.useRef(null),o=mt(t,a),[s,l]=w.useState(null),{trigger:u,onClose:d}=n,p=a.current,{onPointerInTransitChange:g}=r,m=w.useCallback(()=>{l(null),g(!1)},[g]),b=w.useCallback((v,y)=>{const k=v.currentTarget,A={x:v.clientX,y:v.clientY},x=CX(A,k.getBoundingClientRect()),R=_X(A,x),O=NX(y.getBoundingClientRect()),N=IX([...R,...O]);l(N),g(!0)},[g]);return w.useEffect(()=>()=>m(),[m]),w.useEffect(()=>{if(u&&p){const v=k=>b(k,p),y=k=>b(k,u);return u.addEventListener("pointerleave",v),p.addEventListener("pointerleave",y),()=>{u.removeEventListener("pointerleave",v),p.removeEventListener("pointerleave",y)}}},[u,p,b,m]),w.useEffect(()=>{if(s){const v=y=>{const k=y.target,A={x:y.clientX,y:y.clientY},x=(u==null?void 0:u.contains(k))||(p==null?void 0:p.contains(k)),R=!OX(A,s);x?m():R&&(m(),d())};return document.addEventListener("pointermove",v),()=>document.removeEventListener("pointermove",v)}},[u,p,s,d,m]),E.jsx(CU,{...e,ref:o})}),[TX,AX]=up(fp,{isInside:!1}),CU=w.forwardRef((e,t)=>{const{__scopeTooltip:n,children:r,"aria-label":a,onEscapeKeyDown:o,onPointerDownOutside:s,...l}=e,u=pp(Ls,n),d=dp(n),{onClose:p}=u;return w.useEffect(()=>(document.addEventListener(M0,p),()=>document.removeEventListener(M0,p)),[p]),w.useEffect(()=>{if(u.trigger){const g=m=>{const b=m.target;b!=null&&b.contains(u.trigger)&&p()};return window.addEventListener("scroll",g,{capture:!0}),()=>window.removeEventListener("scroll",g,{capture:!0})}},[u.trigger,p]),E.jsx(qc,{asChild:!0,disableOutsidePointerEvents:!1,onEscapeKeyDown:o,onPointerDownOutside:s,onFocusOutside:g=>g.preventDefault(),onDismiss:p,children:E.jsxs(fT,{"data-state":u.stateAttribute,...d,...l,ref:t,style:{...l.style,"--radix-tooltip-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-tooltip-content-available-width":"var(--radix-popper-available-width)","--radix-tooltip-content-available-height":"var(--radix-popper-available-height)","--radix-tooltip-trigger-width":"var(--radix-popper-anchor-width)","--radix-tooltip-trigger-height":"var(--radix-popper-anchor-height)"},children:[E.jsx(Hk,{children:r}),E.jsx(TX,{scope:n,isInside:!0,children:E.jsx(yX,{id:u.contentId,role:"tooltip",children:a||r})})]})})});RU.displayName=Ls;var _U="TooltipArrow",RX=w.forwardRef((e,t)=>{const{__scopeTooltip:n,...r}=e,a=dp(n);return AX(_U,n).isInside?null:E.jsx(pT,{...a,...r,ref:t})});RX.displayName=_U;function CX(e,t){const n=Math.abs(t.top-e.y),r=Math.abs(t.bottom-e.y),a=Math.abs(t.right-e.x),o=Math.abs(t.left-e.x);switch(Math.min(n,r,a,o)){case o:return"left";case a:return"right";case n:return"top";case r:return"bottom";default:throw new Error("unreachable")}}function _X(e,t,n=5){const r=[];switch(t){case"top":r.push({x:e.x-n,y:e.y+n},{x:e.x+n,y:e.y+n});break;case"bottom":r.push({x:e.x-n,y:e.y-n},{x:e.x+n,y:e.y-n});break;case"left":r.push({x:e.x+n,y:e.y-n},{x:e.x+n,y:e.y+n});break;case"right":r.push({x:e.x-n,y:e.y-n},{x:e.x-n,y:e.y+n});break}return r}function NX(e){const{top:t,right:n,bottom:r,left:a}=e;return[{x:a,y:t},{x:n,y:t},{x:n,y:r},{x:a,y:r}]}function OX(e,t){const{x:n,y:r}=e;let a=!1;for(let o=0,s=t.length-1;o<t.length;s=o++){const l=t[o].x,u=t[o].y,d=t[s].x,p=t[s].y;u>r!=p>r&&n<(d-l)*(r-u)/(p-u)+l&&(a=!a)}return a}function IX(e){const t=e.slice();return t.sort((n,r)=>n.x<r.x?-1:n.x>r.x?1:n.y<r.y?-1:n.y>r.y?1:0),DX(t)}function DX(e){if(e.length<=1)return e.slice();const t=[];for(let r=0;r<e.length;r++){const a=e[r];for(;t.length>=2;){const o=t[t.length-1],s=t[t.length-2];if((o.x-s.x)*(a.y-s.y)>=(o.y-s.y)*(a.x-s.x))t.pop();else break}t.push(a)}t.pop();const n=[];for(let r=e.length-1;r>=0;r--){const a=e[r];for(;n.length>=2;){const o=n[n.length-1],s=n[n.length-2];if((o.x-s.x)*(a.y-s.y)>=(o.y-s.y)*(a.x-s.x))n.pop();else break}n.push(a)}return n.pop(),t.length===1&&n.length===1&&t[0].x===n[0].x&&t[0].y===n[0].y?t:t.concat(n)}var LX=kU,MX=TU,PX=AU,NU=RU;const mT=LX,bT=MX,yT=PX,FX=e=>typeof e!="string"?e:E.jsx("div",{className:"relative top-0 pt-1 whitespace-pre-wrap break-words",children:e}),gp=w.forwardRef(({className:e,side:t="left",align:n="start",children:r,...a},o)=>{const s=w.useRef(null);return w.useEffect(()=>{s.current&&(s.current.scrollTop=0)},[r]),E.jsx(NU,{ref:o,side:t,align:n,className:Me("bg-popover text-popover-foreground animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 max-h-[60vh] overflow-y-auto whitespace-pre-wrap break-words rounded-md border px-3 py-2 text-sm shadow-md z-60",e),...a,children:typeof r=="string"?FX(r):r})});gp.displayName=NU.displayName;const xf=dK("inline-flex items-center justify-center gap-2 whitespace-nowrap rounded-md text-sm font-medium ring-offset-background transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg]:size-4 [&_svg]:shrink-0",{variants:{variant:{default:"bg-primary text-primary-foreground hover:bg-primary/90",destructive:"bg-destructive text-destructive-foreground hover:bg-destructive/90",outline:"border border-input bg-background hover:bg-accent hover:text-accent-foreground",secondary:"bg-secondary text-secondary-foreground hover:bg-secondary/80",ghost:"hover:bg-accent hover:text-accent-foreground",link:"text-primary underline-offset-4 hover:underline"},size:{default:"h-10 px-4 py-2",sm:"h-9 rounded-md px-3",lg:"h-11 rounded-md px-8",icon:"size-8"}},defaultVariants:{variant:"default",size:"default"}}),nt=w.forwardRef(({className:e,variant:t,tooltip:n,size:r,side:a="right",asChild:o=!1,...s},l)=>{const u=o?_o:"button";return n?E.jsx(mT,{children:E.jsxs(bT,{children:[E.jsx(yT,{asChild:!0,children:E.jsx(u,{className:Me(xf({variant:t,size:r,className:e}),"cursor-pointer"),ref:l,...s})}),E.jsx(gp,{side:a,children:n})]})}):E.jsx(u,{className:Me(xf({variant:t,size:r,className:e}),"cursor-pointer"),ref:l,...s})});nt.displayName="Button";const zX=cK,BX=uK,OU=w.forwardRef(({className:e,...t},n)=>E.jsx(Xj,{className:Me("data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 z-50 bg-black/50",e),...t,ref:n}));OU.displayName=Xj.displayName;const IU=w.forwardRef(({className:e,...t},n)=>E.jsxs(BX,{children:[E.jsx(OU,{}),E.jsx(Zj,{ref:n,className:Me("bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-top-[48%] fixed top-[50%] left-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border p-6 shadow-lg duration-200 sm:rounded-lg",e),...t})]}));IU.displayName=Zj.displayName;const DU=({className:e,...t})=>E.jsx("div",{className:Me("flex flex-col space-y-2 text-center sm:text-left",e),...t});DU.displayName="AlertDialogHeader";const LU=w.forwardRef(({className:e,...t},n)=>E.jsx(eU,{ref:n,className:Me("text-lg font-semibold",e),...t}));LU.displayName=eU.displayName;const MU=w.forwardRef(({className:e,...t},n)=>E.jsx(tU,{ref:n,className:Me("text-muted-foreground text-sm",e),...t}));MU.displayName=tU.displayName;const jX=w.forwardRef(({className:e,...t},n)=>E.jsx(Qj,{ref:n,className:Me(xf(),e),...t}));jX.displayName=Qj.displayName;const UX=w.forwardRef(({className:e,...t},n)=>E.jsx(Jj,{ref:n,className:Me(xf({variant:"outline"}),"mt-2 sm:mt-0",e),...t}));UX.displayName=Jj.displayName;const kr=w.forwardRef(({className:e,type:t,...n},r)=>E.jsx("input",{type:t,className:Me("border-input file:text-foreground placeholder:text-muted-foreground focus-visible:ring-ring flex h-9 rounded-md border bg-transparent px-3 py-1 text-base shadow-sm transition-colors file:border-0 file:bg-transparent file:text-sm file:font-medium focus-visible:ring-1 focus-visible:outline-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm [&::-webkit-inner-spin-button]:opacity-50 [&::-webkit-outer-spin-button]:opacity-50",e),ref:r,...n}));kr.displayName="Input";const GX=({open:e,onOpenChange:t})=>{const{t:n}=Et(),r=De.use.apiKey(),[a,o]=w.useState(""),s=rr.use.message();w.useEffect(()=>{o(r||"")},[r,e]),w.useEffect(()=>{s&&(s.includes(XB)||s.includes(ZB))&&t(!0)},[s,t]);const l=w.useCallback(()=>{De.setState({apiKey:a||null}),t(!1)},[a,t]),u=w.useCallback(d=>{o(d.target.value)},[o]);return E.jsx(zX,{open:e,onOpenChange:t,children:E.jsxs(IU,{children:[E.jsxs(DU,{children:[E.jsx(LU,{children:n("apiKeyAlert.title")}),E.jsx(MU,{children:n("apiKeyAlert.description")})]}),E.jsxs("div",{className:"flex flex-col gap-4",children:[E.jsxs("form",{className:"flex gap-2",onSubmit:d=>d.preventDefault(),children:[E.jsx(kr,{type:"password",value:a,onChange:u,placeholder:n("apiKeyAlert.placeholder"),className:"max-h-full w-full min-w-0",autoComplete:"off"}),E.jsx(nt,{onClick:l,variant:"outline",size:"sm",children:n("apiKeyAlert.save")})]}),s&&E.jsx("div",{className:"text-sm text-red-500",children:s})]})]})})};/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const HX=e=>e.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase(),PU=(...e)=>e.filter((t,n,r)=>!!t&&t.trim()!==""&&r.indexOf(t)===n).join(" ").trim();/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var $X={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const qX=w.forwardRef(({color:e="currentColor",size:t=24,strokeWidth:n=2,absoluteStrokeWidth:r,className:a="",children:o,iconNode:s,...l},u)=>w.createElement("svg",{ref:u,...$X,width:t,height:t,stroke:e,strokeWidth:r?Number(n)*24/Number(t):n,className:PU("lucide",a),...l},[...s.map(([d,p])=>w.createElement(d,p)),...Array.isArray(o)?o:[o]]));/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const it=(e,t)=>{const n=w.forwardRef(({className:r,...a},o)=>w.createElement(qX,{ref:o,iconNode:t,className:PU(`lucide-${HX(e)}`,r),...a}));return n.displayName=`${e}`,n};/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const VX=[["path",{d:"M22 12h-2.48a2 2 0 0 0-1.93 1.46l-2.35 8.36a.25.25 0 0 1-.48 0L9.24 2.18a.25.25 0 0 0-.48 0l-2.35 8.36A2 2 0 0 1 4.49 12H2",key:"169zse"}]],WX=it("Activity",VX);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const YX=[["path",{d:"M17 12H7",key:"16if0g"}],["path",{d:"M19 18H5",key:"18s9l3"}],["path",{d:"M21 6H3",key:"1jwq7v"}]],KX=it("AlignCenter",YX);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const XX=[["path",{d:"M15 12H3",key:"6jk70r"}],["path",{d:"M17 18H3",key:"1amg6g"}],["path",{d:"M21 6H3",key:"1jwq7v"}]],ZX=it("AlignLeft",XX);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const QX=[["path",{d:"M21 12H9",key:"dn1m92"}],["path",{d:"M21 18H7",key:"1ygte8"}],["path",{d:"M21 6H3",key:"1jwq7v"}]],JX=it("AlignRight",QX);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const eZ=[["path",{d:"M12 5v14",key:"s699le"}],["path",{d:"m19 12-7 7-7-7",key:"1idqje"}]],hm=it("ArrowDown",eZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const tZ=[["path",{d:"m5 12 7-7 7 7",key:"hav0vg"}],["path",{d:"M12 19V5",key:"x0mq9r"}]],mm=it("ArrowUp",tZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nZ=[["path",{d:"M12 7v14",key:"1akyts"}],["path",{d:"M3 18a1 1 0 0 1-1-1V4a1 1 0 0 1 1-1h5a4 4 0 0 1 4 4 4 4 0 0 1 4-4h5a1 1 0 0 1 1 1v13a1 1 0 0 1-1 1h-6a3 3 0 0 0-3 3 3 3 0 0 0-3-3z",key:"ruj8y"}]],rZ=it("BookOpen",nZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const aZ=[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]],vT=it("Check",aZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const oZ=[["path",{d:"m6 9 6 6 6-6",key:"qrunsl"}]],ST=it("ChevronDown",oZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const iZ=[["path",{d:"m18 15-6-6-6 6",key:"153udz"}]],FU=it("ChevronUp",iZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const sZ=[["path",{d:"m7 15 5 5 5-5",key:"1hf1tw"}],["path",{d:"m7 9 5-5 5 5",key:"sgt6xg"}]],lZ=it("ChevronsUpDown",sZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const cZ=[["rect",{width:"14",height:"14",x:"8",y:"8",rx:"2",ry:"2",key:"17jyea"}],["path",{d:"M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2",key:"zix9uf"}]],uZ=it("Copy",cZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const dZ=[["path",{d:"m7 21-4.3-4.3c-1-1-1-2.5 0-3.4l9.6-9.6c1-1 2.5-1 3.4 0l5.6 5.6c1 1 1 2.5 0 3.4L13 21",key:"182aya"}],["path",{d:"M22 21H7",key:"t4ddhn"}],["path",{d:"m5 11 9 9",key:"1mo9qw"}]],zU=it("Eraser",dZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const fZ=[["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z",key:"1rqfz7"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}],["path",{d:"M10 9H8",key:"b1mrlr"}],["path",{d:"M16 13H8",key:"t4e002"}],["path",{d:"M16 17H8",key:"z1uh3a"}]],BU=it("FileText",fZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const pZ=[["path",{d:"M20 7h-3a2 2 0 0 1-2-2V2",key:"x099mo"}],["path",{d:"M9 18a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h7l4 4v10a2 2 0 0 1-2 2Z",key:"18t6ie"}],["path",{d:"M3 7.6v12.8A1.6 1.6 0 0 0 4.6 22h9.8",key:"1nja0z"}]],gZ=it("Files",pZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const hZ=[["polygon",{points:"22 3 2 3 10 12.46 10 19 14 21 14 12.46 22 3",key:"1yg77f"}]],mZ=it("Filter",hZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const bZ=[["path",{d:"M3 7V5a2 2 0 0 1 2-2h2",key:"aa7l1z"}],["path",{d:"M17 3h2a2 2 0 0 1 2 2v2",key:"4qcy5o"}],["path",{d:"M21 17v2a2 2 0 0 1-2 2h-2",key:"6vwrx8"}],["path",{d:"M7 21H5a2 2 0 0 1-2-2v-2",key:"ioqczr"}],["rect",{width:"10",height:"8",x:"7",y:"8",rx:"1",key:"vys8me"}]],yZ=it("Fullscreen",bZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const vZ=[["path",{d:"M6 3v12",key:"qpgusn"}],["path",{d:"M18 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6z",key:"1d02ji"}],["path",{d:"M6 21a3 3 0 1 0 0-6 3 3 0 0 0 0 6z",key:"chk6ph"}],["path",{d:"M15 6a9 9 0 0 0-9 9",key:"or332x"}],["path",{d:"M18 15v6",key:"9wciyi"}],["path",{d:"M21 18h-6",key:"139f0c"}]],SZ=it("GitBranchPlus",vZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const EZ=[["path",{d:"M15 22v-4a4.8 4.8 0 0 0-1-3.5c3 0 6-2 6-5.5.08-1.25-.27-2.48-1-3.5.28-1.15.28-2.35 0-3.5 0 0-1 0-3 1.5-2.64-.5-5.36-.5-8 0C6 2 5 2 5 2c-.3 1.15-.3 2.35 0 3.5A5.403 5.403 0 0 0 4 9c0 3.5 3 5.5 6 5.5-.39.49-.68 1.05-.85 1.65-.17.6-.22 1.23-.15 1.85v4",key:"tonef"}],["path",{d:"M9 18c-4.51 2-5-2-7-2",key:"9comsn"}]],wZ=it("Github",EZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const xZ=[["circle",{cx:"12",cy:"5",r:"1",key:"gxeob9"}],["circle",{cx:"19",cy:"5",r:"1",key:"w8mnmm"}],["circle",{cx:"5",cy:"5",r:"1",key:"lttvr7"}],["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}],["circle",{cx:"19",cy:"12",r:"1",key:"1wjl8i"}],["circle",{cx:"5",cy:"12",r:"1",key:"1pcz8c"}],["circle",{cx:"12",cy:"19",r:"1",key:"lyex9k"}],["circle",{cx:"19",cy:"19",r:"1",key:"shf9b7"}],["circle",{cx:"5",cy:"19",r:"1",key:"bfqh0e"}]],kZ=it("Grip",xZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const TZ=[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56",key:"13zald"}]],jU=it("LoaderCircle",TZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const AZ=[["path",{d:"M12 2v4",key:"3427ic"}],["path",{d:"m16.2 7.8 2.9-2.9",key:"r700ao"}],["path",{d:"M18 12h4",key:"wj9ykh"}],["path",{d:"m16.2 16.2 2.9 2.9",key:"1bxg5t"}],["path",{d:"M12 18v4",key:"jadmvz"}],["path",{d:"m4.9 19.1 2.9-2.9",key:"bwix9q"}],["path",{d:"M2 12h4",key:"j09sii"}],["path",{d:"m4.9 4.9 2.9 2.9",key:"giyufr"}]],RZ=it("Loader",AZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const CZ=[["path",{d:"M9 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4",key:"1uf3rs"}],["polyline",{points:"16 17 21 12 16 7",key:"1gabdz"}],["line",{x1:"21",x2:"9",y1:"12",y2:"12",key:"1uyos4"}]],_Z=it("LogOut",CZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const NZ=[["path",{d:"M8 3H5a2 2 0 0 0-2 2v3",key:"1dcmit"}],["path",{d:"M21 8V5a2 2 0 0 0-2-2h-3",key:"1e4gt3"}],["path",{d:"M3 16v3a2 2 0 0 0 2 2h3",key:"wsl5sc"}],["path",{d:"M16 21h3a2 2 0 0 0 2-2v-3",key:"18trek"}]],OZ=it("Maximize",NZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const IZ=[["path",{d:"M8 3v3a2 2 0 0 1-2 2H3",key:"hohbtr"}],["path",{d:"M21 8h-3a2 2 0 0 1-2-2V3",key:"5jw1f3"}],["path",{d:"M3 16h3a2 2 0 0 1 2 2v3",key:"198tvr"}],["path",{d:"M16 21v-3a2 2 0 0 1 2-2h3",key:"ph8mxp"}]],DZ=it("Minimize",IZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const LZ=[["circle",{cx:"13.5",cy:"6.5",r:".5",fill:"currentColor",key:"1okk4w"}],["circle",{cx:"17.5",cy:"10.5",r:".5",fill:"currentColor",key:"f64h9f"}],["circle",{cx:"8.5",cy:"7.5",r:".5",fill:"currentColor",key:"fotxhn"}],["circle",{cx:"6.5",cy:"12.5",r:".5",fill:"currentColor",key:"qy21gx"}],["path",{d:"M12 2C6.5 2 2 6.5 2 12s4.5 10 10 10c.926 0 1.648-.746 1.648-1.688 0-.437-.18-.835-.437-1.125-.29-.289-.438-.652-.438-1.125a1.64 1.64 0 0 1 1.668-1.668h1.996c3.051 0 5.555-2.503 5.555-5.554C21.965 6.012 17.461 2 12 2z",key:"12rzf8"}]],MZ=it("Palette",LZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const PZ=[["rect",{x:"14",y:"4",width:"4",height:"16",rx:"1",key:"zuxfzm"}],["rect",{x:"6",y:"4",width:"4",height:"16",rx:"1",key:"1okwgv"}]],FZ=it("Pause",PZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const zZ=[["polygon",{points:"6 3 20 12 6 21 6 3",key:"1oa8hb"}]],BZ=it("Play",zZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const jZ=[["path",{d:"M3 12a9 9 0 0 1 9-9 9.75 9.75 0 0 1 6.74 2.74L21 8",key:"v9h5vc"}],["path",{d:"M21 3v5h-5",key:"1q7to0"}],["path",{d:"M21 12a9 9 0 0 1-9 9 9.75 9.75 0 0 1-6.74-2.74L3 16",key:"3uifl3"}],["path",{d:"M8 16H3v5",key:"1cv678"}]],UU=it("RefreshCw",jZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const UZ=[["path",{d:"M3 12a9 9 0 1 0 9-9 9.75 9.75 0 0 0-6.74 2.74L3 8",key:"1357e3"}],["path",{d:"M3 3v5h5",key:"1xhq8a"}]],GZ=it("RotateCcw",UZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const HZ=[["path",{d:"M21 12a9 9 0 1 1-9-9c2.52 0 4.93 1 6.74 2.74L21 8",key:"1p45f6"}],["path",{d:"M21 3v5h-5",key:"1q7to0"}]],$Z=it("RotateCw",HZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const qZ=[["circle",{cx:"6",cy:"6",r:"3",key:"1lh9wr"}],["path",{d:"M8.12 8.12 12 12",key:"1alkpv"}],["path",{d:"M20 4 8.12 15.88",key:"xgtan2"}],["circle",{cx:"6",cy:"18",r:"3",key:"fqmcym"}],["path",{d:"M14.8 14.8 20 20",key:"ptml3r"}]],VZ=it("Scissors",qZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const WZ=[["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}],["path",{d:"m21 21-4.3-4.3",key:"1qie3q"}]],YZ=it("Search",WZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const KZ=[["path",{d:"M14.536 21.686a.5.5 0 0 0 .937-.024l6.5-19a.496.496 0 0 0-.635-.635l-19 6.5a.5.5 0 0 0-.024.937l7.93 3.18a2 2 0 0 1 1.112 1.11z",key:"1ffxy3"}],["path",{d:"m21.854 2.147-10.94 10.939",key:"12cjpa"}]],XZ=it("Send",KZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const ZZ=[["path",{d:"M12.22 2h-.44a2 2 0 0 0-2 2v.18a2 2 0 0 1-1 1.73l-.43.25a2 2 0 0 1-2 0l-.15-.08a2 2 0 0 0-2.73.73l-.22.38a2 2 0 0 0 .73 2.73l.15.1a2 2 0 0 1 1 1.72v.51a2 2 0 0 1-1 1.74l-.15.09a2 2 0 0 0-.73 2.73l.22.38a2 2 0 0 0 2.73.73l.15-.08a2 2 0 0 1 2 0l.43.25a2 2 0 0 1 1 1.73V20a2 2 0 0 0 2 2h.44a2 2 0 0 0 2-2v-.18a2 2 0 0 1 1-1.73l.43-.25a2 2 0 0 1 2 0l.15.08a2 2 0 0 0 2.73-.73l.22-.39a2 2 0 0 0-.73-2.73l-.15-.08a2 2 0 0 1-1-1.74v-.5a2 2 0 0 1 1-1.74l.15-.09a2 2 0 0 0 .73-2.73l-.22-.38a2 2 0 0 0-2.73-.73l-.15.08a2 2 0 0 1-2 0l-.43-.25a2 2 0 0 1-1-1.73V4a2 2 0 0 0-2-2z",key:"1qme2f"}],["circle",{cx:"12",cy:"12",r:"3",key:"1v7zrd"}]],QZ=it("Settings",ZZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const JZ=[["path",{d:"m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3",key:"wmoenq"}],["path",{d:"M12 9v4",key:"juzpu7"}],["path",{d:"M12 17h.01",key:"p32p05"}]],eQ=it("TriangleAlert",JZ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const tQ=[["path",{d:"M9 14 4 9l5-5",key:"102s5s"}],["path",{d:"M4 9h10.5a5.5 5.5 0 0 1 5.5 5.5a5.5 5.5 0 0 1-5.5 5.5H11",key:"f3b9sd"}]],GU=it("Undo2",tQ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const nQ=[["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["polyline",{points:"17 8 12 3 7 8",key:"t8dd8p"}],["line",{x1:"12",x2:"12",y1:"3",y2:"15",key:"widbto"}]],F0=it("Upload",nQ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const rQ=[["path",{d:"M18 6 6 18",key:"1bl5f8"}],["path",{d:"m6 6 12 12",key:"d8bk6v"}]],HU=it("X",rQ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const aQ=[["path",{d:"M4 14a1 1 0 0 1-.78-1.63l9.9-10.2a.5.5 0 0 1 .86.46l-1.92 6.02A1 1 0 0 0 13 10h7a1 1 0 0 1 .78 1.63l-9.9 10.2a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14z",key:"1xq2db"}]],ET=it("Zap",aQ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const oQ=[["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}],["line",{x1:"21",x2:"16.65",y1:"21",y2:"16.65",key:"13gj7c"}],["line",{x1:"11",x2:"11",y1:"8",y2:"14",key:"1vmskp"}],["line",{x1:"8",x2:"14",y1:"11",y2:"11",key:"durymu"}]],iQ=it("ZoomIn",oQ);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const sQ=[["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}],["line",{x1:"21",x2:"16.65",y1:"21",y2:"16.65",key:"13gj7c"}],["line",{x1:"8",x2:"14",y1:"11",y2:"11",key:"durymu"}]],lQ=it("ZoomOut",sQ),hp=Zk,$U=Fj,cQ=Qk,qU=w.forwardRef(({className:e,...t},n)=>E.jsx(ap,{ref:n,className:Me("data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 z-50 bg-black/30",e),...t}));qU.displayName=ap.displayName;const Wc=w.forwardRef(({className:e,children:t,...n},r)=>E.jsxs(cQ,{children:[E.jsx(qU,{}),E.jsxs(op,{ref:r,className:Me("bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-top-[48%] fixed top-[50%] left-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border p-6 shadow-lg duration-200 sm:rounded-lg",e),...n,children:[t,E.jsxs(tT,{className:"ring-offset-background focus:ring-ring data-[state=open]:bg-accent data-[state=open]:text-muted-foreground absolute top-4 right-4 rounded-sm opacity-70 transition-opacity hover:opacity-100 focus:ring-2 focus:ring-offset-2 focus:outline-none disabled:pointer-events-none",children:[E.jsx(HU,{className:"h-4 w-4"}),E.jsx("span",{className:"sr-only",children:"Close"})]})]})]}));Wc.displayName=op.displayName;const Yc=({className:e,...t})=>E.jsx("div",{className:Me("flex flex-col space-y-1.5 text-center sm:text-left",e),...t});Yc.displayName="DialogHeader";const VU=({className:e,...t})=>E.jsx("div",{className:Me("flex flex-col-reverse sm:flex-row sm:justify-end sm:space-x-2",e),...t});VU.displayName="DialogFooter";const Kc=w.forwardRef(({className:e,...t},n)=>E.jsx(Jk,{ref:n,className:Me("text-lg leading-none font-semibold tracking-tight",e),...t}));Kc.displayName=Jk.displayName;const Xc=w.forwardRef(({className:e,...t},n)=>E.jsx(eT,{ref:n,className:Me("text-muted-foreground text-sm",e),...t}));Xc.displayName=eT.displayName;const uQ=({status:e})=>{const{t}=Et();return e?E.jsxs("div",{className:"min-w-[300px] space-y-2 text-xs",children:[E.jsxs("div",{className:"space-y-1",children:[E.jsx("h4",{className:"font-medium",children:t("graphPanel.statusCard.storageInfo")}),E.jsxs("div",{className:"text-foreground grid grid-cols-[120px_1fr] gap-1",children:[E.jsxs("span",{children:[t("graphPanel.statusCard.workingDirectory"),":"]}),E.jsx("span",{className:"truncate",children:e.working_directory}),E.jsxs("span",{children:[t("graphPanel.statusCard.inputDirectory"),":"]}),E.jsx("span",{className:"truncate",children:e.input_directory})]})]}),E.jsxs("div",{className:"space-y-1",children:[E.jsx("h4",{className:"font-medium",children:t("graphPanel.statusCard.llmConfig")}),E.jsxs("div",{className:"text-foreground grid grid-cols-[120px_1fr] gap-1",children:[E.jsxs("span",{children:[t("graphPanel.statusCard.llmBinding"),":"]}),E.jsx("span",{children:e.configuration.llm_binding}),E.jsxs("span",{children:[t("graphPanel.statusCard.llmBindingHost"),":"]}),E.jsx("span",{children:e.configuration.llm_binding_host}),E.jsxs("span",{children:[t("graphPanel.statusCard.llmModel"),":"]}),E.jsx("span",{children:e.configuration.llm_model}),E.jsxs("span",{children:[t("graphPanel.statusCard.maxTokens"),":"]}),E.jsx("span",{children:e.configuration.max_tokens})]})]}),E.jsxs("div",{className:"space-y-1",children:[E.jsx("h4",{className:"font-medium",children:t("graphPanel.statusCard.embeddingConfig")}),E.jsxs("div",{className:"text-foreground grid grid-cols-[120px_1fr] gap-1",children:[E.jsxs("span",{children:[t("graphPanel.statusCard.embeddingBinding"),":"]}),E.jsx("span",{children:e.configuration.embedding_binding}),E.jsxs("span",{children:[t("graphPanel.statusCard.embeddingBindingHost"),":"]}),E.jsx("span",{children:e.configuration.embedding_binding_host}),E.jsxs("span",{children:[t("graphPanel.statusCard.embeddingModel"),":"]}),E.jsx("span",{children:e.configuration.embedding_model})]})]}),E.jsxs("div",{className:"space-y-1",children:[E.jsx("h4",{className:"font-medium",children:t("graphPanel.statusCard.storageConfig")}),E.jsxs("div",{className:"text-foreground grid grid-cols-[120px_1fr] gap-1",children:[E.jsxs("span",{children:[t("graphPanel.statusCard.kvStorage"),":"]}),E.jsx("span",{children:e.configuration.kv_storage}),E.jsxs("span",{children:[t("graphPanel.statusCard.docStatusStorage"),":"]}),E.jsx("span",{children:e.configuration.doc_status_storage}),E.jsxs("span",{children:[t("graphPanel.statusCard.graphStorage"),":"]}),E.jsx("span",{children:e.configuration.graph_storage}),E.jsxs("span",{children:[t("graphPanel.statusCard.vectorStorage"),":"]}),E.jsx("span",{children:e.configuration.vector_storage})]})]})]}):E.jsx("div",{className:"text-foreground text-xs",children:t("graphPanel.statusCard.unavailable")})},dQ=({open:e,onOpenChange:t,status:n})=>{const{t:r}=Et();return E.jsx(hp,{open:e,onOpenChange:t,children:E.jsxs(Wc,{className:"sm:max-w-[500px]",children:[E.jsxs(Yc,{children:[E.jsx(Kc,{children:r("graphPanel.statusDialog.title")}),E.jsx(Xc,{children:r("graphPanel.statusDialog.description")})]}),E.jsx(uQ,{status:n})]})})},fQ=()=>{const{t:e}=Et(),t=rr.use.health(),n=rr.use.lastCheckTime(),r=rr.use.status(),[a,o]=w.useState(!1),[s,l]=w.useState(!1);return w.useEffect(()=>{o(!0);const u=setTimeout(()=>o(!1),300);return()=>clearTimeout(u)},[n]),E.jsxs("div",{className:"fixed right-4 bottom-4 flex items-center gap-2 opacity-80 select-none",children:[E.jsxs("div",{className:"flex cursor-pointer items-center gap-2",onClick:()=>l(!0),children:[E.jsx("div",{className:Me("h-3 w-3 rounded-full transition-all duration-300","shadow-[0_0_8px_rgba(0,0,0,0.2)]",t?"bg-green-500":"bg-red-500",a&&"scale-125",a&&t&&"shadow-[0_0_12px_rgba(34,197,94,0.4)]",a&&!t&&"shadow-[0_0_12px_rgba(239,68,68,0.4)]")}),E.jsx("span",{className:"text-muted-foreground text-xs",children:e(t?"graphPanel.statusIndicator.connected":"graphPanel.statusIndicator.disconnected")})]}),E.jsx(dQ,{open:s,onOpenChange:l,status:r})]})};var wT="Popover",[WU,p0e]=$r(wT,[Ys]),Zc=Ys(),[pQ,Ai]=WU(wT),YU=e=>{const{__scopePopover:t,children:n,open:r,defaultOpen:a,onOpenChange:o,modal:s=!1}=e,l=Zc(t),u=w.useRef(null),[d,p]=w.useState(!1),[g=!1,m]=ja({prop:r,defaultProp:a,onChange:o});return E.jsx(dT,{...l,children:E.jsx(pQ,{scope:t,contentId:An(),triggerRef:u,open:g,onOpenChange:m,onOpenToggle:w.useCallback(()=>m(b=>!b),[m]),hasCustomAnchor:d,onCustomAnchorAdd:w.useCallback(()=>p(!0),[]),onCustomAnchorRemove:w.useCallback(()=>p(!1),[]),modal:s,children:n})})};YU.displayName=wT;var KU="PopoverAnchor",gQ=w.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=Ai(KU,n),o=Zc(n),{onCustomAnchorAdd:s,onCustomAnchorRemove:l}=a;return w.useEffect(()=>(s(),()=>l()),[s,l]),E.jsx(cp,{...o,...r,ref:t})});gQ.displayName=KU;var XU="PopoverTrigger",ZU=w.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=Ai(XU,n),o=Zc(n),s=mt(t,a.triggerRef),l=E.jsx(Je.button,{type:"button","aria-haspopup":"dialog","aria-expanded":a.open,"aria-controls":a.contentId,"data-state":t3(a.open),...r,ref:s,onClick:Ke(e.onClick,a.onOpenToggle)});return a.hasCustomAnchor?l:E.jsx(cp,{asChild:!0,...o,children:l})});ZU.displayName=XU;var hQ="PopoverPortal",[g0e,mQ]=WU(hQ,{forceMount:void 0}),Ms="PopoverContent",QU=w.forwardRef((e,t)=>{const n=mQ(Ms,e.__scopePopover),{forceMount:r=n.forceMount,...a}=e,o=Ai(Ms,e.__scopePopover);return E.jsx(Tr,{present:r||o.open,children:o.modal?E.jsx(bQ,{...a,ref:t}):E.jsx(yQ,{...a,ref:t})})});QU.displayName=Ms;var bQ=w.forwardRef((e,t)=>{const n=Ai(Ms,e.__scopePopover),r=w.useRef(null),a=mt(t,r),o=w.useRef(!1);return w.useEffect(()=>{const s=r.current;if(s)return Vk(s)},[]),E.jsx(rp,{as:_o,allowPinchZoom:!0,children:E.jsx(JU,{...e,ref:a,trapFocus:n.open,disableOutsidePointerEvents:!0,onCloseAutoFocus:Ke(e.onCloseAutoFocus,s=>{var l;s.preventDefault(),o.current||(l=n.triggerRef.current)==null||l.focus()}),onPointerDownOutside:Ke(e.onPointerDownOutside,s=>{const l=s.detail.originalEvent,u=l.button===0&&l.ctrlKey===!0,d=l.button===2||u;o.current=d},{checkForDefaultPrevented:!1}),onFocusOutside:Ke(e.onFocusOutside,s=>s.preventDefault(),{checkForDefaultPrevented:!1})})})}),yQ=w.forwardRef((e,t)=>{const n=Ai(Ms,e.__scopePopover),r=w.useRef(!1),a=w.useRef(!1);return E.jsx(JU,{...e,ref:t,trapFocus:!1,disableOutsidePointerEvents:!1,onCloseAutoFocus:o=>{var s,l;(s=e.onCloseAutoFocus)==null||s.call(e,o),o.defaultPrevented||(r.current||(l=n.triggerRef.current)==null||l.focus(),o.preventDefault()),r.current=!1,a.current=!1},onInteractOutside:o=>{var u,d;(u=e.onInteractOutside)==null||u.call(e,o),o.defaultPrevented||(r.current=!0,o.detail.originalEvent.type==="pointerdown"&&(a.current=!0));const s=o.target;((d=n.triggerRef.current)==null?void 0:d.contains(s))&&o.preventDefault(),o.detail.originalEvent.type==="focusin"&&a.current&&o.preventDefault()}})}),JU=w.forwardRef((e,t)=>{const{__scopePopover:n,trapFocus:r,onOpenAutoFocus:a,onCloseAutoFocus:o,disableOutsidePointerEvents:s,onEscapeKeyDown:l,onPointerDownOutside:u,onFocusOutside:d,onInteractOutside:p,...g}=e,m=Ai(Ms,n),b=Zc(n);return qk(),E.jsx(tp,{asChild:!0,loop:!0,trapped:r,onMountAutoFocus:a,onUnmountAutoFocus:o,children:E.jsx(qc,{asChild:!0,disableOutsidePointerEvents:s,onInteractOutside:p,onEscapeKeyDown:l,onPointerDownOutside:u,onFocusOutside:d,onDismiss:()=>m.onOpenChange(!1),children:E.jsx(fT,{"data-state":t3(m.open),role:"dialog",id:m.contentId,...b,...g,ref:t,style:{...g.style,"--radix-popover-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-popover-content-available-width":"var(--radix-popper-available-width)","--radix-popover-content-available-height":"var(--radix-popper-available-height)","--radix-popover-trigger-width":"var(--radix-popper-anchor-width)","--radix-popover-trigger-height":"var(--radix-popper-anchor-height)"}})})})}),e3="PopoverClose",vQ=w.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=Ai(e3,n);return E.jsx(Je.button,{type:"button",...r,ref:t,onClick:Ke(e.onClick,()=>a.onOpenChange(!1))})});vQ.displayName=e3;var SQ="PopoverArrow",EQ=w.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=Zc(n);return E.jsx(pT,{...a,...r,ref:t})});EQ.displayName=SQ;function t3(e){return e?"open":"closed"}var wQ=YU,xQ=ZU,n3=QU;const mp=wQ,bp=xQ,Qc=w.forwardRef(({className:e,align:t="center",sideOffset:n=4,...r},a)=>E.jsx(n3,{ref:a,align:t,sideOffset:n,className:Me("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 z-50 rounded-md border p-4 shadow-md outline-none",e),...r}));Qc.displayName=n3.displayName;function z0(e,[t,n]){return Math.min(n,Math.max(t,e))}function r3(e){const t=e+"CollectionProvider",[n,r]=$r(t),[a,o]=n(t,{collectionRef:{current:null},itemMap:new Map}),s=b=>{const{scope:v,children:y}=b,k=we.useRef(null),A=we.useRef(new Map).current;return E.jsx(a,{scope:v,itemMap:A,collectionRef:k,children:y})};s.displayName=t;const l=e+"CollectionSlot",u=we.forwardRef((b,v)=>{const{scope:y,children:k}=b,A=o(l,y),x=mt(v,A.collectionRef);return E.jsx(_o,{ref:x,children:k})});u.displayName=l;const d=e+"CollectionItemSlot",p="data-radix-collection-item",g=we.forwardRef((b,v)=>{const{scope:y,children:k,...A}=b,x=we.useRef(null),R=mt(v,x),O=o(d,y);return we.useEffect(()=>(O.itemMap.set(x,{ref:x,...A}),()=>void O.itemMap.delete(x))),E.jsx(_o,{[p]:"",ref:R,children:k})});g.displayName=d;function m(b){const v=o(e+"CollectionConsumer",b);return we.useCallback(()=>{const k=v.collectionRef.current;if(!k)return[];const A=Array.from(k.querySelectorAll(`[${p}]`));return Array.from(v.itemMap.values()).sort((O,N)=>A.indexOf(O.ref.current)-A.indexOf(N.ref.current))},[v.collectionRef,v.itemMap])}return[{Provider:s,Slot:u,ItemSlot:g},m,r]}var kQ=w.createContext(void 0);function yp(e){const t=w.useContext(kQ);return e||t||"ltr"}function a3(e){const t=w.useRef({value:e,previous:e});return w.useMemo(()=>(t.current.value!==e&&(t.current.previous=t.current.value,t.current.value=e),t.current.previous),[e])}var TQ=[" ","Enter","ArrowUp","ArrowDown"],AQ=[" ","Enter"],Jc="Select",[vp,Sp,RQ]=r3(Jc),[Ks,h0e]=$r(Jc,[RQ,Ys]),Ep=Ys(),[CQ,Do]=Ks(Jc),[_Q,NQ]=Ks(Jc),o3=e=>{const{__scopeSelect:t,children:n,open:r,defaultOpen:a,onOpenChange:o,value:s,defaultValue:l,onValueChange:u,dir:d,name:p,autoComplete:g,disabled:m,required:b,form:v}=e,y=Ep(t),[k,A]=w.useState(null),[x,R]=w.useState(null),[O,N]=w.useState(!1),C=yp(d),[_=!1,M]=ja({prop:r,defaultProp:a,onChange:o}),[I,D]=ja({prop:s,defaultProp:l,onChange:u}),U=w.useRef(null),$=k?v||!!k.closest("form"):!0,[B,W]=w.useState(new Set),K=Array.from(B).map(H=>H.props.value).join(";");return E.jsx(dT,{...y,children:E.jsxs(CQ,{required:b,scope:t,trigger:k,onTriggerChange:A,valueNode:x,onValueNodeChange:R,valueNodeHasChildren:O,onValueNodeHasChildrenChange:N,contentId:An(),value:I,onValueChange:D,open:_,onOpenChange:M,dir:C,triggerPointerDownPosRef:U,disabled:m,children:[E.jsx(vp.Provider,{scope:t,children:E.jsx(_Q,{scope:e.__scopeSelect,onNativeOptionAdd:w.useCallback(H=>{W(G=>new Set(G).add(H))},[]),onNativeOptionRemove:w.useCallback(H=>{W(G=>{const z=new Set(G);return z.delete(H),z})},[]),children:n})}),$?E.jsxs(O3,{"aria-hidden":!0,required:b,tabIndex:-1,name:p,autoComplete:g,value:I,onChange:H=>D(H.target.value),disabled:m,form:v,children:[I===void 0?E.jsx("option",{value:""}):null,Array.from(B)]},K):null]})})};o3.displayName=Jc;var i3="SelectTrigger",s3=w.forwardRef((e,t)=>{const{__scopeSelect:n,disabled:r=!1,...a}=e,o=Ep(n),s=Do(i3,n),l=s.disabled||r,u=mt(t,s.onTriggerChange),d=Sp(n),p=w.useRef("touch"),[g,m,b]=I3(y=>{const k=d().filter(R=>!R.disabled),A=k.find(R=>R.value===s.value),x=D3(k,y,A);x!==void 0&&s.onValueChange(x.value)}),v=y=>{l||(s.onOpenChange(!0),b()),y&&(s.triggerPointerDownPosRef.current={x:Math.round(y.pageX),y:Math.round(y.pageY)})};return E.jsx(cp,{asChild:!0,...o,children:E.jsx(Je.button,{type:"button",role:"combobox","aria-controls":s.contentId,"aria-expanded":s.open,"aria-required":s.required,"aria-autocomplete":"none",dir:s.dir,"data-state":s.open?"open":"closed",disabled:l,"data-disabled":l?"":void 0,"data-placeholder":N3(s.value)?"":void 0,...a,ref:u,onClick:Ke(a.onClick,y=>{y.currentTarget.focus(),p.current!=="mouse"&&v(y)}),onPointerDown:Ke(a.onPointerDown,y=>{p.current=y.pointerType;const k=y.target;k.hasPointerCapture(y.pointerId)&&k.releasePointerCapture(y.pointerId),y.button===0&&y.ctrlKey===!1&&y.pointerType==="mouse"&&(v(y),y.preventDefault())}),onKeyDown:Ke(a.onKeyDown,y=>{const k=g.current!=="";!(y.ctrlKey||y.altKey||y.metaKey)&&y.key.length===1&&m(y.key),!(k&&y.key===" ")&&TQ.includes(y.key)&&(v(),y.preventDefault())})})})});s3.displayName=i3;var l3="SelectValue",c3=w.forwardRef((e,t)=>{const{__scopeSelect:n,className:r,style:a,children:o,placeholder:s="",...l}=e,u=Do(l3,n),{onValueNodeHasChildrenChange:d}=u,p=o!==void 0,g=mt(t,u.onValueNodeChange);return Rn(()=>{d(p)},[d,p]),E.jsx(Je.span,{...l,ref:g,style:{pointerEvents:"none"},children:N3(u.value)?E.jsx(E.Fragment,{children:s}):o})});c3.displayName=l3;var OQ="SelectIcon",u3=w.forwardRef((e,t)=>{const{__scopeSelect:n,children:r,...a}=e;return E.jsx(Je.span,{"aria-hidden":!0,...a,ref:t,children:r||"▼"})});u3.displayName=OQ;var IQ="SelectPortal",d3=e=>E.jsx($k,{asChild:!0,...e});d3.displayName=IQ;var yi="SelectContent",f3=w.forwardRef((e,t)=>{const n=Do(yi,e.__scopeSelect),[r,a]=w.useState();if(Rn(()=>{a(new DocumentFragment)},[]),!n.open){const o=r;return o?Gc.createPortal(E.jsx(p3,{scope:e.__scopeSelect,children:E.jsx(vp.Slot,{scope:e.__scopeSelect,children:E.jsx("div",{children:e.children})})}),o):null}return E.jsx(g3,{...e,ref:t})});f3.displayName=yi;var Pr=10,[p3,Lo]=Ks(yi),DQ="SelectContentImpl",g3=w.forwardRef((e,t)=>{const{__scopeSelect:n,position:r="item-aligned",onCloseAutoFocus:a,onEscapeKeyDown:o,onPointerDownOutside:s,side:l,sideOffset:u,align:d,alignOffset:p,arrowPadding:g,collisionBoundary:m,collisionPadding:b,sticky:v,hideWhenDetached:y,avoidCollisions:k,...A}=e,x=Do(yi,n),[R,O]=w.useState(null),[N,C]=w.useState(null),_=mt(t,ae=>O(ae)),[M,I]=w.useState(null),[D,U]=w.useState(null),$=Sp(n),[B,W]=w.useState(!1),K=w.useRef(!1);w.useEffect(()=>{if(R)return Vk(R)},[R]),qk();const H=w.useCallback(ae=>{const[ce,...Re]=$().map(ne=>ne.ref.current),[ie]=Re.slice(-1),Te=document.activeElement;for(const ne of ae)if(ne===Te||(ne==null||ne.scrollIntoView({block:"nearest"}),ne===ce&&N&&(N.scrollTop=0),ne===ie&&N&&(N.scrollTop=N.scrollHeight),ne==null||ne.focus(),document.activeElement!==Te))return},[$,N]),G=w.useCallback(()=>H([M,R]),[H,M,R]);w.useEffect(()=>{B&&G()},[B,G]);const{onOpenChange:z,triggerPointerDownPosRef:Y}=x;w.useEffect(()=>{if(R){let ae={x:0,y:0};const ce=ie=>{var Te,ne;ae={x:Math.abs(Math.round(ie.pageX)-(((Te=Y.current)==null?void 0:Te.x)??0)),y:Math.abs(Math.round(ie.pageY)-(((ne=Y.current)==null?void 0:ne.y)??0))}},Re=ie=>{ae.x<=10&&ae.y<=10?ie.preventDefault():R.contains(ie.target)||z(!1),document.removeEventListener("pointermove",ce),Y.current=null};return Y.current!==null&&(document.addEventListener("pointermove",ce),document.addEventListener("pointerup",Re,{capture:!0,once:!0})),()=>{document.removeEventListener("pointermove",ce),document.removeEventListener("pointerup",Re,{capture:!0})}}},[R,z,Y]),w.useEffect(()=>{const ae=()=>z(!1);return window.addEventListener("blur",ae),window.addEventListener("resize",ae),()=>{window.removeEventListener("blur",ae),window.removeEventListener("resize",ae)}},[z]);const[L,V]=I3(ae=>{const ce=$().filter(Te=>!Te.disabled),Re=ce.find(Te=>Te.ref.current===document.activeElement),ie=D3(ce,ae,Re);ie&&setTimeout(()=>ie.ref.current.focus())}),j=w.useCallback((ae,ce,Re)=>{const ie=!K.current&&!Re;(x.value!==void 0&&x.value===ce||ie)&&(I(ae),ie&&(K.current=!0))},[x.value]),P=w.useCallback(()=>R==null?void 0:R.focus(),[R]),Z=w.useCallback((ae,ce,Re)=>{const ie=!K.current&&!Re;(x.value!==void 0&&x.value===ce||ie)&&U(ae)},[x.value]),Q=r==="popper"?B0:h3,oe=Q===B0?{side:l,sideOffset:u,align:d,alignOffset:p,arrowPadding:g,collisionBoundary:m,collisionPadding:b,sticky:v,hideWhenDetached:y,avoidCollisions:k}:{};return E.jsx(p3,{scope:n,content:R,viewport:N,onViewportChange:C,itemRefCallback:j,selectedItem:M,onItemLeave:P,itemTextRefCallback:Z,focusSelectedItem:G,selectedItemText:D,position:r,isPositioned:B,searchRef:L,children:E.jsx(rp,{as:_o,allowPinchZoom:!0,children:E.jsx(tp,{asChild:!0,trapped:x.open,onMountAutoFocus:ae=>{ae.preventDefault()},onUnmountAutoFocus:Ke(a,ae=>{var ce;(ce=x.trigger)==null||ce.focus({preventScroll:!0}),ae.preventDefault()}),children:E.jsx(qc,{asChild:!0,disableOutsidePointerEvents:!0,onEscapeKeyDown:o,onPointerDownOutside:s,onFocusOutside:ae=>ae.preventDefault(),onDismiss:()=>x.onOpenChange(!1),children:E.jsx(Q,{role:"listbox",id:x.contentId,"data-state":x.open?"open":"closed",dir:x.dir,onContextMenu:ae=>ae.preventDefault(),...A,...oe,onPlaced:()=>W(!0),ref:_,style:{display:"flex",flexDirection:"column",outline:"none",...A.style},onKeyDown:Ke(A.onKeyDown,ae=>{const ce=ae.ctrlKey||ae.altKey||ae.metaKey;if(ae.key==="Tab"&&ae.preventDefault(),!ce&&ae.key.length===1&&V(ae.key),["ArrowUp","ArrowDown","Home","End"].includes(ae.key)){let ie=$().filter(Te=>!Te.disabled).map(Te=>Te.ref.current);if(["ArrowUp","End"].includes(ae.key)&&(ie=ie.slice().reverse()),["ArrowUp","ArrowDown"].includes(ae.key)){const Te=ae.target,ne=ie.indexOf(Te);ie=ie.slice(ne+1)}setTimeout(()=>H(ie)),ae.preventDefault()}})})})})})})});g3.displayName=DQ;var LQ="SelectItemAlignedPosition",h3=w.forwardRef((e,t)=>{const{__scopeSelect:n,onPlaced:r,...a}=e,o=Do(yi,n),s=Lo(yi,n),[l,u]=w.useState(null),[d,p]=w.useState(null),g=mt(t,_=>p(_)),m=Sp(n),b=w.useRef(!1),v=w.useRef(!0),{viewport:y,selectedItem:k,selectedItemText:A,focusSelectedItem:x}=s,R=w.useCallback(()=>{if(o.trigger&&o.valueNode&&l&&d&&y&&k&&A){const _=o.trigger.getBoundingClientRect(),M=d.getBoundingClientRect(),I=o.valueNode.getBoundingClientRect(),D=A.getBoundingClientRect();if(o.dir!=="rtl"){const Te=D.left-M.left,ne=I.left-Te,xe=_.left-ne,Se=_.width+xe,be=Math.max(Se,M.width),J=window.innerWidth-Pr,pe=z0(ne,[Pr,Math.max(Pr,J-be)]);l.style.minWidth=Se+"px",l.style.left=pe+"px"}else{const Te=M.right-D.right,ne=window.innerWidth-I.right-Te,xe=window.innerWidth-_.right-ne,Se=_.width+xe,be=Math.max(Se,M.width),J=window.innerWidth-Pr,pe=z0(ne,[Pr,Math.max(Pr,J-be)]);l.style.minWidth=Se+"px",l.style.right=pe+"px"}const U=m(),$=window.innerHeight-Pr*2,B=y.scrollHeight,W=window.getComputedStyle(d),K=parseInt(W.borderTopWidth,10),H=parseInt(W.paddingTop,10),G=parseInt(W.borderBottomWidth,10),z=parseInt(W.paddingBottom,10),Y=K+H+B+z+G,L=Math.min(k.offsetHeight*5,Y),V=window.getComputedStyle(y),j=parseInt(V.paddingTop,10),P=parseInt(V.paddingBottom,10),Z=_.top+_.height/2-Pr,Q=$-Z,oe=k.offsetHeight/2,ae=k.offsetTop+oe,ce=K+H+ae,Re=Y-ce;if(ce<=Z){const Te=U.length>0&&k===U[U.length-1].ref.current;l.style.bottom="0px";const ne=d.clientHeight-y.offsetTop-y.offsetHeight,xe=Math.max(Q,oe+(Te?P:0)+ne+G),Se=ce+xe;l.style.height=Se+"px"}else{const Te=U.length>0&&k===U[0].ref.current;l.style.top="0px";const xe=Math.max(Z,K+y.offsetTop+(Te?j:0)+oe)+Re;l.style.height=xe+"px",y.scrollTop=ce-Z+y.offsetTop}l.style.margin=`${Pr}px 0`,l.style.minHeight=L+"px",l.style.maxHeight=$+"px",r==null||r(),requestAnimationFrame(()=>b.current=!0)}},[m,o.trigger,o.valueNode,l,d,y,k,A,o.dir,r]);Rn(()=>R(),[R]);const[O,N]=w.useState();Rn(()=>{d&&N(window.getComputedStyle(d).zIndex)},[d]);const C=w.useCallback(_=>{_&&v.current===!0&&(R(),x==null||x(),v.current=!1)},[R,x]);return E.jsx(PQ,{scope:n,contentWrapper:l,shouldExpandOnScrollRef:b,onScrollButtonChange:C,children:E.jsx("div",{ref:u,style:{display:"flex",flexDirection:"column",position:"fixed",zIndex:O},children:E.jsx(Je.div,{...a,ref:g,style:{boxSizing:"border-box",maxHeight:"100%",...a.style}})})})});h3.displayName=LQ;var MQ="SelectPopperPosition",B0=w.forwardRef((e,t)=>{const{__scopeSelect:n,align:r="start",collisionPadding:a=Pr,...o}=e,s=Ep(n);return E.jsx(fT,{...s,...o,ref:t,align:r,collisionPadding:a,style:{boxSizing:"border-box",...o.style,"--radix-select-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-select-content-available-width":"var(--radix-popper-available-width)","--radix-select-content-available-height":"var(--radix-popper-available-height)","--radix-select-trigger-width":"var(--radix-popper-anchor-width)","--radix-select-trigger-height":"var(--radix-popper-anchor-height)"}})});B0.displayName=MQ;var[PQ,xT]=Ks(yi,{}),j0="SelectViewport",m3=w.forwardRef((e,t)=>{const{__scopeSelect:n,nonce:r,...a}=e,o=Lo(j0,n),s=xT(j0,n),l=mt(t,o.onViewportChange),u=w.useRef(0);return E.jsxs(E.Fragment,{children:[E.jsx("style",{dangerouslySetInnerHTML:{__html:"[data-radix-select-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-select-viewport]::-webkit-scrollbar{display:none}"},nonce:r}),E.jsx(vp.Slot,{scope:n,children:E.jsx(Je.div,{"data-radix-select-viewport":"",role:"presentation",...a,ref:l,style:{position:"relative",flex:1,overflow:"hidden auto",...a.style},onScroll:Ke(a.onScroll,d=>{const p=d.currentTarget,{contentWrapper:g,shouldExpandOnScrollRef:m}=s;if(m!=null&&m.current&&g){const b=Math.abs(u.current-p.scrollTop);if(b>0){const v=window.innerHeight-Pr*2,y=parseFloat(g.style.minHeight),k=parseFloat(g.style.height),A=Math.max(y,k);if(A<v){const x=A+b,R=Math.min(v,x),O=x-R;g.style.height=R+"px",g.style.bottom==="0px"&&(p.scrollTop=O>0?O:0,g.style.justifyContent="flex-end")}}}u.current=p.scrollTop})})})]})});m3.displayName=j0;var b3="SelectGroup",[FQ,zQ]=Ks(b3),y3=w.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,a=An();return E.jsx(FQ,{scope:n,id:a,children:E.jsx(Je.div,{role:"group","aria-labelledby":a,...r,ref:t})})});y3.displayName=b3;var v3="SelectLabel",S3=w.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,a=zQ(v3,n);return E.jsx(Je.div,{id:a.id,...r,ref:t})});S3.displayName=v3;var kf="SelectItem",[BQ,E3]=Ks(kf),w3=w.forwardRef((e,t)=>{const{__scopeSelect:n,value:r,disabled:a=!1,textValue:o,...s}=e,l=Do(kf,n),u=Lo(kf,n),d=l.value===r,[p,g]=w.useState(o??""),[m,b]=w.useState(!1),v=mt(t,x=>{var R;return(R=u.itemRefCallback)==null?void 0:R.call(u,x,r,a)}),y=An(),k=w.useRef("touch"),A=()=>{a||(l.onValueChange(r),l.onOpenChange(!1))};if(r==="")throw new Error("A <Select.Item /> must have a value prop that is not an empty string. This is because the Select value can be set to an empty string to clear the selection and show the placeholder.");return E.jsx(BQ,{scope:n,value:r,disabled:a,textId:y,isSelected:d,onItemTextChange:w.useCallback(x=>{g(R=>R||((x==null?void 0:x.textContent)??"").trim())},[]),children:E.jsx(vp.ItemSlot,{scope:n,value:r,disabled:a,textValue:p,children:E.jsx(Je.div,{role:"option","aria-labelledby":y,"data-highlighted":m?"":void 0,"aria-selected":d&&m,"data-state":d?"checked":"unchecked","aria-disabled":a||void 0,"data-disabled":a?"":void 0,tabIndex:a?void 0:-1,...s,ref:v,onFocus:Ke(s.onFocus,()=>b(!0)),onBlur:Ke(s.onBlur,()=>b(!1)),onClick:Ke(s.onClick,()=>{k.current!=="mouse"&&A()}),onPointerUp:Ke(s.onPointerUp,()=>{k.current==="mouse"&&A()}),onPointerDown:Ke(s.onPointerDown,x=>{k.current=x.pointerType}),onPointerMove:Ke(s.onPointerMove,x=>{var R;k.current=x.pointerType,a?(R=u.onItemLeave)==null||R.call(u):k.current==="mouse"&&x.currentTarget.focus({preventScroll:!0})}),onPointerLeave:Ke(s.onPointerLeave,x=>{var R;x.currentTarget===document.activeElement&&((R=u.onItemLeave)==null||R.call(u))}),onKeyDown:Ke(s.onKeyDown,x=>{var O;((O=u.searchRef)==null?void 0:O.current)!==""&&x.key===" "||(AQ.includes(x.key)&&A(),x.key===" "&&x.preventDefault())})})})})});w3.displayName=kf;var pc="SelectItemText",x3=w.forwardRef((e,t)=>{const{__scopeSelect:n,className:r,style:a,...o}=e,s=Do(pc,n),l=Lo(pc,n),u=E3(pc,n),d=NQ(pc,n),[p,g]=w.useState(null),m=mt(t,A=>g(A),u.onItemTextChange,A=>{var x;return(x=l.itemTextRefCallback)==null?void 0:x.call(l,A,u.value,u.disabled)}),b=p==null?void 0:p.textContent,v=w.useMemo(()=>E.jsx("option",{value:u.value,disabled:u.disabled,children:b},u.value),[u.disabled,u.value,b]),{onNativeOptionAdd:y,onNativeOptionRemove:k}=d;return Rn(()=>(y(v),()=>k(v)),[y,k,v]),E.jsxs(E.Fragment,{children:[E.jsx(Je.span,{id:u.textId,...o,ref:m}),u.isSelected&&s.valueNode&&!s.valueNodeHasChildren?Gc.createPortal(o.children,s.valueNode):null]})});x3.displayName=pc;var k3="SelectItemIndicator",T3=w.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e;return E3(k3,n).isSelected?E.jsx(Je.span,{"aria-hidden":!0,...r,ref:t}):null});T3.displayName=k3;var U0="SelectScrollUpButton",A3=w.forwardRef((e,t)=>{const n=Lo(U0,e.__scopeSelect),r=xT(U0,e.__scopeSelect),[a,o]=w.useState(!1),s=mt(t,r.onScrollButtonChange);return Rn(()=>{if(n.viewport&&n.isPositioned){let l=function(){const d=u.scrollTop>0;o(d)};const u=n.viewport;return l(),u.addEventListener("scroll",l),()=>u.removeEventListener("scroll",l)}},[n.viewport,n.isPositioned]),a?E.jsx(C3,{...e,ref:s,onAutoScroll:()=>{const{viewport:l,selectedItem:u}=n;l&&u&&(l.scrollTop=l.scrollTop-u.offsetHeight)}}):null});A3.displayName=U0;var G0="SelectScrollDownButton",R3=w.forwardRef((e,t)=>{const n=Lo(G0,e.__scopeSelect),r=xT(G0,e.__scopeSelect),[a,o]=w.useState(!1),s=mt(t,r.onScrollButtonChange);return Rn(()=>{if(n.viewport&&n.isPositioned){let l=function(){const d=u.scrollHeight-u.clientHeight,p=Math.ceil(u.scrollTop)<d;o(p)};const u=n.viewport;return l(),u.addEventListener("scroll",l),()=>u.removeEventListener("scroll",l)}},[n.viewport,n.isPositioned]),a?E.jsx(C3,{...e,ref:s,onAutoScroll:()=>{const{viewport:l,selectedItem:u}=n;l&&u&&(l.scrollTop=l.scrollTop+u.offsetHeight)}}):null});R3.displayName=G0;var C3=w.forwardRef((e,t)=>{const{__scopeSelect:n,onAutoScroll:r,...a}=e,o=Lo("SelectScrollButton",n),s=w.useRef(null),l=Sp(n),u=w.useCallback(()=>{s.current!==null&&(window.clearInterval(s.current),s.current=null)},[]);return w.useEffect(()=>()=>u(),[u]),Rn(()=>{var p;const d=l().find(g=>g.ref.current===document.activeElement);(p=d==null?void 0:d.ref.current)==null||p.scrollIntoView({block:"nearest"})},[l]),E.jsx(Je.div,{"aria-hidden":!0,...a,ref:t,style:{flexShrink:0,...a.style},onPointerDown:Ke(a.onPointerDown,()=>{s.current===null&&(s.current=window.setInterval(r,50))}),onPointerMove:Ke(a.onPointerMove,()=>{var d;(d=o.onItemLeave)==null||d.call(o),s.current===null&&(s.current=window.setInterval(r,50))}),onPointerLeave:Ke(a.onPointerLeave,()=>{u()})})}),jQ="SelectSeparator",_3=w.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e;return E.jsx(Je.div,{"aria-hidden":!0,...r,ref:t})});_3.displayName=jQ;var H0="SelectArrow",UQ=w.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,a=Ep(n),o=Do(H0,n),s=Lo(H0,n);return o.open&&s.position==="popper"?E.jsx(pT,{...a,...r,ref:t}):null});UQ.displayName=H0;function N3(e){return e===""||e===void 0}var O3=w.forwardRef((e,t)=>{const{value:n,...r}=e,a=w.useRef(null),o=mt(t,a),s=a3(n);return w.useEffect(()=>{const l=a.current,u=window.HTMLSelectElement.prototype,p=Object.getOwnPropertyDescriptor(u,"value").set;if(s!==n&&p){const g=new Event("change",{bubbles:!0});p.call(l,n),l.dispatchEvent(g)}},[s,n]),E.jsx(gT,{asChild:!0,children:E.jsx("select",{...r,ref:o,defaultValue:n})})});O3.displayName="BubbleSelect";function I3(e){const t=yn(e),n=w.useRef(""),r=w.useRef(0),a=w.useCallback(s=>{const l=n.current+s;t(l),function u(d){n.current=d,window.clearTimeout(r.current),d!==""&&(r.current=window.setTimeout(()=>u(""),1e3))}(l)},[t]),o=w.useCallback(()=>{n.current="",window.clearTimeout(r.current)},[]);return w.useEffect(()=>()=>window.clearTimeout(r.current),[]),[n,a,o]}function D3(e,t,n){const a=t.length>1&&Array.from(t).every(d=>d===t[0])?t[0]:t,o=n?e.indexOf(n):-1;let s=GQ(e,Math.max(o,0));a.length===1&&(s=s.filter(d=>d!==n));const u=s.find(d=>d.textValue.toLowerCase().startsWith(a.toLowerCase()));return u!==n?u:void 0}function GQ(e,t){return e.map((n,r)=>e[(t+r)%e.length])}var HQ=o3,L3=s3,$Q=c3,qQ=u3,VQ=d3,M3=f3,WQ=m3,YQ=y3,P3=S3,F3=w3,KQ=x3,XQ=T3,z3=A3,B3=R3,j3=_3;const Tf=HQ,pN=YQ,Af=$Q,Tc=w.forwardRef(({className:e,children:t,...n},r)=>E.jsxs(L3,{ref:r,className:Me("border-input bg-background ring-offset-background placeholder:text-muted-foreground focus:ring-ring flex h-10 w-full items-center justify-between rounded-md border px-3 py-2 text-sm focus:ring-2 focus:ring-offset-2 focus:outline-none disabled:cursor-not-allowed disabled:opacity-50 [&>span]:line-clamp-1",e),...n,children:[t,E.jsx(qQ,{asChild:!0,children:E.jsx(ST,{className:"h-4 w-4 opacity-50"})})]}));Tc.displayName=L3.displayName;const U3=w.forwardRef(({className:e,...t},n)=>E.jsx(z3,{ref:n,className:Me("flex cursor-default items-center justify-center py-1",e),...t,children:E.jsx(FU,{className:"h-4 w-4"})}));U3.displayName=z3.displayName;const G3=w.forwardRef(({className:e,...t},n)=>E.jsx(B3,{ref:n,className:Me("flex cursor-default items-center justify-center py-1",e),...t,children:E.jsx(ST,{className:"h-4 w-4"})}));G3.displayName=B3.displayName;const Ac=w.forwardRef(({className:e,children:t,position:n="popper",...r},a)=>E.jsx(VQ,{children:E.jsxs(M3,{ref:a,className:Me("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 relative z-50 max-h-96 min-w-[8rem] overflow-hidden rounded-md border shadow-md",n==="popper"&&"data-[side=bottom]:translate-y-1 data-[side=left]:-translate-x-1 data-[side=right]:translate-x-1 data-[side=top]:-translate-y-1",e),position:n,...r,children:[E.jsx(U3,{}),E.jsx(WQ,{className:Me("p-1",n==="popper"&&"h-[var(--radix-select-trigger-height)] w-full min-w-[var(--radix-select-trigger-width)]"),children:t}),E.jsx(G3,{})]})}));Ac.displayName=M3.displayName;const ZQ=w.forwardRef(({className:e,...t},n)=>E.jsx(P3,{ref:n,className:Me("py-1.5 pr-2 pl-8 text-sm font-semibold",e),...t}));ZQ.displayName=P3.displayName;const xn=w.forwardRef(({className:e,children:t,...n},r)=>E.jsxs(F3,{ref:r,className:Me("focus:bg-accent focus:text-accent-foreground relative flex w-full cursor-default items-center rounded-sm py-1.5 pr-2 pl-8 text-sm outline-none select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50",e),...n,children:[E.jsx("span",{className:"absolute left-2 flex h-3.5 w-3.5 items-center justify-center",children:E.jsx(XQ,{children:E.jsx(vT,{className:"h-4 w-4"})})}),E.jsx(KQ,{children:t})]}));xn.displayName=F3.displayName;const QQ=w.forwardRef(({className:e,...t},n)=>E.jsx(j3,{ref:n,className:Me("bg-muted -mx-1 my-1 h-px",e),...t}));QQ.displayName=j3.displayName;function H3({className:e}){const[t,n]=w.useState(!1),{t:r}=Et(),a=De.use.language(),o=De.use.setLanguage(),s=De.use.theme(),l=De.use.setTheme(),u=w.useCallback(p=>{o(p)},[o]),d=w.useCallback(p=>{l(p)},[l]);return E.jsxs(mp,{open:t,onOpenChange:n,children:[E.jsx(bp,{asChild:!0,children:E.jsx(nt,{variant:"ghost",size:"icon",className:Me("h-9 w-9",e),children:E.jsx(MZ,{className:"h-5 w-5"})})}),E.jsx(Qc,{side:"bottom",align:"end",className:"w-56",children:E.jsxs("div",{className:"flex flex-col gap-4",children:[E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsx("label",{className:"text-sm font-medium",children:r("settings.language")}),E.jsxs(Tf,{value:a,onValueChange:u,children:[E.jsx(Tc,{children:E.jsx(Af,{})}),E.jsxs(Ac,{children:[E.jsx(xn,{value:"en",children:"English"}),E.jsx(xn,{value:"zh",children:"中文"}),E.jsx(xn,{value:"fr",children:"Français"}),E.jsx(xn,{value:"ar",children:"العربية"})]})]})]}),E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsx("label",{className:"text-sm font-medium",children:r("settings.theme")}),E.jsxs(Tf,{value:s,onValueChange:d,children:[E.jsx(Tc,{children:E.jsx(Af,{})}),E.jsxs(Ac,{children:[E.jsx(xn,{value:"light",children:r("settings.light")}),E.jsx(xn,{value:"dark",children:r("settings.dark")}),E.jsx(xn,{value:"system",children:r("settings.system")})]})]})]})]})})]})}var bm="rovingFocusGroup.onEntryFocus",JQ={bubbles:!1,cancelable:!0},wp="RovingFocusGroup",[$0,$3,eJ]=r3(wp),[tJ,q3]=$r(wp,[eJ]),[nJ,rJ]=tJ(wp),V3=w.forwardRef((e,t)=>E.jsx($0.Provider,{scope:e.__scopeRovingFocusGroup,children:E.jsx($0.Slot,{scope:e.__scopeRovingFocusGroup,children:E.jsx(aJ,{...e,ref:t})})}));V3.displayName=wp;var aJ=w.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,orientation:r,loop:a=!1,dir:o,currentTabStopId:s,defaultCurrentTabStopId:l,onCurrentTabStopIdChange:u,onEntryFocus:d,preventScrollOnEntryFocus:p=!1,...g}=e,m=w.useRef(null),b=mt(t,m),v=yp(o),[y=null,k]=ja({prop:s,defaultProp:l,onChange:u}),[A,x]=w.useState(!1),R=yn(d),O=$3(n),N=w.useRef(!1),[C,_]=w.useState(0);return w.useEffect(()=>{const M=m.current;if(M)return M.addEventListener(bm,R),()=>M.removeEventListener(bm,R)},[R]),E.jsx(nJ,{scope:n,orientation:r,dir:v,loop:a,currentTabStopId:y,onItemFocus:w.useCallback(M=>k(M),[k]),onItemShiftTab:w.useCallback(()=>x(!0),[]),onFocusableItemAdd:w.useCallback(()=>_(M=>M+1),[]),onFocusableItemRemove:w.useCallback(()=>_(M=>M-1),[]),children:E.jsx(Je.div,{tabIndex:A||C===0?-1:0,"data-orientation":r,...g,ref:b,style:{outline:"none",...e.style},onMouseDown:Ke(e.onMouseDown,()=>{N.current=!0}),onFocus:Ke(e.onFocus,M=>{const I=!N.current;if(M.target===M.currentTarget&&I&&!A){const D=new CustomEvent(bm,JQ);if(M.currentTarget.dispatchEvent(D),!D.defaultPrevented){const U=O().filter(H=>H.focusable),$=U.find(H=>H.active),B=U.find(H=>H.id===y),K=[$,B,...U].filter(Boolean).map(H=>H.ref.current);K3(K,p)}}N.current=!1}),onBlur:Ke(e.onBlur,()=>x(!1))})})}),W3="RovingFocusGroupItem",Y3=w.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,focusable:r=!0,active:a=!1,tabStopId:o,...s}=e,l=An(),u=o||l,d=rJ(W3,n),p=d.currentTabStopId===u,g=$3(n),{onFocusableItemAdd:m,onFocusableItemRemove:b}=d;return w.useEffect(()=>{if(r)return m(),()=>b()},[r,m,b]),E.jsx($0.ItemSlot,{scope:n,id:u,focusable:r,active:a,children:E.jsx(Je.span,{tabIndex:p?0:-1,"data-orientation":d.orientation,...s,ref:t,onMouseDown:Ke(e.onMouseDown,v=>{r?d.onItemFocus(u):v.preventDefault()}),onFocus:Ke(e.onFocus,()=>d.onItemFocus(u)),onKeyDown:Ke(e.onKeyDown,v=>{if(v.key==="Tab"&&v.shiftKey){d.onItemShiftTab();return}if(v.target!==v.currentTarget)return;const y=sJ(v,d.orientation,d.dir);if(y!==void 0){if(v.metaKey||v.ctrlKey||v.altKey||v.shiftKey)return;v.preventDefault();let A=g().filter(x=>x.focusable).map(x=>x.ref.current);if(y==="last")A.reverse();else if(y==="prev"||y==="next"){y==="prev"&&A.reverse();const x=A.indexOf(v.currentTarget);A=d.loop?lJ(A,x+1):A.slice(x+1)}setTimeout(()=>K3(A))}})})})});Y3.displayName=W3;var oJ={ArrowLeft:"prev",ArrowUp:"prev",ArrowRight:"next",ArrowDown:"next",PageUp:"first",Home:"first",PageDown:"last",End:"last"};function iJ(e,t){return t!=="rtl"?e:e==="ArrowLeft"?"ArrowRight":e==="ArrowRight"?"ArrowLeft":e}function sJ(e,t,n){const r=iJ(e.key,n);if(!(t==="vertical"&&["ArrowLeft","ArrowRight"].includes(r))&&!(t==="horizontal"&&["ArrowUp","ArrowDown"].includes(r)))return oJ[r]}function K3(e,t=!1){const n=document.activeElement;for(const r of e)if(r===n||(r.focus({preventScroll:t}),document.activeElement!==n))return}function lJ(e,t){return e.map((n,r)=>e[(t+r)%e.length])}var cJ=V3,uJ=Y3,kT="Tabs",[dJ,m0e]=$r(kT,[q3]),X3=q3(),[fJ,TT]=dJ(kT),Z3=w.forwardRef((e,t)=>{const{__scopeTabs:n,value:r,onValueChange:a,defaultValue:o,orientation:s="horizontal",dir:l,activationMode:u="automatic",...d}=e,p=yp(l),[g,m]=ja({prop:r,onChange:a,defaultProp:o});return E.jsx(fJ,{scope:n,baseId:An(),value:g,onValueChange:m,orientation:s,dir:p,activationMode:u,children:E.jsx(Je.div,{dir:p,"data-orientation":s,...d,ref:t})})});Z3.displayName=kT;var Q3="TabsList",J3=w.forwardRef((e,t)=>{const{__scopeTabs:n,loop:r=!0,...a}=e,o=TT(Q3,n),s=X3(n);return E.jsx(cJ,{asChild:!0,...s,orientation:o.orientation,dir:o.dir,loop:r,children:E.jsx(Je.div,{role:"tablist","aria-orientation":o.orientation,...a,ref:t})})});J3.displayName=Q3;var e4="TabsTrigger",t4=w.forwardRef((e,t)=>{const{__scopeTabs:n,value:r,disabled:a=!1,...o}=e,s=TT(e4,n),l=X3(n),u=a4(s.baseId,r),d=o4(s.baseId,r),p=r===s.value;return E.jsx(uJ,{asChild:!0,...l,focusable:!a,active:p,children:E.jsx(Je.button,{type:"button",role:"tab","aria-selected":p,"aria-controls":d,"data-state":p?"active":"inactive","data-disabled":a?"":void 0,disabled:a,id:u,...o,ref:t,onMouseDown:Ke(e.onMouseDown,g=>{!a&&g.button===0&&g.ctrlKey===!1?s.onValueChange(r):g.preventDefault()}),onKeyDown:Ke(e.onKeyDown,g=>{[" ","Enter"].includes(g.key)&&s.onValueChange(r)}),onFocus:Ke(e.onFocus,()=>{const g=s.activationMode!=="manual";!p&&!a&&g&&s.onValueChange(r)})})})});t4.displayName=e4;var n4="TabsContent",r4=w.forwardRef((e,t)=>{const{__scopeTabs:n,value:r,forceMount:a,children:o,...s}=e,l=TT(n4,n),u=a4(l.baseId,r),d=o4(l.baseId,r),p=r===l.value,g=w.useRef(p);return w.useEffect(()=>{const m=requestAnimationFrame(()=>g.current=!1);return()=>cancelAnimationFrame(m)},[]),E.jsx(Tr,{present:a||p,children:({present:m})=>E.jsx(Je.div,{"data-state":p?"active":"inactive","data-orientation":l.orientation,role:"tabpanel","aria-labelledby":u,hidden:!m,id:d,tabIndex:0,...s,ref:t,style:{...e.style,animationDuration:g.current?"0s":void 0},children:m&&o})})});r4.displayName=n4;function a4(e,t){return`${e}-trigger-${t}`}function o4(e,t){return`${e}-content-${t}`}var pJ=Z3,i4=J3,s4=t4,l4=r4;const gJ=pJ,c4=w.forwardRef(({className:e,...t},n)=>E.jsx(i4,{ref:n,className:Me("bg-muted text-muted-foreground inline-flex h-10 items-center justify-center rounded-md p-1",e),...t}));c4.displayName=i4.displayName;const u4=w.forwardRef(({className:e,...t},n)=>E.jsx(s4,{ref:n,className:Me("ring-offset-background focus-visible:ring-ring data-[state=active]:bg-background data-[state=active]:text-foreground inline-flex items-center justify-center rounded-sm px-3 py-1.5 text-sm font-medium whitespace-nowrap transition-all focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none disabled:pointer-events-none disabled:opacity-50 data-[state=active]:shadow-sm",e),...t}));u4.displayName=s4.displayName;const gc=w.forwardRef(({className:e,...t},n)=>E.jsx(l4,{ref:n,className:Me("ring-offset-background focus-visible:ring-ring focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none","data-[state=inactive]:invisible data-[state=active]:visible","h-full w-full",e),forceMount:!0,...t}));gc.displayName=l4.displayName;function Rd({value:e,currentTab:t,children:n}){return E.jsx(u4,{value:e,className:Me("cursor-pointer px-2 py-1 transition-all",t===e?"!bg-emerald-400 !text-zinc-50":"hover:bg-background/60"),children:n})}function hJ(){const e=De.use.currentTab(),{t}=Et();return E.jsx("div",{className:"flex h-8 self-center",children:E.jsxs(c4,{className:"h-full gap-2",children:[E.jsx(Rd,{value:"documents",currentTab:e,children:t("header.documents")}),E.jsx(Rd,{value:"knowledge-graph",currentTab:e,children:t("header.knowledgeGraph")}),E.jsx(Rd,{value:"retrieval",currentTab:e,children:t("header.retrieval")}),E.jsx(Rd,{value:"api",currentTab:e,children:t("header.api")})]})})}function mJ(){const{t:e}=Et(),{isGuestMode:t,coreVersion:n,apiVersion:r,username:a,webuiTitle:o,webuiDescription:s}=wr(),l=n&&r?`${n}/${r}`:null,u=()=>{Gk.navigateToLogin()};return E.jsxs("header",{className:"border-border/40 bg-background/95 supports-[backdrop-filter]:bg-background/60 sticky top-0 z-50 flex h-10 w-full border-b px-4 backdrop-blur",children:[E.jsxs("div",{className:"min-w-[200px] w-auto flex items-center",children:[E.jsxs("a",{href:YB,className:"flex items-center gap-2",children:[E.jsx(ET,{className:"size-4 text-emerald-400","aria-hidden":"true"}),E.jsx("span",{className:"font-bold md:inline-block",children:x0.name})]}),o&&E.jsxs("div",{className:"flex items-center",children:[E.jsx("span",{className:"mx-1 text-xs text-gray-500 dark:text-gray-400",children:"|"}),E.jsx(mT,{children:E.jsxs(bT,{children:[E.jsx(yT,{asChild:!0,children:E.jsx("span",{className:"font-medium text-sm cursor-default",children:o})}),s&&E.jsx(gp,{side:"bottom",children:s})]})})]})]}),E.jsxs("div",{className:"flex h-10 flex-1 items-center justify-center",children:[E.jsx(hJ,{}),t&&E.jsx("div",{className:"ml-2 self-center px-2 py-1 text-xs bg-amber-100 text-amber-800 dark:bg-amber-900 dark:text-amber-200 rounded-md",children:e("login.guestMode","Guest Mode")})]}),E.jsx("nav",{className:"w-[200px] flex items-center justify-end",children:E.jsxs("div",{className:"flex items-center gap-2",children:[l&&E.jsxs("span",{className:"text-xs text-gray-500 dark:text-gray-400 mr-1",children:["v",l]}),E.jsx(nt,{variant:"ghost",size:"icon",side:"bottom",tooltip:e("header.projectRepository"),children:E.jsx("a",{href:x0.github,target:"_blank",rel:"noopener noreferrer",children:E.jsx(wZ,{className:"size-4","aria-hidden":"true"})})}),E.jsx(H3,{}),!t&&E.jsx(nt,{variant:"ghost",size:"icon",side:"bottom",tooltip:`${e("header.logout")} (${a})`,onClick:u,children:E.jsx(_Z,{className:"size-4","aria-hidden":"true"})})]})})]})}var Cd={exports:{}},gN;function bJ(){if(gN)return Cd.exports;gN=1;var e=typeof Reflect=="object"?Reflect:null,t=e&&typeof e.apply=="function"?e.apply:function(N,C,_){return Function.prototype.apply.call(N,C,_)},n;e&&typeof e.ownKeys=="function"?n=e.ownKeys:Object.getOwnPropertySymbols?n=function(N){return Object.getOwnPropertyNames(N).concat(Object.getOwnPropertySymbols(N))}:n=function(N){return Object.getOwnPropertyNames(N)};function r(O){console&&console.warn&&console.warn(O)}var a=Number.isNaN||function(N){return N!==N};function o(){o.init.call(this)}Cd.exports=o,Cd.exports.once=A,o.EventEmitter=o,o.prototype._events=void 0,o.prototype._eventsCount=0,o.prototype._maxListeners=void 0;var s=10;function l(O){if(typeof O!="function")throw new TypeError('The "listener" argument must be of type Function. Received type '+typeof O)}Object.defineProperty(o,"defaultMaxListeners",{enumerable:!0,get:function(){return s},set:function(O){if(typeof O!="number"||O<0||a(O))throw new RangeError('The value of "defaultMaxListeners" is out of range. It must be a non-negative number. Received '+O+".");s=O}}),o.init=function(){(this._events===void 0||this._events===Object.getPrototypeOf(this)._events)&&(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},o.prototype.setMaxListeners=function(N){if(typeof N!="number"||N<0||a(N))throw new RangeError('The value of "n" is out of range. It must be a non-negative number. Received '+N+".");return this._maxListeners=N,this};function u(O){return O._maxListeners===void 0?o.defaultMaxListeners:O._maxListeners}o.prototype.getMaxListeners=function(){return u(this)},o.prototype.emit=function(N){for(var C=[],_=1;_<arguments.length;_++)C.push(arguments[_]);var M=N==="error",I=this._events;if(I!==void 0)M=M&&I.error===void 0;else if(!M)return!1;if(M){var D;if(C.length>0&&(D=C[0]),D instanceof Error)throw D;var U=new Error("Unhandled error."+(D?" ("+D.message+")":""));throw U.context=D,U}var $=I[N];if($===void 0)return!1;if(typeof $=="function")t($,this,C);else for(var B=$.length,W=v($,B),_=0;_<B;++_)t(W[_],this,C);return!0};function d(O,N,C,_){var M,I,D;if(l(C),I=O._events,I===void 0?(I=O._events=Object.create(null),O._eventsCount=0):(I.newListener!==void 0&&(O.emit("newListener",N,C.listener?C.listener:C),I=O._events),D=I[N]),D===void 0)D=I[N]=C,++O._eventsCount;else if(typeof D=="function"?D=I[N]=_?[C,D]:[D,C]:_?D.unshift(C):D.push(C),M=u(O),M>0&&D.length>M&&!D.warned){D.warned=!0;var U=new Error("Possible EventEmitter memory leak detected. "+D.length+" "+String(N)+" listeners added. Use emitter.setMaxListeners() to increase limit");U.name="MaxListenersExceededWarning",U.emitter=O,U.type=N,U.count=D.length,r(U)}return O}o.prototype.addListener=function(N,C){return d(this,N,C,!1)},o.prototype.on=o.prototype.addListener,o.prototype.prependListener=function(N,C){return d(this,N,C,!0)};function p(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length===0?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function g(O,N,C){var _={fired:!1,wrapFn:void 0,target:O,type:N,listener:C},M=p.bind(_);return M.listener=C,_.wrapFn=M,M}o.prototype.once=function(N,C){return l(C),this.on(N,g(this,N,C)),this},o.prototype.prependOnceListener=function(N,C){return l(C),this.prependListener(N,g(this,N,C)),this},o.prototype.removeListener=function(N,C){var _,M,I,D,U;if(l(C),M=this._events,M===void 0)return this;if(_=M[N],_===void 0)return this;if(_===C||_.listener===C)--this._eventsCount===0?this._events=Object.create(null):(delete M[N],M.removeListener&&this.emit("removeListener",N,_.listener||C));else if(typeof _!="function"){for(I=-1,D=_.length-1;D>=0;D--)if(_[D]===C||_[D].listener===C){U=_[D].listener,I=D;break}if(I<0)return this;I===0?_.shift():y(_,I),_.length===1&&(M[N]=_[0]),M.removeListener!==void 0&&this.emit("removeListener",N,U||C)}return this},o.prototype.off=o.prototype.removeListener,o.prototype.removeAllListeners=function(N){var C,_,M;if(_=this._events,_===void 0)return this;if(_.removeListener===void 0)return arguments.length===0?(this._events=Object.create(null),this._eventsCount=0):_[N]!==void 0&&(--this._eventsCount===0?this._events=Object.create(null):delete _[N]),this;if(arguments.length===0){var I=Object.keys(_),D;for(M=0;M<I.length;++M)D=I[M],D!=="removeListener"&&this.removeAllListeners(D);return this.removeAllListeners("removeListener"),this._events=Object.create(null),this._eventsCount=0,this}if(C=_[N],typeof C=="function")this.removeListener(N,C);else if(C!==void 0)for(M=C.length-1;M>=0;M--)this.removeListener(N,C[M]);return this};function m(O,N,C){var _=O._events;if(_===void 0)return[];var M=_[N];return M===void 0?[]:typeof M=="function"?C?[M.listener||M]:[M]:C?k(M):v(M,M.length)}o.prototype.listeners=function(N){return m(this,N,!0)},o.prototype.rawListeners=function(N){return m(this,N,!1)},o.listenerCount=function(O,N){return typeof O.listenerCount=="function"?O.listenerCount(N):b.call(O,N)},o.prototype.listenerCount=b;function b(O){var N=this._events;if(N!==void 0){var C=N[O];if(typeof C=="function")return 1;if(C!==void 0)return C.length}return 0}o.prototype.eventNames=function(){return this._eventsCount>0?n(this._events):[]};function v(O,N){for(var C=new Array(N),_=0;_<N;++_)C[_]=O[_];return C}function y(O,N){for(;N+1<O.length;N++)O[N]=O[N+1];O.pop()}function k(O){for(var N=new Array(O.length),C=0;C<N.length;++C)N[C]=O[C].listener||O[C];return N}function A(O,N){return new Promise(function(C,_){function M(D){O.removeListener(N,I),_(D)}function I(){typeof O.removeListener=="function"&&O.removeListener("error",M),C([].slice.call(arguments))}R(O,N,I,{once:!0}),N!=="error"&&x(O,M,{once:!0})})}function x(O,N,C){typeof O.on=="function"&&R(O,"error",N,C)}function R(O,N,C,_){if(typeof O.on=="function")_.once?O.once(N,C):O.on(N,C);else if(typeof O.addEventListener=="function")O.addEventListener(N,function M(I){_.once&&O.removeEventListener(N,M),C(I)});else throw new TypeError('The "emitter" argument must be of type EventEmitter. Received type '+typeof O)}return Cd.exports}var d4=bJ();function yJ(){const e=arguments[0];for(let t=1,n=arguments.length;t<n;t++)if(arguments[t])for(const r in arguments[t])e[r]=arguments[t][r];return e}let nn=yJ;typeof Object.assign=="function"&&(nn=Object.assign);function xr(e,t,n,r){const a=e._nodes.get(t);let o=null;return a&&(r==="mixed"?o=a.out&&a.out[n]||a.undirected&&a.undirected[n]:r==="directed"?o=a.out&&a.out[n]:o=a.undirected&&a.undirected[n]),o}function vn(e){return typeof e=="object"&&e!==null}function f4(e){let t;for(t in e)return!1;return!0}function vr(e,t,n){Object.defineProperty(e,t,{enumerable:!1,configurable:!1,writable:!0,value:n})}function Mr(e,t,n){const r={enumerable:!0,configurable:!0};typeof n=="function"?r.get=n:(r.value=n,r.writable=!1),Object.defineProperty(e,t,r)}function hN(e){return!(!vn(e)||e.attributes&&!Array.isArray(e.attributes))}function vJ(){let e=Math.floor(Math.random()*256)&255;return()=>e++}function za(){const e=arguments;let t=null,n=-1;return{[Symbol.iterator](){return this},next(){let r=null;do{if(t===null){if(n++,n>=e.length)return{done:!0};t=e[n][Symbol.iterator]()}if(r=t.next(),r.done){t=null;continue}break}while(!0);return r}}}function Xs(){return{[Symbol.iterator](){return this},next(){return{done:!0}}}}class AT extends Error{constructor(t){super(),this.name="GraphError",this.message=t}}class Pe extends AT{constructor(t){super(t),this.name="InvalidArgumentsGraphError",typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(this,Pe.prototype.constructor)}}class Le extends AT{constructor(t){super(t),this.name="NotFoundGraphError",typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(this,Le.prototype.constructor)}}class Ze extends AT{constructor(t){super(t),this.name="UsageGraphError",typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(this,Ze.prototype.constructor)}}function p4(e,t){this.key=e,this.attributes=t,this.clear()}p4.prototype.clear=function(){this.inDegree=0,this.outDegree=0,this.undirectedDegree=0,this.undirectedLoops=0,this.directedLoops=0,this.in={},this.out={},this.undirected={}};function g4(e,t){this.key=e,this.attributes=t,this.clear()}g4.prototype.clear=function(){this.inDegree=0,this.outDegree=0,this.directedLoops=0,this.in={},this.out={}};function h4(e,t){this.key=e,this.attributes=t,this.clear()}h4.prototype.clear=function(){this.undirectedDegree=0,this.undirectedLoops=0,this.undirected={}};function Zs(e,t,n,r,a){this.key=t,this.attributes=a,this.undirected=e,this.source=n,this.target=r}Zs.prototype.attach=function(){let e="out",t="in";this.undirected&&(e=t="undirected");const n=this.source.key,r=this.target.key;this.source[e][r]=this,!(this.undirected&&n===r)&&(this.target[t][n]=this)};Zs.prototype.attachMulti=function(){let e="out",t="in";const n=this.source.key,r=this.target.key;this.undirected&&(e=t="undirected");const a=this.source[e],o=a[r];if(typeof o>"u"){a[r]=this,this.undirected&&n===r||(this.target[t][n]=this);return}o.previous=this,this.next=o,a[r]=this,this.target[t][n]=this};Zs.prototype.detach=function(){const e=this.source.key,t=this.target.key;let n="out",r="in";this.undirected&&(n=r="undirected"),delete this.source[n][t],delete this.target[r][e]};Zs.prototype.detachMulti=function(){const e=this.source.key,t=this.target.key;let n="out",r="in";this.undirected&&(n=r="undirected"),this.previous===void 0?this.next===void 0?(delete this.source[n][t],delete this.target[r][e]):(this.next.previous=void 0,this.source[n][t]=this.next,this.target[r][e]=this.next):(this.previous.next=this.next,this.next!==void 0&&(this.next.previous=this.previous))};const m4=0,b4=1,SJ=2,y4=3;function qa(e,t,n,r,a,o,s){let l,u,d,p;if(r=""+r,n===m4){if(l=e._nodes.get(r),!l)throw new Le(`Graph.${t}: could not find the "${r}" node in the graph.`);d=a,p=o}else if(n===y4){if(a=""+a,u=e._edges.get(a),!u)throw new Le(`Graph.${t}: could not find the "${a}" edge in the graph.`);const g=u.source.key,m=u.target.key;if(r===g)l=u.target;else if(r===m)l=u.source;else throw new Le(`Graph.${t}: the "${r}" node is not attached to the "${a}" edge (${g}, ${m}).`);d=o,p=s}else{if(u=e._edges.get(r),!u)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`);n===b4?l=u.source:l=u.target,d=a,p=o}return[l,d,p]}function EJ(e,t,n){e.prototype[t]=function(r,a,o){const[s,l]=qa(this,t,n,r,a,o);return s.attributes[l]}}function wJ(e,t,n){e.prototype[t]=function(r,a){const[o]=qa(this,t,n,r,a);return o.attributes}}function xJ(e,t,n){e.prototype[t]=function(r,a,o){const[s,l]=qa(this,t,n,r,a,o);return s.attributes.hasOwnProperty(l)}}function kJ(e,t,n){e.prototype[t]=function(r,a,o,s){const[l,u,d]=qa(this,t,n,r,a,o,s);return l.attributes[u]=d,this.emit("nodeAttributesUpdated",{key:l.key,type:"set",attributes:l.attributes,name:u}),this}}function TJ(e,t,n){e.prototype[t]=function(r,a,o,s){const[l,u,d]=qa(this,t,n,r,a,o,s);if(typeof d!="function")throw new Pe(`Graph.${t}: updater should be a function.`);const p=l.attributes,g=d(p[u]);return p[u]=g,this.emit("nodeAttributesUpdated",{key:l.key,type:"set",attributes:l.attributes,name:u}),this}}function AJ(e,t,n){e.prototype[t]=function(r,a,o){const[s,l]=qa(this,t,n,r,a,o);return delete s.attributes[l],this.emit("nodeAttributesUpdated",{key:s.key,type:"remove",attributes:s.attributes,name:l}),this}}function RJ(e,t,n){e.prototype[t]=function(r,a,o){const[s,l]=qa(this,t,n,r,a,o);if(!vn(l))throw new Pe(`Graph.${t}: provided attributes are not a plain object.`);return s.attributes=l,this.emit("nodeAttributesUpdated",{key:s.key,type:"replace",attributes:s.attributes}),this}}function CJ(e,t,n){e.prototype[t]=function(r,a,o){const[s,l]=qa(this,t,n,r,a,o);if(!vn(l))throw new Pe(`Graph.${t}: provided attributes are not a plain object.`);return nn(s.attributes,l),this.emit("nodeAttributesUpdated",{key:s.key,type:"merge",attributes:s.attributes,data:l}),this}}function _J(e,t,n){e.prototype[t]=function(r,a,o){const[s,l]=qa(this,t,n,r,a,o);if(typeof l!="function")throw new Pe(`Graph.${t}: provided updater is not a function.`);return s.attributes=l(s.attributes),this.emit("nodeAttributesUpdated",{key:s.key,type:"update",attributes:s.attributes}),this}}const NJ=[{name:e=>`get${e}Attribute`,attacher:EJ},{name:e=>`get${e}Attributes`,attacher:wJ},{name:e=>`has${e}Attribute`,attacher:xJ},{name:e=>`set${e}Attribute`,attacher:kJ},{name:e=>`update${e}Attribute`,attacher:TJ},{name:e=>`remove${e}Attribute`,attacher:AJ},{name:e=>`replace${e}Attributes`,attacher:RJ},{name:e=>`merge${e}Attributes`,attacher:CJ},{name:e=>`update${e}Attributes`,attacher:_J}];function OJ(e){NJ.forEach(function({name:t,attacher:n}){n(e,t("Node"),m4),n(e,t("Source"),b4),n(e,t("Target"),SJ),n(e,t("Opposite"),y4)})}function IJ(e,t,n){e.prototype[t]=function(r,a){let o;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const s=""+r,l=""+a;if(a=arguments[2],o=xr(this,s,l,n),!o)throw new Le(`Graph.${t}: could not find an edge for the given path ("${s}" - "${l}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,o=this._edges.get(r),!o)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return o.attributes[a]}}function DJ(e,t,n){e.prototype[t]=function(r){let a;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>1){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const o=""+r,s=""+arguments[1];if(a=xr(this,o,s,n),!a)throw new Le(`Graph.${t}: could not find an edge for the given path ("${o}" - "${s}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,a=this._edges.get(r),!a)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return a.attributes}}function LJ(e,t,n){e.prototype[t]=function(r,a){let o;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const s=""+r,l=""+a;if(a=arguments[2],o=xr(this,s,l,n),!o)throw new Le(`Graph.${t}: could not find an edge for the given path ("${s}" - "${l}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,o=this._edges.get(r),!o)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return o.attributes.hasOwnProperty(a)}}function MJ(e,t,n){e.prototype[t]=function(r,a,o){let s;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>3){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],o=arguments[3],s=xr(this,l,u,n),!s)throw new Le(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,s=this._edges.get(r),!s)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return s.attributes[a]=o,this.emit("edgeAttributesUpdated",{key:s.key,type:"set",attributes:s.attributes,name:a}),this}}function PJ(e,t,n){e.prototype[t]=function(r,a,o){let s;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>3){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],o=arguments[3],s=xr(this,l,u,n),!s)throw new Le(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,s=this._edges.get(r),!s)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(typeof o!="function")throw new Pe(`Graph.${t}: updater should be a function.`);return s.attributes[a]=o(s.attributes[a]),this.emit("edgeAttributesUpdated",{key:s.key,type:"set",attributes:s.attributes,name:a}),this}}function FJ(e,t,n){e.prototype[t]=function(r,a){let o;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const s=""+r,l=""+a;if(a=arguments[2],o=xr(this,s,l,n),!o)throw new Le(`Graph.${t}: could not find an edge for the given path ("${s}" - "${l}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,o=this._edges.get(r),!o)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return delete o.attributes[a],this.emit("edgeAttributesUpdated",{key:o.key,type:"remove",attributes:o.attributes,name:a}),this}}function zJ(e,t,n){e.prototype[t]=function(r,a){let o;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const s=""+r,l=""+a;if(a=arguments[2],o=xr(this,s,l,n),!o)throw new Le(`Graph.${t}: could not find an edge for the given path ("${s}" - "${l}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,o=this._edges.get(r),!o)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(!vn(a))throw new Pe(`Graph.${t}: provided attributes are not a plain object.`);return o.attributes=a,this.emit("edgeAttributesUpdated",{key:o.key,type:"replace",attributes:o.attributes}),this}}function BJ(e,t,n){e.prototype[t]=function(r,a){let o;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const s=""+r,l=""+a;if(a=arguments[2],o=xr(this,s,l,n),!o)throw new Le(`Graph.${t}: could not find an edge for the given path ("${s}" - "${l}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,o=this._edges.get(r),!o)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(!vn(a))throw new Pe(`Graph.${t}: provided attributes are not a plain object.`);return nn(o.attributes,a),this.emit("edgeAttributesUpdated",{key:o.key,type:"merge",attributes:o.attributes,data:a}),this}}function jJ(e,t,n){e.prototype[t]=function(r,a){let o;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const s=""+r,l=""+a;if(a=arguments[2],o=xr(this,s,l,n),!o)throw new Le(`Graph.${t}: could not find an edge for the given path ("${s}" - "${l}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,o=this._edges.get(r),!o)throw new Le(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(typeof a!="function")throw new Pe(`Graph.${t}: provided updater is not a function.`);return o.attributes=a(o.attributes),this.emit("edgeAttributesUpdated",{key:o.key,type:"update",attributes:o.attributes}),this}}const UJ=[{name:e=>`get${e}Attribute`,attacher:IJ},{name:e=>`get${e}Attributes`,attacher:DJ},{name:e=>`has${e}Attribute`,attacher:LJ},{name:e=>`set${e}Attribute`,attacher:MJ},{name:e=>`update${e}Attribute`,attacher:PJ},{name:e=>`remove${e}Attribute`,attacher:FJ},{name:e=>`replace${e}Attributes`,attacher:zJ},{name:e=>`merge${e}Attributes`,attacher:BJ},{name:e=>`update${e}Attributes`,attacher:jJ}];function GJ(e){UJ.forEach(function({name:t,attacher:n}){n(e,t("Edge"),"mixed"),n(e,t("DirectedEdge"),"directed"),n(e,t("UndirectedEdge"),"undirected")})}const HJ=[{name:"edges",type:"mixed"},{name:"inEdges",type:"directed",direction:"in"},{name:"outEdges",type:"directed",direction:"out"},{name:"inboundEdges",type:"mixed",direction:"in"},{name:"outboundEdges",type:"mixed",direction:"out"},{name:"directedEdges",type:"directed"},{name:"undirectedEdges",type:"undirected"}];function $J(e,t,n,r){let a=!1;for(const o in t){if(o===r)continue;const s=t[o];if(a=n(s.key,s.attributes,s.source.key,s.target.key,s.source.attributes,s.target.attributes,s.undirected),e&&a)return s.key}}function qJ(e,t,n,r){let a,o,s,l=!1;for(const u in t)if(u!==r){a=t[u];do{if(o=a.source,s=a.target,l=n(a.key,a.attributes,o.key,s.key,o.attributes,s.attributes,a.undirected),e&&l)return a.key;a=a.next}while(a!==void 0)}}function ym(e,t){const n=Object.keys(e),r=n.length;let a,o=0;return{[Symbol.iterator](){return this},next(){do if(a)a=a.next;else{if(o>=r)return{done:!0};const s=n[o++];if(s===t){a=void 0;continue}a=e[s]}while(!a);return{done:!1,value:{edge:a.key,attributes:a.attributes,source:a.source.key,target:a.target.key,sourceAttributes:a.source.attributes,targetAttributes:a.target.attributes,undirected:a.undirected}}}}}function VJ(e,t,n,r){const a=t[n];if(!a)return;const o=a.source,s=a.target;if(r(a.key,a.attributes,o.key,s.key,o.attributes,s.attributes,a.undirected)&&e)return a.key}function WJ(e,t,n,r){let a=t[n];if(!a)return;let o=!1;do{if(o=r(a.key,a.attributes,a.source.key,a.target.key,a.source.attributes,a.target.attributes,a.undirected),e&&o)return a.key;a=a.next}while(a!==void 0)}function vm(e,t){let n=e[t];if(n.next!==void 0)return{[Symbol.iterator](){return this},next(){if(!n)return{done:!0};const a={edge:n.key,attributes:n.attributes,source:n.source.key,target:n.target.key,sourceAttributes:n.source.attributes,targetAttributes:n.target.attributes,undirected:n.undirected};return n=n.next,{done:!1,value:a}}};let r=!1;return{[Symbol.iterator](){return this},next(){return r===!0?{done:!0}:(r=!0,{done:!1,value:{edge:n.key,attributes:n.attributes,source:n.source.key,target:n.target.key,sourceAttributes:n.source.attributes,targetAttributes:n.target.attributes,undirected:n.undirected}})}}}function YJ(e,t){if(e.size===0)return[];if(t==="mixed"||t===e.type)return Array.from(e._edges.keys());const n=t==="undirected"?e.undirectedSize:e.directedSize,r=new Array(n),a=t==="undirected",o=e._edges.values();let s=0,l,u;for(;l=o.next(),l.done!==!0;)u=l.value,u.undirected===a&&(r[s++]=u.key);return r}function v4(e,t,n,r){if(t.size===0)return;const a=n!=="mixed"&&n!==t.type,o=n==="undirected";let s,l,u=!1;const d=t._edges.values();for(;s=d.next(),s.done!==!0;){if(l=s.value,a&&l.undirected!==o)continue;const{key:p,attributes:g,source:m,target:b}=l;if(u=r(p,g,m.key,b.key,m.attributes,b.attributes,l.undirected),e&&u)return p}}function KJ(e,t){if(e.size===0)return Xs();const n=t!=="mixed"&&t!==e.type,r=t==="undirected",a=e._edges.values();return{[Symbol.iterator](){return this},next(){let o,s;for(;;){if(o=a.next(),o.done)return o;if(s=o.value,!(n&&s.undirected!==r))break}return{value:{edge:s.key,attributes:s.attributes,source:s.source.key,target:s.target.key,sourceAttributes:s.source.attributes,targetAttributes:s.target.attributes,undirected:s.undirected},done:!1}}}}function RT(e,t,n,r,a,o){const s=t?qJ:$J;let l;if(n!=="undirected"&&(r!=="out"&&(l=s(e,a.in,o),e&&l)||r!=="in"&&(l=s(e,a.out,o,r?void 0:a.key),e&&l))||n!=="directed"&&(l=s(e,a.undirected,o),e&&l))return l}function XJ(e,t,n,r){const a=[];return RT(!1,e,t,n,r,function(o){a.push(o)}),a}function ZJ(e,t,n){let r=Xs();return e!=="undirected"&&(t!=="out"&&typeof n.in<"u"&&(r=za(r,ym(n.in))),t!=="in"&&typeof n.out<"u"&&(r=za(r,ym(n.out,t?void 0:n.key)))),e!=="directed"&&typeof n.undirected<"u"&&(r=za(r,ym(n.undirected))),r}function CT(e,t,n,r,a,o,s){const l=n?WJ:VJ;let u;if(t!=="undirected"&&(typeof a.in<"u"&&r!=="out"&&(u=l(e,a.in,o,s),e&&u)||typeof a.out<"u"&&r!=="in"&&(r||a.key!==o)&&(u=l(e,a.out,o,s),e&&u))||t!=="directed"&&typeof a.undirected<"u"&&(u=l(e,a.undirected,o,s),e&&u))return u}function QJ(e,t,n,r,a){const o=[];return CT(!1,e,t,n,r,a,function(s){o.push(s)}),o}function JJ(e,t,n,r){let a=Xs();return e!=="undirected"&&(typeof n.in<"u"&&t!=="out"&&r in n.in&&(a=za(a,vm(n.in,r))),typeof n.out<"u"&&t!=="in"&&r in n.out&&(t||n.key!==r)&&(a=za(a,vm(n.out,r)))),e!=="directed"&&typeof n.undirected<"u"&&r in n.undirected&&(a=za(a,vm(n.undirected,r))),a}function eee(e,t){const{name:n,type:r,direction:a}=t;e.prototype[n]=function(o,s){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return[];if(!arguments.length)return YJ(this,r);if(arguments.length===1){o=""+o;const l=this._nodes.get(o);if(typeof l>"u")throw new Le(`Graph.${n}: could not find the "${o}" node in the graph.`);return XJ(this.multi,r==="mixed"?this.type:r,a,l)}if(arguments.length===2){o=""+o,s=""+s;const l=this._nodes.get(o);if(!l)throw new Le(`Graph.${n}:  could not find the "${o}" source node in the graph.`);if(!this._nodes.has(s))throw new Le(`Graph.${n}:  could not find the "${s}" target node in the graph.`);return QJ(r,this.multi,a,l,s)}throw new Pe(`Graph.${n}: too many arguments (expecting 0, 1 or 2 and got ${arguments.length}).`)}}function tee(e,t){const{name:n,type:r,direction:a}=t,o="forEach"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[o]=function(d,p,g){if(!(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)){if(arguments.length===1)return g=d,v4(!1,this,r,g);if(arguments.length===2){d=""+d,g=p;const m=this._nodes.get(d);if(typeof m>"u")throw new Le(`Graph.${o}: could not find the "${d}" node in the graph.`);return RT(!1,this.multi,r==="mixed"?this.type:r,a,m,g)}if(arguments.length===3){d=""+d,p=""+p;const m=this._nodes.get(d);if(!m)throw new Le(`Graph.${o}:  could not find the "${d}" source node in the graph.`);if(!this._nodes.has(p))throw new Le(`Graph.${o}:  could not find the "${p}" target node in the graph.`);return CT(!1,r,this.multi,a,m,p,g)}throw new Pe(`Graph.${o}: too many arguments (expecting 1, 2 or 3 and got ${arguments.length}).`)}};const s="map"+n[0].toUpperCase()+n.slice(1);e.prototype[s]=function(){const d=Array.prototype.slice.call(arguments),p=d.pop();let g;if(d.length===0){let m=0;r!=="directed"&&(m+=this.undirectedSize),r!=="undirected"&&(m+=this.directedSize),g=new Array(m);let b=0;d.push((v,y,k,A,x,R,O)=>{g[b++]=p(v,y,k,A,x,R,O)})}else g=[],d.push((m,b,v,y,k,A,x)=>{g.push(p(m,b,v,y,k,A,x))});return this[o].apply(this,d),g};const l="filter"+n[0].toUpperCase()+n.slice(1);e.prototype[l]=function(){const d=Array.prototype.slice.call(arguments),p=d.pop(),g=[];return d.push((m,b,v,y,k,A,x)=>{p(m,b,v,y,k,A,x)&&g.push(m)}),this[o].apply(this,d),g};const u="reduce"+n[0].toUpperCase()+n.slice(1);e.prototype[u]=function(){let d=Array.prototype.slice.call(arguments);if(d.length<2||d.length>4)throw new Pe(`Graph.${u}: invalid number of arguments (expecting 2, 3 or 4 and got ${d.length}).`);if(typeof d[d.length-1]=="function"&&typeof d[d.length-2]!="function")throw new Pe(`Graph.${u}: missing initial value. You must provide it because the callback takes more than one argument and we cannot infer the initial value from the first iteration, as you could with a simple array.`);let p,g;d.length===2?(p=d[0],g=d[1],d=[]):d.length===3?(p=d[1],g=d[2],d=[d[0]]):d.length===4&&(p=d[2],g=d[3],d=[d[0],d[1]]);let m=g;return d.push((b,v,y,k,A,x,R)=>{m=p(m,b,v,y,k,A,x,R)}),this[o].apply(this,d),m}}function nee(e,t){const{name:n,type:r,direction:a}=t,o="find"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[o]=function(u,d,p){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return!1;if(arguments.length===1)return p=u,v4(!0,this,r,p);if(arguments.length===2){u=""+u,p=d;const g=this._nodes.get(u);if(typeof g>"u")throw new Le(`Graph.${o}: could not find the "${u}" node in the graph.`);return RT(!0,this.multi,r==="mixed"?this.type:r,a,g,p)}if(arguments.length===3){u=""+u,d=""+d;const g=this._nodes.get(u);if(!g)throw new Le(`Graph.${o}:  could not find the "${u}" source node in the graph.`);if(!this._nodes.has(d))throw new Le(`Graph.${o}:  could not find the "${d}" target node in the graph.`);return CT(!0,r,this.multi,a,g,d,p)}throw new Pe(`Graph.${o}: too many arguments (expecting 1, 2 or 3 and got ${arguments.length}).`)};const s="some"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[s]=function(){const u=Array.prototype.slice.call(arguments),d=u.pop();return u.push((g,m,b,v,y,k,A)=>d(g,m,b,v,y,k,A)),!!this[o].apply(this,u)};const l="every"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[l]=function(){const u=Array.prototype.slice.call(arguments),d=u.pop();return u.push((g,m,b,v,y,k,A)=>!d(g,m,b,v,y,k,A)),!this[o].apply(this,u)}}function ree(e,t){const{name:n,type:r,direction:a}=t,o=n.slice(0,-1)+"Entries";e.prototype[o]=function(s,l){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return Xs();if(!arguments.length)return KJ(this,r);if(arguments.length===1){s=""+s;const u=this._nodes.get(s);if(!u)throw new Le(`Graph.${o}: could not find the "${s}" node in the graph.`);return ZJ(r,a,u)}if(arguments.length===2){s=""+s,l=""+l;const u=this._nodes.get(s);if(!u)throw new Le(`Graph.${o}:  could not find the "${s}" source node in the graph.`);if(!this._nodes.has(l))throw new Le(`Graph.${o}:  could not find the "${l}" target node in the graph.`);return JJ(r,a,u,l)}throw new Pe(`Graph.${o}: too many arguments (expecting 0, 1 or 2 and got ${arguments.length}).`)}}function aee(e){HJ.forEach(t=>{eee(e,t),tee(e,t),nee(e,t),ree(e,t)})}const oee=[{name:"neighbors",type:"mixed"},{name:"inNeighbors",type:"directed",direction:"in"},{name:"outNeighbors",type:"directed",direction:"out"},{name:"inboundNeighbors",type:"mixed",direction:"in"},{name:"outboundNeighbors",type:"mixed",direction:"out"},{name:"directedNeighbors",type:"directed"},{name:"undirectedNeighbors",type:"undirected"}];function xp(){this.A=null,this.B=null}xp.prototype.wrap=function(e){this.A===null?this.A=e:this.B===null&&(this.B=e)};xp.prototype.has=function(e){return this.A!==null&&e in this.A||this.B!==null&&e in this.B};function nc(e,t,n,r,a){for(const o in r){const s=r[o],l=s.source,u=s.target,d=l===n?u:l;if(t&&t.has(d.key))continue;const p=a(d.key,d.attributes);if(e&&p)return d.key}}function _T(e,t,n,r,a){if(t!=="mixed"){if(t==="undirected")return nc(e,null,r,r.undirected,a);if(typeof n=="string")return nc(e,null,r,r[n],a)}const o=new xp;let s;if(t!=="undirected"){if(n!=="out"){if(s=nc(e,null,r,r.in,a),e&&s)return s;o.wrap(r.in)}if(n!=="in"){if(s=nc(e,o,r,r.out,a),e&&s)return s;o.wrap(r.out)}}if(t!=="directed"&&(s=nc(e,o,r,r.undirected,a),e&&s))return s}function iee(e,t,n){if(e!=="mixed"){if(e==="undirected")return Object.keys(n.undirected);if(typeof t=="string")return Object.keys(n[t])}const r=[];return _T(!1,e,t,n,function(a){r.push(a)}),r}function rc(e,t,n){const r=Object.keys(n),a=r.length;let o=0;return{[Symbol.iterator](){return this},next(){let s=null;do{if(o>=a)return e&&e.wrap(n),{done:!0};const l=n[r[o++]],u=l.source,d=l.target;if(s=u===t?d:u,e&&e.has(s.key)){s=null;continue}}while(s===null);return{done:!1,value:{neighbor:s.key,attributes:s.attributes}}}}}function see(e,t,n){if(e!=="mixed"){if(e==="undirected")return rc(null,n,n.undirected);if(typeof t=="string")return rc(null,n,n[t])}let r=Xs();const a=new xp;return e!=="undirected"&&(t!=="out"&&(r=za(r,rc(a,n,n.in))),t!=="in"&&(r=za(r,rc(a,n,n.out)))),e!=="directed"&&(r=za(r,rc(a,n,n.undirected))),r}function lee(e,t){const{name:n,type:r,direction:a}=t;e.prototype[n]=function(o){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return[];o=""+o;const s=this._nodes.get(o);if(typeof s>"u")throw new Le(`Graph.${n}: could not find the "${o}" node in the graph.`);return iee(r==="mixed"?this.type:r,a,s)}}function cee(e,t){const{name:n,type:r,direction:a}=t,o="forEach"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[o]=function(d,p){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return;d=""+d;const g=this._nodes.get(d);if(typeof g>"u")throw new Le(`Graph.${o}: could not find the "${d}" node in the graph.`);_T(!1,r==="mixed"?this.type:r,a,g,p)};const s="map"+n[0].toUpperCase()+n.slice(1);e.prototype[s]=function(d,p){const g=[];return this[o](d,(m,b)=>{g.push(p(m,b))}),g};const l="filter"+n[0].toUpperCase()+n.slice(1);e.prototype[l]=function(d,p){const g=[];return this[o](d,(m,b)=>{p(m,b)&&g.push(m)}),g};const u="reduce"+n[0].toUpperCase()+n.slice(1);e.prototype[u]=function(d,p,g){if(arguments.length<3)throw new Pe(`Graph.${u}: missing initial value. You must provide it because the callback takes more than one argument and we cannot infer the initial value from the first iteration, as you could with a simple array.`);let m=g;return this[o](d,(b,v)=>{m=p(m,b,v)}),m}}function uee(e,t){const{name:n,type:r,direction:a}=t,o=n[0].toUpperCase()+n.slice(1,-1),s="find"+o;e.prototype[s]=function(d,p){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return;d=""+d;const g=this._nodes.get(d);if(typeof g>"u")throw new Le(`Graph.${s}: could not find the "${d}" node in the graph.`);return _T(!0,r==="mixed"?this.type:r,a,g,p)};const l="some"+o;e.prototype[l]=function(d,p){return!!this[s](d,p)};const u="every"+o;e.prototype[u]=function(d,p){return!this[s](d,(m,b)=>!p(m,b))}}function dee(e,t){const{name:n,type:r,direction:a}=t,o=n.slice(0,-1)+"Entries";e.prototype[o]=function(s){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return Xs();s=""+s;const l=this._nodes.get(s);if(typeof l>"u")throw new Le(`Graph.${o}: could not find the "${s}" node in the graph.`);return see(r==="mixed"?this.type:r,a,l)}}function fee(e){oee.forEach(t=>{lee(e,t),cee(e,t),uee(e,t),dee(e,t)})}function _d(e,t,n,r,a){const o=r._nodes.values(),s=r.type;let l,u,d,p,g,m;for(;l=o.next(),l.done!==!0;){let b=!1;if(u=l.value,s!=="undirected"){p=u.out;for(d in p){g=p[d];do m=g.target,b=!0,a(u.key,m.key,u.attributes,m.attributes,g.key,g.attributes,g.undirected),g=g.next;while(g)}}if(s!=="directed"){p=u.undirected;for(d in p)if(!(t&&u.key>d)){g=p[d];do m=g.target,m.key!==d&&(m=g.source),b=!0,a(u.key,m.key,u.attributes,m.attributes,g.key,g.attributes,g.undirected),g=g.next;while(g)}}n&&!b&&a(u.key,null,u.attributes,null,null,null,null)}}function pee(e,t){const n={key:e};return f4(t.attributes)||(n.attributes=nn({},t.attributes)),n}function gee(e,t,n){const r={key:t,source:n.source.key,target:n.target.key};return f4(n.attributes)||(r.attributes=nn({},n.attributes)),e==="mixed"&&n.undirected&&(r.undirected=!0),r}function hee(e){if(!vn(e))throw new Pe('Graph.import: invalid serialized node. A serialized node should be a plain object with at least a "key" property.');if(!("key"in e))throw new Pe("Graph.import: serialized node is missing its key.");if("attributes"in e&&(!vn(e.attributes)||e.attributes===null))throw new Pe("Graph.import: invalid attributes. Attributes should be a plain object, null or omitted.")}function mee(e){if(!vn(e))throw new Pe('Graph.import: invalid serialized edge. A serialized edge should be a plain object with at least a "source" & "target" property.');if(!("source"in e))throw new Pe("Graph.import: serialized edge is missing its source.");if(!("target"in e))throw new Pe("Graph.import: serialized edge is missing its target.");if("attributes"in e&&(!vn(e.attributes)||e.attributes===null))throw new Pe("Graph.import: invalid attributes. Attributes should be a plain object, null or omitted.");if("undirected"in e&&typeof e.undirected!="boolean")throw new Pe("Graph.import: invalid undirectedness information. Undirected should be boolean or omitted.")}const bee=vJ(),yee=new Set(["directed","undirected","mixed"]),mN=new Set(["domain","_events","_eventsCount","_maxListeners"]),vee=[{name:e=>`${e}Edge`,generateKey:!0},{name:e=>`${e}DirectedEdge`,generateKey:!0,type:"directed"},{name:e=>`${e}UndirectedEdge`,generateKey:!0,type:"undirected"},{name:e=>`${e}EdgeWithKey`},{name:e=>`${e}DirectedEdgeWithKey`,type:"directed"},{name:e=>`${e}UndirectedEdgeWithKey`,type:"undirected"}],See={allowSelfLoops:!0,multi:!1,type:"mixed"};function Eee(e,t,n){if(n&&!vn(n))throw new Pe(`Graph.addNode: invalid attributes. Expecting an object but got "${n}"`);if(t=""+t,n=n||{},e._nodes.has(t))throw new Ze(`Graph.addNode: the "${t}" node already exist in the graph.`);const r=new e.NodeDataClass(t,n);return e._nodes.set(t,r),e.emit("nodeAdded",{key:t,attributes:n}),r}function bN(e,t,n){const r=new e.NodeDataClass(t,n);return e._nodes.set(t,r),e.emit("nodeAdded",{key:t,attributes:n}),r}function S4(e,t,n,r,a,o,s,l){if(!r&&e.type==="undirected")throw new Ze(`Graph.${t}: you cannot add a directed edge to an undirected graph. Use the #.addEdge or #.addUndirectedEdge instead.`);if(r&&e.type==="directed")throw new Ze(`Graph.${t}: you cannot add an undirected edge to a directed graph. Use the #.addEdge or #.addDirectedEdge instead.`);if(l&&!vn(l))throw new Pe(`Graph.${t}: invalid attributes. Expecting an object but got "${l}"`);if(o=""+o,s=""+s,l=l||{},!e.allowSelfLoops&&o===s)throw new Ze(`Graph.${t}: source & target are the same ("${o}"), thus creating a loop explicitly forbidden by this graph 'allowSelfLoops' option set to false.`);const u=e._nodes.get(o),d=e._nodes.get(s);if(!u)throw new Le(`Graph.${t}: source node "${o}" not found.`);if(!d)throw new Le(`Graph.${t}: target node "${s}" not found.`);const p={key:null,undirected:r,source:o,target:s,attributes:l};if(n)a=e._edgeKeyGenerator();else if(a=""+a,e._edges.has(a))throw new Ze(`Graph.${t}: the "${a}" edge already exists in the graph.`);if(!e.multi&&(r?typeof u.undirected[s]<"u":typeof u.out[s]<"u"))throw new Ze(`Graph.${t}: an edge linking "${o}" to "${s}" already exists. If you really want to add multiple edges linking those nodes, you should create a multi graph by using the 'multi' option.`);const g=new Zs(r,a,u,d,l);e._edges.set(a,g);const m=o===s;return r?(u.undirectedDegree++,d.undirectedDegree++,m&&(u.undirectedLoops++,e._undirectedSelfLoopCount++)):(u.outDegree++,d.inDegree++,m&&(u.directedLoops++,e._directedSelfLoopCount++)),e.multi?g.attachMulti():g.attach(),r?e._undirectedSize++:e._directedSize++,p.key=a,e.emit("edgeAdded",p),a}function wee(e,t,n,r,a,o,s,l,u){if(!r&&e.type==="undirected")throw new Ze(`Graph.${t}: you cannot merge/update a directed edge to an undirected graph. Use the #.mergeEdge/#.updateEdge or #.addUndirectedEdge instead.`);if(r&&e.type==="directed")throw new Ze(`Graph.${t}: you cannot merge/update an undirected edge to a directed graph. Use the #.mergeEdge/#.updateEdge or #.addDirectedEdge instead.`);if(l){if(u){if(typeof l!="function")throw new Pe(`Graph.${t}: invalid updater function. Expecting a function but got "${l}"`)}else if(!vn(l))throw new Pe(`Graph.${t}: invalid attributes. Expecting an object but got "${l}"`)}o=""+o,s=""+s;let d;if(u&&(d=l,l=void 0),!e.allowSelfLoops&&o===s)throw new Ze(`Graph.${t}: source & target are the same ("${o}"), thus creating a loop explicitly forbidden by this graph 'allowSelfLoops' option set to false.`);let p=e._nodes.get(o),g=e._nodes.get(s),m,b;if(!n&&(m=e._edges.get(a),m)){if((m.source.key!==o||m.target.key!==s)&&(!r||m.source.key!==s||m.target.key!==o))throw new Ze(`Graph.${t}: inconsistency detected when attempting to merge the "${a}" edge with "${o}" source & "${s}" target vs. ("${m.source.key}", "${m.target.key}").`);b=m}if(!b&&!e.multi&&p&&(b=r?p.undirected[s]:p.out[s]),b){const x=[b.key,!1,!1,!1];if(u?!d:!l)return x;if(u){const R=b.attributes;b.attributes=d(R),e.emit("edgeAttributesUpdated",{type:"replace",key:b.key,attributes:b.attributes})}else nn(b.attributes,l),e.emit("edgeAttributesUpdated",{type:"merge",key:b.key,attributes:b.attributes,data:l});return x}l=l||{},u&&d&&(l=d(l));const v={key:null,undirected:r,source:o,target:s,attributes:l};if(n)a=e._edgeKeyGenerator();else if(a=""+a,e._edges.has(a))throw new Ze(`Graph.${t}: the "${a}" edge already exists in the graph.`);let y=!1,k=!1;p||(p=bN(e,o,{}),y=!0,o===s&&(g=p,k=!0)),g||(g=bN(e,s,{}),k=!0),m=new Zs(r,a,p,g,l),e._edges.set(a,m);const A=o===s;return r?(p.undirectedDegree++,g.undirectedDegree++,A&&(p.undirectedLoops++,e._undirectedSelfLoopCount++)):(p.outDegree++,g.inDegree++,A&&(p.directedLoops++,e._directedSelfLoopCount++)),e.multi?m.attachMulti():m.attach(),r?e._undirectedSize++:e._directedSize++,v.key=a,e.emit("edgeAdded",v),[a,!0,y,k]}function gs(e,t){e._edges.delete(t.key);const{source:n,target:r,attributes:a}=t,o=t.undirected,s=n===r;o?(n.undirectedDegree--,r.undirectedDegree--,s&&(n.undirectedLoops--,e._undirectedSelfLoopCount--)):(n.outDegree--,r.inDegree--,s&&(n.directedLoops--,e._directedSelfLoopCount--)),e.multi?t.detachMulti():t.detach(),o?e._undirectedSize--:e._directedSize--,e.emit("edgeDropped",{key:t.key,attributes:a,source:n.key,target:r.key,undirected:o})}class _t extends d4.EventEmitter{constructor(t){if(super(),t=nn({},See,t),typeof t.multi!="boolean")throw new Pe(`Graph.constructor: invalid 'multi' option. Expecting a boolean but got "${t.multi}".`);if(!yee.has(t.type))throw new Pe(`Graph.constructor: invalid 'type' option. Should be one of "mixed", "directed" or "undirected" but got "${t.type}".`);if(typeof t.allowSelfLoops!="boolean")throw new Pe(`Graph.constructor: invalid 'allowSelfLoops' option. Expecting a boolean but got "${t.allowSelfLoops}".`);const n=t.type==="mixed"?p4:t.type==="directed"?g4:h4;vr(this,"NodeDataClass",n);const r="geid_"+bee()+"_";let a=0;const o=()=>{let s;do s=r+a++;while(this._edges.has(s));return s};vr(this,"_attributes",{}),vr(this,"_nodes",new Map),vr(this,"_edges",new Map),vr(this,"_directedSize",0),vr(this,"_undirectedSize",0),vr(this,"_directedSelfLoopCount",0),vr(this,"_undirectedSelfLoopCount",0),vr(this,"_edgeKeyGenerator",o),vr(this,"_options",t),mN.forEach(s=>vr(this,s,this[s])),Mr(this,"order",()=>this._nodes.size),Mr(this,"size",()=>this._edges.size),Mr(this,"directedSize",()=>this._directedSize),Mr(this,"undirectedSize",()=>this._undirectedSize),Mr(this,"selfLoopCount",()=>this._directedSelfLoopCount+this._undirectedSelfLoopCount),Mr(this,"directedSelfLoopCount",()=>this._directedSelfLoopCount),Mr(this,"undirectedSelfLoopCount",()=>this._undirectedSelfLoopCount),Mr(this,"multi",this._options.multi),Mr(this,"type",this._options.type),Mr(this,"allowSelfLoops",this._options.allowSelfLoops),Mr(this,"implementation",()=>"graphology")}_resetInstanceCounters(){this._directedSize=0,this._undirectedSize=0,this._directedSelfLoopCount=0,this._undirectedSelfLoopCount=0}hasNode(t){return this._nodes.has(""+t)}hasDirectedEdge(t,n){if(this.type==="undirected")return!1;if(arguments.length===1){const r=""+t,a=this._edges.get(r);return!!a&&!a.undirected}else if(arguments.length===2){t=""+t,n=""+n;const r=this._nodes.get(t);return r?r.out.hasOwnProperty(n):!1}throw new Pe(`Graph.hasDirectedEdge: invalid arity (${arguments.length}, instead of 1 or 2). You can either ask for an edge id or for the existence of an edge between a source & a target.`)}hasUndirectedEdge(t,n){if(this.type==="directed")return!1;if(arguments.length===1){const r=""+t,a=this._edges.get(r);return!!a&&a.undirected}else if(arguments.length===2){t=""+t,n=""+n;const r=this._nodes.get(t);return r?r.undirected.hasOwnProperty(n):!1}throw new Pe(`Graph.hasDirectedEdge: invalid arity (${arguments.length}, instead of 1 or 2). You can either ask for an edge id or for the existence of an edge between a source & a target.`)}hasEdge(t,n){if(arguments.length===1){const r=""+t;return this._edges.has(r)}else if(arguments.length===2){t=""+t,n=""+n;const r=this._nodes.get(t);return r?typeof r.out<"u"&&r.out.hasOwnProperty(n)||typeof r.undirected<"u"&&r.undirected.hasOwnProperty(n):!1}throw new Pe(`Graph.hasEdge: invalid arity (${arguments.length}, instead of 1 or 2). You can either ask for an edge id or for the existence of an edge between a source & a target.`)}directedEdge(t,n){if(this.type==="undirected")return;if(t=""+t,n=""+n,this.multi)throw new Ze("Graph.directedEdge: this method is irrelevant with multigraphs since there might be multiple edges between source & target. See #.directedEdges instead.");const r=this._nodes.get(t);if(!r)throw new Le(`Graph.directedEdge: could not find the "${t}" source node in the graph.`);if(!this._nodes.has(n))throw new Le(`Graph.directedEdge: could not find the "${n}" target node in the graph.`);const a=r.out&&r.out[n]||void 0;if(a)return a.key}undirectedEdge(t,n){if(this.type==="directed")return;if(t=""+t,n=""+n,this.multi)throw new Ze("Graph.undirectedEdge: this method is irrelevant with multigraphs since there might be multiple edges between source & target. See #.undirectedEdges instead.");const r=this._nodes.get(t);if(!r)throw new Le(`Graph.undirectedEdge: could not find the "${t}" source node in the graph.`);if(!this._nodes.has(n))throw new Le(`Graph.undirectedEdge: could not find the "${n}" target node in the graph.`);const a=r.undirected&&r.undirected[n]||void 0;if(a)return a.key}edge(t,n){if(this.multi)throw new Ze("Graph.edge: this method is irrelevant with multigraphs since there might be multiple edges between source & target. See #.edges instead.");t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.edge: could not find the "${t}" source node in the graph.`);if(!this._nodes.has(n))throw new Le(`Graph.edge: could not find the "${n}" target node in the graph.`);const a=r.out&&r.out[n]||r.undirected&&r.undirected[n]||void 0;if(a)return a.key}areDirectedNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.areDirectedNeighbors: could not find the "${t}" node in the graph.`);return this.type==="undirected"?!1:n in r.in||n in r.out}areOutNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.areOutNeighbors: could not find the "${t}" node in the graph.`);return this.type==="undirected"?!1:n in r.out}areInNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.areInNeighbors: could not find the "${t}" node in the graph.`);return this.type==="undirected"?!1:n in r.in}areUndirectedNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.areUndirectedNeighbors: could not find the "${t}" node in the graph.`);return this.type==="directed"?!1:n in r.undirected}areNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.areNeighbors: could not find the "${t}" node in the graph.`);return this.type!=="undirected"&&(n in r.in||n in r.out)||this.type!=="directed"&&n in r.undirected}areInboundNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.areInboundNeighbors: could not find the "${t}" node in the graph.`);return this.type!=="undirected"&&n in r.in||this.type!=="directed"&&n in r.undirected}areOutboundNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new Le(`Graph.areOutboundNeighbors: could not find the "${t}" node in the graph.`);return this.type!=="undirected"&&n in r.out||this.type!=="directed"&&n in r.undirected}inDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.inDegree: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree}outDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.outDegree: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.outDegree}directedDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.directedDegree: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree+n.outDegree}undirectedDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.undirectedDegree: could not find the "${t}" node in the graph.`);return this.type==="directed"?0:n.undirectedDegree}inboundDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.inboundDegree: could not find the "${t}" node in the graph.`);let r=0;return this.type!=="directed"&&(r+=n.undirectedDegree),this.type!=="undirected"&&(r+=n.inDegree),r}outboundDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.outboundDegree: could not find the "${t}" node in the graph.`);let r=0;return this.type!=="directed"&&(r+=n.undirectedDegree),this.type!=="undirected"&&(r+=n.outDegree),r}degree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.degree: could not find the "${t}" node in the graph.`);let r=0;return this.type!=="directed"&&(r+=n.undirectedDegree),this.type!=="undirected"&&(r+=n.inDegree+n.outDegree),r}inDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.inDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree-n.directedLoops}outDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.outDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.outDegree-n.directedLoops}directedDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.directedDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree+n.outDegree-n.directedLoops*2}undirectedDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.undirectedDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="directed"?0:n.undirectedDegree-n.undirectedLoops*2}inboundDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.inboundDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);let r=0,a=0;return this.type!=="directed"&&(r+=n.undirectedDegree,a+=n.undirectedLoops*2),this.type!=="undirected"&&(r+=n.inDegree,a+=n.directedLoops),r-a}outboundDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.outboundDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);let r=0,a=0;return this.type!=="directed"&&(r+=n.undirectedDegree,a+=n.undirectedLoops*2),this.type!=="undirected"&&(r+=n.outDegree,a+=n.directedLoops),r-a}degreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.degreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);let r=0,a=0;return this.type!=="directed"&&(r+=n.undirectedDegree,a+=n.undirectedLoops*2),this.type!=="undirected"&&(r+=n.inDegree+n.outDegree,a+=n.directedLoops*2),r-a}source(t){t=""+t;const n=this._edges.get(t);if(!n)throw new Le(`Graph.source: could not find the "${t}" edge in the graph.`);return n.source.key}target(t){t=""+t;const n=this._edges.get(t);if(!n)throw new Le(`Graph.target: could not find the "${t}" edge in the graph.`);return n.target.key}extremities(t){t=""+t;const n=this._edges.get(t);if(!n)throw new Le(`Graph.extremities: could not find the "${t}" edge in the graph.`);return[n.source.key,n.target.key]}opposite(t,n){t=""+t,n=""+n;const r=this._edges.get(n);if(!r)throw new Le(`Graph.opposite: could not find the "${n}" edge in the graph.`);const a=r.source.key,o=r.target.key;if(t===a)return o;if(t===o)return a;throw new Le(`Graph.opposite: the "${t}" node is not attached to the "${n}" edge (${a}, ${o}).`)}hasExtremity(t,n){t=""+t,n=""+n;const r=this._edges.get(t);if(!r)throw new Le(`Graph.hasExtremity: could not find the "${t}" edge in the graph.`);return r.source.key===n||r.target.key===n}isUndirected(t){t=""+t;const n=this._edges.get(t);if(!n)throw new Le(`Graph.isUndirected: could not find the "${t}" edge in the graph.`);return n.undirected}isDirected(t){t=""+t;const n=this._edges.get(t);if(!n)throw new Le(`Graph.isDirected: could not find the "${t}" edge in the graph.`);return!n.undirected}isSelfLoop(t){t=""+t;const n=this._edges.get(t);if(!n)throw new Le(`Graph.isSelfLoop: could not find the "${t}" edge in the graph.`);return n.source===n.target}addNode(t,n){return Eee(this,t,n).key}mergeNode(t,n){if(n&&!vn(n))throw new Pe(`Graph.mergeNode: invalid attributes. Expecting an object but got "${n}"`);t=""+t,n=n||{};let r=this._nodes.get(t);return r?(n&&(nn(r.attributes,n),this.emit("nodeAttributesUpdated",{type:"merge",key:t,attributes:r.attributes,data:n})),[t,!1]):(r=new this.NodeDataClass(t,n),this._nodes.set(t,r),this.emit("nodeAdded",{key:t,attributes:n}),[t,!0])}updateNode(t,n){if(n&&typeof n!="function")throw new Pe(`Graph.updateNode: invalid updater function. Expecting a function but got "${n}"`);t=""+t;let r=this._nodes.get(t);if(r){if(n){const o=r.attributes;r.attributes=n(o),this.emit("nodeAttributesUpdated",{type:"replace",key:t,attributes:r.attributes})}return[t,!1]}const a=n?n({}):{};return r=new this.NodeDataClass(t,a),this._nodes.set(t,r),this.emit("nodeAdded",{key:t,attributes:a}),[t,!0]}dropNode(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new Le(`Graph.dropNode: could not find the "${t}" node in the graph.`);let r;if(this.type!=="undirected"){for(const a in n.out){r=n.out[a];do gs(this,r),r=r.next;while(r)}for(const a in n.in){r=n.in[a];do gs(this,r),r=r.next;while(r)}}if(this.type!=="directed")for(const a in n.undirected){r=n.undirected[a];do gs(this,r),r=r.next;while(r)}this._nodes.delete(t),this.emit("nodeDropped",{key:t,attributes:n.attributes})}dropEdge(t){let n;if(arguments.length>1){const r=""+arguments[0],a=""+arguments[1];if(n=xr(this,r,a,this.type),!n)throw new Le(`Graph.dropEdge: could not find the "${r}" -> "${a}" edge in the graph.`)}else if(t=""+t,n=this._edges.get(t),!n)throw new Le(`Graph.dropEdge: could not find the "${t}" edge in the graph.`);return gs(this,n),this}dropDirectedEdge(t,n){if(arguments.length<2)throw new Ze("Graph.dropDirectedEdge: it does not make sense to try and drop a directed edge by key. What if the edge with this key is undirected? Use #.dropEdge for this purpose instead.");if(this.multi)throw new Ze("Graph.dropDirectedEdge: cannot use a {source,target} combo when dropping an edge in a MultiGraph since we cannot infer the one you want to delete as there could be multiple ones.");t=""+t,n=""+n;const r=xr(this,t,n,"directed");if(!r)throw new Le(`Graph.dropDirectedEdge: could not find a "${t}" -> "${n}" edge in the graph.`);return gs(this,r),this}dropUndirectedEdge(t,n){if(arguments.length<2)throw new Ze("Graph.dropUndirectedEdge: it does not make sense to drop a directed edge by key. What if the edge with this key is undirected? Use #.dropEdge for this purpose instead.");if(this.multi)throw new Ze("Graph.dropUndirectedEdge: cannot use a {source,target} combo when dropping an edge in a MultiGraph since we cannot infer the one you want to delete as there could be multiple ones.");const r=xr(this,t,n,"undirected");if(!r)throw new Le(`Graph.dropUndirectedEdge: could not find a "${t}" -> "${n}" edge in the graph.`);return gs(this,r),this}clear(){this._edges.clear(),this._nodes.clear(),this._resetInstanceCounters(),this.emit("cleared")}clearEdges(){const t=this._nodes.values();let n;for(;n=t.next(),n.done!==!0;)n.value.clear();this._edges.clear(),this._resetInstanceCounters(),this.emit("edgesCleared")}getAttribute(t){return this._attributes[t]}getAttributes(){return this._attributes}hasAttribute(t){return this._attributes.hasOwnProperty(t)}setAttribute(t,n){return this._attributes[t]=n,this.emit("attributesUpdated",{type:"set",attributes:this._attributes,name:t}),this}updateAttribute(t,n){if(typeof n!="function")throw new Pe("Graph.updateAttribute: updater should be a function.");const r=this._attributes[t];return this._attributes[t]=n(r),this.emit("attributesUpdated",{type:"set",attributes:this._attributes,name:t}),this}removeAttribute(t){return delete this._attributes[t],this.emit("attributesUpdated",{type:"remove",attributes:this._attributes,name:t}),this}replaceAttributes(t){if(!vn(t))throw new Pe("Graph.replaceAttributes: provided attributes are not a plain object.");return this._attributes=t,this.emit("attributesUpdated",{type:"replace",attributes:this._attributes}),this}mergeAttributes(t){if(!vn(t))throw new Pe("Graph.mergeAttributes: provided attributes are not a plain object.");return nn(this._attributes,t),this.emit("attributesUpdated",{type:"merge",attributes:this._attributes,data:t}),this}updateAttributes(t){if(typeof t!="function")throw new Pe("Graph.updateAttributes: provided updater is not a function.");return this._attributes=t(this._attributes),this.emit("attributesUpdated",{type:"update",attributes:this._attributes}),this}updateEachNodeAttributes(t,n){if(typeof t!="function")throw new Pe("Graph.updateEachNodeAttributes: expecting an updater function.");if(n&&!hN(n))throw new Pe("Graph.updateEachNodeAttributes: invalid hints. Expecting an object having the following shape: {attributes?: [string]}");const r=this._nodes.values();let a,o;for(;a=r.next(),a.done!==!0;)o=a.value,o.attributes=t(o.key,o.attributes);this.emit("eachNodeAttributesUpdated",{hints:n||null})}updateEachEdgeAttributes(t,n){if(typeof t!="function")throw new Pe("Graph.updateEachEdgeAttributes: expecting an updater function.");if(n&&!hN(n))throw new Pe("Graph.updateEachEdgeAttributes: invalid hints. Expecting an object having the following shape: {attributes?: [string]}");const r=this._edges.values();let a,o,s,l;for(;a=r.next(),a.done!==!0;)o=a.value,s=o.source,l=o.target,o.attributes=t(o.key,o.attributes,s.key,l.key,s.attributes,l.attributes,o.undirected);this.emit("eachEdgeAttributesUpdated",{hints:n||null})}forEachAdjacencyEntry(t){if(typeof t!="function")throw new Pe("Graph.forEachAdjacencyEntry: expecting a callback.");_d(!1,!1,!1,this,t)}forEachAdjacencyEntryWithOrphans(t){if(typeof t!="function")throw new Pe("Graph.forEachAdjacencyEntryWithOrphans: expecting a callback.");_d(!1,!1,!0,this,t)}forEachAssymetricAdjacencyEntry(t){if(typeof t!="function")throw new Pe("Graph.forEachAssymetricAdjacencyEntry: expecting a callback.");_d(!1,!0,!1,this,t)}forEachAssymetricAdjacencyEntryWithOrphans(t){if(typeof t!="function")throw new Pe("Graph.forEachAssymetricAdjacencyEntryWithOrphans: expecting a callback.");_d(!1,!0,!0,this,t)}nodes(){return Array.from(this._nodes.keys())}forEachNode(t){if(typeof t!="function")throw new Pe("Graph.forEachNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)a=r.value,t(a.key,a.attributes)}findNode(t){if(typeof t!="function")throw new Pe("Graph.findNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)if(a=r.value,t(a.key,a.attributes))return a.key}mapNodes(t){if(typeof t!="function")throw new Pe("Graph.mapNode: expecting a callback.");const n=this._nodes.values();let r,a;const o=new Array(this.order);let s=0;for(;r=n.next(),r.done!==!0;)a=r.value,o[s++]=t(a.key,a.attributes);return o}someNode(t){if(typeof t!="function")throw new Pe("Graph.someNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)if(a=r.value,t(a.key,a.attributes))return!0;return!1}everyNode(t){if(typeof t!="function")throw new Pe("Graph.everyNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)if(a=r.value,!t(a.key,a.attributes))return!1;return!0}filterNodes(t){if(typeof t!="function")throw new Pe("Graph.filterNodes: expecting a callback.");const n=this._nodes.values();let r,a;const o=[];for(;r=n.next(),r.done!==!0;)a=r.value,t(a.key,a.attributes)&&o.push(a.key);return o}reduceNodes(t,n){if(typeof t!="function")throw new Pe("Graph.reduceNodes: expecting a callback.");if(arguments.length<2)throw new Pe("Graph.reduceNodes: missing initial value. You must provide it because the callback takes more than one argument and we cannot infer the initial value from the first iteration, as you could with a simple array.");let r=n;const a=this._nodes.values();let o,s;for(;o=a.next(),o.done!==!0;)s=o.value,r=t(r,s.key,s.attributes);return r}nodeEntries(){const t=this._nodes.values();return{[Symbol.iterator](){return this},next(){const n=t.next();if(n.done)return n;const r=n.value;return{value:{node:r.key,attributes:r.attributes},done:!1}}}}export(){const t=new Array(this._nodes.size);let n=0;this._nodes.forEach((a,o)=>{t[n++]=pee(o,a)});const r=new Array(this._edges.size);return n=0,this._edges.forEach((a,o)=>{r[n++]=gee(this.type,o,a)}),{options:{type:this.type,multi:this.multi,allowSelfLoops:this.allowSelfLoops},attributes:this.getAttributes(),nodes:t,edges:r}}import(t,n=!1){if(t instanceof _t)return t.forEachNode((u,d)=>{n?this.mergeNode(u,d):this.addNode(u,d)}),t.forEachEdge((u,d,p,g,m,b,v)=>{n?v?this.mergeUndirectedEdgeWithKey(u,p,g,d):this.mergeDirectedEdgeWithKey(u,p,g,d):v?this.addUndirectedEdgeWithKey(u,p,g,d):this.addDirectedEdgeWithKey(u,p,g,d)}),this;if(!vn(t))throw new Pe("Graph.import: invalid argument. Expecting a serialized graph or, alternatively, a Graph instance.");if(t.attributes){if(!vn(t.attributes))throw new Pe("Graph.import: invalid attributes. Expecting a plain object.");n?this.mergeAttributes(t.attributes):this.replaceAttributes(t.attributes)}let r,a,o,s,l;if(t.nodes){if(o=t.nodes,!Array.isArray(o))throw new Pe("Graph.import: invalid nodes. Expecting an array.");for(r=0,a=o.length;r<a;r++){s=o[r],hee(s);const{key:u,attributes:d}=s;n?this.mergeNode(u,d):this.addNode(u,d)}}if(t.edges){let u=!1;if(this.type==="undirected"&&(u=!0),o=t.edges,!Array.isArray(o))throw new Pe("Graph.import: invalid edges. Expecting an array.");for(r=0,a=o.length;r<a;r++){l=o[r],mee(l);const{source:d,target:p,attributes:g,undirected:m=u}=l;let b;"key"in l?(b=n?m?this.mergeUndirectedEdgeWithKey:this.mergeDirectedEdgeWithKey:m?this.addUndirectedEdgeWithKey:this.addDirectedEdgeWithKey,b.call(this,l.key,d,p,g)):(b=n?m?this.mergeUndirectedEdge:this.mergeDirectedEdge:m?this.addUndirectedEdge:this.addDirectedEdge,b.call(this,d,p,g))}}return this}nullCopy(t){const n=new _t(nn({},this._options,t));return n.replaceAttributes(nn({},this.getAttributes())),n}emptyCopy(t){const n=this.nullCopy(t);return this._nodes.forEach((r,a)=>{const o=nn({},r.attributes);r=new n.NodeDataClass(a,o),n._nodes.set(a,r)}),n}copy(t){if(t=t||{},typeof t.type=="string"&&t.type!==this.type&&t.type!=="mixed")throw new Ze(`Graph.copy: cannot create an incompatible copy from "${this.type}" type to "${t.type}" because this would mean losing information about the current graph.`);if(typeof t.multi=="boolean"&&t.multi!==this.multi&&t.multi!==!0)throw new Ze("Graph.copy: cannot create an incompatible copy by downgrading a multi graph to a simple one because this would mean losing information about the current graph.");if(typeof t.allowSelfLoops=="boolean"&&t.allowSelfLoops!==this.allowSelfLoops&&t.allowSelfLoops!==!0)throw new Ze("Graph.copy: cannot create an incompatible copy from a graph allowing self loops to one that does not because this would mean losing information about the current graph.");const n=this.emptyCopy(t),r=this._edges.values();let a,o;for(;a=r.next(),a.done!==!0;)o=a.value,S4(n,"copy",!1,o.undirected,o.key,o.source.key,o.target.key,nn({},o.attributes));return n}toJSON(){return this.export()}toString(){return"[object Graph]"}inspect(){const t={};this._nodes.forEach((o,s)=>{t[s]=o.attributes});const n={},r={};this._edges.forEach((o,s)=>{const l=o.undirected?"--":"->";let u="",d=o.source.key,p=o.target.key,g;o.undirected&&d>p&&(g=d,d=p,p=g);const m=`(${d})${l}(${p})`;s.startsWith("geid_")?this.multi&&(typeof r[m]>"u"?r[m]=0:r[m]++,u+=`${r[m]}. `):u+=`[${s}]: `,u+=m,n[u]=o.attributes});const a={};for(const o in this)this.hasOwnProperty(o)&&!mN.has(o)&&typeof this[o]!="function"&&typeof o!="symbol"&&(a[o]=this[o]);return a.attributes=this._attributes,a.nodes=t,a.edges=n,vr(a,"constructor",this.constructor),a}}typeof Symbol<"u"&&(_t.prototype[Symbol.for("nodejs.util.inspect.custom")]=_t.prototype.inspect);vee.forEach(e=>{["add","merge","update"].forEach(t=>{const n=e.name(t),r=t==="add"?S4:wee;e.generateKey?_t.prototype[n]=function(a,o,s){return r(this,n,!0,(e.type||this.type)==="undirected",null,a,o,s,t==="update")}:_t.prototype[n]=function(a,o,s,l){return r(this,n,!1,(e.type||this.type)==="undirected",a,o,s,l,t==="update")}})});OJ(_t);GJ(_t);aee(_t);fee(_t);class E4 extends _t{constructor(t){const n=nn({type:"directed"},t);if("multi"in n&&n.multi!==!1)throw new Pe("DirectedGraph.from: inconsistent indication that the graph should be multi in given options!");if(n.type!=="directed")throw new Pe('DirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}class Rc extends _t{constructor(t){const n=nn({type:"undirected"},t);if("multi"in n&&n.multi!==!1)throw new Pe("UndirectedGraph.from: inconsistent indication that the graph should be multi in given options!");if(n.type!=="undirected")throw new Pe('UndirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}class w4 extends _t{constructor(t){const n=nn({multi:!0},t);if("multi"in n&&n.multi!==!0)throw new Pe("MultiGraph.from: inconsistent indication that the graph should be simple in given options!");super(n)}}class x4 extends _t{constructor(t){const n=nn({type:"directed",multi:!0},t);if("multi"in n&&n.multi!==!0)throw new Pe("MultiDirectedGraph.from: inconsistent indication that the graph should be simple in given options!");if(n.type!=="directed")throw new Pe('MultiDirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}class k4 extends _t{constructor(t){const n=nn({type:"undirected",multi:!0},t);if("multi"in n&&n.multi!==!0)throw new Pe("MultiUndirectedGraph.from: inconsistent indication that the graph should be simple in given options!");if(n.type!=="undirected")throw new Pe('MultiUndirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}function Qs(e){e.from=function(t,n){const r=nn({},t.options,n),a=new e(r);return a.import(t),a}}Qs(_t);Qs(E4);Qs(Rc);Qs(w4);Qs(x4);Qs(k4);_t.Graph=_t;_t.DirectedGraph=E4;_t.UndirectedGraph=Rc;_t.MultiGraph=w4;_t.MultiDirectedGraph=x4;_t.MultiUndirectedGraph=k4;_t.InvalidArgumentsGraphError=Pe;_t.NotFoundGraphError=Le;_t.UsageGraphError=Ze;function xee(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}function mc(e){var t=xee(e,"string");return typeof t=="symbol"?t:t+""}function dn(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function yN(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,mc(r.key),r)}}function fn(e,t,n){return t&&yN(e.prototype,t),n&&yN(e,n),Object.defineProperty(e,"prototype",{writable:!1}),e}function Ps(e){return Ps=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},Ps(e)}function T4(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(T4=function(){return!!e})()}function kee(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function Tee(e,t){if(t&&(typeof t=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return kee(e)}function $n(e,t,n){return t=Ps(t),Tee(e,T4()?Reflect.construct(t,n||[],Ps(e).constructor):t.apply(e,n))}function q0(e,t){return q0=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},q0(e,t)}function qn(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&q0(e,t)}function Aee(e){if(Array.isArray(e))return e}function Ree(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r,a,o,s,l=[],u=!0,d=!1;try{if(o=(n=n.call(e)).next,t===0){if(Object(n)!==n)return;u=!1}else for(;!(u=(r=o.call(n)).done)&&(l.push(r.value),l.length!==t);u=!0);}catch(p){d=!0,a=p}finally{try{if(!u&&n.return!=null&&(s=n.return(),Object(s)!==s))return}finally{if(d)throw a}}return l}}function V0(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function A4(e,t){if(e){if(typeof e=="string")return V0(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?V0(e,t):void 0}}function Cee(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Fs(e,t){return Aee(e)||Ree(e,t)||A4(e,t)||Cee()}var Sm={black:"#000000",silver:"#C0C0C0",gray:"#808080",grey:"#808080",white:"#FFFFFF",maroon:"#800000",red:"#FF0000",purple:"#800080",fuchsia:"#FF00FF",green:"#008000",lime:"#00FF00",olive:"#808000",yellow:"#FFFF00",navy:"#000080",blue:"#0000FF",teal:"#008080",aqua:"#00FFFF",darkblue:"#00008B",mediumblue:"#0000CD",darkgreen:"#006400",darkcyan:"#008B8B",deepskyblue:"#00BFFF",darkturquoise:"#00CED1",mediumspringgreen:"#00FA9A",springgreen:"#00FF7F",cyan:"#00FFFF",midnightblue:"#191970",dodgerblue:"#1E90FF",lightseagreen:"#20B2AA",forestgreen:"#228B22",seagreen:"#2E8B57",darkslategray:"#2F4F4F",darkslategrey:"#2F4F4F",limegreen:"#32CD32",mediumseagreen:"#3CB371",turquoise:"#40E0D0",royalblue:"#4169E1",steelblue:"#4682B4",darkslateblue:"#483D8B",mediumturquoise:"#48D1CC",indigo:"#4B0082",darkolivegreen:"#556B2F",cadetblue:"#5F9EA0",cornflowerblue:"#6495ED",rebeccapurple:"#663399",mediumaquamarine:"#66CDAA",dimgray:"#696969",dimgrey:"#696969",slateblue:"#6A5ACD",olivedrab:"#6B8E23",slategray:"#708090",slategrey:"#708090",lightslategray:"#778899",lightslategrey:"#778899",mediumslateblue:"#7B68EE",lawngreen:"#7CFC00",chartreuse:"#7FFF00",aquamarine:"#7FFFD4",skyblue:"#87CEEB",lightskyblue:"#87CEFA",blueviolet:"#8A2BE2",darkred:"#8B0000",darkmagenta:"#8B008B",saddlebrown:"#8B4513",darkseagreen:"#8FBC8F",lightgreen:"#90EE90",mediumpurple:"#9370DB",darkviolet:"#9400D3",palegreen:"#98FB98",darkorchid:"#9932CC",yellowgreen:"#9ACD32",sienna:"#A0522D",brown:"#A52A2A",darkgray:"#A9A9A9",darkgrey:"#A9A9A9",lightblue:"#ADD8E6",greenyellow:"#ADFF2F",paleturquoise:"#AFEEEE",lightsteelblue:"#B0C4DE",powderblue:"#B0E0E6",firebrick:"#B22222",darkgoldenrod:"#B8860B",mediumorchid:"#BA55D3",rosybrown:"#BC8F8F",darkkhaki:"#BDB76B",mediumvioletred:"#C71585",indianred:"#CD5C5C",peru:"#CD853F",chocolate:"#D2691E",tan:"#D2B48C",lightgray:"#D3D3D3",lightgrey:"#D3D3D3",thistle:"#D8BFD8",orchid:"#DA70D6",goldenrod:"#DAA520",palevioletred:"#DB7093",crimson:"#DC143C",gainsboro:"#DCDCDC",plum:"#DDA0DD",burlywood:"#DEB887",lightcyan:"#E0FFFF",lavender:"#E6E6FA",darksalmon:"#E9967A",violet:"#EE82EE",palegoldenrod:"#EEE8AA",lightcoral:"#F08080",khaki:"#F0E68C",aliceblue:"#F0F8FF",honeydew:"#F0FFF0",azure:"#F0FFFF",sandybrown:"#F4A460",wheat:"#F5DEB3",beige:"#F5F5DC",whitesmoke:"#F5F5F5",mintcream:"#F5FFFA",ghostwhite:"#F8F8FF",salmon:"#FA8072",antiquewhite:"#FAEBD7",linen:"#FAF0E6",lightgoldenrodyellow:"#FAFAD2",oldlace:"#FDF5E6",magenta:"#FF00FF",deeppink:"#FF1493",orangered:"#FF4500",tomato:"#FF6347",hotpink:"#FF69B4",coral:"#FF7F50",darkorange:"#FF8C00",lightsalmon:"#FFA07A",orange:"#FFA500",lightpink:"#FFB6C1",pink:"#FFC0CB",gold:"#FFD700",peachpuff:"#FFDAB9",navajowhite:"#FFDEAD",moccasin:"#FFE4B5",bisque:"#FFE4C4",mistyrose:"#FFE4E1",blanchedalmond:"#FFEBCD",papayawhip:"#FFEFD5",lavenderblush:"#FFF0F5",seashell:"#FFF5EE",cornsilk:"#FFF8DC",lemonchiffon:"#FFFACD",floralwhite:"#FFFAF0",snow:"#FFFAFA",lightyellow:"#FFFFE0",ivory:"#FFFFF0"},R4=new Int8Array(4),nf=new Int32Array(R4.buffer,0,1),C4=new Float32Array(R4.buffer,0,1),_ee=/^\s*rgba?\s*\(/,Nee=/^\s*rgba?\s*\(\s*([0-9]*)\s*,\s*([0-9]*)\s*,\s*([0-9]*)(?:\s*,\s*(.*)?)?\)\s*$/;function Oee(e){var t=0,n=0,r=0,a=1;if(e[0]==="#")e.length===4?(t=parseInt(e.charAt(1)+e.charAt(1),16),n=parseInt(e.charAt(2)+e.charAt(2),16),r=parseInt(e.charAt(3)+e.charAt(3),16)):(t=parseInt(e.charAt(1)+e.charAt(2),16),n=parseInt(e.charAt(3)+e.charAt(4),16),r=parseInt(e.charAt(5)+e.charAt(6),16)),e.length===9&&(a=parseInt(e.charAt(7)+e.charAt(8),16)/255);else if(_ee.test(e)){var o=e.match(Nee);o&&(t=+o[1],n=+o[2],r=+o[3],o[4]&&(a=+o[4]))}return{r:t,g:n,b:r,a}}var _s={};for(var Nd in Sm)_s[Nd]=ca(Sm[Nd]),_s[Sm[Nd]]=_s[Nd];function _4(e,t,n,r,a){return nf[0]=r<<24|n<<16|t<<8|e,nf[0]=nf[0]&4278190079,C4[0]}function ca(e){if(e=e.toLowerCase(),typeof _s[e]<"u")return _s[e];var t=Oee(e),n=t.r,r=t.g,a=t.b,o=t.a;o=o*255|0;var s=_4(n,r,a,o);return _s[e]=s,s}function Iee(e,t){C4[0]=ca(e);var n=nf[0],r=n&255,a=n>>8&255,o=n>>16&255,s=n>>24&255;return[r,a,o,s]}var Em={};function N4(e){if(typeof Em[e]<"u")return Em[e];var t=(e&16711680)>>>16,n=(e&65280)>>>8,r=e&255,a=255,o=_4(t,n,r,a);return Em[e]=o,o}function vN(e,t,n,r){return n+(t<<8)+(e<<16)}function SN(e,t,n,r,a,o){var s=Math.floor(n/o*a),l=Math.floor(e.drawingBufferHeight/o-r/o*a),u=new Uint8Array(4);e.bindFramebuffer(e.FRAMEBUFFER,t),e.readPixels(s,l,1,1,e.RGBA,e.UNSIGNED_BYTE,u);var d=Fs(u,4),p=d[0],g=d[1],m=d[2],b=d[3];return[p,g,m,b]}function _e(e,t,n){return(t=mc(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function EN(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ue(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?EN(Object(n),!0).forEach(function(r){_e(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):EN(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function Dee(e,t){for(;!{}.hasOwnProperty.call(e,t)&&(e=Ps(e))!==null;);return e}function W0(){return W0=typeof Reflect<"u"&&Reflect.get?Reflect.get.bind():function(e,t,n){var r=Dee(e,t);if(r){var a=Object.getOwnPropertyDescriptor(r,t);return a.get?a.get.call(arguments.length<3?e:n):a.value}},W0.apply(null,arguments)}function O4(e,t,n,r){var a=W0(Ps(e.prototype),t,n);return typeof a=="function"?function(o){return a.apply(n,o)}:a}function Lee(e){return e.normalized?1:e.size}function wm(e){var t=0;return e.forEach(function(n){return t+=Lee(n)}),t}function I4(e,t,n){var r=e==="VERTEX"?t.VERTEX_SHADER:t.FRAGMENT_SHADER,a=t.createShader(r);if(a===null)throw new Error("loadShader: error while creating the shader");t.shaderSource(a,n),t.compileShader(a);var o=t.getShaderParameter(a,t.COMPILE_STATUS);if(!o){var s=t.getShaderInfoLog(a);throw t.deleteShader(a),new Error(`loadShader: error while compiling the shader:
`.concat(s,`
`).concat(n))}return a}function Mee(e,t){return I4("VERTEX",e,t)}function Pee(e,t){return I4("FRAGMENT",e,t)}function Fee(e,t){var n=e.createProgram();if(n===null)throw new Error("loadProgram: error while creating the program.");var r,a;for(r=0,a=t.length;r<a;r++)e.attachShader(n,t[r]);e.linkProgram(n);var o=e.getProgramParameter(n,e.LINK_STATUS);if(!o)throw e.deleteProgram(n),new Error("loadProgram: error while linking the program.");return n}function wN(e){var t=e.gl,n=e.buffer,r=e.program,a=e.vertexShader,o=e.fragmentShader;t.deleteShader(a),t.deleteShader(o),t.deleteProgram(r),t.deleteBuffer(n)}function xN(e){return e%1===0?e.toFixed(1):e.toString()}var kN=`#define PICKING_MODE
`,zee=_e(_e(_e(_e(_e(_e(_e(_e({},WebGL2RenderingContext.BOOL,1),WebGL2RenderingContext.BYTE,1),WebGL2RenderingContext.UNSIGNED_BYTE,1),WebGL2RenderingContext.SHORT,2),WebGL2RenderingContext.UNSIGNED_SHORT,2),WebGL2RenderingContext.INT,4),WebGL2RenderingContext.UNSIGNED_INT,4),WebGL2RenderingContext.FLOAT,4),D4=function(){function e(t,n,r){dn(this,e),_e(this,"array",new Float32Array),_e(this,"constantArray",new Float32Array),_e(this,"capacity",0),_e(this,"verticesCount",0);var a=this.getDefinition();if(this.VERTICES=a.VERTICES,this.VERTEX_SHADER_SOURCE=a.VERTEX_SHADER_SOURCE,this.FRAGMENT_SHADER_SOURCE=a.FRAGMENT_SHADER_SOURCE,this.UNIFORMS=a.UNIFORMS,this.ATTRIBUTES=a.ATTRIBUTES,this.METHOD=a.METHOD,this.CONSTANT_ATTRIBUTES="CONSTANT_ATTRIBUTES"in a?a.CONSTANT_ATTRIBUTES:[],this.CONSTANT_DATA="CONSTANT_DATA"in a?a.CONSTANT_DATA:[],this.isInstanced="CONSTANT_ATTRIBUTES"in a,this.ATTRIBUTES_ITEMS_COUNT=wm(this.ATTRIBUTES),this.STRIDE=this.VERTICES*this.ATTRIBUTES_ITEMS_COUNT,this.renderer=r,this.normalProgram=this.getProgramInfo("normal",t,a.VERTEX_SHADER_SOURCE,a.FRAGMENT_SHADER_SOURCE,null),this.pickProgram=n?this.getProgramInfo("pick",t,kN+a.VERTEX_SHADER_SOURCE,kN+a.FRAGMENT_SHADER_SOURCE,n):null,this.isInstanced){var o=wm(this.CONSTANT_ATTRIBUTES);if(this.CONSTANT_DATA.length!==this.VERTICES)throw new Error("Program: error while getting constant data (expected ".concat(this.VERTICES," items, received ").concat(this.CONSTANT_DATA.length," instead)"));this.constantArray=new Float32Array(this.CONSTANT_DATA.length*o);for(var s=0;s<this.CONSTANT_DATA.length;s++){var l=this.CONSTANT_DATA[s];if(l.length!==o)throw new Error("Program: error while getting constant data (one vector has ".concat(l.length," items instead of ").concat(o,")"));for(var u=0;u<l.length;u++)this.constantArray[s*o+u]=l[u]}this.STRIDE=this.ATTRIBUTES_ITEMS_COUNT}}return fn(e,[{key:"kill",value:function(){wN(this.normalProgram),this.pickProgram&&(wN(this.pickProgram),this.pickProgram=null)}},{key:"getProgramInfo",value:function(n,r,a,o,s){var l=this.getDefinition(),u=r.createBuffer();if(u===null)throw new Error("Program: error while creating the WebGL buffer.");var d=Mee(r,a),p=Pee(r,o),g=Fee(r,[d,p]),m={};l.UNIFORMS.forEach(function(y){var k=r.getUniformLocation(g,y);k&&(m[y]=k)});var b={};l.ATTRIBUTES.forEach(function(y){b[y.name]=r.getAttribLocation(g,y.name)});var v;if("CONSTANT_ATTRIBUTES"in l&&(l.CONSTANT_ATTRIBUTES.forEach(function(y){b[y.name]=r.getAttribLocation(g,y.name)}),v=r.createBuffer(),v===null))throw new Error("Program: error while creating the WebGL constant buffer.");return{name:n,program:g,gl:r,frameBuffer:s,buffer:u,constantBuffer:v||{},uniformLocations:m,attributeLocations:b,isPicking:n==="pick",vertexShader:d,fragmentShader:p}}},{key:"bindProgram",value:function(n){var r=this,a=0,o=n.gl,s=n.buffer;this.isInstanced?(o.bindBuffer(o.ARRAY_BUFFER,n.constantBuffer),a=0,this.CONSTANT_ATTRIBUTES.forEach(function(l){return a+=r.bindAttribute(l,n,a,!1)}),o.bufferData(o.ARRAY_BUFFER,this.constantArray,o.STATIC_DRAW),o.bindBuffer(o.ARRAY_BUFFER,n.buffer),a=0,this.ATTRIBUTES.forEach(function(l){return a+=r.bindAttribute(l,n,a,!0)}),o.bufferData(o.ARRAY_BUFFER,this.array,o.DYNAMIC_DRAW)):(o.bindBuffer(o.ARRAY_BUFFER,s),a=0,this.ATTRIBUTES.forEach(function(l){return a+=r.bindAttribute(l,n,a)}),o.bufferData(o.ARRAY_BUFFER,this.array,o.DYNAMIC_DRAW)),o.bindBuffer(o.ARRAY_BUFFER,null)}},{key:"unbindProgram",value:function(n){var r=this;this.isInstanced?(this.CONSTANT_ATTRIBUTES.forEach(function(a){return r.unbindAttribute(a,n,!1)}),this.ATTRIBUTES.forEach(function(a){return r.unbindAttribute(a,n,!0)})):this.ATTRIBUTES.forEach(function(a){return r.unbindAttribute(a,n)})}},{key:"bindAttribute",value:function(n,r,a,o){var s=zee[n.type];if(typeof s!="number")throw new Error('Program.bind: yet unsupported attribute type "'.concat(n.type,'"'));var l=r.attributeLocations[n.name],u=r.gl;if(l!==-1){u.enableVertexAttribArray(l);var d=this.isInstanced?(o?this.ATTRIBUTES_ITEMS_COUNT:wm(this.CONSTANT_ATTRIBUTES))*Float32Array.BYTES_PER_ELEMENT:this.ATTRIBUTES_ITEMS_COUNT*Float32Array.BYTES_PER_ELEMENT;if(u.vertexAttribPointer(l,n.size,n.type,n.normalized||!1,d,a),this.isInstanced&&o)if(u instanceof WebGL2RenderingContext)u.vertexAttribDivisor(l,1);else{var p=u.getExtension("ANGLE_instanced_arrays");p&&p.vertexAttribDivisorANGLE(l,1)}}return n.size*s}},{key:"unbindAttribute",value:function(n,r,a){var o=r.attributeLocations[n.name],s=r.gl;if(o!==-1&&(s.disableVertexAttribArray(o),this.isInstanced&&a))if(s instanceof WebGL2RenderingContext)s.vertexAttribDivisor(o,0);else{var l=s.getExtension("ANGLE_instanced_arrays");l&&l.vertexAttribDivisorANGLE(o,0)}}},{key:"reallocate",value:function(n){n!==this.capacity&&(this.capacity=n,this.verticesCount=this.VERTICES*n,this.array=new Float32Array(this.isInstanced?this.capacity*this.ATTRIBUTES_ITEMS_COUNT:this.verticesCount*this.ATTRIBUTES_ITEMS_COUNT))}},{key:"hasNothingToRender",value:function(){return this.verticesCount===0}},{key:"renderProgram",value:function(n,r){var a=r.gl,o=r.program;a.enable(a.BLEND),a.useProgram(o),this.setUniforms(n,r),this.drawWebGL(this.METHOD,r)}},{key:"render",value:function(n){this.hasNothingToRender()||(this.pickProgram&&(this.pickProgram.gl.viewport(0,0,n.width*n.pixelRatio/n.downSizingRatio,n.height*n.pixelRatio/n.downSizingRatio),this.bindProgram(this.pickProgram),this.renderProgram(Ue(Ue({},n),{},{pixelRatio:n.pixelRatio/n.downSizingRatio}),this.pickProgram),this.unbindProgram(this.pickProgram)),this.normalProgram.gl.viewport(0,0,n.width*n.pixelRatio,n.height*n.pixelRatio),this.bindProgram(this.normalProgram),this.renderProgram(n,this.normalProgram),this.unbindProgram(this.normalProgram))}},{key:"drawWebGL",value:function(n,r){var a=r.gl,o=r.frameBuffer;if(a.bindFramebuffer(a.FRAMEBUFFER,o),!this.isInstanced)a.drawArrays(n,0,this.verticesCount);else if(a instanceof WebGL2RenderingContext)a.drawArraysInstanced(n,0,this.VERTICES,this.capacity);else{var s=a.getExtension("ANGLE_instanced_arrays");s&&s.drawArraysInstancedANGLE(n,0,this.VERTICES,this.capacity)}}}])}(),NT=function(e){function t(){return dn(this,t),$n(this,t,arguments)}return qn(t,e),fn(t,[{key:"kill",value:function(){O4(t,"kill",this)([])}},{key:"process",value:function(r,a,o){var s=a*this.STRIDE;if(o.hidden){for(var l=s+this.STRIDE;s<l;s++)this.array[s]=0;return}return this.processVisibleItem(N4(r),s,o)}}])}(D4),eu=function(e){function t(){var n;dn(this,t);for(var r=arguments.length,a=new Array(r),o=0;o<r;o++)a[o]=arguments[o];return n=$n(this,t,[].concat(a)),_e(n,"drawLabel",void 0),n}return qn(t,e),fn(t,[{key:"kill",value:function(){O4(t,"kill",this)([])}},{key:"process",value:function(r,a,o,s,l){var u=a*this.STRIDE;if(l.hidden||o.hidden||s.hidden){for(var d=u+this.STRIDE;u<d;u++)this.array[u]=0;return}return this.processVisibleItem(N4(r),u,o,s,l)}}])}(D4);function L4(e,t){return function(){function n(r,a,o){dn(this,n),_e(this,"drawLabel",t),this.programs=e.map(function(s){return new s(r,a,o)})}return fn(n,[{key:"reallocate",value:function(a){this.programs.forEach(function(o){return o.reallocate(a)})}},{key:"process",value:function(a,o,s,l,u){this.programs.forEach(function(d){return d.process(a,o,s,l,u)})}},{key:"render",value:function(a){this.programs.forEach(function(o){return o.render(a)})}},{key:"kill",value:function(){this.programs.forEach(function(a){return a.kill()})}}])}()}function Bee(e,t,n,r,a){var o=a.edgeLabelSize,s=a.edgeLabelFont,l=a.edgeLabelWeight,u=a.edgeLabelColor.attribute?t[a.edgeLabelColor.attribute]||a.edgeLabelColor.color||"#000":a.edgeLabelColor.color,d=t.label;if(d){e.fillStyle=u,e.font="".concat(l," ").concat(o,"px ").concat(s);var p=n.size,g=r.size,m=n.x,b=n.y,v=r.x,y=r.y,k=(m+v)/2,A=(b+y)/2,x=v-m,R=y-b,O=Math.sqrt(x*x+R*R);if(!(O<p+g)){m+=x*p/O,b+=R*p/O,v-=x*g/O,y-=R*g/O,k=(m+v)/2,A=(b+y)/2,x=v-m,R=y-b,O=Math.sqrt(x*x+R*R);var N=e.measureText(d).width;if(N>O){var C="…";for(d=d+C,N=e.measureText(d).width;N>O&&d.length>1;)d=d.slice(0,-2)+C,N=e.measureText(d).width;if(d.length<4)return}var _;x>0?R>0?_=Math.acos(x/O):_=Math.asin(R/O):R>0?_=Math.acos(x/O)+Math.PI:_=Math.asin(x/O)+Math.PI/2,e.save(),e.translate(k,A),e.rotate(_),e.fillText(d,-N/2,t.size/2+o),e.restore()}}}function M4(e,t,n){if(t.label){var r=n.labelSize,a=n.labelFont,o=n.labelWeight,s=n.labelColor.attribute?t[n.labelColor.attribute]||n.labelColor.color||"#000":n.labelColor.color;e.fillStyle=s,e.font="".concat(o," ").concat(r,"px ").concat(a),e.fillText(t.label,t.x+t.size+3,t.y+r/3)}}function jee(e,t,n){var r=n.labelSize,a=n.labelFont,o=n.labelWeight;e.font="".concat(o," ").concat(r,"px ").concat(a),e.fillStyle="#FFF",e.shadowOffsetX=0,e.shadowOffsetY=0,e.shadowBlur=8,e.shadowColor="#000";var s=2;if(typeof t.label=="string"){var l=e.measureText(t.label).width,u=Math.round(l+5),d=Math.round(r+2*s),p=Math.max(t.size,r/2)+s,g=Math.asin(d/2/p),m=Math.sqrt(Math.abs(Math.pow(p,2)-Math.pow(d/2,2)));e.beginPath(),e.moveTo(t.x+m,t.y+d/2),e.lineTo(t.x+p+u,t.y+d/2),e.lineTo(t.x+p+u,t.y-d/2),e.lineTo(t.x+m,t.y-d/2),e.arc(t.x,t.y,p,g,-g),e.closePath(),e.fill()}else e.beginPath(),e.arc(t.x,t.y,t.size+s,0,Math.PI*2),e.closePath(),e.fill();e.shadowOffsetX=0,e.shadowOffsetY=0,e.shadowBlur=0,M4(e,t,n)}var Uee=`
precision highp float;

varying vec4 v_color;
varying vec2 v_diffVector;
varying float v_radius;

uniform float u_correctionRatio;

const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  float border = u_correctionRatio * 2.0;
  float dist = length(v_diffVector) - v_radius + border;

  // No antialiasing for picking mode:
  #ifdef PICKING_MODE
  if (dist > border)
    gl_FragColor = transparent;
  else
    gl_FragColor = v_color;

  #else
  float t = 0.0;
  if (dist > border)
    t = 1.0;
  else if (dist > 0.0)
    t = dist / border;

  gl_FragColor = mix(v_color, transparent, t);
  #endif
}
`,Gee=Uee,Hee=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_position;
attribute float a_size;
attribute float a_angle;

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_correctionRatio;

varying vec4 v_color;
varying vec2 v_diffVector;
varying float v_radius;
varying float v_border;

const float bias = 255.0 / 254.0;

void main() {
  float size = a_size * u_correctionRatio / u_sizeRatio * 4.0;
  vec2 diffVector = size * vec2(cos(a_angle), sin(a_angle));
  vec2 position = a_position + diffVector;
  gl_Position = vec4(
    (u_matrix * vec3(position, 1)).xy,
    0,
    1
  );

  v_diffVector = diffVector;
  v_radius = size / 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,$ee=Hee,P4=WebGLRenderingContext,TN=P4.UNSIGNED_BYTE,xm=P4.FLOAT,qee=["u_sizeRatio","u_correctionRatio","u_matrix"],tu=function(e){function t(){return dn(this,t),$n(this,t,arguments)}return qn(t,e),fn(t,[{key:"getDefinition",value:function(){return{VERTICES:3,VERTEX_SHADER_SOURCE:$ee,FRAGMENT_SHADER_SOURCE:Gee,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:qee,ATTRIBUTES:[{name:"a_position",size:2,type:xm},{name:"a_size",size:1,type:xm},{name:"a_color",size:4,type:TN,normalized:!0},{name:"a_id",size:4,type:TN,normalized:!0}],CONSTANT_ATTRIBUTES:[{name:"a_angle",size:1,type:xm}],CONSTANT_DATA:[[t.ANGLE_1],[t.ANGLE_2],[t.ANGLE_3]]}}},{key:"processVisibleItem",value:function(r,a,o){var s=this.array,l=ca(o.color);s[a++]=o.x,s[a++]=o.y,s[a++]=o.size,s[a++]=l,s[a++]=r}},{key:"setUniforms",value:function(r,a){var o=a.gl,s=a.uniformLocations,l=s.u_sizeRatio,u=s.u_correctionRatio,d=s.u_matrix;o.uniform1f(u,r.correctionRatio),o.uniform1f(l,r.sizeRatio),o.uniformMatrix3fv(d,!1,r.matrix)}}])}(NT);_e(tu,"ANGLE_1",0);_e(tu,"ANGLE_2",2*Math.PI/3);_e(tu,"ANGLE_3",4*Math.PI/3);var Vee=`
precision mediump float;

varying vec4 v_color;

void main(void) {
  gl_FragColor = v_color;
}
`,Wee=Vee,Yee=`
attribute vec2 a_position;
attribute vec2 a_normal;
attribute float a_radius;
attribute vec3 a_barycentric;

#ifdef PICKING_MODE
attribute vec4 a_id;
#else
attribute vec4 a_color;
#endif

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_lengthToThicknessRatio;
uniform float u_widenessToThicknessRatio;

varying vec4 v_color;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  float normalLength = length(a_normal);
  vec2 unitNormal = a_normal / normalLength;

  // These first computations are taken from edge.vert.glsl and
  // edge.clamped.vert.glsl. Please read it to get better comments on what's
  // happening:
  float pixelsThickness = max(normalLength / u_sizeRatio, minThickness);
  float webGLThickness = pixelsThickness * u_correctionRatio;
  float webGLNodeRadius = a_radius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;
  float webGLArrowHeadThickness = webGLThickness * u_widenessToThicknessRatio;

  float da = a_barycentric.x;
  float db = a_barycentric.y;
  float dc = a_barycentric.z;

  vec2 delta = vec2(
      da * (webGLNodeRadius * unitNormal.y)
    + db * ((webGLNodeRadius + webGLArrowHeadLength) * unitNormal.y + webGLArrowHeadThickness * unitNormal.x)
    + dc * ((webGLNodeRadius + webGLArrowHeadLength) * unitNormal.y - webGLArrowHeadThickness * unitNormal.x),

      da * (-webGLNodeRadius * unitNormal.x)
    + db * (-(webGLNodeRadius + webGLArrowHeadLength) * unitNormal.x + webGLArrowHeadThickness * unitNormal.y)
    + dc * (-(webGLNodeRadius + webGLArrowHeadLength) * unitNormal.x - webGLArrowHeadThickness * unitNormal.y)
  );

  vec2 position = (u_matrix * vec3(a_position + delta, 1)).xy;

  gl_Position = vec4(position, 0, 1);

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,Kee=Yee,F4=WebGLRenderingContext,AN=F4.UNSIGNED_BYTE,Od=F4.FLOAT,Xee=["u_matrix","u_sizeRatio","u_correctionRatio","u_minEdgeThickness","u_lengthToThicknessRatio","u_widenessToThicknessRatio"],nu={extremity:"target",lengthToThicknessRatio:2.5,widenessToThicknessRatio:2};function Rf(e){var t=Ue(Ue({},nu),e||{});return function(n){function r(){return dn(this,r),$n(this,r,arguments)}return qn(r,n),fn(r,[{key:"getDefinition",value:function(){return{VERTICES:3,VERTEX_SHADER_SOURCE:Kee,FRAGMENT_SHADER_SOURCE:Wee,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:Xee,ATTRIBUTES:[{name:"a_position",size:2,type:Od},{name:"a_normal",size:2,type:Od},{name:"a_radius",size:1,type:Od},{name:"a_color",size:4,type:AN,normalized:!0},{name:"a_id",size:4,type:AN,normalized:!0}],CONSTANT_ATTRIBUTES:[{name:"a_barycentric",size:3,type:Od}],CONSTANT_DATA:[[1,0,0],[0,1,0],[0,0,1]]}}},{key:"processVisibleItem",value:function(o,s,l,u,d){if(t.extremity==="source"){var p=[u,l];l=p[0],u=p[1]}var g=d.size||1,m=u.size||1,b=l.x,v=l.y,y=u.x,k=u.y,A=ca(d.color),x=y-b,R=k-v,O=x*x+R*R,N=0,C=0;O&&(O=1/Math.sqrt(O),N=-R*O*g,C=x*O*g);var _=this.array;_[s++]=y,_[s++]=k,_[s++]=-N,_[s++]=-C,_[s++]=m,_[s++]=A,_[s++]=o}},{key:"setUniforms",value:function(o,s){var l=s.gl,u=s.uniformLocations,d=u.u_matrix,p=u.u_sizeRatio,g=u.u_correctionRatio,m=u.u_minEdgeThickness,b=u.u_lengthToThicknessRatio,v=u.u_widenessToThicknessRatio;l.uniformMatrix3fv(d,!1,o.matrix),l.uniform1f(p,o.sizeRatio),l.uniform1f(g,o.correctionRatio),l.uniform1f(m,o.minEdgeThickness),l.uniform1f(b,t.lengthToThicknessRatio),l.uniform1f(v,t.widenessToThicknessRatio)}}])}(eu)}Rf();var Zee=`
precision mediump float;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  // We only handle antialiasing for normal mode:
  #ifdef PICKING_MODE
  gl_FragColor = v_color;
  #else
  float dist = length(v_normal) * v_thickness;

  float t = smoothstep(
    v_thickness - v_feather,
    v_thickness,
    dist
  );

  gl_FragColor = mix(v_color, transparent, t);
  #endif
}
`,OT=Zee,Qee=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_normal;
attribute float a_normalCoef;
attribute vec2 a_positionStart;
attribute vec2 a_positionEnd;
attribute float a_positionCoef;
attribute float a_radius;
attribute float a_radiusCoef;

uniform mat3 u_matrix;
uniform float u_zoomRatio;
uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_lengthToThicknessRatio;
uniform float u_feather;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  float radius = a_radius * a_radiusCoef;
  vec2 normal = a_normal * a_normalCoef;
  vec2 position = a_positionStart * (1.0 - a_positionCoef) + a_positionEnd * a_positionCoef;

  float normalLength = length(normal);
  vec2 unitNormal = normal / normalLength;

  // These first computations are taken from edge.vert.glsl. Please read it to
  // get better comments on what's happening:
  float pixelsThickness = max(normalLength, minThickness * u_sizeRatio);
  float webGLThickness = pixelsThickness * u_correctionRatio / u_sizeRatio;

  // Here, we move the point to leave space for the arrow head:
  float direction = sign(radius);
  float webGLNodeRadius = direction * radius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;

  vec2 compensationVector = vec2(-direction * unitNormal.y, direction * unitNormal.x) * (webGLNodeRadius + webGLArrowHeadLength);

  // Here is the proper position of the vertex
  gl_Position = vec4((u_matrix * vec3(position + unitNormal * webGLThickness + compensationVector, 1)).xy, 0, 1);

  v_thickness = webGLThickness / u_zoomRatio;

  v_normal = unitNormal;

  v_feather = u_feather * u_correctionRatio / u_zoomRatio / u_pixelRatio * 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,Jee=Qee,z4=WebGLRenderingContext,RN=z4.UNSIGNED_BYTE,oi=z4.FLOAT,ete=["u_matrix","u_zoomRatio","u_sizeRatio","u_correctionRatio","u_pixelRatio","u_feather","u_minEdgeThickness","u_lengthToThicknessRatio"],tte={lengthToThicknessRatio:nu.lengthToThicknessRatio};function B4(e){var t=Ue(Ue({},tte),{});return function(n){function r(){return dn(this,r),$n(this,r,arguments)}return qn(r,n),fn(r,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:Jee,FRAGMENT_SHADER_SOURCE:OT,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:ete,ATTRIBUTES:[{name:"a_positionStart",size:2,type:oi},{name:"a_positionEnd",size:2,type:oi},{name:"a_normal",size:2,type:oi},{name:"a_color",size:4,type:RN,normalized:!0},{name:"a_id",size:4,type:RN,normalized:!0},{name:"a_radius",size:1,type:oi}],CONSTANT_ATTRIBUTES:[{name:"a_positionCoef",size:1,type:oi},{name:"a_normalCoef",size:1,type:oi},{name:"a_radiusCoef",size:1,type:oi}],CONSTANT_DATA:[[0,1,0],[0,-1,0],[1,1,1],[1,1,1],[0,-1,0],[1,-1,-1]]}}},{key:"processVisibleItem",value:function(o,s,l,u,d){var p=d.size||1,g=l.x,m=l.y,b=u.x,v=u.y,y=ca(d.color),k=b-g,A=v-m,x=u.size||1,R=k*k+A*A,O=0,N=0;R&&(R=1/Math.sqrt(R),O=-A*R*p,N=k*R*p);var C=this.array;C[s++]=g,C[s++]=m,C[s++]=b,C[s++]=v,C[s++]=O,C[s++]=N,C[s++]=y,C[s++]=o,C[s++]=x}},{key:"setUniforms",value:function(o,s){var l=s.gl,u=s.uniformLocations,d=u.u_matrix,p=u.u_zoomRatio,g=u.u_feather,m=u.u_pixelRatio,b=u.u_correctionRatio,v=u.u_sizeRatio,y=u.u_minEdgeThickness,k=u.u_lengthToThicknessRatio;l.uniformMatrix3fv(d,!1,o.matrix),l.uniform1f(p,o.zoomRatio),l.uniform1f(v,o.sizeRatio),l.uniform1f(b,o.correctionRatio),l.uniform1f(m,o.pixelRatio),l.uniform1f(g,o.antiAliasingFeather),l.uniform1f(y,o.minEdgeThickness),l.uniform1f(k,t.lengthToThicknessRatio)}}])}(eu)}B4();function nte(e){return L4([B4(),Rf(e)])}var rte=nte(),j4=rte,ate=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_normal;
attribute float a_normalCoef;
attribute vec2 a_positionStart;
attribute vec2 a_positionEnd;
attribute float a_positionCoef;

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_zoomRatio;
uniform float u_pixelRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_feather;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  vec2 normal = a_normal * a_normalCoef;
  vec2 position = a_positionStart * (1.0 - a_positionCoef) + a_positionEnd * a_positionCoef;

  float normalLength = length(normal);
  vec2 unitNormal = normal / normalLength;

  // We require edges to be at least "minThickness" pixels thick *on screen*
  // (so we need to compensate the size ratio):
  float pixelsThickness = max(normalLength, minThickness * u_sizeRatio);

  // Then, we need to retrieve the normalized thickness of the edge in the WebGL
  // referential (in a ([0, 1], [0, 1]) space), using our "magic" correction
  // ratio:
  float webGLThickness = pixelsThickness * u_correctionRatio / u_sizeRatio;

  // Here is the proper position of the vertex
  gl_Position = vec4((u_matrix * vec3(position + unitNormal * webGLThickness, 1)).xy, 0, 1);

  // For the fragment shader though, we need a thickness that takes the "magic"
  // correction ratio into account (as in webGLThickness), but so that the
  // antialiasing effect does not depend on the zoom level. So here's yet
  // another thickness version:
  v_thickness = webGLThickness / u_zoomRatio;

  v_normal = unitNormal;

  v_feather = u_feather * u_correctionRatio / u_zoomRatio / u_pixelRatio * 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,ote=ate,U4=WebGLRenderingContext,CN=U4.UNSIGNED_BYTE,ac=U4.FLOAT,ite=["u_matrix","u_zoomRatio","u_sizeRatio","u_correctionRatio","u_pixelRatio","u_feather","u_minEdgeThickness"],ste=function(e){function t(){return dn(this,t),$n(this,t,arguments)}return qn(t,e),fn(t,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:ote,FRAGMENT_SHADER_SOURCE:OT,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:ite,ATTRIBUTES:[{name:"a_positionStart",size:2,type:ac},{name:"a_positionEnd",size:2,type:ac},{name:"a_normal",size:2,type:ac},{name:"a_color",size:4,type:CN,normalized:!0},{name:"a_id",size:4,type:CN,normalized:!0}],CONSTANT_ATTRIBUTES:[{name:"a_positionCoef",size:1,type:ac},{name:"a_normalCoef",size:1,type:ac}],CONSTANT_DATA:[[0,1],[0,-1],[1,1],[1,1],[0,-1],[1,-1]]}}},{key:"processVisibleItem",value:function(r,a,o,s,l){var u=l.size||1,d=o.x,p=o.y,g=s.x,m=s.y,b=ca(l.color),v=g-d,y=m-p,k=v*v+y*y,A=0,x=0;k&&(k=1/Math.sqrt(k),A=-y*k*u,x=v*k*u);var R=this.array;R[a++]=d,R[a++]=p,R[a++]=g,R[a++]=m,R[a++]=A,R[a++]=x,R[a++]=b,R[a++]=r}},{key:"setUniforms",value:function(r,a){var o=a.gl,s=a.uniformLocations,l=s.u_matrix,u=s.u_zoomRatio,d=s.u_feather,p=s.u_pixelRatio,g=s.u_correctionRatio,m=s.u_sizeRatio,b=s.u_minEdgeThickness;o.uniformMatrix3fv(l,!1,r.matrix),o.uniform1f(u,r.zoomRatio),o.uniform1f(m,r.sizeRatio),o.uniform1f(g,r.correctionRatio),o.uniform1f(p,r.pixelRatio),o.uniform1f(d,r.antiAliasingFeather),o.uniform1f(b,r.minEdgeThickness)}}])}(eu),IT=function(e){function t(){var n;return dn(this,t),n=$n(this,t),n.rawEmitter=n,n}return qn(t,e),fn(t)}(d4.EventEmitter),km,_N;function ua(){return _N||(_N=1,km=function(t){return t!==null&&typeof t=="object"&&typeof t.addUndirectedEdgeWithKey=="function"&&typeof t.dropNode=="function"&&typeof t.multi=="boolean"}),km}var lte=ua();const cte=un(lte);var ute=function(t){return t},dte=function(t){return t*t},fte=function(t){return t*(2-t)},pte=function(t){return(t*=2)<1?.5*t*t:-.5*(--t*(t-2)-1)},gte=function(t){return t*t*t},hte=function(t){return--t*t*t+1},mte=function(t){return(t*=2)<1?.5*t*t*t:.5*((t-=2)*t*t+2)},G4={linear:ute,quadraticIn:dte,quadraticOut:fte,quadraticInOut:pte,cubicIn:gte,cubicOut:hte,cubicInOut:mte},H4={easing:"quadraticInOut",duration:150};function $4(e,t,n,r){var a=Object.assign({},H4,n),o=typeof a.easing=="function"?a.easing:G4[a.easing],s=Date.now(),l={};for(var u in t){var d=t[u];l[u]={};for(var p in d)l[u][p]=e.getNodeAttribute(u,p)}var g=null,m=function(){g=null;var v=(Date.now()-s)/a.duration;if(v>=1){for(var y in t){var k=t[y];for(var A in k)e.setNodeAttribute(y,A,k[A])}return}v=o(v);for(var x in t){var R=t[x],O=l[x];for(var N in R)e.setNodeAttribute(x,N,R[N]*v+O[N]*(1-v))}g=requestAnimationFrame(m)};return m(),function(){g&&cancelAnimationFrame(g)}}function Fr(){return Float32Array.of(1,0,0,0,1,0,0,0,1)}function Id(e,t,n){return e[0]=t,e[4]=typeof n=="number"?n:t,e}function NN(e,t){var n=Math.sin(t),r=Math.cos(t);return e[0]=r,e[1]=n,e[3]=-n,e[4]=r,e}function ON(e,t,n){return e[6]=t,e[7]=n,e}function bo(e,t){var n=e[0],r=e[1],a=e[2],o=e[3],s=e[4],l=e[5],u=e[6],d=e[7],p=e[8],g=t[0],m=t[1],b=t[2],v=t[3],y=t[4],k=t[5],A=t[6],x=t[7],R=t[8];return e[0]=g*n+m*o+b*u,e[1]=g*r+m*s+b*d,e[2]=g*a+m*l+b*p,e[3]=v*n+y*o+k*u,e[4]=v*r+y*s+k*d,e[5]=v*a+y*l+k*p,e[6]=A*n+x*o+R*u,e[7]=A*r+x*s+R*d,e[8]=A*a+x*l+R*p,e}function Y0(e,t){var n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:1,r=e[0],a=e[1],o=e[3],s=e[4],l=e[6],u=e[7],d=t.x,p=t.y;return{x:d*r+p*o+l*n,y:d*a+p*s+u*n}}function bte(e,t){var n=e.height/e.width,r=t.height/t.width;return n<1&&r>1||n>1&&r<1?1:Math.min(Math.max(r,1/r),Math.max(1/n,n))}function oc(e,t,n,r,a){var o=e.angle,s=e.ratio,l=e.x,u=e.y,d=t.width,p=t.height,g=Fr(),m=Math.min(d,p)-2*r,b=bte(t,n);return a?(bo(g,ON(Fr(),l,u)),bo(g,Id(Fr(),s)),bo(g,NN(Fr(),o)),bo(g,Id(Fr(),d/m/2/b,p/m/2/b))):(bo(g,Id(Fr(),2*(m/d)*b,2*(m/p)*b)),bo(g,NN(Fr(),-o)),bo(g,Id(Fr(),1/s)),bo(g,ON(Fr(),-l,-u))),g}function yte(e,t,n){var r=Y0(e,{x:Math.cos(t.angle),y:Math.sin(t.angle)},0),a=r.x,o=r.y;return 1/Math.sqrt(Math.pow(a,2)+Math.pow(o,2))/n.width}function vte(e){if(!e.order)return{x:[0,1],y:[0,1]};var t=1/0,n=-1/0,r=1/0,a=-1/0;return e.forEachNode(function(o,s){var l=s.x,u=s.y;l<t&&(t=l),l>n&&(n=l),u<r&&(r=u),u>a&&(a=u)}),{x:[t,n],y:[r,a]}}function Ste(e){if(!cte(e))throw new Error("Sigma: invalid graph instance.");e.forEachNode(function(t,n){if(!Number.isFinite(n.x)||!Number.isFinite(n.y))throw new Error("Sigma: Coordinates of node ".concat(t," are invalid. A node must have a numeric 'x' and 'y' attribute."))})}function Ete(e,t,n){var r=document.createElement(e);if(t)for(var a in t)r.style[a]=t[a];if(n)for(var o in n)r.setAttribute(o,n[o]);return r}function IN(){return typeof window.devicePixelRatio<"u"?window.devicePixelRatio:1}function DN(e,t,n){return n.sort(function(r,a){var o=t(r)||0,s=t(a)||0;return o<s?-1:o>s?1:0})}function LN(e){var t=Fs(e.x,2),n=t[0],r=t[1],a=Fs(e.y,2),o=a[0],s=a[1],l=Math.max(r-n,s-o),u=(r+n)/2,d=(s+o)/2;(l===0||Math.abs(l)===1/0||isNaN(l))&&(l=1),isNaN(u)&&(u=0),isNaN(d)&&(d=0);var p=function(m){return{x:.5+(m.x-u)/l,y:.5+(m.y-d)/l}};return p.applyTo=function(g){g.x=.5+(g.x-u)/l,g.y=.5+(g.y-d)/l},p.inverse=function(g){return{x:u+l*(g.x-.5),y:d+l*(g.y-.5)}},p.ratio=l,p}function K0(e){"@babel/helpers - typeof";return K0=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},K0(e)}function MN(e,t){var n=t.size;if(n!==0){var r=e.length;e.length+=n;var a=0;t.forEach(function(o){e[r+a]=o,a++})}}function Tm(e){e=e||{};for(var t=0,n=arguments.length<=1?0:arguments.length-1;t<n;t++){var r=t+1<1||arguments.length<=t+1?void 0:arguments[t+1];r&&Object.assign(e,r)}return e}var DT={hideEdgesOnMove:!1,hideLabelsOnMove:!1,renderLabels:!0,renderEdgeLabels:!1,enableEdgeEvents:!1,defaultNodeColor:"#999",defaultNodeType:"circle",defaultEdgeColor:"#ccc",defaultEdgeType:"line",labelFont:"Arial",labelSize:14,labelWeight:"normal",labelColor:{color:"#000"},edgeLabelFont:"Arial",edgeLabelSize:14,edgeLabelWeight:"normal",edgeLabelColor:{attribute:"color"},stagePadding:30,defaultDrawEdgeLabel:Bee,defaultDrawNodeLabel:M4,defaultDrawNodeHover:jee,minEdgeThickness:1.7,antiAliasingFeather:1,dragTimeout:100,draggedEventsTolerance:3,inertiaDuration:200,inertiaRatio:3,zoomDuration:250,zoomingRatio:1.7,doubleClickTimeout:300,doubleClickZoomingRatio:2.2,doubleClickZoomingDuration:200,tapMoveTolerance:10,zoomToSizeRatioFunction:Math.sqrt,itemSizesReference:"screen",autoRescale:!0,autoCenter:!0,labelDensity:1,labelGridCellSize:100,labelRenderedSizeThreshold:6,nodeReducer:null,edgeReducer:null,zIndex:!1,minCameraRatio:null,maxCameraRatio:null,enableCameraZooming:!0,enableCameraPanning:!0,enableCameraRotation:!0,cameraPanBoundaries:null,allowInvalidContainer:!1,nodeProgramClasses:{},nodeHoverProgramClasses:{},edgeProgramClasses:{}},wte={circle:tu},xte={arrow:j4,line:ste};function Am(e){if(typeof e.labelDensity!="number"||e.labelDensity<0)throw new Error("Settings: invalid `labelDensity`. Expecting a positive number.");var t=e.minCameraRatio,n=e.maxCameraRatio;if(typeof t=="number"&&typeof n=="number"&&n<t)throw new Error("Settings: invalid camera ratio boundaries. Expecting `maxCameraRatio` to be greater than `minCameraRatio`.")}function kte(e){var t=Tm({},DT,e);return t.nodeProgramClasses=Tm({},wte,t.nodeProgramClasses),t.edgeProgramClasses=Tm({},xte,t.edgeProgramClasses),t}var Dd=1.5,PN=function(e){function t(){var n;return dn(this,t),n=$n(this,t),_e(n,"x",.5),_e(n,"y",.5),_e(n,"angle",0),_e(n,"ratio",1),_e(n,"minRatio",null),_e(n,"maxRatio",null),_e(n,"enabledZooming",!0),_e(n,"enabledPanning",!0),_e(n,"enabledRotation",!0),_e(n,"clean",null),_e(n,"nextFrame",null),_e(n,"previousState",null),_e(n,"enabled",!0),n.previousState=n.getState(),n}return qn(t,e),fn(t,[{key:"enable",value:function(){return this.enabled=!0,this}},{key:"disable",value:function(){return this.enabled=!1,this}},{key:"getState",value:function(){return{x:this.x,y:this.y,angle:this.angle,ratio:this.ratio}}},{key:"hasState",value:function(r){return this.x===r.x&&this.y===r.y&&this.ratio===r.ratio&&this.angle===r.angle}},{key:"getPreviousState",value:function(){var r=this.previousState;return r?{x:r.x,y:r.y,angle:r.angle,ratio:r.ratio}:null}},{key:"getBoundedRatio",value:function(r){var a=r;return typeof this.minRatio=="number"&&(a=Math.max(a,this.minRatio)),typeof this.maxRatio=="number"&&(a=Math.min(a,this.maxRatio)),a}},{key:"validateState",value:function(r){var a={};return this.enabledPanning&&typeof r.x=="number"&&(a.x=r.x),this.enabledPanning&&typeof r.y=="number"&&(a.y=r.y),this.enabledZooming&&typeof r.ratio=="number"&&(a.ratio=this.getBoundedRatio(r.ratio)),this.enabledRotation&&typeof r.angle=="number"&&(a.angle=r.angle),this.clean?this.clean(Ue(Ue({},this.getState()),a)):a}},{key:"isAnimated",value:function(){return!!this.nextFrame}},{key:"setState",value:function(r){if(!this.enabled)return this;this.previousState=this.getState();var a=this.validateState(r);return typeof a.x=="number"&&(this.x=a.x),typeof a.y=="number"&&(this.y=a.y),typeof a.ratio=="number"&&(this.ratio=a.ratio),typeof a.angle=="number"&&(this.angle=a.angle),this.hasState(this.previousState)||this.emit("updated",this.getState()),this}},{key:"updateState",value:function(r){return this.setState(r(this.getState())),this}},{key:"animate",value:function(r){var a=this,o=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},s=arguments.length>2?arguments[2]:void 0;if(!s)return new Promise(function(b){return a.animate(r,o,b)});if(this.enabled){var l=Ue(Ue({},H4),o),u=this.validateState(r),d=typeof l.easing=="function"?l.easing:G4[l.easing],p=Date.now(),g=this.getState(),m=function(){var v=(Date.now()-p)/l.duration;if(v>=1){a.nextFrame=null,a.setState(u),a.animationCallback&&(a.animationCallback.call(null),a.animationCallback=void 0);return}var y=d(v),k={};typeof u.x=="number"&&(k.x=g.x+(u.x-g.x)*y),typeof u.y=="number"&&(k.y=g.y+(u.y-g.y)*y),a.enabledRotation&&typeof u.angle=="number"&&(k.angle=g.angle+(u.angle-g.angle)*y),typeof u.ratio=="number"&&(k.ratio=g.ratio+(u.ratio-g.ratio)*y),a.setState(k),a.nextFrame=requestAnimationFrame(m)};this.nextFrame?(cancelAnimationFrame(this.nextFrame),this.animationCallback&&this.animationCallback.call(null),this.nextFrame=requestAnimationFrame(m)):m(),this.animationCallback=s}}},{key:"animatedZoom",value:function(r){return r?typeof r=="number"?this.animate({ratio:this.ratio/r}):this.animate({ratio:this.ratio/(r.factor||Dd)},r):this.animate({ratio:this.ratio/Dd})}},{key:"animatedUnzoom",value:function(r){return r?typeof r=="number"?this.animate({ratio:this.ratio*r}):this.animate({ratio:this.ratio*(r.factor||Dd)},r):this.animate({ratio:this.ratio*Dd})}},{key:"animatedReset",value:function(r){return this.animate({x:.5,y:.5,ratio:1,angle:0},r)}},{key:"copy",value:function(){return t.from(this.getState())}}],[{key:"from",value:function(r){var a=new t;return a.setState(r)}}])}(IT);function zr(e,t){var n=t.getBoundingClientRect();return{x:e.clientX-n.left,y:e.clientY-n.top}}function Ma(e,t){var n=Ue(Ue({},zr(e,t)),{},{sigmaDefaultPrevented:!1,preventSigmaDefault:function(){n.sigmaDefaultPrevented=!0},original:e});return n}function ic(e){var t="x"in e?e:Ue(Ue({},e.touches[0]||e.previousTouches[0]),{},{original:e.original,sigmaDefaultPrevented:e.sigmaDefaultPrevented,preventSigmaDefault:function(){e.sigmaDefaultPrevented=!0,t.sigmaDefaultPrevented=!0}});return t}function Tte(e,t){return Ue(Ue({},Ma(e,t)),{},{delta:q4(e)})}var Ate=2;function rf(e){for(var t=[],n=0,r=Math.min(e.length,Ate);n<r;n++)t.push(e[n]);return t}function sc(e,t,n){var r={touches:rf(e.touches).map(function(a){return zr(a,n)}),previousTouches:t.map(function(a){return zr(a,n)}),sigmaDefaultPrevented:!1,preventSigmaDefault:function(){r.sigmaDefaultPrevented=!0},original:e};return r}function q4(e){if(typeof e.deltaY<"u")return e.deltaY*-3/360;if(typeof e.detail<"u")return e.detail/-9;throw new Error("Captor: could not extract delta from event.")}var V4=function(e){function t(n,r){var a;return dn(this,t),a=$n(this,t),a.container=n,a.renderer=r,a}return qn(t,e),fn(t)}(IT),Rte=["doubleClickTimeout","doubleClickZoomingDuration","doubleClickZoomingRatio","dragTimeout","draggedEventsTolerance","inertiaDuration","inertiaRatio","zoomDuration","zoomingRatio"],Cte=Rte.reduce(function(e,t){return Ue(Ue({},e),{},_e({},t,DT[t]))},{}),_te=function(e){function t(n,r){var a;return dn(this,t),a=$n(this,t,[n,r]),_e(a,"enabled",!0),_e(a,"draggedEvents",0),_e(a,"downStartTime",null),_e(a,"lastMouseX",null),_e(a,"lastMouseY",null),_e(a,"isMouseDown",!1),_e(a,"isMoving",!1),_e(a,"movingTimeout",null),_e(a,"startCameraState",null),_e(a,"clicks",0),_e(a,"doubleClickTimeout",null),_e(a,"currentWheelDirection",0),_e(a,"settings",Cte),a.handleClick=a.handleClick.bind(a),a.handleRightClick=a.handleRightClick.bind(a),a.handleDown=a.handleDown.bind(a),a.handleUp=a.handleUp.bind(a),a.handleMove=a.handleMove.bind(a),a.handleWheel=a.handleWheel.bind(a),a.handleLeave=a.handleLeave.bind(a),a.handleEnter=a.handleEnter.bind(a),n.addEventListener("click",a.handleClick,{capture:!1}),n.addEventListener("contextmenu",a.handleRightClick,{capture:!1}),n.addEventListener("mousedown",a.handleDown,{capture:!1}),n.addEventListener("wheel",a.handleWheel,{capture:!1}),n.addEventListener("mouseleave",a.handleLeave,{capture:!1}),n.addEventListener("mouseenter",a.handleEnter,{capture:!1}),document.addEventListener("mousemove",a.handleMove,{capture:!1}),document.addEventListener("mouseup",a.handleUp,{capture:!1}),a}return qn(t,e),fn(t,[{key:"kill",value:function(){var r=this.container;r.removeEventListener("click",this.handleClick),r.removeEventListener("contextmenu",this.handleRightClick),r.removeEventListener("mousedown",this.handleDown),r.removeEventListener("wheel",this.handleWheel),r.removeEventListener("mouseleave",this.handleLeave),r.removeEventListener("mouseenter",this.handleEnter),document.removeEventListener("mousemove",this.handleMove),document.removeEventListener("mouseup",this.handleUp)}},{key:"handleClick",value:function(r){var a=this;if(this.enabled){if(this.clicks++,this.clicks===2)return this.clicks=0,typeof this.doubleClickTimeout=="number"&&(clearTimeout(this.doubleClickTimeout),this.doubleClickTimeout=null),this.handleDoubleClick(r);setTimeout(function(){a.clicks=0,a.doubleClickTimeout=null},this.settings.doubleClickTimeout),this.draggedEvents<this.settings.draggedEventsTolerance&&this.emit("click",Ma(r,this.container))}}},{key:"handleRightClick",value:function(r){this.enabled&&this.emit("rightClick",Ma(r,this.container))}},{key:"handleDoubleClick",value:function(r){if(this.enabled){r.preventDefault(),r.stopPropagation();var a=Ma(r,this.container);if(this.emit("doubleClick",a),!a.sigmaDefaultPrevented){var o=this.renderer.getCamera(),s=o.getBoundedRatio(o.getState().ratio/this.settings.doubleClickZoomingRatio);o.animate(this.renderer.getViewportZoomedState(zr(r,this.container),s),{easing:"quadraticInOut",duration:this.settings.doubleClickZoomingDuration})}}}},{key:"handleDown",value:function(r){if(this.enabled){if(r.button===0){this.startCameraState=this.renderer.getCamera().getState();var a=zr(r,this.container),o=a.x,s=a.y;this.lastMouseX=o,this.lastMouseY=s,this.draggedEvents=0,this.downStartTime=Date.now(),this.isMouseDown=!0}this.emit("mousedown",Ma(r,this.container))}}},{key:"handleUp",value:function(r){var a=this;if(!(!this.enabled||!this.isMouseDown)){var o=this.renderer.getCamera();this.isMouseDown=!1,typeof this.movingTimeout=="number"&&(clearTimeout(this.movingTimeout),this.movingTimeout=null);var s=zr(r,this.container),l=s.x,u=s.y,d=o.getState(),p=o.getPreviousState()||{x:0,y:0};this.isMoving?o.animate({x:d.x+this.settings.inertiaRatio*(d.x-p.x),y:d.y+this.settings.inertiaRatio*(d.y-p.y)},{duration:this.settings.inertiaDuration,easing:"quadraticOut"}):(this.lastMouseX!==l||this.lastMouseY!==u)&&o.setState({x:d.x,y:d.y}),this.isMoving=!1,setTimeout(function(){var g=a.draggedEvents>0;a.draggedEvents=0,g&&a.renderer.getSetting("hideEdgesOnMove")&&a.renderer.refresh()},0),this.emit("mouseup",Ma(r,this.container))}}},{key:"handleMove",value:function(r){var a=this;if(this.enabled){var o=Ma(r,this.container);if(this.emit("mousemovebody",o),(r.target===this.container||r.composedPath()[0]===this.container)&&this.emit("mousemove",o),!o.sigmaDefaultPrevented&&this.isMouseDown){this.isMoving=!0,this.draggedEvents++,typeof this.movingTimeout=="number"&&clearTimeout(this.movingTimeout),this.movingTimeout=window.setTimeout(function(){a.movingTimeout=null,a.isMoving=!1},this.settings.dragTimeout);var s=this.renderer.getCamera(),l=zr(r,this.container),u=l.x,d=l.y,p=this.renderer.viewportToFramedGraph({x:this.lastMouseX,y:this.lastMouseY}),g=this.renderer.viewportToFramedGraph({x:u,y:d}),m=p.x-g.x,b=p.y-g.y,v=s.getState(),y=v.x+m,k=v.y+b;s.setState({x:y,y:k}),this.lastMouseX=u,this.lastMouseY=d,r.preventDefault(),r.stopPropagation()}}}},{key:"handleLeave",value:function(r){this.emit("mouseleave",Ma(r,this.container))}},{key:"handleEnter",value:function(r){this.emit("mouseenter",Ma(r,this.container))}},{key:"handleWheel",value:function(r){var a=this,o=this.renderer.getCamera();if(!(!this.enabled||!o.enabledZooming)){var s=q4(r);if(s){var l=Tte(r,this.container);if(this.emit("wheel",l),l.sigmaDefaultPrevented){r.preventDefault(),r.stopPropagation();return}var u=o.getState().ratio,d=s>0?1/this.settings.zoomingRatio:this.settings.zoomingRatio,p=o.getBoundedRatio(u*d),g=s>0?1:-1,m=Date.now();u!==p&&(r.preventDefault(),r.stopPropagation(),!(this.currentWheelDirection===g&&this.lastWheelTriggerTime&&m-this.lastWheelTriggerTime<this.settings.zoomDuration/5)&&(o.animate(this.renderer.getViewportZoomedState(zr(r,this.container),p),{easing:"quadraticOut",duration:this.settings.zoomDuration},function(){a.currentWheelDirection=0}),this.currentWheelDirection=g,this.lastWheelTriggerTime=m))}}}},{key:"setSettings",value:function(r){this.settings=r}}])}(V4),Nte=["dragTimeout","inertiaDuration","inertiaRatio","doubleClickTimeout","doubleClickZoomingRatio","doubleClickZoomingDuration","tapMoveTolerance"],Ote=Nte.reduce(function(e,t){return Ue(Ue({},e),{},_e({},t,DT[t]))},{}),Ite=function(e){function t(n,r){var a;return dn(this,t),a=$n(this,t,[n,r]),_e(a,"enabled",!0),_e(a,"isMoving",!1),_e(a,"hasMoved",!1),_e(a,"touchMode",0),_e(a,"startTouchesPositions",[]),_e(a,"lastTouches",[]),_e(a,"lastTap",null),_e(a,"settings",Ote),a.handleStart=a.handleStart.bind(a),a.handleLeave=a.handleLeave.bind(a),a.handleMove=a.handleMove.bind(a),n.addEventListener("touchstart",a.handleStart,{capture:!1}),n.addEventListener("touchcancel",a.handleLeave,{capture:!1}),document.addEventListener("touchend",a.handleLeave,{capture:!1,passive:!1}),document.addEventListener("touchmove",a.handleMove,{capture:!1,passive:!1}),a}return qn(t,e),fn(t,[{key:"kill",value:function(){var r=this.container;r.removeEventListener("touchstart",this.handleStart),r.removeEventListener("touchcancel",this.handleLeave),document.removeEventListener("touchend",this.handleLeave),document.removeEventListener("touchmove",this.handleMove)}},{key:"getDimensions",value:function(){return{width:this.container.offsetWidth,height:this.container.offsetHeight}}},{key:"handleStart",value:function(r){var a=this;if(this.enabled){r.preventDefault();var o=rf(r.touches);if(this.touchMode=o.length,this.startCameraState=this.renderer.getCamera().getState(),this.startTouchesPositions=o.map(function(b){return zr(b,a.container)}),this.touchMode===2){var s=Fs(this.startTouchesPositions,2),l=s[0],u=l.x,d=l.y,p=s[1],g=p.x,m=p.y;this.startTouchesAngle=Math.atan2(m-d,g-u),this.startTouchesDistance=Math.sqrt(Math.pow(g-u,2)+Math.pow(m-d,2))}this.emit("touchdown",sc(r,this.lastTouches,this.container)),this.lastTouches=o,this.lastTouchesPositions=this.startTouchesPositions}}},{key:"handleLeave",value:function(r){if(!(!this.enabled||!this.startTouchesPositions.length)){switch(r.cancelable&&r.preventDefault(),this.movingTimeout&&(this.isMoving=!1,clearTimeout(this.movingTimeout)),this.touchMode){case 2:if(r.touches.length===1){this.handleStart(r),r.preventDefault();break}case 1:if(this.isMoving){var a=this.renderer.getCamera(),o=a.getState(),s=a.getPreviousState()||{x:0,y:0};a.animate({x:o.x+this.settings.inertiaRatio*(o.x-s.x),y:o.y+this.settings.inertiaRatio*(o.y-s.y)},{duration:this.settings.inertiaDuration,easing:"quadraticOut"})}this.hasMoved=!1,this.isMoving=!1,this.touchMode=0;break}if(this.emit("touchup",sc(r,this.lastTouches,this.container)),!r.touches.length){var l=zr(this.lastTouches[0],this.container),u=this.startTouchesPositions[0],d=Math.pow(l.x-u.x,2)+Math.pow(l.y-u.y,2);if(!r.touches.length&&d<Math.pow(this.settings.tapMoveTolerance,2))if(this.lastTap&&Date.now()-this.lastTap.time<this.settings.doubleClickTimeout){var p=sc(r,this.lastTouches,this.container);if(this.emit("doubletap",p),this.lastTap=null,!p.sigmaDefaultPrevented){var g=this.renderer.getCamera(),m=g.getBoundedRatio(g.getState().ratio/this.settings.doubleClickZoomingRatio);g.animate(this.renderer.getViewportZoomedState(l,m),{easing:"quadraticInOut",duration:this.settings.doubleClickZoomingDuration})}}else{var b=sc(r,this.lastTouches,this.container);this.emit("tap",b),this.lastTap={time:Date.now(),position:b.touches[0]||b.previousTouches[0]}}}this.lastTouches=rf(r.touches),this.startTouchesPositions=[]}}},{key:"handleMove",value:function(r){var a=this;if(!(!this.enabled||!this.startTouchesPositions.length)){r.preventDefault();var o=rf(r.touches),s=o.map(function(V){return zr(V,a.container)}),l=this.lastTouches;this.lastTouches=o,this.lastTouchesPositions=s;var u=sc(r,l,this.container);if(this.emit("touchmove",u),!u.sigmaDefaultPrevented&&(this.hasMoved||(this.hasMoved=s.some(function(V,j){var P=a.startTouchesPositions[j];return P&&(V.x!==P.x||V.y!==P.y)})),!!this.hasMoved)){this.isMoving=!0,this.movingTimeout&&clearTimeout(this.movingTimeout),this.movingTimeout=window.setTimeout(function(){a.isMoving=!1},this.settings.dragTimeout);var d=this.renderer.getCamera(),p=this.startCameraState,g=this.renderer.getSetting("stagePadding");switch(this.touchMode){case 1:{var m=this.renderer.viewportToFramedGraph((this.startTouchesPositions||[])[0]),b=m.x,v=m.y,y=this.renderer.viewportToFramedGraph(s[0]),k=y.x,A=y.y;d.setState({x:p.x+b-k,y:p.y+v-A});break}case 2:{var x={x:.5,y:.5,angle:0,ratio:1},R=s[0],O=R.x,N=R.y,C=s[1],_=C.x,M=C.y,I=Math.atan2(M-N,_-O)-this.startTouchesAngle,D=Math.hypot(M-N,_-O)/this.startTouchesDistance,U=d.getBoundedRatio(p.ratio/D);x.ratio=U,x.angle=p.angle+I;var $=this.getDimensions(),B=this.renderer.viewportToFramedGraph((this.startTouchesPositions||[])[0],{cameraState:p}),W=Math.min($.width,$.height)-2*g,K=W/$.width,H=W/$.height,G=U/W,z=O-W/2/K,Y=N-W/2/H,L=[z*Math.cos(-x.angle)-Y*Math.sin(-x.angle),Y*Math.cos(-x.angle)+z*Math.sin(-x.angle)];z=L[0],Y=L[1],x.x=B.x-z*G,x.y=B.y+Y*G,d.setState(x);break}}}}}},{key:"setSettings",value:function(r){this.settings=r}}])}(V4);function Dte(e){if(Array.isArray(e))return V0(e)}function Lte(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function Mte(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function FN(e){return Dte(e)||Lte(e)||A4(e)||Mte()}function Pte(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.includes(r))continue;n[r]=e[r]}return n}function Rm(e,t){if(e==null)return{};var n,r,a=Pte(e,t);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);for(r=0;r<o.length;r++)n=o[r],t.includes(n)||{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}var zN=function(){function e(t,n){dn(this,e),this.key=t,this.size=n}return fn(e,null,[{key:"compare",value:function(n,r){return n.size>r.size?-1:n.size<r.size||n.key>r.key?1:-1}}])}(),BN=function(){function e(){dn(this,e),_e(this,"width",0),_e(this,"height",0),_e(this,"cellSize",0),_e(this,"columns",0),_e(this,"rows",0),_e(this,"cells",{})}return fn(e,[{key:"resizeAndClear",value:function(n,r){this.width=n.width,this.height=n.height,this.cellSize=r,this.columns=Math.ceil(n.width/r),this.rows=Math.ceil(n.height/r),this.cells={}}},{key:"getIndex",value:function(n){var r=Math.floor(n.x/this.cellSize),a=Math.floor(n.y/this.cellSize);return a*this.columns+r}},{key:"add",value:function(n,r,a){var o=new zN(n,r),s=this.getIndex(a),l=this.cells[s];l||(l=[],this.cells[s]=l),l.push(o)}},{key:"organize",value:function(){for(var n in this.cells){var r=this.cells[n];r.sort(zN.compare)}}},{key:"getLabelsToDisplay",value:function(n,r){var a=this.cellSize*this.cellSize,o=a/n/n,s=o*r/a,l=Math.ceil(s),u=[];for(var d in this.cells)for(var p=this.cells[d],g=0;g<Math.min(l,p.length);g++)u.push(p[g].key);return u}}])}();function Fte(e){var t=e.graph,n=e.hoveredNode,r=e.highlightedNodes,a=e.displayedNodeLabels,o=[];return t.forEachEdge(function(s,l,u,d){(u===n||d===n||r.has(u)||r.has(d)||a.has(u)&&a.has(d))&&o.push(s)}),o}var zte=150,Bte=50,Pa=Object.prototype.hasOwnProperty;function jte(e,t,n){if(!Pa.call(n,"x")||!Pa.call(n,"y"))throw new Error('Sigma: could not find a valid position (x, y) for node "'.concat(t,'". All your nodes must have a number "x" and "y". Maybe your forgot to apply a layout or your "nodeReducer" is not returning the correct data?'));return n.color||(n.color=e.defaultNodeColor),!n.label&&n.label!==""&&(n.label=null),n.label!==void 0&&n.label!==null?n.label=""+n.label:n.label=null,n.size||(n.size=2),Pa.call(n,"hidden")||(n.hidden=!1),Pa.call(n,"highlighted")||(n.highlighted=!1),Pa.call(n,"forceLabel")||(n.forceLabel=!1),(!n.type||n.type==="")&&(n.type=e.defaultNodeType),n.zIndex||(n.zIndex=0),n}function Ute(e,t,n){return n.color||(n.color=e.defaultEdgeColor),n.label||(n.label=""),n.size||(n.size=.5),Pa.call(n,"hidden")||(n.hidden=!1),Pa.call(n,"forceLabel")||(n.forceLabel=!1),(!n.type||n.type==="")&&(n.type=e.defaultEdgeType),n.zIndex||(n.zIndex=0),n}var Gte=function(e){function t(n,r){var a,o=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};if(dn(this,t),a=$n(this,t),_e(a,"elements",{}),_e(a,"canvasContexts",{}),_e(a,"webGLContexts",{}),_e(a,"pickingLayers",new Set),_e(a,"textures",{}),_e(a,"frameBuffers",{}),_e(a,"activeListeners",{}),_e(a,"labelGrid",new BN),_e(a,"nodeDataCache",{}),_e(a,"edgeDataCache",{}),_e(a,"nodeProgramIndex",{}),_e(a,"edgeProgramIndex",{}),_e(a,"nodesWithForcedLabels",new Set),_e(a,"edgesWithForcedLabels",new Set),_e(a,"nodeExtent",{x:[0,1],y:[0,1]}),_e(a,"nodeZExtent",[1/0,-1/0]),_e(a,"edgeZExtent",[1/0,-1/0]),_e(a,"matrix",Fr()),_e(a,"invMatrix",Fr()),_e(a,"correctionRatio",1),_e(a,"customBBox",null),_e(a,"normalizationFunction",LN({x:[0,1],y:[0,1]})),_e(a,"graphToViewportRatio",1),_e(a,"itemIDsIndex",{}),_e(a,"nodeIndices",{}),_e(a,"edgeIndices",{}),_e(a,"width",0),_e(a,"height",0),_e(a,"pixelRatio",IN()),_e(a,"pickingDownSizingRatio",2*a.pixelRatio),_e(a,"displayedNodeLabels",new Set),_e(a,"displayedEdgeLabels",new Set),_e(a,"highlightedNodes",new Set),_e(a,"hoveredNode",null),_e(a,"hoveredEdge",null),_e(a,"renderFrame",null),_e(a,"renderHighlightedNodesFrame",null),_e(a,"needToProcess",!1),_e(a,"checkEdgesEventsFrame",null),_e(a,"nodePrograms",{}),_e(a,"nodeHoverPrograms",{}),_e(a,"edgePrograms",{}),a.settings=kte(o),Am(a.settings),Ste(n),!(r instanceof HTMLElement))throw new Error("Sigma: container should be an html element.");a.graph=n,a.container=r,a.createWebGLContext("edges",{picking:o.enableEdgeEvents}),a.createCanvasContext("edgeLabels"),a.createWebGLContext("nodes",{picking:!0}),a.createCanvasContext("labels"),a.createCanvasContext("hovers"),a.createWebGLContext("hoverNodes"),a.createCanvasContext("mouse",{style:{touchAction:"none",userSelect:"none"}}),a.resize();for(var s in a.settings.nodeProgramClasses)a.registerNodeProgram(s,a.settings.nodeProgramClasses[s],a.settings.nodeHoverProgramClasses[s]);for(var l in a.settings.edgeProgramClasses)a.registerEdgeProgram(l,a.settings.edgeProgramClasses[l]);return a.camera=new PN,a.bindCameraHandlers(),a.mouseCaptor=new _te(a.elements.mouse,a),a.mouseCaptor.setSettings(a.settings),a.touchCaptor=new Ite(a.elements.mouse,a),a.touchCaptor.setSettings(a.settings),a.bindEventHandlers(),a.bindGraphHandlers(),a.handleSettingsUpdate(),a.refresh(),a}return qn(t,e),fn(t,[{key:"registerNodeProgram",value:function(r,a,o){return this.nodePrograms[r]&&this.nodePrograms[r].kill(),this.nodeHoverPrograms[r]&&this.nodeHoverPrograms[r].kill(),this.nodePrograms[r]=new a(this.webGLContexts.nodes,this.frameBuffers.nodes,this),this.nodeHoverPrograms[r]=new(o||a)(this.webGLContexts.hoverNodes,null,this),this}},{key:"registerEdgeProgram",value:function(r,a){return this.edgePrograms[r]&&this.edgePrograms[r].kill(),this.edgePrograms[r]=new a(this.webGLContexts.edges,this.frameBuffers.edges,this),this}},{key:"unregisterNodeProgram",value:function(r){if(this.nodePrograms[r]){var a=this.nodePrograms,o=a[r],s=Rm(a,[r].map(mc));o.kill(),this.nodePrograms=s}if(this.nodeHoverPrograms[r]){var l=this.nodeHoverPrograms,u=l[r],d=Rm(l,[r].map(mc));u.kill(),this.nodePrograms=d}return this}},{key:"unregisterEdgeProgram",value:function(r){if(this.edgePrograms[r]){var a=this.edgePrograms,o=a[r],s=Rm(a,[r].map(mc));o.kill(),this.edgePrograms=s}return this}},{key:"resetWebGLTexture",value:function(r){var a=this.webGLContexts[r],o=this.frameBuffers[r],s=this.textures[r];s&&a.deleteTexture(s);var l=a.createTexture();return a.bindFramebuffer(a.FRAMEBUFFER,o),a.bindTexture(a.TEXTURE_2D,l),a.texImage2D(a.TEXTURE_2D,0,a.RGBA,this.width,this.height,0,a.RGBA,a.UNSIGNED_BYTE,null),a.framebufferTexture2D(a.FRAMEBUFFER,a.COLOR_ATTACHMENT0,a.TEXTURE_2D,l,0),this.textures[r]=l,this}},{key:"bindCameraHandlers",value:function(){var r=this;return this.activeListeners.camera=function(){r.scheduleRender()},this.camera.on("updated",this.activeListeners.camera),this}},{key:"unbindCameraHandlers",value:function(){return this.camera.removeListener("updated",this.activeListeners.camera),this}},{key:"getNodeAtPosition",value:function(r){var a=r.x,o=r.y,s=SN(this.webGLContexts.nodes,this.frameBuffers.nodes,a,o,this.pixelRatio,this.pickingDownSizingRatio),l=vN.apply(void 0,FN(s)),u=this.itemIDsIndex[l];return u&&u.type==="node"?u.id:null}},{key:"bindEventHandlers",value:function(){var r=this;this.activeListeners.handleResize=function(){r.scheduleRefresh()},window.addEventListener("resize",this.activeListeners.handleResize),this.activeListeners.handleMove=function(o){var s=ic(o),l={event:s,preventSigmaDefault:function(){s.preventSigmaDefault()}},u=r.getNodeAtPosition(s);if(u&&r.hoveredNode!==u&&!r.nodeDataCache[u].hidden){r.hoveredNode&&r.emit("leaveNode",Ue(Ue({},l),{},{node:r.hoveredNode})),r.hoveredNode=u,r.emit("enterNode",Ue(Ue({},l),{},{node:u})),r.scheduleHighlightedNodesRender();return}if(r.hoveredNode&&r.getNodeAtPosition(s)!==r.hoveredNode){var d=r.hoveredNode;r.hoveredNode=null,r.emit("leaveNode",Ue(Ue({},l),{},{node:d})),r.scheduleHighlightedNodesRender();return}if(r.settings.enableEdgeEvents){var p=r.hoveredNode?null:r.getEdgeAtPoint(l.event.x,l.event.y);p!==r.hoveredEdge&&(r.hoveredEdge&&r.emit("leaveEdge",Ue(Ue({},l),{},{edge:r.hoveredEdge})),p&&r.emit("enterEdge",Ue(Ue({},l),{},{edge:p})),r.hoveredEdge=p)}},this.activeListeners.handleMoveBody=function(o){var s=ic(o);r.emit("moveBody",{event:s,preventSigmaDefault:function(){s.preventSigmaDefault()}})},this.activeListeners.handleLeave=function(o){var s=ic(o),l={event:s,preventSigmaDefault:function(){s.preventSigmaDefault()}};r.hoveredNode&&(r.emit("leaveNode",Ue(Ue({},l),{},{node:r.hoveredNode})),r.scheduleHighlightedNodesRender()),r.settings.enableEdgeEvents&&r.hoveredEdge&&(r.emit("leaveEdge",Ue(Ue({},l),{},{edge:r.hoveredEdge})),r.scheduleHighlightedNodesRender()),r.emit("leaveStage",Ue({},l))},this.activeListeners.handleEnter=function(o){var s=ic(o),l={event:s,preventSigmaDefault:function(){s.preventSigmaDefault()}};r.emit("enterStage",Ue({},l))};var a=function(s){return function(l){var u=ic(l),d={event:u,preventSigmaDefault:function(){u.preventSigmaDefault()}},p=r.getNodeAtPosition(u);if(p)return r.emit("".concat(s,"Node"),Ue(Ue({},d),{},{node:p}));if(r.settings.enableEdgeEvents){var g=r.getEdgeAtPoint(u.x,u.y);if(g)return r.emit("".concat(s,"Edge"),Ue(Ue({},d),{},{edge:g}))}return r.emit("".concat(s,"Stage"),d)}};return this.activeListeners.handleClick=a("click"),this.activeListeners.handleRightClick=a("rightClick"),this.activeListeners.handleDoubleClick=a("doubleClick"),this.activeListeners.handleWheel=a("wheel"),this.activeListeners.handleDown=a("down"),this.activeListeners.handleUp=a("up"),this.mouseCaptor.on("mousemove",this.activeListeners.handleMove),this.mouseCaptor.on("mousemovebody",this.activeListeners.handleMoveBody),this.mouseCaptor.on("click",this.activeListeners.handleClick),this.mouseCaptor.on("rightClick",this.activeListeners.handleRightClick),this.mouseCaptor.on("doubleClick",this.activeListeners.handleDoubleClick),this.mouseCaptor.on("wheel",this.activeListeners.handleWheel),this.mouseCaptor.on("mousedown",this.activeListeners.handleDown),this.mouseCaptor.on("mouseup",this.activeListeners.handleUp),this.mouseCaptor.on("mouseleave",this.activeListeners.handleLeave),this.mouseCaptor.on("mouseenter",this.activeListeners.handleEnter),this.touchCaptor.on("touchdown",this.activeListeners.handleDown),this.touchCaptor.on("touchdown",this.activeListeners.handleMove),this.touchCaptor.on("touchup",this.activeListeners.handleUp),this.touchCaptor.on("touchmove",this.activeListeners.handleMove),this.touchCaptor.on("tap",this.activeListeners.handleClick),this.touchCaptor.on("doubletap",this.activeListeners.handleDoubleClick),this.touchCaptor.on("touchmove",this.activeListeners.handleMoveBody),this}},{key:"bindGraphHandlers",value:function(){var r=this,a=this.graph,o=new Set(["x","y","zIndex","type"]);return this.activeListeners.eachNodeAttributesUpdatedGraphUpdate=function(s){var l,u=(l=s.hints)===null||l===void 0?void 0:l.attributes;r.graph.forEachNode(function(p){return r.updateNode(p)});var d=!u||u.some(function(p){return o.has(p)});r.refresh({partialGraph:{nodes:a.nodes()},skipIndexation:!d,schedule:!0})},this.activeListeners.eachEdgeAttributesUpdatedGraphUpdate=function(s){var l,u=(l=s.hints)===null||l===void 0?void 0:l.attributes;r.graph.forEachEdge(function(p){return r.updateEdge(p)});var d=u&&["zIndex","type"].some(function(p){return u==null?void 0:u.includes(p)});r.refresh({partialGraph:{edges:a.edges()},skipIndexation:!d,schedule:!0})},this.activeListeners.addNodeGraphUpdate=function(s){var l=s.key;r.addNode(l),r.refresh({partialGraph:{nodes:[l]},skipIndexation:!1,schedule:!0})},this.activeListeners.updateNodeGraphUpdate=function(s){var l=s.key;r.refresh({partialGraph:{nodes:[l]},skipIndexation:!1,schedule:!0})},this.activeListeners.dropNodeGraphUpdate=function(s){var l=s.key;r.removeNode(l),r.refresh({schedule:!0})},this.activeListeners.addEdgeGraphUpdate=function(s){var l=s.key;r.addEdge(l),r.refresh({partialGraph:{edges:[l]},schedule:!0})},this.activeListeners.updateEdgeGraphUpdate=function(s){var l=s.key;r.refresh({partialGraph:{edges:[l]},skipIndexation:!1,schedule:!0})},this.activeListeners.dropEdgeGraphUpdate=function(s){var l=s.key;r.removeEdge(l),r.refresh({schedule:!0})},this.activeListeners.clearEdgesGraphUpdate=function(){r.clearEdgeState(),r.clearEdgeIndices(),r.refresh({schedule:!0})},this.activeListeners.clearGraphUpdate=function(){r.clearEdgeState(),r.clearNodeState(),r.clearEdgeIndices(),r.clearNodeIndices(),r.refresh({schedule:!0})},a.on("nodeAdded",this.activeListeners.addNodeGraphUpdate),a.on("nodeDropped",this.activeListeners.dropNodeGraphUpdate),a.on("nodeAttributesUpdated",this.activeListeners.updateNodeGraphUpdate),a.on("eachNodeAttributesUpdated",this.activeListeners.eachNodeAttributesUpdatedGraphUpdate),a.on("edgeAdded",this.activeListeners.addEdgeGraphUpdate),a.on("edgeDropped",this.activeListeners.dropEdgeGraphUpdate),a.on("edgeAttributesUpdated",this.activeListeners.updateEdgeGraphUpdate),a.on("eachEdgeAttributesUpdated",this.activeListeners.eachEdgeAttributesUpdatedGraphUpdate),a.on("edgesCleared",this.activeListeners.clearEdgesGraphUpdate),a.on("cleared",this.activeListeners.clearGraphUpdate),this}},{key:"unbindGraphHandlers",value:function(){var r=this.graph;r.removeListener("nodeAdded",this.activeListeners.addNodeGraphUpdate),r.removeListener("nodeDropped",this.activeListeners.dropNodeGraphUpdate),r.removeListener("nodeAttributesUpdated",this.activeListeners.updateNodeGraphUpdate),r.removeListener("eachNodeAttributesUpdated",this.activeListeners.eachNodeAttributesUpdatedGraphUpdate),r.removeListener("edgeAdded",this.activeListeners.addEdgeGraphUpdate),r.removeListener("edgeDropped",this.activeListeners.dropEdgeGraphUpdate),r.removeListener("edgeAttributesUpdated",this.activeListeners.updateEdgeGraphUpdate),r.removeListener("eachEdgeAttributesUpdated",this.activeListeners.eachEdgeAttributesUpdatedGraphUpdate),r.removeListener("edgesCleared",this.activeListeners.clearEdgesGraphUpdate),r.removeListener("cleared",this.activeListeners.clearGraphUpdate)}},{key:"getEdgeAtPoint",value:function(r,a){var o=SN(this.webGLContexts.edges,this.frameBuffers.edges,r,a,this.pixelRatio,this.pickingDownSizingRatio),s=vN.apply(void 0,FN(o)),l=this.itemIDsIndex[s];return l&&l.type==="edge"?l.id:null}},{key:"process",value:function(){var r=this;this.emit("beforeProcess");var a=this.graph,o=this.settings,s=this.getDimensions();if(this.nodeExtent=vte(this.graph),!this.settings.autoRescale){var l=s.width,u=s.height,d=this.nodeExtent,p=d.x,g=d.y;this.nodeExtent={x:[(p[0]+p[1])/2-l/2,(p[0]+p[1])/2+l/2],y:[(g[0]+g[1])/2-u/2,(g[0]+g[1])/2+u/2]}}this.normalizationFunction=LN(this.customBBox||this.nodeExtent);var m=new PN,b=oc(m.getState(),s,this.getGraphDimensions(),this.getStagePadding());this.labelGrid.resizeAndClear(s,o.labelGridCellSize);for(var v={},y={},k={},A={},x=1,R=a.nodes(),O=0,N=R.length;O<N;O++){var C=R[O],_=this.nodeDataCache[C],M=a.getNodeAttributes(C);_.x=M.x,_.y=M.y,this.normalizationFunction.applyTo(_),typeof _.label=="string"&&!_.hidden&&this.labelGrid.add(C,_.size,this.framedGraphToViewport(_,{matrix:b})),v[_.type]=(v[_.type]||0)+1}this.labelGrid.organize();for(var I in this.nodePrograms){if(!Pa.call(this.nodePrograms,I))throw new Error('Sigma: could not find a suitable program for node type "'.concat(I,'"!'));this.nodePrograms[I].reallocate(v[I]||0),v[I]=0}this.settings.zIndex&&this.nodeZExtent[0]!==this.nodeZExtent[1]&&(R=DN(this.nodeZExtent,function(Q){return r.nodeDataCache[Q].zIndex},R));for(var D=0,U=R.length;D<U;D++){var $=R[D];y[$]=x,A[y[$]]={type:"node",id:$},x++;var B=this.nodeDataCache[$];this.addNodeToProgram($,y[$],v[B.type]++)}for(var W={},K=a.edges(),H=0,G=K.length;H<G;H++){var z=K[H],Y=this.edgeDataCache[z];W[Y.type]=(W[Y.type]||0)+1}this.settings.zIndex&&this.edgeZExtent[0]!==this.edgeZExtent[1]&&(K=DN(this.edgeZExtent,function(Q){return r.edgeDataCache[Q].zIndex},K));for(var L in this.edgePrograms){if(!Pa.call(this.edgePrograms,L))throw new Error('Sigma: could not find a suitable program for edge type "'.concat(L,'"!'));this.edgePrograms[L].reallocate(W[L]||0),W[L]=0}for(var V=0,j=K.length;V<j;V++){var P=K[V];k[P]=x,A[k[P]]={type:"edge",id:P},x++;var Z=this.edgeDataCache[P];this.addEdgeToProgram(P,k[P],W[Z.type]++)}return this.itemIDsIndex=A,this.nodeIndices=y,this.edgeIndices=k,this.emit("afterProcess"),this}},{key:"handleSettingsUpdate",value:function(r){var a=this,o=this.settings;if(this.camera.minRatio=o.minCameraRatio,this.camera.maxRatio=o.maxCameraRatio,this.camera.enabledZooming=o.enableCameraZooming,this.camera.enabledPanning=o.enableCameraPanning,this.camera.enabledRotation=o.enableCameraRotation,o.cameraPanBoundaries?this.camera.clean=function(p){return a.cleanCameraState(p,o.cameraPanBoundaries&&K0(o.cameraPanBoundaries)==="object"?o.cameraPanBoundaries:{})}:this.camera.clean=null,this.camera.setState(this.camera.validateState(this.camera.getState())),r){if(r.edgeProgramClasses!==o.edgeProgramClasses){for(var s in o.edgeProgramClasses)o.edgeProgramClasses[s]!==r.edgeProgramClasses[s]&&this.registerEdgeProgram(s,o.edgeProgramClasses[s]);for(var l in r.edgeProgramClasses)o.edgeProgramClasses[l]||this.unregisterEdgeProgram(l)}if(r.nodeProgramClasses!==o.nodeProgramClasses||r.nodeHoverProgramClasses!==o.nodeHoverProgramClasses){for(var u in o.nodeProgramClasses)(o.nodeProgramClasses[u]!==r.nodeProgramClasses[u]||o.nodeHoverProgramClasses[u]!==r.nodeHoverProgramClasses[u])&&this.registerNodeProgram(u,o.nodeProgramClasses[u],o.nodeHoverProgramClasses[u]);for(var d in r.nodeProgramClasses)o.nodeProgramClasses[d]||this.unregisterNodeProgram(d)}}return this.mouseCaptor.setSettings(this.settings),this.touchCaptor.setSettings(this.settings),this}},{key:"cleanCameraState",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},o=a.tolerance,s=o===void 0?0:o,l=a.boundaries,u=Ue({},r),d=l||this.nodeExtent,p=Fs(d.x,2),g=p[0],m=p[1],b=Fs(d.y,2),v=b[0],y=b[1],k=[this.graphToViewport({x:g,y:v},{cameraState:r}),this.graphToViewport({x:m,y:v},{cameraState:r}),this.graphToViewport({x:g,y},{cameraState:r}),this.graphToViewport({x:m,y},{cameraState:r})],A=1/0,x=-1/0,R=1/0,O=-1/0;k.forEach(function(W){var K=W.x,H=W.y;A=Math.min(A,K),x=Math.max(x,K),R=Math.min(R,H),O=Math.max(O,H)});var N=x-A,C=O-R,_=this.getDimensions(),M=_.width,I=_.height,D=0,U=0;if(N>=M?x<M-s?D=x-(M-s):A>s&&(D=A-s):x>M+s?D=x-(M+s):A<-s&&(D=A+s),C>=I?O<I-s?U=O-(I-s):R>s&&(U=R-s):O>I+s?U=O-(I+s):R<-s&&(U=R+s),D||U){var $=this.viewportToFramedGraph({x:0,y:0},{cameraState:r}),B=this.viewportToFramedGraph({x:D,y:U},{cameraState:r});D=B.x-$.x,U=B.y-$.y,u.x+=D,u.y+=U}return u}},{key:"renderLabels",value:function(){if(!this.settings.renderLabels)return this;var r=this.camera.getState(),a=this.labelGrid.getLabelsToDisplay(r.ratio,this.settings.labelDensity);MN(a,this.nodesWithForcedLabels),this.displayedNodeLabels=new Set;for(var o=this.canvasContexts.labels,s=0,l=a.length;s<l;s++){var u=a[s],d=this.nodeDataCache[u];if(!this.displayedNodeLabels.has(u)&&!d.hidden){var p=this.framedGraphToViewport(d),g=p.x,m=p.y,b=this.scaleSize(d.size);if(!(!d.forceLabel&&b<this.settings.labelRenderedSizeThreshold)&&!(g<-150||g>this.width+zte||m<-50||m>this.height+Bte)){this.displayedNodeLabels.add(u);var v=this.settings.defaultDrawNodeLabel,y=this.nodePrograms[d.type],k=(y==null?void 0:y.drawLabel)||v;k(o,Ue(Ue({key:u},d),{},{size:b,x:g,y:m}),this.settings)}}}return this}},{key:"renderEdgeLabels",value:function(){if(!this.settings.renderEdgeLabels)return this;var r=this.canvasContexts.edgeLabels;r.clearRect(0,0,this.width,this.height);var a=Fte({graph:this.graph,hoveredNode:this.hoveredNode,displayedNodeLabels:this.displayedNodeLabels,highlightedNodes:this.highlightedNodes});MN(a,this.edgesWithForcedLabels);for(var o=new Set,s=0,l=a.length;s<l;s++){var u=a[s],d=this.graph.extremities(u),p=this.nodeDataCache[d[0]],g=this.nodeDataCache[d[1]],m=this.edgeDataCache[u];if(!o.has(u)&&!(m.hidden||p.hidden||g.hidden)){var b=this.settings.defaultDrawEdgeLabel,v=this.edgePrograms[m.type],y=(v==null?void 0:v.drawLabel)||b;y(r,Ue(Ue({key:u},m),{},{size:this.scaleSize(m.size)}),Ue(Ue(Ue({key:d[0]},p),this.framedGraphToViewport(p)),{},{size:this.scaleSize(p.size)}),Ue(Ue(Ue({key:d[1]},g),this.framedGraphToViewport(g)),{},{size:this.scaleSize(g.size)}),this.settings),o.add(u)}}return this.displayedEdgeLabels=o,this}},{key:"renderHighlightedNodes",value:function(){var r=this,a=this.canvasContexts.hovers;a.clearRect(0,0,this.width,this.height);var o=function(b){var v=r.nodeDataCache[b],y=r.framedGraphToViewport(v),k=y.x,A=y.y,x=r.scaleSize(v.size),R=r.settings.defaultDrawNodeHover,O=r.nodePrograms[v.type],N=(O==null?void 0:O.drawHover)||R;N(a,Ue(Ue({key:b},v),{},{size:x,x:k,y:A}),r.settings)},s=[];this.hoveredNode&&!this.nodeDataCache[this.hoveredNode].hidden&&s.push(this.hoveredNode),this.highlightedNodes.forEach(function(m){m!==r.hoveredNode&&s.push(m)}),s.forEach(function(m){return o(m)});var l={};s.forEach(function(m){var b=r.nodeDataCache[m].type;l[b]=(l[b]||0)+1});for(var u in this.nodeHoverPrograms)this.nodeHoverPrograms[u].reallocate(l[u]||0),l[u]=0;s.forEach(function(m){var b=r.nodeDataCache[m];r.nodeHoverPrograms[b.type].process(0,l[b.type]++,b)}),this.webGLContexts.hoverNodes.clear(this.webGLContexts.hoverNodes.COLOR_BUFFER_BIT);var d=this.getRenderParams();for(var p in this.nodeHoverPrograms){var g=this.nodeHoverPrograms[p];g.render(d)}}},{key:"scheduleHighlightedNodesRender",value:function(){var r=this;this.renderHighlightedNodesFrame||this.renderFrame||(this.renderHighlightedNodesFrame=requestAnimationFrame(function(){r.renderHighlightedNodesFrame=null,r.renderHighlightedNodes(),r.renderEdgeLabels()}))}},{key:"render",value:function(){var r=this;this.emit("beforeRender");var a=function(){return r.emit("afterRender"),r};if(this.renderFrame&&(cancelAnimationFrame(this.renderFrame),this.renderFrame=null),this.resize(),this.needToProcess&&this.process(),this.needToProcess=!1,this.clear(),this.pickingLayers.forEach(function(k){return r.resetWebGLTexture(k)}),!this.graph.order)return a();var o=this.mouseCaptor,s=this.camera.isAnimated()||o.isMoving||o.draggedEvents||o.currentWheelDirection,l=this.camera.getState(),u=this.getDimensions(),d=this.getGraphDimensions(),p=this.getStagePadding();this.matrix=oc(l,u,d,p),this.invMatrix=oc(l,u,d,p,!0),this.correctionRatio=yte(this.matrix,l,u),this.graphToViewportRatio=this.getGraphToViewportRatio();var g=this.getRenderParams();for(var m in this.nodePrograms){var b=this.nodePrograms[m];b.render(g)}if(!this.settings.hideEdgesOnMove||!s)for(var v in this.edgePrograms){var y=this.edgePrograms[v];y.render(g)}return this.settings.hideLabelsOnMove&&s||(this.renderLabels(),this.renderEdgeLabels(),this.renderHighlightedNodes()),a()}},{key:"addNode",value:function(r){var a=Object.assign({},this.graph.getNodeAttributes(r));this.settings.nodeReducer&&(a=this.settings.nodeReducer(r,a));var o=jte(this.settings,r,a);this.nodeDataCache[r]=o,this.nodesWithForcedLabels.delete(r),o.forceLabel&&!o.hidden&&this.nodesWithForcedLabels.add(r),this.highlightedNodes.delete(r),o.highlighted&&!o.hidden&&this.highlightedNodes.add(r),this.settings.zIndex&&(o.zIndex<this.nodeZExtent[0]&&(this.nodeZExtent[0]=o.zIndex),o.zIndex>this.nodeZExtent[1]&&(this.nodeZExtent[1]=o.zIndex))}},{key:"updateNode",value:function(r){this.addNode(r);var a=this.nodeDataCache[r];this.normalizationFunction.applyTo(a)}},{key:"removeNode",value:function(r){delete this.nodeDataCache[r],delete this.nodeProgramIndex[r],this.highlightedNodes.delete(r),this.hoveredNode===r&&(this.hoveredNode=null),this.nodesWithForcedLabels.delete(r)}},{key:"addEdge",value:function(r){var a=Object.assign({},this.graph.getEdgeAttributes(r));this.settings.edgeReducer&&(a=this.settings.edgeReducer(r,a));var o=Ute(this.settings,r,a);this.edgeDataCache[r]=o,this.edgesWithForcedLabels.delete(r),o.forceLabel&&!o.hidden&&this.edgesWithForcedLabels.add(r),this.settings.zIndex&&(o.zIndex<this.edgeZExtent[0]&&(this.edgeZExtent[0]=o.zIndex),o.zIndex>this.edgeZExtent[1]&&(this.edgeZExtent[1]=o.zIndex))}},{key:"updateEdge",value:function(r){this.addEdge(r)}},{key:"removeEdge",value:function(r){delete this.edgeDataCache[r],delete this.edgeProgramIndex[r],this.hoveredEdge===r&&(this.hoveredEdge=null),this.edgesWithForcedLabels.delete(r)}},{key:"clearNodeIndices",value:function(){this.labelGrid=new BN,this.nodeExtent={x:[0,1],y:[0,1]},this.nodeDataCache={},this.edgeProgramIndex={},this.nodesWithForcedLabels=new Set,this.nodeZExtent=[1/0,-1/0]}},{key:"clearEdgeIndices",value:function(){this.edgeDataCache={},this.edgeProgramIndex={},this.edgesWithForcedLabels=new Set,this.edgeZExtent=[1/0,-1/0]}},{key:"clearIndices",value:function(){this.clearEdgeIndices(),this.clearNodeIndices()}},{key:"clearNodeState",value:function(){this.displayedNodeLabels=new Set,this.highlightedNodes=new Set,this.hoveredNode=null}},{key:"clearEdgeState",value:function(){this.displayedEdgeLabels=new Set,this.highlightedNodes=new Set,this.hoveredEdge=null}},{key:"clearState",value:function(){this.clearEdgeState(),this.clearNodeState()}},{key:"addNodeToProgram",value:function(r,a,o){var s=this.nodeDataCache[r],l=this.nodePrograms[s.type];if(!l)throw new Error('Sigma: could not find a suitable program for node type "'.concat(s.type,'"!'));l.process(a,o,s),this.nodeProgramIndex[r]=o}},{key:"addEdgeToProgram",value:function(r,a,o){var s=this.edgeDataCache[r],l=this.edgePrograms[s.type];if(!l)throw new Error('Sigma: could not find a suitable program for edge type "'.concat(s.type,'"!'));var u=this.graph.extremities(r),d=this.nodeDataCache[u[0]],p=this.nodeDataCache[u[1]];l.process(a,o,d,p,s),this.edgeProgramIndex[r]=o}},{key:"getRenderParams",value:function(){return{matrix:this.matrix,invMatrix:this.invMatrix,width:this.width,height:this.height,pixelRatio:this.pixelRatio,zoomRatio:this.camera.ratio,cameraAngle:this.camera.angle,sizeRatio:1/this.scaleSize(),correctionRatio:this.correctionRatio,downSizingRatio:this.pickingDownSizingRatio,minEdgeThickness:this.settings.minEdgeThickness,antiAliasingFeather:this.settings.antiAliasingFeather}}},{key:"getStagePadding",value:function(){var r=this.settings,a=r.stagePadding,o=r.autoRescale;return o&&a||0}},{key:"createLayer",value:function(r,a){var o=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};if(this.elements[r])throw new Error('Sigma: a layer named "'.concat(r,'" already exists'));var s=Ete(a,{position:"absolute"},{class:"sigma-".concat(r)});return o.style&&Object.assign(s.style,o.style),this.elements[r]=s,"beforeLayer"in o&&o.beforeLayer?this.elements[o.beforeLayer].before(s):"afterLayer"in o&&o.afterLayer?this.elements[o.afterLayer].after(s):this.container.appendChild(s),s}},{key:"createCanvas",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};return this.createLayer(r,"canvas",a)}},{key:"createCanvasContext",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},o=this.createCanvas(r,a),s={preserveDrawingBuffer:!1,antialias:!1};return this.canvasContexts[r]=o.getContext("2d",s),this}},{key:"createWebGLContext",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},o=(a==null?void 0:a.canvas)||this.createCanvas(r,a);a.hidden&&o.remove();var s=Ue({preserveDrawingBuffer:!1,antialias:!1},a),l;l=o.getContext("webgl2",s),l||(l=o.getContext("webgl",s)),l||(l=o.getContext("experimental-webgl",s));var u=l;if(this.webGLContexts[r]=u,u.blendFunc(u.ONE,u.ONE_MINUS_SRC_ALPHA),a.picking){this.pickingLayers.add(r);var d=u.createFramebuffer();if(!d)throw new Error("Sigma: cannot create a new frame buffer for layer ".concat(r));this.frameBuffers[r]=d}return u}},{key:"killLayer",value:function(r){var a=this.elements[r];if(!a)throw new Error("Sigma: cannot kill layer ".concat(r,", which does not exist"));if(this.webGLContexts[r]){var o,s=this.webGLContexts[r];(o=s.getExtension("WEBGL_lose_context"))===null||o===void 0||o.loseContext(),delete this.webGLContexts[r]}else this.canvasContexts[r]&&delete this.canvasContexts[r];return a.remove(),delete this.elements[r],this}},{key:"getCamera",value:function(){return this.camera}},{key:"setCamera",value:function(r){this.unbindCameraHandlers(),this.camera=r,this.bindCameraHandlers()}},{key:"getContainer",value:function(){return this.container}},{key:"getGraph",value:function(){return this.graph}},{key:"setGraph",value:function(r){r!==this.graph&&(this.hoveredNode&&!r.hasNode(this.hoveredNode)&&(this.hoveredNode=null),this.hoveredEdge&&!r.hasEdge(this.hoveredEdge)&&(this.hoveredEdge=null),this.unbindGraphHandlers(),this.checkEdgesEventsFrame!==null&&(cancelAnimationFrame(this.checkEdgesEventsFrame),this.checkEdgesEventsFrame=null),this.graph=r,this.bindGraphHandlers(),this.refresh())}},{key:"getMouseCaptor",value:function(){return this.mouseCaptor}},{key:"getTouchCaptor",value:function(){return this.touchCaptor}},{key:"getDimensions",value:function(){return{width:this.width,height:this.height}}},{key:"getGraphDimensions",value:function(){var r=this.customBBox||this.nodeExtent;return{width:r.x[1]-r.x[0]||1,height:r.y[1]-r.y[0]||1}}},{key:"getNodeDisplayData",value:function(r){var a=this.nodeDataCache[r];return a?Object.assign({},a):void 0}},{key:"getEdgeDisplayData",value:function(r){var a=this.edgeDataCache[r];return a?Object.assign({},a):void 0}},{key:"getNodeDisplayedLabels",value:function(){return new Set(this.displayedNodeLabels)}},{key:"getEdgeDisplayedLabels",value:function(){return new Set(this.displayedEdgeLabels)}},{key:"getSettings",value:function(){return Ue({},this.settings)}},{key:"getSetting",value:function(r){return this.settings[r]}},{key:"setSetting",value:function(r,a){var o=Ue({},this.settings);return this.settings[r]=a,Am(this.settings),this.handleSettingsUpdate(o),this.scheduleRefresh(),this}},{key:"updateSetting",value:function(r,a){return this.setSetting(r,a(this.settings[r])),this}},{key:"setSettings",value:function(r){var a=Ue({},this.settings);return this.settings=Ue(Ue({},this.settings),r),Am(this.settings),this.handleSettingsUpdate(a),this.scheduleRefresh(),this}},{key:"resize",value:function(r){var a=this.width,o=this.height;if(this.width=this.container.offsetWidth,this.height=this.container.offsetHeight,this.pixelRatio=IN(),this.width===0)if(this.settings.allowInvalidContainer)this.width=1;else throw new Error("Sigma: Container has no width. You can set the allowInvalidContainer setting to true to stop seeing this error.");if(this.height===0)if(this.settings.allowInvalidContainer)this.height=1;else throw new Error("Sigma: Container has no height. You can set the allowInvalidContainer setting to true to stop seeing this error.");if(!r&&a===this.width&&o===this.height)return this;for(var s in this.elements){var l=this.elements[s];l.style.width=this.width+"px",l.style.height=this.height+"px"}for(var u in this.canvasContexts)this.elements[u].setAttribute("width",this.width*this.pixelRatio+"px"),this.elements[u].setAttribute("height",this.height*this.pixelRatio+"px"),this.pixelRatio!==1&&this.canvasContexts[u].scale(this.pixelRatio,this.pixelRatio);for(var d in this.webGLContexts){this.elements[d].setAttribute("width",this.width*this.pixelRatio+"px"),this.elements[d].setAttribute("height",this.height*this.pixelRatio+"px");var p=this.webGLContexts[d];if(p.viewport(0,0,this.width*this.pixelRatio,this.height*this.pixelRatio),this.pickingLayers.has(d)){var g=this.textures[d];g&&p.deleteTexture(g)}}return this.emit("resize"),this}},{key:"clear",value:function(){return this.emit("beforeClear"),this.webGLContexts.nodes.bindFramebuffer(WebGLRenderingContext.FRAMEBUFFER,null),this.webGLContexts.nodes.clear(WebGLRenderingContext.COLOR_BUFFER_BIT),this.webGLContexts.edges.bindFramebuffer(WebGLRenderingContext.FRAMEBUFFER,null),this.webGLContexts.edges.clear(WebGLRenderingContext.COLOR_BUFFER_BIT),this.webGLContexts.hoverNodes.clear(WebGLRenderingContext.COLOR_BUFFER_BIT),this.canvasContexts.labels.clearRect(0,0,this.width,this.height),this.canvasContexts.hovers.clearRect(0,0,this.width,this.height),this.canvasContexts.edgeLabels.clearRect(0,0,this.width,this.height),this.emit("afterClear"),this}},{key:"refresh",value:function(r){var a=this,o=(r==null?void 0:r.skipIndexation)!==void 0?r==null?void 0:r.skipIndexation:!1,s=(r==null?void 0:r.schedule)!==void 0?r.schedule:!1,l=!r||!r.partialGraph;if(l)this.clearEdgeIndices(),this.clearNodeIndices(),this.graph.forEachNode(function(O){return a.addNode(O)}),this.graph.forEachEdge(function(O){return a.addEdge(O)});else{for(var u,d,p=((u=r.partialGraph)===null||u===void 0?void 0:u.nodes)||[],g=0,m=(p==null?void 0:p.length)||0;g<m;g++){var b=p[g];if(this.updateNode(b),o){var v=this.nodeProgramIndex[b];if(v===void 0)throw new Error('Sigma: node "'.concat(b,`" can't be repaint`));this.addNodeToProgram(b,this.nodeIndices[b],v)}}for(var y=(r==null||(d=r.partialGraph)===null||d===void 0?void 0:d.edges)||[],k=0,A=y.length;k<A;k++){var x=y[k];if(this.updateEdge(x),o){var R=this.edgeProgramIndex[x];if(R===void 0)throw new Error('Sigma: edge "'.concat(x,`" can't be repaint`));this.addEdgeToProgram(x,this.edgeIndices[x],R)}}}return(l||!o)&&(this.needToProcess=!0),s?this.scheduleRender():this.render(),this}},{key:"scheduleRender",value:function(){var r=this;return this.renderFrame||(this.renderFrame=requestAnimationFrame(function(){r.render()})),this}},{key:"scheduleRefresh",value:function(r){return this.refresh(Ue(Ue({},r),{},{schedule:!0}))}},{key:"getViewportZoomedState",value:function(r,a){var o=this.camera.getState(),s=o.ratio,l=o.angle,u=o.x,d=o.y,p=this.settings,g=p.minCameraRatio,m=p.maxCameraRatio;typeof m=="number"&&(a=Math.min(a,m)),typeof g=="number"&&(a=Math.max(a,g));var b=a/s,v={x:this.width/2,y:this.height/2},y=this.viewportToFramedGraph(r),k=this.viewportToFramedGraph(v);return{angle:l,x:(y.x-k.x)*(1-b)+u,y:(y.y-k.y)*(1-b)+d,ratio:a}}},{key:"viewRectangle",value:function(){var r=this.viewportToFramedGraph({x:0,y:0}),a=this.viewportToFramedGraph({x:this.width,y:0}),o=this.viewportToFramedGraph({x:0,y:this.height});return{x1:r.x,y1:r.y,x2:a.x,y2:a.y,height:a.y-o.y}}},{key:"framedGraphToViewport",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},o=!!a.cameraState||!!a.viewportDimensions||!!a.graphDimensions,s=a.matrix?a.matrix:o?oc(a.cameraState||this.camera.getState(),a.viewportDimensions||this.getDimensions(),a.graphDimensions||this.getGraphDimensions(),a.padding||this.getStagePadding()):this.matrix,l=Y0(s,r);return{x:(1+l.x)*this.width/2,y:(1-l.y)*this.height/2}}},{key:"viewportToFramedGraph",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},o=!!a.cameraState||!!a.viewportDimensions||!a.graphDimensions,s=a.matrix?a.matrix:o?oc(a.cameraState||this.camera.getState(),a.viewportDimensions||this.getDimensions(),a.graphDimensions||this.getGraphDimensions(),a.padding||this.getStagePadding(),!0):this.invMatrix,l=Y0(s,{x:r.x/this.width*2-1,y:1-r.y/this.height*2});return isNaN(l.x)&&(l.x=0),isNaN(l.y)&&(l.y=0),l}},{key:"viewportToGraph",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};return this.normalizationFunction.inverse(this.viewportToFramedGraph(r,a))}},{key:"graphToViewport",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};return this.framedGraphToViewport(this.normalizationFunction(r),a)}},{key:"getGraphToViewportRatio",value:function(){var r={x:0,y:0},a={x:1,y:1},o=Math.sqrt(Math.pow(r.x-a.x,2)+Math.pow(r.y-a.y,2)),s=this.graphToViewport(r),l=this.graphToViewport(a),u=Math.sqrt(Math.pow(s.x-l.x,2)+Math.pow(s.y-l.y,2));return u/o}},{key:"getBBox",value:function(){return this.nodeExtent}},{key:"getCustomBBox",value:function(){return this.customBBox}},{key:"setCustomBBox",value:function(r){return this.customBBox=r,this.scheduleRender(),this}},{key:"kill",value:function(){this.emit("kill"),this.removeAllListeners(),this.unbindCameraHandlers(),window.removeEventListener("resize",this.activeListeners.handleResize),this.mouseCaptor.kill(),this.touchCaptor.kill(),this.unbindGraphHandlers(),this.clearIndices(),this.clearState(),this.nodeDataCache={},this.edgeDataCache={},this.highlightedNodes.clear(),this.renderFrame&&(cancelAnimationFrame(this.renderFrame),this.renderFrame=null),this.renderHighlightedNodesFrame&&(cancelAnimationFrame(this.renderHighlightedNodesFrame),this.renderHighlightedNodesFrame=null);for(var r=this.container;r.firstChild;)r.removeChild(r.firstChild);this.canvasContexts={},this.webGLContexts={},this.elements={};for(var a in this.nodePrograms)this.nodePrograms[a].kill();for(var o in this.nodeHoverPrograms)this.nodeHoverPrograms[o].kill();for(var s in this.edgePrograms)this.edgePrograms[s].kill();this.nodePrograms={},this.nodeHoverPrograms={},this.edgePrograms={};for(var l in this.elements)this.killLayer(l)}},{key:"scaleSize",value:function(){var r=arguments.length>0&&arguments[0]!==void 0?arguments[0]:1,a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:this.camera.ratio;return r/this.settings.zoomToSizeRatioFunction(a)*(this.getSetting("itemSizesReference")==="positions"?a*this.graphToViewportRatio:1)}},{key:"getCanvases",value:function(){var r={};for(var a in this.elements)this.elements[a]instanceof HTMLCanvasElement&&(r[a]=this.elements[a]);return r}}])}(IT);const W4=w.createContext(null),Hte=W4.Provider;function LT(){const e=w.useContext(W4);if(e==null)throw new Error("No context provided: useSigmaContext() can only be used in a descendant of <SigmaContainer>");return e}function Ar(){return LT().sigma}function Y4(){const{sigma:e}=LT();return w.useCallback(t=>{e&&Object.keys(t).forEach(n=>{e.setSetting(n,t[n])})},[e])}function kp(e){return new Set(Object.keys(e))}const jN=kp({clickNode:!0,rightClickNode:!0,downNode:!0,enterNode:!0,leaveNode:!0,doubleClickNode:!0,wheelNode:!0,clickEdge:!0,rightClickEdge:!0,downEdge:!0,enterEdge:!0,leaveEdge:!0,doubleClickEdge:!0,wheelEdge:!0,clickStage:!0,rightClickStage:!0,downStage:!0,doubleClickStage:!0,wheelStage:!0,beforeRender:!0,afterRender:!0,kill:!0,upStage:!0,upEdge:!0,upNode:!0,enterStage:!0,leaveStage:!0,resize:!0,afterClear:!0,afterProcess:!0,beforeClear:!0,beforeProcess:!0,moveBody:!0}),UN=kp({click:!0,rightClick:!0,doubleClick:!0,mouseup:!0,mousedown:!0,mousemove:!0,mousemovebody:!0,mouseleave:!0,mouseenter:!0,wheel:!0}),GN=kp({touchup:!0,touchdown:!0,touchmove:!0,touchmovebody:!0,tap:!0,doubletap:!0}),HN=kp({updated:!0});function K4(){const e=Ar(),t=Y4(),[n,r]=w.useState({});return w.useEffect(()=>{if(!e||!n)return;const a=n,o=Object.keys(a);return o.forEach(s=>{const l=a[s];jN.has(s)&&e.on(s,l),UN.has(s)&&e.getMouseCaptor().on(s,l),GN.has(s)&&e.getTouchCaptor().on(s,l),HN.has(s)&&e.getCamera().on(s,l)}),()=>{e&&o.forEach(s=>{const l=a[s];jN.has(s)&&e.off(s,l),UN.has(s)&&e.getMouseCaptor().off(s,l),GN.has(s)&&e.getTouchCaptor().off(s,l),HN.has(s)&&e.getCamera().off(s,l)})}},[e,n,t]),r}function ru(e,t){if(e===t)return!0;if(typeof e=="object"&&e!=null&&typeof t=="object"&&t!=null){if(Object.keys(e).length!=Object.keys(t).length)return!1;for(const n in e)if(!Object.hasOwn(t,n)||!ru(e[n],t[n]))return!1;return!0}return!1}function X4(e){const t=Ar(),[n,r]=w.useState(e||{});w.useEffect(()=>{r(d=>ru(d,e||{})?d:e||{})},[e]);const a=w.useCallback(d=>{t.getCamera().animatedZoom(Object.assign(Object.assign({},n),d))},[t,n]),o=w.useCallback(d=>{t.getCamera().animatedUnzoom(Object.assign(Object.assign({},n),d))},[t,n]),s=w.useCallback(d=>{t.getCamera().animatedReset(Object.assign(Object.assign({},n),d))},[t,n]),l=w.useCallback((d,p)=>{t.getCamera().animate(d,Object.assign(Object.assign({},n),p))},[t,n]),u=w.useCallback((d,p)=>{const g=t.getNodeDisplayData(d);g?t.getCamera().animate(g,Object.assign(Object.assign({},n),p)):console.warn(`Node ${d} not found`)},[t,n]);return{zoomIn:a,zoomOut:o,reset:s,goto:l,gotoNode:u}}function $te(e){const t=LT(),[n,r]=w.useState(!1),[a,o]=w.useState(t.container),s=w.useCallback(()=>r(l=>!l),[]);return w.useEffect(()=>(document.addEventListener("fullscreenchange",s),()=>document.removeEventListener("fullscreenchange",s)),[s]),w.useEffect(()=>{o(t.container)},[e,t.container]),{toggle:w.useCallback(()=>{var l;l=a,document.fullscreenElement!==l?l.requestFullscreen():document.exitFullscreen&&document.exitFullscreen()},[a]),isFullScreen:n}}const qte=w.forwardRef(({graph:e,id:t,className:n,style:r,settings:a={},children:o},s)=>{const l=w.useRef(null),u=w.useRef(null),d={className:`react-sigma ${n||""}`,id:t,style:r},[p,g]=w.useState(null),[m,b]=w.useState(a);w.useEffect(()=>{b(k=>ru(k,a)?k:a)},[a]),w.useEffect(()=>{g(k=>{let A=null;if(u.current!==null){let x=new _t;e&&(x=typeof e=="function"?new e:e);let R=null;k&&(R=k.getCamera().getState(),k.kill()),A=new Gte(x,u.current,m),R&&A.getCamera().setState(R)}return A})},[u,e,m]),w.useImperativeHandle(s,()=>p,[p]);const v=w.useMemo(()=>p&&l.current?{sigma:p,container:l.current}:null,[p,l]),y=v!==null?we.createElement(Hte,{value:v},o):null;return we.createElement("div",Object.assign({},d,{ref:l}),we.createElement("div",{className:"sigma-container",ref:u}),y)});var Vte=`
precision mediump float;

varying vec4 v_color;
varying float v_border;

const float radius = 0.5;
const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  vec2 m = gl_PointCoord - vec2(0.5, 0.5);
  float dist = radius - length(m);

  // No antialiasing for picking mode:
  #ifdef PICKING_MODE
  if (dist > v_border)
    gl_FragColor = v_color;
  else
    gl_FragColor = transparent;

  #else
  float t = 0.0;
  if (dist > v_border)
    t = 1.0;
  else if (dist > 0.0)
    t = dist / v_border;

  gl_FragColor = mix(transparent, v_color, t);
  #endif
}
`,Wte=Vte,Yte=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_position;
attribute float a_size;

uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform mat3 u_matrix;

varying vec4 v_color;
varying float v_border;

const float bias = 255.0 / 254.0;

void main() {
  gl_Position = vec4(
    (u_matrix * vec3(a_position, 1)).xy,
    0,
    1
  );

  // Multiply the point size twice:
  //  - x SCALING_RATIO to correct the canvas scaling
  //  - x 2 to correct the formulae
  gl_PointSize = a_size / u_sizeRatio * u_pixelRatio * 2.0;

  v_border = (0.5 / a_size) * u_sizeRatio;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,Kte=Yte,Z4=WebGLRenderingContext,$N=Z4.UNSIGNED_BYTE,qN=Z4.FLOAT,Xte=["u_sizeRatio","u_pixelRatio","u_matrix"],Zte=function(e){function t(){return dn(this,t),$n(this,t,arguments)}return qn(t,e),fn(t,[{key:"getDefinition",value:function(){return{VERTICES:1,VERTEX_SHADER_SOURCE:Kte,FRAGMENT_SHADER_SOURCE:Wte,METHOD:WebGLRenderingContext.POINTS,UNIFORMS:Xte,ATTRIBUTES:[{name:"a_position",size:2,type:qN},{name:"a_size",size:1,type:qN},{name:"a_color",size:4,type:$N,normalized:!0},{name:"a_id",size:4,type:$N,normalized:!0}]}}},{key:"processVisibleItem",value:function(r,a,o){var s=this.array;s[a++]=o.x,s[a++]=o.y,s[a++]=o.size,s[a++]=ca(o.color),s[a++]=r}},{key:"setUniforms",value:function(r,a){var o=r.sizeRatio,s=r.pixelRatio,l=r.matrix,u=a.gl,d=a.uniformLocations,p=d.u_sizeRatio,g=d.u_pixelRatio,m=d.u_matrix;u.uniform1f(g,s),u.uniform1f(p,o),u.uniformMatrix3fv(m,!1,l)}}])}(NT),Qte=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_normal;
attribute float a_normalCoef;
attribute vec2 a_positionStart;
attribute vec2 a_positionEnd;
attribute float a_positionCoef;
attribute float a_sourceRadius;
attribute float a_targetRadius;
attribute float a_sourceRadiusCoef;
attribute float a_targetRadiusCoef;

uniform mat3 u_matrix;
uniform float u_zoomRatio;
uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_lengthToThicknessRatio;
uniform float u_feather;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  vec2 normal = a_normal * a_normalCoef;
  vec2 position = a_positionStart * (1.0 - a_positionCoef) + a_positionEnd * a_positionCoef;

  float normalLength = length(normal);
  vec2 unitNormal = normal / normalLength;

  // These first computations are taken from edge.vert.glsl. Please read it to
  // get better comments on what's happening:
  float pixelsThickness = max(normalLength, minThickness * u_sizeRatio);
  float webGLThickness = pixelsThickness * u_correctionRatio / u_sizeRatio;

  // Here, we move the point to leave space for the arrow heads:
  // Source arrow head
  float sourceRadius = a_sourceRadius * a_sourceRadiusCoef;
  float sourceDirection = sign(sourceRadius);
  float webGLSourceRadius = sourceDirection * sourceRadius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLSourceArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;
  vec2 sourceCompensationVector =
    vec2(-sourceDirection * unitNormal.y, sourceDirection * unitNormal.x)
    * (webGLSourceRadius + webGLSourceArrowHeadLength);
    
  // Target arrow head
  float targetRadius = a_targetRadius * a_targetRadiusCoef;
  float targetDirection = sign(targetRadius);
  float webGLTargetRadius = targetDirection * targetRadius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLTargetArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;
  vec2 targetCompensationVector =
  vec2(-targetDirection * unitNormal.y, targetDirection * unitNormal.x)
    * (webGLTargetRadius + webGLTargetArrowHeadLength);

  // Here is the proper position of the vertex
  gl_Position = vec4((u_matrix * vec3(position + unitNormal * webGLThickness + sourceCompensationVector + targetCompensationVector, 1)).xy, 0, 1);

  v_thickness = webGLThickness / u_zoomRatio;

  v_normal = unitNormal;

  v_feather = u_feather * u_correctionRatio / u_zoomRatio / u_pixelRatio * 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,Jte=Qte,Q4=WebGLRenderingContext,VN=Q4.UNSIGNED_BYTE,Ia=Q4.FLOAT,ene=["u_matrix","u_zoomRatio","u_sizeRatio","u_correctionRatio","u_pixelRatio","u_feather","u_minEdgeThickness","u_lengthToThicknessRatio"],tne={lengthToThicknessRatio:nu.lengthToThicknessRatio};function J4(e){var t=Ue(Ue({},tne),{});return function(n){function r(){return dn(this,r),$n(this,r,arguments)}return qn(r,n),fn(r,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:Jte,FRAGMENT_SHADER_SOURCE:OT,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:ene,ATTRIBUTES:[{name:"a_positionStart",size:2,type:Ia},{name:"a_positionEnd",size:2,type:Ia},{name:"a_normal",size:2,type:Ia},{name:"a_color",size:4,type:VN,normalized:!0},{name:"a_id",size:4,type:VN,normalized:!0},{name:"a_sourceRadius",size:1,type:Ia},{name:"a_targetRadius",size:1,type:Ia}],CONSTANT_ATTRIBUTES:[{name:"a_positionCoef",size:1,type:Ia},{name:"a_normalCoef",size:1,type:Ia},{name:"a_sourceRadiusCoef",size:1,type:Ia},{name:"a_targetRadiusCoef",size:1,type:Ia}],CONSTANT_DATA:[[0,1,-1,0],[0,-1,1,0],[1,1,0,1],[1,1,0,1],[0,-1,1,0],[1,-1,0,-1]]}}},{key:"processVisibleItem",value:function(o,s,l,u,d){var p=d.size||1,g=l.x,m=l.y,b=u.x,v=u.y,y=ca(d.color),k=b-g,A=v-m,x=l.size||1,R=u.size||1,O=k*k+A*A,N=0,C=0;O&&(O=1/Math.sqrt(O),N=-A*O*p,C=k*O*p);var _=this.array;_[s++]=g,_[s++]=m,_[s++]=b,_[s++]=v,_[s++]=N,_[s++]=C,_[s++]=y,_[s++]=o,_[s++]=x,_[s++]=R}},{key:"setUniforms",value:function(o,s){var l=s.gl,u=s.uniformLocations,d=u.u_matrix,p=u.u_zoomRatio,g=u.u_feather,m=u.u_pixelRatio,b=u.u_correctionRatio,v=u.u_sizeRatio,y=u.u_minEdgeThickness,k=u.u_lengthToThicknessRatio;l.uniformMatrix3fv(d,!1,o.matrix),l.uniform1f(p,o.zoomRatio),l.uniform1f(v,o.sizeRatio),l.uniform1f(b,o.correctionRatio),l.uniform1f(m,o.pixelRatio),l.uniform1f(g,o.antiAliasingFeather),l.uniform1f(y,o.minEdgeThickness),l.uniform1f(k,t.lengthToThicknessRatio)}}])}(eu)}J4();function nne(e){return L4([J4(),Rf(e),Rf(Ue(Ue({},e),{},{extremity:"source"}))])}nne();function rne(e){if(Array.isArray(e))return e}function ane(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r,a,o,s,l=[],u=!0,d=!1;try{if(o=(n=n.call(e)).next,t!==0)for(;!(u=(r=o.call(n)).done)&&(l.push(r.value),l.length!==t);u=!0);}catch(p){d=!0,a=p}finally{try{if(!u&&n.return!=null&&(s=n.return(),Object(s)!==s))return}finally{if(d)throw a}}return l}}function X0(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function e5(e,t){if(e){if(typeof e=="string")return X0(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?X0(e,t):void 0}}function one(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function ine(e,t){return rne(e)||ane(e,t)||e5(e,t)||one()}function sne(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function lne(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function t5(e){var t=lne(e,"string");return typeof t=="symbol"?t:t+""}function cne(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,t5(r.key),r)}}function une(e,t,n){return t&&cne(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e}function Cf(e){return Cf=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},Cf(e)}function n5(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(n5=function(){return!!e})()}function Z0(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function dne(e,t){if(t&&(typeof t=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return Z0(e)}function fne(e,t,n){return t=Cf(t),dne(e,n5()?Reflect.construct(t,n||[],Cf(e).constructor):t.apply(e,n))}function Q0(e,t){return Q0=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},Q0(e,t)}function pne(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&Q0(e,t)}function Ss(e,t,n){return(t=t5(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function gne(e){if(Array.isArray(e))return X0(e)}function hne(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function mne(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Cm(e){return gne(e)||hne(e)||e5(e)||mne()}function WN(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function YN(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?WN(Object(n),!0).forEach(function(r){Ss(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):WN(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}var bne="relative",yne={drawLabel:void 0,drawHover:void 0,borders:[{size:{value:.1},color:{attribute:"borderColor"}},{size:{fill:!0},color:{attribute:"color"}}]},vne="#000000";function Sne(e){var t=e.borders,n=xN(t.filter(function(a){var o=a.size;return"fill"in o}).length),r=`
precision highp float;

varying vec2 v_diffVector;
varying float v_radius;

#ifdef PICKING_MODE
varying vec4 v_color;
#else
// For normal mode, we use the border colors defined in the program:
`.concat(t.flatMap(function(a,o){var s=a.size;return"attribute"in s?["varying float v_borderSize_".concat(o+1,";")]:[]}).join(`
`),`
`).concat(t.flatMap(function(a,o){var s=a.color;return"attribute"in s?["varying vec4 v_borderColor_".concat(o+1,";")]:"value"in s?["uniform vec4 u_borderColor_".concat(o+1,";")]:[]}).join(`
`),`
#endif

uniform float u_correctionRatio;

const float bias = 255.0 / 254.0;
const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  float dist = length(v_diffVector);
  float aaBorder = 2.0 * u_correctionRatio;
  float v_borderSize_0 = v_radius;
  vec4 v_borderColor_0 = transparent;

  // No antialiasing for picking mode:
  #ifdef PICKING_MODE
  if (dist > v_radius)
    gl_FragColor = transparent;
  else {
    gl_FragColor = v_color;
    gl_FragColor.a *= bias;
  }
  #else
  // Sizes:
`).concat(t.flatMap(function(a,o){var s=a.size;if("fill"in s)return[];s=s;var l="attribute"in s?"v_borderSize_".concat(o+1):xN(s.value),u=(s.mode||bne)==="pixels"?"u_correctionRatio":"v_radius";return["  float borderSize_".concat(o+1," = ").concat(u," * ").concat(l,";")]}).join(`
`),`
  // Now, let's split the remaining space between "fill" borders:
  float fillBorderSize = (v_radius - (`).concat(t.flatMap(function(a,o){var s=a.size;return"fill"in s?[]:["borderSize_".concat(o+1)]}).join(" + "),") ) / ").concat(n,`;
`).concat(t.flatMap(function(a,o){var s=a.size;return"fill"in s?["  float borderSize_".concat(o+1," = fillBorderSize;")]:[]}).join(`
`),`

  // Finally, normalize all border sizes, to start from the full size and to end with the smallest:
  float adjustedBorderSize_0 = v_radius;
`).concat(t.map(function(a,o){return"  float adjustedBorderSize_".concat(o+1," = adjustedBorderSize_").concat(o," - borderSize_").concat(o+1,";")}).join(`
`),`

  // Colors:
  vec4 borderColor_0 = transparent;
`).concat(t.map(function(a,o){var s=a.color,l=[];return"attribute"in s?l.push("  vec4 borderColor_".concat(o+1," = v_borderColor_").concat(o+1,";")):"transparent"in s?l.push("  vec4 borderColor_".concat(o+1," = vec4(0.0, 0.0, 0.0, 0.0);")):l.push("  vec4 borderColor_".concat(o+1," = u_borderColor_").concat(o+1,";")),l.push("  borderColor_".concat(o+1,".a *= bias;")),l.push("  if (borderSize_".concat(o+1," <= 1.0 * u_correctionRatio) { borderColor_").concat(o+1," = borderColor_").concat(o,"; }")),l.join(`
`)}).join(`
`),`
  if (dist > adjustedBorderSize_0) {
    gl_FragColor = borderColor_0;
  } else `).concat(t.map(function(a,o){return"if (dist > adjustedBorderSize_".concat(o,` - aaBorder) {
    gl_FragColor = mix(borderColor_`).concat(o+1,", borderColor_").concat(o,", (dist - adjustedBorderSize_").concat(o,` + aaBorder) / aaBorder);
  } else if (dist > adjustedBorderSize_`).concat(o+1,`) {
    gl_FragColor = borderColor_`).concat(o+1,`;
  } else `)}).join(""),` { /* Nothing to add here */ }
  #endif
}
`);return r}function Ene(e){var t=e.borders,n=`
attribute vec2 a_position;
attribute float a_size;
attribute float a_angle;

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_correctionRatio;

varying vec2 v_diffVector;
varying float v_radius;

#ifdef PICKING_MODE
attribute vec4 a_id;
varying vec4 v_color;
#else
`.concat(t.flatMap(function(r,a){var o=r.size;return"attribute"in o?["attribute float a_borderSize_".concat(a+1,";"),"varying float v_borderSize_".concat(a+1,";")]:[]}).join(`
`),`
`).concat(t.flatMap(function(r,a){var o=r.color;return"attribute"in o?["attribute vec4 a_borderColor_".concat(a+1,";"),"varying vec4 v_borderColor_".concat(a+1,";")]:[]}).join(`
`),`
#endif

const float bias = 255.0 / 254.0;
const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main() {
  float size = a_size * u_correctionRatio / u_sizeRatio * 4.0;
  vec2 diffVector = size * vec2(cos(a_angle), sin(a_angle));
  vec2 position = a_position + diffVector;
  gl_Position = vec4(
    (u_matrix * vec3(position, 1)).xy,
    0,
    1
  );

  v_radius = size / 2.0;
  v_diffVector = diffVector;

  #ifdef PICKING_MODE
  v_color = a_id;
  #else
`).concat(t.flatMap(function(r,a){var o=r.size;return"attribute"in o?["  v_borderSize_".concat(a+1," = a_borderSize_").concat(a+1,";")]:[]}).join(`
`),`
`).concat(t.flatMap(function(r,a){var o=r.color;return"attribute"in o?["  v_borderColor_".concat(a+1," = a_borderColor_").concat(a+1,";")]:[]}).join(`
`),`
  #endif
}
`);return n}var r5=WebGLRenderingContext,KN=r5.UNSIGNED_BYTE,Ld=r5.FLOAT;function wne(e){var t,n=YN(YN({},yne),{}),r=n.borders,a=n.drawLabel,o=n.drawHover,s=["u_sizeRatio","u_correctionRatio","u_matrix"].concat(Cm(r.flatMap(function(l,u){var d=l.color;return"value"in d?["u_borderColor_".concat(u+1)]:[]})));return t=function(l){pne(u,l);function u(){var d;sne(this,u);for(var p=arguments.length,g=new Array(p),m=0;m<p;m++)g[m]=arguments[m];return d=fne(this,u,[].concat(g)),Ss(Z0(d),"drawLabel",a),Ss(Z0(d),"drawHover",o),d}return une(u,[{key:"getDefinition",value:function(){return{VERTICES:3,VERTEX_SHADER_SOURCE:Ene(n),FRAGMENT_SHADER_SOURCE:Sne(n),METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:s,ATTRIBUTES:[{name:"a_position",size:2,type:Ld},{name:"a_id",size:4,type:KN,normalized:!0},{name:"a_size",size:1,type:Ld}].concat(Cm(r.flatMap(function(p,g){var m=p.color;return"attribute"in m?[{name:"a_borderColor_".concat(g+1),size:4,type:KN,normalized:!0}]:[]})),Cm(r.flatMap(function(p,g){var m=p.size;return"attribute"in m?[{name:"a_borderSize_".concat(g+1),size:1,type:Ld}]:[]}))),CONSTANT_ATTRIBUTES:[{name:"a_angle",size:1,type:Ld}],CONSTANT_DATA:[[u.ANGLE_1],[u.ANGLE_2],[u.ANGLE_3]]}}},{key:"processVisibleItem",value:function(p,g,m){var b=this.array;b[g++]=m.x,b[g++]=m.y,b[g++]=p,b[g++]=m.size,r.forEach(function(v){var y=v.color;"attribute"in y&&(b[g++]=ca(m[y.attribute]||y.defaultValue||vne))}),r.forEach(function(v){var y=v.size;"attribute"in y&&(b[g++]=m[y.attribute]||y.defaultValue)})}},{key:"setUniforms",value:function(p,g){var m=g.gl,b=g.uniformLocations,v=b.u_sizeRatio,y=b.u_correctionRatio,k=b.u_matrix;m.uniform1f(y,p.correctionRatio),m.uniform1f(v,p.sizeRatio),m.uniformMatrix3fv(k,!1,p.matrix),r.forEach(function(A,x){var R=A.color;if("value"in R){var O=b["u_borderColor_".concat(x+1)],N=Iee(R.value),C=ine(N,4),_=C[0],M=C[1],I=C[2],D=C[3];m.uniform4f(O,_/255,M/255,I/255,D/255)}})}}]),u}(NT),Ss(t,"ANGLE_1",0),Ss(t,"ANGLE_2",2*Math.PI/3),Ss(t,"ANGLE_3",4*Math.PI/3),t}var xne=wne();function kne(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function a5(e){var t=kne(e,"string");return typeof t=="symbol"?t:t+""}function o5(e,t,n){return(t=a5(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function XN(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function _f(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?XN(Object(n),!0).forEach(function(r){o5(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):XN(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function Tne(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function Ane(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,a5(r.key),r)}}function Rne(e,t,n){return t&&Ane(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e}function Nf(e){return Nf=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},Nf(e)}function i5(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(i5=function(){return!!e})()}function s5(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function Cne(e,t){if(t&&(typeof t=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return s5(e)}function _ne(e,t,n){return t=Nf(t),Cne(e,i5()?Reflect.construct(t,n||[],Nf(e).constructor):t.apply(e,n))}function J0(e,t){return J0=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},J0(e,t)}function Nne(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&J0(e,t)}function ek(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function One(e){if(Array.isArray(e))return ek(e)}function Ine(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function Dne(e,t){if(e){if(typeof e=="string")return ek(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?ek(e,t):void 0}}function Lne(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function _m(e){return One(e)||Ine(e)||Dne(e)||Lne()}function l5(e,t,n,r){var a=Math.pow(1-e,2)*t.x+2*(1-e)*e*n.x+Math.pow(e,2)*r.x,o=Math.pow(1-e,2)*t.y+2*(1-e)*e*n.y+Math.pow(e,2)*r.y;return{x:a,y:o}}function Mne(e,t,n){for(var r=20,a=0,o=e,s=0;s<r;s++){var l=l5((s+1)/r,e,t,n);a+=Math.sqrt(Math.pow(o.x-l.x,2)+Math.pow(o.y-l.y,2)),o=l}return a}function Pne(e){var t=e.curvatureAttribute,n=e.defaultCurvature,r=e.keepLabelUpright,a=r===void 0?!0:r;return function(o,s,l,u,d){var p=d.edgeLabelSize,g=s[t]||n,m=d.edgeLabelFont,b=d.edgeLabelWeight,v=d.edgeLabelColor.attribute?s[d.edgeLabelColor.attribute]||d.edgeLabelColor.color||"#000":d.edgeLabelColor.color,y=s.label;if(y){o.fillStyle=v,o.font="".concat(b," ").concat(p,"px ").concat(m);var k=!a||l.x<u.x,A=k?l.x:u.x,x=k?l.y:u.y,R=k?u.x:l.x,O=k?u.y:l.y,N=(A+R)/2,C=(x+O)/2,_=R-A,M=O-x,I=Math.sqrt(Math.pow(_,2)+Math.pow(M,2)),D=k?1:-1,U=N+M*g*D,$=C-_*g*D,B=s.size*.7+5,W={x:$-x,y:-(U-A)},K=Math.sqrt(Math.pow(W.x,2)+Math.pow(W.y,2)),H={x:O-$,y:-(R-U)},G=Math.sqrt(Math.pow(H.x,2)+Math.pow(H.y,2));A+=B*W.x/K,x+=B*W.y/K,R+=B*H.x/G,O+=B*H.y/G,U+=B*M/I,$-=B*_/I;var z={x:U,y:$},Y={x:A,y:x},L={x:R,y:O},V=Mne(Y,z,L);if(!(V<l.size+u.size)){var j=o.measureText(y).width,P=V-l.size-u.size;if(j>P){var Z="…";for(y=y+Z,j=o.measureText(y).width;j>P&&y.length>1;)y=y.slice(0,-2)+Z,j=o.measureText(y).width;if(y.length<4)return}for(var Q={},oe=0,ae=y.length;oe<ae;oe++){var ce=y[oe];Q[ce]||(Q[ce]=o.measureText(ce).width*(1+g*.35))}for(var Re=.5-j/V/2,ie=0,Te=y.length;ie<Te;ie++){var ne=y[ie],xe=l5(Re,Y,z,L),Se=2*(1-Re)*(U-A)+2*Re*(R-U),be=2*(1-Re)*($-x)+2*Re*(O-$),J=Math.atan2(be,Se);o.save(),o.translate(xe.x,xe.y),o.rotate(J),o.fillText(ne,0,0),o.restore(),Re+=Q[ne]/V}}}}}function Fne(e){var t=e.arrowHead,n=(t==null?void 0:t.extremity)==="target"||(t==null?void 0:t.extremity)==="both",r=(t==null?void 0:t.extremity)==="source"||(t==null?void 0:t.extremity)==="both",a=`
precision highp float;

varying vec4 v_color;
varying float v_thickness;
varying float v_feather;
varying vec2 v_cpA;
varying vec2 v_cpB;
varying vec2 v_cpC;
`.concat(n?`
varying float v_targetSize;
varying vec2 v_targetPoint;`:"",`
`).concat(r?`
varying float v_sourceSize;
varying vec2 v_sourcePoint;`:"",`
`).concat(t?`
uniform float u_lengthToThicknessRatio;
uniform float u_widenessToThicknessRatio;`:"",`

float det(vec2 a, vec2 b) {
  return a.x * b.y - b.x * a.y;
}

vec2 getDistanceVector(vec2 b0, vec2 b1, vec2 b2) {
  float a = det(b0, b2), b = 2.0 * det(b1, b0), d = 2.0 * det(b2, b1);
  float f = b * d - a * a;
  vec2 d21 = b2 - b1, d10 = b1 - b0, d20 = b2 - b0;
  vec2 gf = 2.0 * (b * d21 + d * d10 + a * d20);
  gf = vec2(gf.y, -gf.x);
  vec2 pp = -f * gf / dot(gf, gf);
  vec2 d0p = b0 - pp;
  float ap = det(d0p, d20), bp = 2.0 * det(d10, d0p);
  float t = clamp((ap + bp) / (2.0 * a + b + d), 0.0, 1.0);
  return mix(mix(b0, b1, t), mix(b1, b2, t), t);
}

float distToQuadraticBezierCurve(vec2 p, vec2 b0, vec2 b1, vec2 b2) {
  return length(getDistanceVector(b0 - p, b1 - p, b2 - p));
}

const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  float dist = distToQuadraticBezierCurve(gl_FragCoord.xy, v_cpA, v_cpB, v_cpC);
  float thickness = v_thickness;
`).concat(n?`
  float distToTarget = length(gl_FragCoord.xy - v_targetPoint);
  float targetArrowLength = v_targetSize + thickness * u_lengthToThicknessRatio;
  if (distToTarget < targetArrowLength) {
    thickness = (distToTarget - v_targetSize) / (targetArrowLength - v_targetSize) * u_widenessToThicknessRatio * thickness;
  }`:"",`
`).concat(r?`
  float distToSource = length(gl_FragCoord.xy - v_sourcePoint);
  float sourceArrowLength = v_sourceSize + thickness * u_lengthToThicknessRatio;
  if (distToSource < sourceArrowLength) {
    thickness = (distToSource - v_sourceSize) / (sourceArrowLength - v_sourceSize) * u_widenessToThicknessRatio * thickness;
  }`:"",`

  float halfThickness = thickness / 2.0;
  if (dist < halfThickness) {
    #ifdef PICKING_MODE
    gl_FragColor = v_color;
    #else
    float t = smoothstep(
      halfThickness - v_feather,
      halfThickness,
      dist
    );

    gl_FragColor = mix(v_color, transparent, t);
    #endif
  } else {
    gl_FragColor = transparent;
  }
}
`);return a}function zne(e){var t=e.arrowHead,n=(t==null?void 0:t.extremity)==="target"||(t==null?void 0:t.extremity)==="both",r=(t==null?void 0:t.extremity)==="source"||(t==null?void 0:t.extremity)==="both",a=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute float a_direction;
attribute float a_thickness;
attribute vec2 a_source;
attribute vec2 a_target;
attribute float a_current;
attribute float a_curvature;
`.concat(n?`attribute float a_targetSize;
`:"",`
`).concat(r?`attribute float a_sourceSize;
`:"",`

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform vec2 u_dimensions;
uniform float u_minEdgeThickness;
uniform float u_feather;

varying vec4 v_color;
varying float v_thickness;
varying float v_feather;
varying vec2 v_cpA;
varying vec2 v_cpB;
varying vec2 v_cpC;
`).concat(n?`
varying float v_targetSize;
varying vec2 v_targetPoint;`:"",`
`).concat(r?`
varying float v_sourceSize;
varying vec2 v_sourcePoint;`:"",`
`).concat(t?`
uniform float u_widenessToThicknessRatio;`:"",`

const float bias = 255.0 / 254.0;
const float epsilon = 0.7;

vec2 clipspaceToViewport(vec2 pos, vec2 dimensions) {
  return vec2(
    (pos.x + 1.0) * dimensions.x / 2.0,
    (pos.y + 1.0) * dimensions.y / 2.0
  );
}

vec2 viewportToClipspace(vec2 pos, vec2 dimensions) {
  return vec2(
    pos.x / dimensions.x * 2.0 - 1.0,
    pos.y / dimensions.y * 2.0 - 1.0
  );
}

void main() {
  float minThickness = u_minEdgeThickness;

  // Selecting the correct position
  // Branchless "position = a_source if a_current == 1.0 else a_target"
  vec2 position = a_source * max(0.0, a_current) + a_target * max(0.0, 1.0 - a_current);
  position = (u_matrix * vec3(position, 1)).xy;

  vec2 source = (u_matrix * vec3(a_source, 1)).xy;
  vec2 target = (u_matrix * vec3(a_target, 1)).xy;

  vec2 viewportPosition = clipspaceToViewport(position, u_dimensions);
  vec2 viewportSource = clipspaceToViewport(source, u_dimensions);
  vec2 viewportTarget = clipspaceToViewport(target, u_dimensions);

  vec2 delta = viewportTarget.xy - viewportSource.xy;
  float len = length(delta);
  vec2 normal = vec2(-delta.y, delta.x) * a_direction;
  vec2 unitNormal = normal / len;
  float boundingBoxThickness = len * a_curvature;

  float curveThickness = max(minThickness, a_thickness / u_sizeRatio);
  v_thickness = curveThickness * u_pixelRatio;
  v_feather = u_feather;

  v_cpA = viewportSource;
  v_cpB = 0.5 * (viewportSource + viewportTarget) + unitNormal * a_direction * boundingBoxThickness;
  v_cpC = viewportTarget;

  vec2 viewportOffsetPosition = (
    viewportPosition +
    unitNormal * (boundingBoxThickness / 2.0 + sign(boundingBoxThickness) * (`).concat(t?"curveThickness * u_widenessToThicknessRatio":"curveThickness",` + epsilon)) *
    max(0.0, a_direction) // NOTE: cutting the bounding box in half to avoid overdraw
  );

  position = viewportToClipspace(viewportOffsetPosition, u_dimensions);
  gl_Position = vec4(position, 0, 1);
    
`).concat(n?`
  v_targetSize = a_targetSize * u_pixelRatio / u_sizeRatio;
  v_targetPoint = viewportTarget;
`:"",`
`).concat(r?`
  v_sourceSize = a_sourceSize * u_pixelRatio / u_sizeRatio;
  v_sourcePoint = viewportSource;
`:"",`

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`);return a}var c5=.25,Bne={arrowHead:null,curvatureAttribute:"curvature",defaultCurvature:c5},u5=WebGLRenderingContext,ZN=u5.UNSIGNED_BYTE,yo=u5.FLOAT;function MT(e){var t=_f(_f({},Bne),e||{}),n=t,r=n.arrowHead,a=n.curvatureAttribute,o=n.drawLabel,s=(r==null?void 0:r.extremity)==="target"||(r==null?void 0:r.extremity)==="both",l=(r==null?void 0:r.extremity)==="source"||(r==null?void 0:r.extremity)==="both",u=["u_matrix","u_sizeRatio","u_dimensions","u_pixelRatio","u_feather","u_minEdgeThickness"].concat(_m(r?["u_lengthToThicknessRatio","u_widenessToThicknessRatio"]:[]));return function(d){Nne(p,d);function p(){var g;Tne(this,p);for(var m=arguments.length,b=new Array(m),v=0;v<m;v++)b[v]=arguments[v];return g=_ne(this,p,[].concat(b)),o5(s5(g),"drawLabel",o||Pne(t)),g}return Rne(p,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:zne(t),FRAGMENT_SHADER_SOURCE:Fne(t),METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:u,ATTRIBUTES:[{name:"a_source",size:2,type:yo},{name:"a_target",size:2,type:yo}].concat(_m(s?[{name:"a_targetSize",size:1,type:yo}]:[]),_m(l?[{name:"a_sourceSize",size:1,type:yo}]:[]),[{name:"a_thickness",size:1,type:yo},{name:"a_curvature",size:1,type:yo},{name:"a_color",size:4,type:ZN,normalized:!0},{name:"a_id",size:4,type:ZN,normalized:!0}]),CONSTANT_ATTRIBUTES:[{name:"a_current",size:1,type:yo},{name:"a_direction",size:1,type:yo}],CONSTANT_DATA:[[0,1],[0,-1],[1,1],[0,-1],[1,1],[1,-1]]}}},{key:"processVisibleItem",value:function(m,b,v,y,k){var A,x=k.size||1,R=v.x,O=v.y,N=y.x,C=y.y,_=ca(k.color),M=(A=k[a])!==null&&A!==void 0?A:c5,I=this.array;I[b++]=R,I[b++]=O,I[b++]=N,I[b++]=C,s&&(I[b++]=y.size),l&&(I[b++]=v.size),I[b++]=x,I[b++]=M,I[b++]=_,I[b++]=m}},{key:"setUniforms",value:function(m,b){var v=b.gl,y=b.uniformLocations,k=y.u_matrix,A=y.u_pixelRatio,x=y.u_feather,R=y.u_sizeRatio,O=y.u_dimensions,N=y.u_minEdgeThickness;if(v.uniformMatrix3fv(k,!1,m.matrix),v.uniform1f(A,m.pixelRatio),v.uniform1f(R,m.sizeRatio),v.uniform1f(x,m.antiAliasingFeather),v.uniform2f(O,m.width*m.pixelRatio,m.height*m.pixelRatio),v.uniform1f(N,m.minEdgeThickness),r){var C=y.u_lengthToThicknessRatio,_=y.u_widenessToThicknessRatio;v.uniform1f(C,r.lengthToThicknessRatio),v.uniform1f(_,r.widenessToThicknessRatio)}}}]),p}(eu)}var jne=MT(),Une=MT({arrowHead:nu});MT({arrowHead:_f(_f({},nu),{},{extremity:"both"})});const Gne=({node:e,move:t})=>{const n=Ar(),{gotoNode:r}=X4();return w.useEffect(()=>{const a=n.getGraph();if(t){if(e&&a.hasNode(e))try{a.setNodeAttribute(e,"highlighted",!0),r(e)}catch(o){console.error("Error focusing on node:",o)}else n.setCustomBBox(null),n.getCamera().animate({x:.5,y:.5,ratio:1},{duration:0});ze.getState().setMoveToSelectedNode(!1)}else if(e&&a.hasNode(e))try{a.setNodeAttribute(e,"highlighted",!0)}catch(o){console.error("Error highlighting node:",o)}return()=>{if(e&&a.hasNode(e))try{a.setNodeAttribute(e,"highlighted",!1)}catch(o){console.error("Error cleaning up node highlight:",o)}}},[e,t,n,r]),null};function Js(e,t){const n=Ar(),r=w.useRef(t);return ru(r.current,t)||(r.current=t),{positions:w.useCallback(()=>r.current?e(n.getGraph(),r.current):{},[n,r,e]),assign:w.useCallback(()=>{r.current&&e.assign(n.getGraph(),r.current)},[n,r,e])}}function PT(e,t){const n=Ar(),[r,a]=w.useState(!1),[o,s]=w.useState(null),l=w.useRef(t);return ru(l.current,t)||(l.current=t),w.useEffect(()=>{a(!1);let u=null;return l.current&&(u=new e(n.getGraph(),l.current)),s(u),()=>{u!==null&&u.kill()}},[n,l,s,a,e]),{stop:w.useCallback(()=>{o&&(o.stop(),a(!1))},[o,a]),start:w.useCallback(()=>{o&&(o.start(),a(!0))},[o,a]),kill:w.useCallback(()=>{o&&o.kill(),a(!1)},[o,a]),isRunning:r}}var Nm,QN;function au(){if(QN)return Nm;QN=1;function e(n){return!n||typeof n!="object"||typeof n=="function"||Array.isArray(n)||n instanceof Set||n instanceof Map||n instanceof RegExp||n instanceof Date}function t(n,r){n=n||{};var a={};for(var o in r){var s=n[o],l=r[o];if(!e(l)){a[o]=t(s,l);continue}s===void 0?a[o]=l:a[o]=s}return a}return Nm=t,Nm}var Om,JN;function Hne(){if(JN)return Om;JN=1;function e(n){return function(r,a){return r+Math.floor(n()*(a-r+1))}}var t=e(Math.random);return t.createRandom=e,Om=t,Om}var Im,eO;function $ne(){if(eO)return Im;eO=1;var e=Hne().createRandom;function t(r){var a=e(r);return function(o){for(var s=o.length,l=s-1,u=-1;++u<s;){var d=a(u,l),p=o[d];o[d]=o[u],o[u]=p}}}var n=t(Math.random);return n.createShuffleInPlace=t,Im=n,Im}var Dm,tO;function qne(){if(tO)return Dm;tO=1;var e=au(),t=ua(),n=$ne(),r={attributes:{x:"x",y:"y"},center:0,hierarchyAttributes:[],rng:Math.random,scale:1};function a(_,M,I,D,U){this.wrappedCircle=U||null,this.children={},this.countChildren=0,this.id=_||null,this.next=null,this.previous=null,this.x=M||null,this.y=I||null,U?this.r=1010101:this.r=D||999}a.prototype.hasChildren=function(){return this.countChildren>0},a.prototype.addChild=function(_,M){this.children[_]=M,++this.countChildren},a.prototype.getChild=function(_){if(!this.children.hasOwnProperty(_)){var M=new a;this.children[_]=M,++this.countChildren}return this.children[_]},a.prototype.applyPositionToChildren=function(){if(this.hasChildren()){var _=this;for(var M in _.children){var I=_.children[M];I.x+=_.x,I.y+=_.y,I.applyPositionToChildren()}}};function o(_,M,I){for(var D in M.children){var U=M.children[D];U.hasChildren()?o(_,U,I):I[U.id]={x:U.x,y:U.y}}}function s(_,M){var I=_.r-M.r,D=M.x-_.x,U=M.y-_.y;return I<0||I*I<D*D+U*U}function l(_,M){var I=_.r-M.r+1e-6,D=M.x-_.x,U=M.y-_.y;return I>0&&I*I>D*D+U*U}function u(_,M){for(var I=0;I<M.length;++I)if(!l(_,M[I]))return!1;return!0}function d(_){return new a(null,_.x,_.y,_.r)}function p(_,M){var I=_.x,D=_.y,U=_.r,$=M.x,B=M.y,W=M.r,K=$-I,H=B-D,G=W-U,z=Math.sqrt(K*K+H*H);return new a(null,(I+$+K/z*G)/2,(D+B+H/z*G)/2,(z+U+W)/2)}function g(_,M,I){var D=_.x,U=_.y,$=_.r,B=M.x,W=M.y,K=M.r,H=I.x,G=I.y,z=I.r,Y=D-B,L=D-H,V=U-W,j=U-G,P=K-$,Z=z-$,Q=D*D+U*U-$*$,oe=Q-B*B-W*W+K*K,ae=Q-H*H-G*G+z*z,ce=L*V-Y*j,Re=(V*ae-j*oe)/(ce*2)-D,ie=(j*P-V*Z)/ce,Te=(L*oe-Y*ae)/(ce*2)-U,ne=(Y*Z-L*P)/ce,xe=ie*ie+ne*ne-1,Se=2*($+Re*ie+Te*ne),be=Re*Re+Te*Te-$*$,J=-(xe?(Se+Math.sqrt(Se*Se-4*xe*be))/(2*xe):be/Se);return new a(null,D+Re+ie*J,U+Te+ne*J,J)}function m(_){switch(_.length){case 1:return d(_[0]);case 2:return p(_[0],_[1]);case 3:return g(_[0],_[1],_[2]);default:throw new Error("graphology-layout/circlepack: Invalid basis length "+_.length)}}function b(_,M){var I,D;if(u(M,_))return[M];for(I=0;I<_.length;++I)if(s(M,_[I])&&u(p(_[I],M),_))return[_[I],M];for(I=0;I<_.length-1;++I)for(D=I+1;D<_.length;++D)if(s(p(_[I],_[D]),M)&&s(p(_[I],M),_[D])&&s(p(_[D],M),_[I])&&u(g(_[I],_[D],M),_))return[_[I],_[D],M];throw new Error("graphology-layout/circlepack: extendBasis failure !")}function v(_){var M=_.wrappedCircle,I=_.next.wrappedCircle,D=M.r+I.r,U=(M.x*I.r+I.x*M.r)/D,$=(M.y*I.r+I.y*M.r)/D;return U*U+$*$}function y(_,M){var I=0,D=_.slice(),U=_.length,$=[],B,W;for(M(D);I<U;)B=D[I],W&&l(W,B)?++I:($=b($,B),W=m($),I=0);return W}function k(_,M,I){var D=_.x-M.x,U,$,B=_.y-M.y,W,K,H=D*D+B*B;H?($=M.r+I.r,$*=$,K=_.r+I.r,K*=K,$>K?(U=(H+K-$)/(2*H),W=Math.sqrt(Math.max(0,K/H-U*U)),I.x=_.x-U*D-W*B,I.y=_.y-U*B+W*D):(U=(H+$-K)/(2*H),W=Math.sqrt(Math.max(0,$/H-U*U)),I.x=M.x+U*D-W*B,I.y=M.y+U*B+W*D)):(I.x=M.x+I.r,I.y=M.y)}function A(_,M){var I=_.r+M.r-1e-6,D=M.x-_.x,U=M.y-_.y;return I>0&&I*I>D*D+U*U}function x(_,M){var I=_.length;if(I===0)return 0;var D,U,$,B,W,K,H,G,z,Y;if(D=_[0],D.x=0,D.y=0,I<=1)return D.r;if(U=_[1],D.x=-U.r,U.x=D.r,U.y=0,I<=2)return D.r+U.r;$=_[2],k(U,D,$),D=new a(null,null,null,null,D),U=new a(null,null,null,null,U),$=new a(null,null,null,null,$),D.next=$.previous=U,U.next=D.previous=$,$.next=U.previous=D;e:for(K=3;K<I;++K){$=_[K],k(D.wrappedCircle,U.wrappedCircle,$),$=new a(null,null,null,null,$),H=U.next,G=D.previous,z=U.wrappedCircle.r,Y=D.wrappedCircle.r;do if(z<=Y){if(A(H.wrappedCircle,$.wrappedCircle)){U=H,D.next=U,U.previous=D,--K;continue e}z+=H.wrappedCircle.r,H=H.next}else{if(A(G.wrappedCircle,$.wrappedCircle)){D=G,D.next=U,U.previous=D,--K;continue e}Y+=G.wrappedCircle.r,G=G.previous}while(H!==G.next);for($.previous=D,$.next=U,D.next=U.previous=U=$,B=v(D);($=$.next)!==U;)(W=v($))<B&&(D=$,B=W);U=D.next}D=[U.wrappedCircle],$=U;for(var L=1e4;($=$.next)!==U&&--L!==0;)D.push($.wrappedCircle);for($=y(D,M),K=0;K<I;++K)D=_[K],D.x-=$.x,D.y-=$.y;return $.r}function R(_,M){var I=0;if(_.hasChildren()){for(var D in _.children){var U=_.children[D];U.hasChildren()&&(U.r=R(U,M))}I=x(Object.values(_.children),M)}return I}function O(_,M){R(_,M);for(var I in _.children){var D=_.children[I];D.applyPositionToChildren()}}function N(_,M,I){if(!t(M))throw new Error("graphology-layout/circlepack: the given graph is not a valid graphology instance.");I=e(I,r);var D={},U={},$=M.nodes(),B=I.center,W=I.hierarchyAttributes,K=n.createShuffleInPlace(I.rng),H=I.scale,G=new a;M.forEachNode(function(P,Z){var Q=Z.size?Z.size:1,oe=new a(P,null,null,Q),ae=G;W.forEach(function(ce){var Re=Z[ce];ae=ae.getChild(Re)}),ae.addChild(P,oe)}),O(G,K),o(M,G,D);var z=$.length,Y,L,V;for(V=0;V<z;V++){var j=$[V];Y=B+H*D[j].x,L=B+H*D[j].y,U[j]={x:Y,y:L},_&&(M.setNodeAttribute(j,I.attributes.x,Y),M.setNodeAttribute(j,I.attributes.y,L))}return U}var C=N.bind(null,!1);return C.assign=N.bind(null,!0),Dm=C,Dm}var Vne=qne();const Wne=un(Vne);function Yne(e={}){return Js(Wne,e)}var Lm,nO;function Kne(){if(nO)return Lm;nO=1;var e=au(),t=ua(),n={dimensions:["x","y"],center:.5,scale:1};function r(o,s,l){if(!t(s))throw new Error("graphology-layout/random: the given graph is not a valid graphology instance.");l=e(l,n);var u=l.dimensions;if(!Array.isArray(u)||u.length!==2)throw new Error("graphology-layout/random: given dimensions are invalid.");var d=l.center,p=l.scale,g=Math.PI*2,m=(d-.5)*p,b=s.order,v=u[0],y=u[1];function k(R,O){return O[v]=p*Math.cos(R*g/b)+m,O[y]=p*Math.sin(R*g/b)+m,O}var A=0;if(!o){var x={};return s.forEachNode(function(R){x[R]=k(A++,{})}),x}s.updateEachNodeAttributes(function(R,O){return k(A++,O),O},{attributes:u})}var a=r.bind(null,!1);return a.assign=r.bind(null,!0),Lm=a,Lm}var Xne=Kne();const Zne=un(Xne);function Qne(e={}){return Js(Zne,e)}var lc={},rO;function FT(){if(rO)return lc;rO=1;function e(r){return typeof r!="number"||isNaN(r)?1:r}function t(r,a){var o={},s=function(d){return typeof d>"u"?a:d};typeof a=="function"&&(s=a);var l=function(d){return s(d[r])},u=function(){return s(void 0)};return typeof r=="string"?(o.fromAttributes=l,o.fromGraph=function(d,p){return l(d.getNodeAttributes(p))},o.fromEntry=function(d,p){return l(p)}):typeof r=="function"?(o.fromAttributes=function(){throw new Error("graphology-utils/getters/createNodeValueGetter: irrelevant usage.")},o.fromGraph=function(d,p){return s(r(p,d.getNodeAttributes(p)))},o.fromEntry=function(d,p){return s(r(d,p))}):(o.fromAttributes=u,o.fromGraph=u,o.fromEntry=u),o}function n(r,a){var o={},s=function(d){return typeof d>"u"?a:d};typeof a=="function"&&(s=a);var l=function(d){return s(d[r])},u=function(){return s(void 0)};return typeof r=="string"?(o.fromAttributes=l,o.fromGraph=function(d,p){return l(d.getEdgeAttributes(p))},o.fromEntry=function(d,p){return l(p)},o.fromPartialEntry=o.fromEntry,o.fromMinimalEntry=o.fromEntry):typeof r=="function"?(o.fromAttributes=function(){throw new Error("graphology-utils/getters/createEdgeValueGetter: irrelevant usage.")},o.fromGraph=function(d,p){var g=d.extremities(p);return s(r(p,d.getEdgeAttributes(p),g[0],g[1],d.getNodeAttributes(g[0]),d.getNodeAttributes(g[1]),d.isUndirected(p)))},o.fromEntry=function(d,p,g,m,b,v,y){return s(r(d,p,g,m,b,v,y))},o.fromPartialEntry=function(d,p,g,m){return s(r(d,p,g,m))},o.fromMinimalEntry=function(d,p){return s(r(d,p))}):(o.fromAttributes=u,o.fromGraph=u,o.fromEntry=u,o.fromMinimalEntry=u),o}return lc.createNodeValueGetter=t,lc.createEdgeValueGetter=n,lc.createEdgeWeightGetter=function(r){return n(r,e)},lc}var Mm,aO;function d5(){if(aO)return Mm;aO=1;const{createNodeValueGetter:e,createEdgeValueGetter:t}=FT();return Mm=function(r,a,o){const{nodeXAttribute:s,nodeYAttribute:l}=o,{attraction:u,repulsion:d,gravity:p,inertia:g,maxMove:m}=o.settings;let{shouldSkipNode:b,shouldSkipEdge:v,isNodeFixed:y}=o;y=e(y),b=e(b,!1),v=t(v,!1);const k=r.filterNodes((R,O)=>!b.fromEntry(R,O)),A=k.length;for(let R=0;R<A;R++){const O=k[R],N=r.getNodeAttributes(O),C=a[O];C?a[O]={dx:C.dx*g,dy:C.dy*g,x:N[s]||0,y:N[l]||0}:a[O]={dx:0,dy:0,x:N[s]||0,y:N[l]||0}}if(d)for(let R=0;R<A;R++){const O=k[R],N=a[O];for(let C=R+1;C<A;C++){const _=k[C],M=a[_],I=M.x-N.x,D=M.y-N.y,U=Math.sqrt(I*I+D*D)||1,$=d/U*I,B=d/U*D;N.dx-=$,N.dy-=B,M.dx+=$,M.dy+=B}}if(u&&r.forEachEdge((R,O,N,C,_,M,I)=>{if(N===C||b.fromEntry(N,_)||b.fromEntry(C,M)||v.fromEntry(R,O,N,C,_,M,I))return;const D=a[N],U=a[C],$=U.x-D.x,B=U.y-D.y,W=Math.sqrt($*$+B*B)||1,K=u*W*$,H=u*W*B;D.dx+=K,D.dy+=H,U.dx-=K,U.dy-=H}),p)for(let R=0;R<A;R++){const O=k[R],N=a[O],{x:C,y:_}=N,M=Math.sqrt(C*C+_*_)||1;a[O].dx-=C*p*M,a[O].dy-=_*p*M}const x=!1;for(let R=0;R<A;R++){const O=k[R],N=a[O],C=Math.sqrt(N.dx*N.dx+N.dy*N.dy);C>m&&(N.dx*=m/C,N.dy*=m/C),y.fromGraph(r,O)?N.fixed=!0:(N.x+=N.dx,N.y+=N.dy,N.fixed=!1)}return{converged:x}},Mm}var Md={},oO;function f5(){return oO||(oO=1,Md.assignLayoutChanges=function(e,t,n){const{nodeXAttribute:r,nodeYAttribute:a}=n;e.updateEachNodeAttributes((o,s)=>{const l=t[o];return!l||l.fixed||(s[r]=l.x,s[a]=l.y),s},{attributes:["x","y"]})},Md.collectLayoutChanges=function(e){const t={};for(const n in e){const r=e[n];t[n]={x:r.x,y:r.y}}return t}),Md}var Pm,iO;function p5(){return iO||(iO=1,Pm={nodeXAttribute:"x",nodeYAttribute:"y",isNodeFixed:"fixed",shouldSkipNode:null,shouldSkipEdge:null,settings:{attraction:5e-4,repulsion:.1,gravity:1e-4,inertia:.6,maxMove:200}}),Pm}var Fm,sO;function Jne(){if(sO)return Fm;sO=1;const e=ua(),t=au(),n=d5(),r=f5(),a=p5();function o(l,u,d){if(!e(u))throw new Error("graphology-layout-force: the given graph is not a valid graphology instance.");typeof d=="number"?d={maxIterations:d}:d=d||{};const p=d.maxIterations;if(d=t(d,a),typeof p!="number"||p<=0)throw new Error("graphology-layout-force: you should provide a positive number of maximum iterations.");const g={};let m=null,b;for(b=0;b<p&&(m=n(u,g,d),!m.converged);b++);if(l){r.assignLayoutChanges(u,g,d);return}return r.collectLayoutChanges(g)}const s=o.bind(null,!1);return s.assign=o.bind(null,!0),Fm=s,Fm}var ere=Jne();const tre=un(ere);var zm,lO;function nre(){if(lO)return zm;lO=1;const e=ua(),t=au(),n=d5(),r=f5(),a=p5();function o(s,l){if(!e(s))throw new Error("graphology-layout-force/worker: the given graph is not a valid graphology instance.");l=t(l,a),this.callbacks={},l.onConverged&&(this.callbacks.onConverged=l.onConverged),this.graph=s,this.params=l,this.nodeStates={},this.frameID=null,this.running=!1,this.killed=!1}return o.prototype.isRunning=function(){return this.running},o.prototype.runFrame=function(){let{converged:s}=n(this.graph,this.nodeStates,this.params);r.assignLayoutChanges(this.graph,this.nodeStates,this.params),s=!1,s?(this.callbacks.onConverged&&this.callbacks.onConverged(),this.stop()):this.frameID=window.requestAnimationFrame(()=>this.runFrame())},o.prototype.stop=function(){return this.running=!1,this.frameID!==null&&(window.cancelAnimationFrame(this.frameID),this.frameID=null),this},o.prototype.start=function(){if(this.killed)throw new Error("graphology-layout-force/worker.start: layout was killed.");this.running||(this.running=!0,this.runFrame())},o.prototype.kill=function(){this.stop(),delete this.nodeStates,this.killed=!0},zm=o,zm}var rre=nre();const are=un(rre);function ore(e={maxIterations:100}){return Js(tre,e)}function ire(e={}){return PT(are,e)}var Bm,cO;function sre(){if(cO)return Bm;cO=1;var e=0,t=1,n=2,r=3,a=4,o=5,s=6,l=7,u=8,d=9,p=0,g=1,m=2,b=0,v=1,y=2,k=3,A=4,x=5,R=6,O=7,N=8,C=3,_=10,M=3,I=9,D=10;return Bm=function($,B,W){var K,H,G,z,Y,L,V,j,P,Z,Q=B.length,oe=W.length,ae=$.adjustSizes,ce=$.barnesHutTheta*$.barnesHutTheta,Re,ie,Te,ne,xe,Se,be,J=[];for(G=0;G<Q;G+=_)B[G+a]=B[G+n],B[G+o]=B[G+r],B[G+n]=0,B[G+r]=0;if($.outboundAttractionDistribution){for(Re=0,G=0;G<Q;G+=_)Re+=B[G+s];Re/=Q/_}if($.barnesHutOptimize){var pe=1/0,ke=-1/0,he=1/0,Ee=-1/0,se,Be,je;for(G=0;G<Q;G+=_)pe=Math.min(pe,B[G+e]),ke=Math.max(ke,B[G+e]),he=Math.min(he,B[G+t]),Ee=Math.max(Ee,B[G+t]);var ye=ke-pe,Oe=Ee-he;for(ye>Oe?(he-=(ye-Oe)/2,Ee=he+ye):(pe-=(Oe-ye)/2,ke=pe+Oe),J[0+b]=-1,J[0+v]=(pe+ke)/2,J[0+y]=(he+Ee)/2,J[0+k]=Math.max(ke-pe,Ee-he),J[0+A]=-1,J[0+x]=-1,J[0+R]=0,J[0+O]=0,J[0+N]=0,K=1,G=0;G<Q;G+=_)for(H=0,je=C;;)if(J[H+x]>=0){B[G+e]<J[H+v]?B[G+t]<J[H+y]?se=J[H+x]:se=J[H+x]+I:B[G+t]<J[H+y]?se=J[H+x]+I*2:se=J[H+x]+I*3,J[H+O]=(J[H+O]*J[H+R]+B[G+e]*B[G+s])/(J[H+R]+B[G+s]),J[H+N]=(J[H+N]*J[H+R]+B[G+t]*B[G+s])/(J[H+R]+B[G+s]),J[H+R]+=B[G+s],H=se;continue}else if(J[H+b]<0){J[H+b]=G;break}else{if(J[H+x]=K*I,j=J[H+k]/2,P=J[H+x],J[P+b]=-1,J[P+v]=J[H+v]-j,J[P+y]=J[H+y]-j,J[P+k]=j,J[P+A]=P+I,J[P+x]=-1,J[P+R]=0,J[P+O]=0,J[P+N]=0,P+=I,J[P+b]=-1,J[P+v]=J[H+v]-j,J[P+y]=J[H+y]+j,J[P+k]=j,J[P+A]=P+I,J[P+x]=-1,J[P+R]=0,J[P+O]=0,J[P+N]=0,P+=I,J[P+b]=-1,J[P+v]=J[H+v]+j,J[P+y]=J[H+y]-j,J[P+k]=j,J[P+A]=P+I,J[P+x]=-1,J[P+R]=0,J[P+O]=0,J[P+N]=0,P+=I,J[P+b]=-1,J[P+v]=J[H+v]+j,J[P+y]=J[H+y]+j,J[P+k]=j,J[P+A]=J[H+A],J[P+x]=-1,J[P+R]=0,J[P+O]=0,J[P+N]=0,K+=4,B[J[H+b]+e]<J[H+v]?B[J[H+b]+t]<J[H+y]?se=J[H+x]:se=J[H+x]+I:B[J[H+b]+t]<J[H+y]?se=J[H+x]+I*2:se=J[H+x]+I*3,J[H+R]=B[J[H+b]+s],J[H+O]=B[J[H+b]+e],J[H+N]=B[J[H+b]+t],J[se+b]=J[H+b],J[H+b]=-1,B[G+e]<J[H+v]?B[G+t]<J[H+y]?Be=J[H+x]:Be=J[H+x]+I:B[G+t]<J[H+y]?Be=J[H+x]+I*2:Be=J[H+x]+I*3,se===Be)if(je--){H=se;continue}else{je=C;break}J[Be+b]=G;break}}if($.barnesHutOptimize)for(ie=$.scalingRatio,G=0;G<Q;G+=_)for(H=0;;)if(J[H+x]>=0)if(Se=Math.pow(B[G+e]-J[H+O],2)+Math.pow(B[G+t]-J[H+N],2),Z=J[H+k],4*Z*Z/Se<ce){if(Te=B[G+e]-J[H+O],ne=B[G+t]-J[H+N],ae===!0?Se>0?(be=ie*B[G+s]*J[H+R]/Se,B[G+n]+=Te*be,B[G+r]+=ne*be):Se<0&&(be=-ie*B[G+s]*J[H+R]/Math.sqrt(Se),B[G+n]+=Te*be,B[G+r]+=ne*be):Se>0&&(be=ie*B[G+s]*J[H+R]/Se,B[G+n]+=Te*be,B[G+r]+=ne*be),H=J[H+A],H<0)break;continue}else{H=J[H+x];continue}else{if(L=J[H+b],L>=0&&L!==G&&(Te=B[G+e]-B[L+e],ne=B[G+t]-B[L+t],Se=Te*Te+ne*ne,ae===!0?Se>0?(be=ie*B[G+s]*B[L+s]/Se,B[G+n]+=Te*be,B[G+r]+=ne*be):Se<0&&(be=-ie*B[G+s]*B[L+s]/Math.sqrt(Se),B[G+n]+=Te*be,B[G+r]+=ne*be):Se>0&&(be=ie*B[G+s]*B[L+s]/Se,B[G+n]+=Te*be,B[G+r]+=ne*be)),H=J[H+A],H<0)break;continue}else for(ie=$.scalingRatio,z=0;z<Q;z+=_)for(Y=0;Y<z;Y+=_)Te=B[z+e]-B[Y+e],ne=B[z+t]-B[Y+t],ae===!0?(Se=Math.sqrt(Te*Te+ne*ne)-B[z+u]-B[Y+u],Se>0?(be=ie*B[z+s]*B[Y+s]/Se/Se,B[z+n]+=Te*be,B[z+r]+=ne*be,B[Y+n]-=Te*be,B[Y+r]-=ne*be):Se<0&&(be=100*ie*B[z+s]*B[Y+s],B[z+n]+=Te*be,B[z+r]+=ne*be,B[Y+n]-=Te*be,B[Y+r]-=ne*be)):(Se=Math.sqrt(Te*Te+ne*ne),Se>0&&(be=ie*B[z+s]*B[Y+s]/Se/Se,B[z+n]+=Te*be,B[z+r]+=ne*be,B[Y+n]-=Te*be,B[Y+r]-=ne*be));for(P=$.gravity/$.scalingRatio,ie=$.scalingRatio,G=0;G<Q;G+=_)be=0,Te=B[G+e],ne=B[G+t],Se=Math.sqrt(Math.pow(Te,2)+Math.pow(ne,2)),$.strongGravityMode?Se>0&&(be=ie*B[G+s]*P):Se>0&&(be=ie*B[G+s]*P/Se),B[G+n]-=Te*be,B[G+r]-=ne*be;for(ie=1*($.outboundAttractionDistribution?Re:1),V=0;V<oe;V+=M)z=W[V+p],Y=W[V+g],j=W[V+m],xe=Math.pow(j,$.edgeWeightInfluence),Te=B[z+e]-B[Y+e],ne=B[z+t]-B[Y+t],ae===!0?(Se=Math.sqrt(Te*Te+ne*ne)-B[z+u]-B[Y+u],$.linLogMode?$.outboundAttractionDistribution?Se>0&&(be=-ie*xe*Math.log(1+Se)/Se/B[z+s]):Se>0&&(be=-ie*xe*Math.log(1+Se)/Se):$.outboundAttractionDistribution?Se>0&&(be=-ie*xe/B[z+s]):Se>0&&(be=-ie*xe)):(Se=Math.sqrt(Math.pow(Te,2)+Math.pow(ne,2)),$.linLogMode?$.outboundAttractionDistribution?Se>0&&(be=-ie*xe*Math.log(1+Se)/Se/B[z+s]):Se>0&&(be=-ie*xe*Math.log(1+Se)/Se):$.outboundAttractionDistribution?(Se=1,be=-ie*xe/B[z+s]):(Se=1,be=-ie*xe)),Se>0&&(B[z+n]+=Te*be,B[z+r]+=ne*be,B[Y+n]-=Te*be,B[Y+r]-=ne*be);var ee,de,Ne,Fe,We,St;if(ae===!0)for(G=0;G<Q;G+=_)B[G+d]!==1&&(ee=Math.sqrt(Math.pow(B[G+n],2)+Math.pow(B[G+r],2)),ee>D&&(B[G+n]=B[G+n]*D/ee,B[G+r]=B[G+r]*D/ee),de=B[G+s]*Math.sqrt((B[G+a]-B[G+n])*(B[G+a]-B[G+n])+(B[G+o]-B[G+r])*(B[G+o]-B[G+r])),Ne=Math.sqrt((B[G+a]+B[G+n])*(B[G+a]+B[G+n])+(B[G+o]+B[G+r])*(B[G+o]+B[G+r]))/2,Fe=.1*Math.log(1+Ne)/(1+Math.sqrt(de)),We=B[G+e]+B[G+n]*(Fe/$.slowDown),B[G+e]=We,St=B[G+t]+B[G+r]*(Fe/$.slowDown),B[G+t]=St);else for(G=0;G<Q;G+=_)B[G+d]!==1&&(de=B[G+s]*Math.sqrt((B[G+a]-B[G+n])*(B[G+a]-B[G+n])+(B[G+o]-B[G+r])*(B[G+o]-B[G+r])),Ne=Math.sqrt((B[G+a]+B[G+n])*(B[G+a]+B[G+n])+(B[G+o]+B[G+r])*(B[G+o]+B[G+r]))/2,Fe=B[G+l]*Math.log(1+Ne)/(1+Math.sqrt(de)),B[G+l]=Math.min(1,Math.sqrt(Fe*(Math.pow(B[G+n],2)+Math.pow(B[G+r],2))/(1+Math.sqrt(de)))),We=B[G+e]+B[G+n]*(Fe/$.slowDown),B[G+e]=We,St=B[G+t]+B[G+r]*(Fe/$.slowDown),B[G+t]=St);return{}},Bm}var Da={},uO;function g5(){if(uO)return Da;uO=1;var e=10,t=3;return Da.assign=function(n){n=n||{};var r=Array.prototype.slice.call(arguments).slice(1),a,o,s;for(a=0,s=r.length;a<s;a++)if(r[a])for(o in r[a])n[o]=r[a][o];return n},Da.validateSettings=function(n){return"linLogMode"in n&&typeof n.linLogMode!="boolean"?{message:"the `linLogMode` setting should be a boolean."}:"outboundAttractionDistribution"in n&&typeof n.outboundAttractionDistribution!="boolean"?{message:"the `outboundAttractionDistribution` setting should be a boolean."}:"adjustSizes"in n&&typeof n.adjustSizes!="boolean"?{message:"the `adjustSizes` setting should be a boolean."}:"edgeWeightInfluence"in n&&typeof n.edgeWeightInfluence!="number"?{message:"the `edgeWeightInfluence` setting should be a number."}:"scalingRatio"in n&&!(typeof n.scalingRatio=="number"&&n.scalingRatio>=0)?{message:"the `scalingRatio` setting should be a number >= 0."}:"strongGravityMode"in n&&typeof n.strongGravityMode!="boolean"?{message:"the `strongGravityMode` setting should be a boolean."}:"gravity"in n&&!(typeof n.gravity=="number"&&n.gravity>=0)?{message:"the `gravity` setting should be a number >= 0."}:"slowDown"in n&&!(typeof n.slowDown=="number"||n.slowDown>=0)?{message:"the `slowDown` setting should be a number >= 0."}:"barnesHutOptimize"in n&&typeof n.barnesHutOptimize!="boolean"?{message:"the `barnesHutOptimize` setting should be a boolean."}:"barnesHutTheta"in n&&!(typeof n.barnesHutTheta=="number"&&n.barnesHutTheta>=0)?{message:"the `barnesHutTheta` setting should be a number >= 0."}:null},Da.graphToByteArrays=function(n,r){var a=n.order,o=n.size,s={},l,u=new Float32Array(a*e),d=new Float32Array(o*t);return l=0,n.forEachNode(function(p,g){s[p]=l,u[l]=g.x,u[l+1]=g.y,u[l+2]=0,u[l+3]=0,u[l+4]=0,u[l+5]=0,u[l+6]=1,u[l+7]=1,u[l+8]=g.size||1,u[l+9]=g.fixed?1:0,l+=e}),l=0,n.forEachEdge(function(p,g,m,b,v,y,k){var A=s[m],x=s[b],R=r(p,g,m,b,v,y,k);u[A+6]+=R,u[x+6]+=R,d[l]=A,d[l+1]=x,d[l+2]=R,l+=t}),{nodes:u,edges:d}},Da.assignLayoutChanges=function(n,r,a){var o=0;n.updateEachNodeAttributes(function(s,l){return l.x=r[o],l.y=r[o+1],o+=e,a?a(s,l):l})},Da.readGraphPositions=function(n,r){var a=0;n.forEachNode(function(o,s){r[a]=s.x,r[a+1]=s.y,a+=e})},Da.collectLayoutChanges=function(n,r,a){for(var o=n.nodes(),s={},l=0,u=0,d=r.length;l<d;l+=e){if(a){var p=Object.assign({},n.getNodeAttributes(o[u]));p.x=r[l],p.y=r[l+1],p=a(o[u],p),s[o[u]]={x:p.x,y:p.y}}else s[o[u]]={x:r[l],y:r[l+1]};u++}return s},Da.createWorker=function(r){var a=window.URL||window.webkitURL,o=r.toString(),s=a.createObjectURL(new Blob(["("+o+").call(this);"],{type:"text/javascript"})),l=new Worker(s);return a.revokeObjectURL(s),l},Da}var jm,dO;function h5(){return dO||(dO=1,jm={linLogMode:!1,outboundAttractionDistribution:!1,adjustSizes:!1,edgeWeightInfluence:1,scalingRatio:1,strongGravityMode:!1,gravity:1,slowDown:1,barnesHutOptimize:!1,barnesHutTheta:.5}),jm}var Um,fO;function lre(){if(fO)return Um;fO=1;var e=ua(),t=FT().createEdgeWeightGetter,n=sre(),r=g5(),a=h5();function o(u,d,p){if(!e(d))throw new Error("graphology-layout-forceatlas2: the given graph is not a valid graphology instance.");typeof p=="number"&&(p={iterations:p});var g=p.iterations;if(typeof g!="number")throw new Error("graphology-layout-forceatlas2: invalid number of iterations.");if(g<=0)throw new Error("graphology-layout-forceatlas2: you should provide a positive number of iterations.");var m=t("getEdgeWeight"in p?p.getEdgeWeight:"weight").fromEntry,b=typeof p.outputReducer=="function"?p.outputReducer:null,v=r.assign({},a,p.settings),y=r.validateSettings(v);if(y)throw new Error("graphology-layout-forceatlas2: "+y.message);var k=r.graphToByteArrays(d,m),A;for(A=0;A<g;A++)n(v,k.nodes,k.edges);if(u){r.assignLayoutChanges(d,k.nodes,b);return}return r.collectLayoutChanges(d,k.nodes)}function s(u){var d=typeof u=="number"?u:u.order;return{barnesHutOptimize:d>2e3,strongGravityMode:!0,gravity:.05,scalingRatio:10,slowDown:1+Math.log(d)}}var l=o.bind(null,!1);return l.assign=o.bind(null,!0),l.inferSettings=s,Um=l,Um}var cre=lre();const ure=un(cre);var Gm,pO;function dre(){return pO||(pO=1,Gm=function(){var t,n,r={};(function(){var o=0,s=1,l=2,u=3,d=4,p=5,g=6,m=7,b=8,v=9,y=0,k=1,A=2,x=0,R=1,O=2,N=3,C=4,_=5,M=6,I=7,D=8,U=3,$=10,B=3,W=9,K=10;r.exports=function(G,z,Y){var L,V,j,P,Z,Q,oe,ae,ce,Re,ie=z.length,Te=Y.length,ne=G.adjustSizes,xe=G.barnesHutTheta*G.barnesHutTheta,Se,be,J,pe,ke,he,Ee,se=[];for(j=0;j<ie;j+=$)z[j+d]=z[j+l],z[j+p]=z[j+u],z[j+l]=0,z[j+u]=0;if(G.outboundAttractionDistribution){for(Se=0,j=0;j<ie;j+=$)Se+=z[j+g];Se/=ie/$}if(G.barnesHutOptimize){var Be=1/0,je=-1/0,ye=1/0,Oe=-1/0,ee,de,Ne;for(j=0;j<ie;j+=$)Be=Math.min(Be,z[j+o]),je=Math.max(je,z[j+o]),ye=Math.min(ye,z[j+s]),Oe=Math.max(Oe,z[j+s]);var Fe=je-Be,We=Oe-ye;for(Fe>We?(ye-=(Fe-We)/2,Oe=ye+Fe):(Be-=(We-Fe)/2,je=Be+We),se[0+x]=-1,se[0+R]=(Be+je)/2,se[0+O]=(ye+Oe)/2,se[0+N]=Math.max(je-Be,Oe-ye),se[0+C]=-1,se[0+_]=-1,se[0+M]=0,se[0+I]=0,se[0+D]=0,L=1,j=0;j<ie;j+=$)for(V=0,Ne=U;;)if(se[V+_]>=0){z[j+o]<se[V+R]?z[j+s]<se[V+O]?ee=se[V+_]:ee=se[V+_]+W:z[j+s]<se[V+O]?ee=se[V+_]+W*2:ee=se[V+_]+W*3,se[V+I]=(se[V+I]*se[V+M]+z[j+o]*z[j+g])/(se[V+M]+z[j+g]),se[V+D]=(se[V+D]*se[V+M]+z[j+s]*z[j+g])/(se[V+M]+z[j+g]),se[V+M]+=z[j+g],V=ee;continue}else if(se[V+x]<0){se[V+x]=j;break}else{if(se[V+_]=L*W,ae=se[V+N]/2,ce=se[V+_],se[ce+x]=-1,se[ce+R]=se[V+R]-ae,se[ce+O]=se[V+O]-ae,se[ce+N]=ae,se[ce+C]=ce+W,se[ce+_]=-1,se[ce+M]=0,se[ce+I]=0,se[ce+D]=0,ce+=W,se[ce+x]=-1,se[ce+R]=se[V+R]-ae,se[ce+O]=se[V+O]+ae,se[ce+N]=ae,se[ce+C]=ce+W,se[ce+_]=-1,se[ce+M]=0,se[ce+I]=0,se[ce+D]=0,ce+=W,se[ce+x]=-1,se[ce+R]=se[V+R]+ae,se[ce+O]=se[V+O]-ae,se[ce+N]=ae,se[ce+C]=ce+W,se[ce+_]=-1,se[ce+M]=0,se[ce+I]=0,se[ce+D]=0,ce+=W,se[ce+x]=-1,se[ce+R]=se[V+R]+ae,se[ce+O]=se[V+O]+ae,se[ce+N]=ae,se[ce+C]=se[V+C],se[ce+_]=-1,se[ce+M]=0,se[ce+I]=0,se[ce+D]=0,L+=4,z[se[V+x]+o]<se[V+R]?z[se[V+x]+s]<se[V+O]?ee=se[V+_]:ee=se[V+_]+W:z[se[V+x]+s]<se[V+O]?ee=se[V+_]+W*2:ee=se[V+_]+W*3,se[V+M]=z[se[V+x]+g],se[V+I]=z[se[V+x]+o],se[V+D]=z[se[V+x]+s],se[ee+x]=se[V+x],se[V+x]=-1,z[j+o]<se[V+R]?z[j+s]<se[V+O]?de=se[V+_]:de=se[V+_]+W:z[j+s]<se[V+O]?de=se[V+_]+W*2:de=se[V+_]+W*3,ee===de)if(Ne--){V=ee;continue}else{Ne=U;break}se[de+x]=j;break}}if(G.barnesHutOptimize)for(be=G.scalingRatio,j=0;j<ie;j+=$)for(V=0;;)if(se[V+_]>=0)if(he=Math.pow(z[j+o]-se[V+I],2)+Math.pow(z[j+s]-se[V+D],2),Re=se[V+N],4*Re*Re/he<xe){if(J=z[j+o]-se[V+I],pe=z[j+s]-se[V+D],ne===!0?he>0?(Ee=be*z[j+g]*se[V+M]/he,z[j+l]+=J*Ee,z[j+u]+=pe*Ee):he<0&&(Ee=-be*z[j+g]*se[V+M]/Math.sqrt(he),z[j+l]+=J*Ee,z[j+u]+=pe*Ee):he>0&&(Ee=be*z[j+g]*se[V+M]/he,z[j+l]+=J*Ee,z[j+u]+=pe*Ee),V=se[V+C],V<0)break;continue}else{V=se[V+_];continue}else{if(Q=se[V+x],Q>=0&&Q!==j&&(J=z[j+o]-z[Q+o],pe=z[j+s]-z[Q+s],he=J*J+pe*pe,ne===!0?he>0?(Ee=be*z[j+g]*z[Q+g]/he,z[j+l]+=J*Ee,z[j+u]+=pe*Ee):he<0&&(Ee=-be*z[j+g]*z[Q+g]/Math.sqrt(he),z[j+l]+=J*Ee,z[j+u]+=pe*Ee):he>0&&(Ee=be*z[j+g]*z[Q+g]/he,z[j+l]+=J*Ee,z[j+u]+=pe*Ee)),V=se[V+C],V<0)break;continue}else for(be=G.scalingRatio,P=0;P<ie;P+=$)for(Z=0;Z<P;Z+=$)J=z[P+o]-z[Z+o],pe=z[P+s]-z[Z+s],ne===!0?(he=Math.sqrt(J*J+pe*pe)-z[P+b]-z[Z+b],he>0?(Ee=be*z[P+g]*z[Z+g]/he/he,z[P+l]+=J*Ee,z[P+u]+=pe*Ee,z[Z+l]-=J*Ee,z[Z+u]-=pe*Ee):he<0&&(Ee=100*be*z[P+g]*z[Z+g],z[P+l]+=J*Ee,z[P+u]+=pe*Ee,z[Z+l]-=J*Ee,z[Z+u]-=pe*Ee)):(he=Math.sqrt(J*J+pe*pe),he>0&&(Ee=be*z[P+g]*z[Z+g]/he/he,z[P+l]+=J*Ee,z[P+u]+=pe*Ee,z[Z+l]-=J*Ee,z[Z+u]-=pe*Ee));for(ce=G.gravity/G.scalingRatio,be=G.scalingRatio,j=0;j<ie;j+=$)Ee=0,J=z[j+o],pe=z[j+s],he=Math.sqrt(Math.pow(J,2)+Math.pow(pe,2)),G.strongGravityMode?he>0&&(Ee=be*z[j+g]*ce):he>0&&(Ee=be*z[j+g]*ce/he),z[j+l]-=J*Ee,z[j+u]-=pe*Ee;for(be=1*(G.outboundAttractionDistribution?Se:1),oe=0;oe<Te;oe+=B)P=Y[oe+y],Z=Y[oe+k],ae=Y[oe+A],ke=Math.pow(ae,G.edgeWeightInfluence),J=z[P+o]-z[Z+o],pe=z[P+s]-z[Z+s],ne===!0?(he=Math.sqrt(J*J+pe*pe)-z[P+b]-z[Z+b],G.linLogMode?G.outboundAttractionDistribution?he>0&&(Ee=-be*ke*Math.log(1+he)/he/z[P+g]):he>0&&(Ee=-be*ke*Math.log(1+he)/he):G.outboundAttractionDistribution?he>0&&(Ee=-be*ke/z[P+g]):he>0&&(Ee=-be*ke)):(he=Math.sqrt(Math.pow(J,2)+Math.pow(pe,2)),G.linLogMode?G.outboundAttractionDistribution?he>0&&(Ee=-be*ke*Math.log(1+he)/he/z[P+g]):he>0&&(Ee=-be*ke*Math.log(1+he)/he):G.outboundAttractionDistribution?(he=1,Ee=-be*ke/z[P+g]):(he=1,Ee=-be*ke)),he>0&&(z[P+l]+=J*Ee,z[P+u]+=pe*Ee,z[Z+l]-=J*Ee,z[Z+u]-=pe*Ee);var St,Tt,bt,et,At,st;if(ne===!0)for(j=0;j<ie;j+=$)z[j+v]!==1&&(St=Math.sqrt(Math.pow(z[j+l],2)+Math.pow(z[j+u],2)),St>K&&(z[j+l]=z[j+l]*K/St,z[j+u]=z[j+u]*K/St),Tt=z[j+g]*Math.sqrt((z[j+d]-z[j+l])*(z[j+d]-z[j+l])+(z[j+p]-z[j+u])*(z[j+p]-z[j+u])),bt=Math.sqrt((z[j+d]+z[j+l])*(z[j+d]+z[j+l])+(z[j+p]+z[j+u])*(z[j+p]+z[j+u]))/2,et=.1*Math.log(1+bt)/(1+Math.sqrt(Tt)),At=z[j+o]+z[j+l]*(et/G.slowDown),z[j+o]=At,st=z[j+s]+z[j+u]*(et/G.slowDown),z[j+s]=st);else for(j=0;j<ie;j+=$)z[j+v]!==1&&(Tt=z[j+g]*Math.sqrt((z[j+d]-z[j+l])*(z[j+d]-z[j+l])+(z[j+p]-z[j+u])*(z[j+p]-z[j+u])),bt=Math.sqrt((z[j+d]+z[j+l])*(z[j+d]+z[j+l])+(z[j+p]+z[j+u])*(z[j+p]+z[j+u]))/2,et=z[j+m]*Math.log(1+bt)/(1+Math.sqrt(Tt)),z[j+m]=Math.min(1,Math.sqrt(et*(Math.pow(z[j+l],2)+Math.pow(z[j+u],2))/(1+Math.sqrt(Tt)))),At=z[j+o]+z[j+l]*(et/G.slowDown),z[j+o]=At,st=z[j+s]+z[j+u]*(et/G.slowDown),z[j+s]=st);return{}}})();var a=r.exports;self.addEventListener("message",function(o){var s=o.data;t=new Float32Array(s.nodes),s.edges&&(n=new Float32Array(s.edges)),a(s.settings,t,n),self.postMessage({nodes:t.buffer},[t.buffer])})}),Gm}var Hm,gO;function fre(){if(gO)return Hm;gO=1;var e=dre(),t=ua(),n=FT().createEdgeWeightGetter,r=g5(),a=h5();function o(s,l){if(l=l||{},!t(s))throw new Error("graphology-layout-forceatlas2/worker: the given graph is not a valid graphology instance.");var u=n("getEdgeWeight"in l?l.getEdgeWeight:"weight").fromEntry,d=r.assign({},a,l.settings),p=r.validateSettings(d);if(p)throw new Error("graphology-layout-forceatlas2/worker: "+p.message);this.worker=null,this.graph=s,this.settings=d,this.getEdgeWeight=u,this.matrices=null,this.running=!1,this.killed=!1,this.outputReducer=typeof l.outputReducer=="function"?l.outputReducer:null,this.handleMessage=this.handleMessage.bind(this);var g=void 0,m=this;this.handleGraphUpdate=function(){m.worker&&m.worker.terminate(),g&&clearTimeout(g),g=setTimeout(function(){g=void 0,m.spawnWorker()},0)},s.on("nodeAdded",this.handleGraphUpdate),s.on("edgeAdded",this.handleGraphUpdate),s.on("nodeDropped",this.handleGraphUpdate),s.on("edgeDropped",this.handleGraphUpdate),this.spawnWorker()}return o.prototype.isRunning=function(){return this.running},o.prototype.spawnWorker=function(){this.worker&&this.worker.terminate(),this.worker=r.createWorker(e),this.worker.addEventListener("message",this.handleMessage),this.running&&(this.running=!1,this.start())},o.prototype.handleMessage=function(s){if(this.running){var l=new Float32Array(s.data.nodes);r.assignLayoutChanges(this.graph,l,this.outputReducer),this.outputReducer&&r.readGraphPositions(this.graph,l),this.matrices.nodes=l,this.askForIterations()}},o.prototype.askForIterations=function(s){var l=this.matrices,u={settings:this.settings,nodes:l.nodes.buffer},d=[l.nodes.buffer];return s&&(u.edges=l.edges.buffer,d.push(l.edges.buffer)),this.worker.postMessage(u,d),this},o.prototype.start=function(){if(this.killed)throw new Error("graphology-layout-forceatlas2/worker.start: layout was killed.");return this.running?this:(this.matrices=r.graphToByteArrays(this.graph,this.getEdgeWeight),this.running=!0,this.askForIterations(!0),this)},o.prototype.stop=function(){return this.running=!1,this},o.prototype.kill=function(){if(this.killed)return this;this.running=!1,this.killed=!0,this.matrices=null,this.worker.terminate(),this.graph.removeListener("nodeAdded",this.handleGraphUpdate),this.graph.removeListener("edgeAdded",this.handleGraphUpdate),this.graph.removeListener("nodeDropped",this.handleGraphUpdate),this.graph.removeListener("edgeDropped",this.handleGraphUpdate)},Hm=o,Hm}var pre=fre();const gre=un(pre);function m5(e={iterations:100}){return Js(ure,e)}function hre(e={}){return PT(gre,e)}var $m,hO;function mre(){if(hO)return $m;hO=1;var e=0,t=1,n=2,r=3;function a(s,l){return s+"§"+l}function o(){return .01*(.5-Math.random())}return $m=function(l,u){var d=l.margin,p=l.ratio,g=l.expansion,m=l.gridSize,b=l.speed,v,y,k,A,x,R,O=!0,N=u.length,C=N/r|0,_=new Float32Array(C),M=new Float32Array(C),I=1/0,D=1/0,U=-1/0,$=-1/0;for(v=0;v<N;v+=r)k=u[v+e],A=u[v+t],R=u[v+n]*p+d,I=Math.min(I,k-R),U=Math.max(U,k+R),D=Math.min(D,A-R),$=Math.max($,A+R);var B=U-I,W=$-D,K=(I+U)/2,H=(D+$)/2;I=K-g*B/2,U=K+g*B/2,D=H-g*W/2,$=H+g*W/2;var G=new Array(m*m),z=G.length,Y;for(Y=0;Y<z;Y++)G[Y]=[];var L,V,j,P,Z,Q,oe,ae,ce,Re;for(v=0;v<N;v+=r)for(k=u[v+e],A=u[v+t],R=u[v+n]*p+d,L=k-R,V=k+R,j=A-R,P=A+R,Z=Math.floor(m*(L-I)/(U-I)),Q=Math.floor(m*(V-I)/(U-I)),oe=Math.floor(m*(j-D)/($-D)),ae=Math.floor(m*(P-D)/($-D)),ce=Z;ce<=Q;ce++)for(Re=oe;Re<=ae;Re++)G[ce*m+Re].push(v);var ie,Te=new Set,ne,xe,Se,be,J,pe,ke,he,Ee,se,Be,je,ye;for(Y=0;Y<z;Y++)for(ie=G[Y],v=0,x=ie.length;v<x;v++)for(ne=ie[v],Se=u[ne+e],J=u[ne+t],ke=u[ne+n],y=v+1;y<x;y++)xe=ie[y],Ee=a(ne,xe),!(z>1&&Te.has(Ee))&&(z>1&&Te.add(Ee),be=u[xe+e],pe=u[xe+t],he=u[xe+n],se=be-Se,Be=pe-J,je=Math.sqrt(se*se+Be*Be),ye=je<ke*p+d+(he*p+d),ye&&(O=!1,xe=xe/r|0,je>0?(_[xe]+=se/je*(1+ke),M[xe]+=Be/je*(1+ke)):(_[xe]+=B*o(),M[xe]+=W*o())));for(v=0,y=0;v<N;v+=r,y++)u[v+e]+=_[y]*.1*b,u[v+t]+=M[y]*.1*b;return{converged:O}},$m}var ii={},mO;function b5(){if(mO)return ii;mO=1;var e=3;return ii.validateSettings=function(t){return"gridSize"in t&&typeof t.gridSize!="number"||t.gridSize<=0?{message:"the `gridSize` setting should be a positive number."}:"margin"in t&&typeof t.margin!="number"||t.margin<0?{message:"the `margin` setting should be 0 or a positive number."}:"expansion"in t&&typeof t.expansion!="number"||t.expansion<=0?{message:"the `expansion` setting should be a positive number."}:"ratio"in t&&typeof t.ratio!="number"||t.ratio<=0?{message:"the `ratio` setting should be a positive number."}:"speed"in t&&typeof t.speed!="number"||t.speed<=0?{message:"the `speed` setting should be a positive number."}:null},ii.graphToByteArray=function(t,n){var r=t.order,a=new Float32Array(r*e),o=0;return t.forEachNode(function(s,l){typeof n=="function"&&(l=n(s,l)),a[o]=l.x,a[o+1]=l.y,a[o+2]=l.size||1,o+=e}),a},ii.assignLayoutChanges=function(t,n,r){var a=0;t.forEachNode(function(o){var s={x:n[a],y:n[a+1]};typeof r=="function"&&(s=r(o,s)),t.mergeNodeAttributes(o,s),a+=e})},ii.collectLayoutChanges=function(t,n,r){var a={},o=0;return t.forEachNode(function(s){var l={x:n[o],y:n[o+1]};typeof r=="function"&&(l=r(s,l)),a[s]=l,o+=e}),a},ii.createWorker=function(n){var r=window.URL||window.webkitURL,a=n.toString(),o=r.createObjectURL(new Blob(["("+a+").call(this);"],{type:"text/javascript"})),s=new Worker(o);return r.revokeObjectURL(o),s},ii}var qm,bO;function y5(){return bO||(bO=1,qm={gridSize:20,margin:5,expansion:1.1,ratio:1,speed:3}),qm}var Vm,yO;function bre(){if(yO)return Vm;yO=1;var e=ua(),t=mre(),n=b5(),r=y5(),a=500;function o(l,u,d){if(!e(u))throw new Error("graphology-layout-noverlap: the given graph is not a valid graphology instance.");typeof d=="number"?d={maxIterations:d}:d=d||{};var p=d.maxIterations||a;if(typeof p!="number"||p<=0)throw new Error("graphology-layout-force: you should provide a positive number of maximum iterations.");var g=Object.assign({},r,d.settings),m=n.validateSettings(g);if(m)throw new Error("graphology-layout-noverlap: "+m.message);var b=n.graphToByteArray(u,d.inputReducer),v=!1,y;for(y=0;y<p&&!v;y++)v=t(g,b).converged;if(l){n.assignLayoutChanges(u,b,d.outputReducer);return}return n.collectLayoutChanges(u,b,d.outputReducer)}var s=o.bind(null,!1);return s.assign=o.bind(null,!0),Vm=s,Vm}var yre=bre();const vre=un(yre);var Wm,vO;function Sre(){return vO||(vO=1,Wm=function(){var t,n={};(function(){var a=0,o=1,s=2,l=3;function u(p,g){return p+"§"+g}function d(){return .01*(.5-Math.random())}n.exports=function(g,m){var b=g.margin,v=g.ratio,y=g.expansion,k=g.gridSize,A=g.speed,x,R,O,N,C,_,M=!0,I=m.length,D=I/l|0,U=new Float32Array(D),$=new Float32Array(D),B=1/0,W=1/0,K=-1/0,H=-1/0;for(x=0;x<I;x+=l)O=m[x+a],N=m[x+o],_=m[x+s]*v+b,B=Math.min(B,O-_),K=Math.max(K,O+_),W=Math.min(W,N-_),H=Math.max(H,N+_);var G=K-B,z=H-W,Y=(B+K)/2,L=(W+H)/2;B=Y-y*G/2,K=Y+y*G/2,W=L-y*z/2,H=L+y*z/2;var V=new Array(k*k),j=V.length,P;for(P=0;P<j;P++)V[P]=[];var Z,Q,oe,ae,ce,Re,ie,Te,ne,xe;for(x=0;x<I;x+=l)for(O=m[x+a],N=m[x+o],_=m[x+s]*v+b,Z=O-_,Q=O+_,oe=N-_,ae=N+_,ce=Math.floor(k*(Z-B)/(K-B)),Re=Math.floor(k*(Q-B)/(K-B)),ie=Math.floor(k*(oe-W)/(H-W)),Te=Math.floor(k*(ae-W)/(H-W)),ne=ce;ne<=Re;ne++)for(xe=ie;xe<=Te;xe++)V[ne*k+xe].push(x);var Se,be=new Set,J,pe,ke,he,Ee,se,Be,je,ye,Oe,ee,de,Ne;for(P=0;P<j;P++)for(Se=V[P],x=0,C=Se.length;x<C;x++)for(J=Se[x],ke=m[J+a],Ee=m[J+o],Be=m[J+s],R=x+1;R<C;R++)pe=Se[R],ye=u(J,pe),!(j>1&&be.has(ye))&&(j>1&&be.add(ye),he=m[pe+a],se=m[pe+o],je=m[pe+s],Oe=he-ke,ee=se-Ee,de=Math.sqrt(Oe*Oe+ee*ee),Ne=de<Be*v+b+(je*v+b),Ne&&(M=!1,pe=pe/l|0,de>0?(U[pe]+=Oe/de*(1+Be),$[pe]+=ee/de*(1+Be)):(U[pe]+=G*d(),$[pe]+=z*d())));for(x=0,R=0;x<I;x+=l,R++)m[x+a]+=U[R]*.1*A,m[x+o]+=$[R]*.1*A;return{converged:M}}})();var r=n.exports;self.addEventListener("message",function(a){var o=a.data;t=new Float32Array(o.nodes);var s=r(o.settings,t);self.postMessage({result:s,nodes:t.buffer},[t.buffer])})}),Wm}var Ym,SO;function Ere(){if(SO)return Ym;SO=1;var e=Sre(),t=ua(),n=b5(),r=y5();function a(o,s){if(s=s||{},!t(o))throw new Error("graphology-layout-noverlap/worker: the given graph is not a valid graphology instance.");var l=Object.assign({},r,s.settings),u=n.validateSettings(l);if(u)throw new Error("graphology-layout-noverlap/worker: "+u.message);this.worker=null,this.graph=o,this.settings=l,this.matrices=null,this.running=!1,this.killed=!1,this.inputReducer=s.inputReducer,this.outputReducer=s.outputReducer,this.callbacks={onConverged:typeof s.onConverged=="function"?s.onConverged:null},this.handleMessage=this.handleMessage.bind(this);var d=!1,p=this;this.handleAddition=function(){d||(d=!0,p.spawnWorker(),setTimeout(function(){d=!1},0))},o.on("nodeAdded",this.handleAddition),o.on("edgeAdded",this.handleAddition),this.spawnWorker()}return a.prototype.isRunning=function(){return this.running},a.prototype.spawnWorker=function(){this.worker&&this.worker.terminate(),this.worker=n.createWorker(e),this.worker.addEventListener("message",this.handleMessage),this.running&&(this.running=!1,this.start())},a.prototype.handleMessage=function(o){if(this.running){var s=new Float32Array(o.data.nodes);if(n.assignLayoutChanges(this.graph,s,this.outputReducer),this.matrices.nodes=s,o.data.result.converged){this.callbacks.onConverged&&this.callbacks.onConverged(),this.stop();return}this.askForIterations()}},a.prototype.askForIterations=function(){var o=this.matrices,s={settings:this.settings,nodes:o.nodes.buffer},l=[o.nodes.buffer];return this.worker.postMessage(s,l),this},a.prototype.start=function(){if(this.killed)throw new Error("graphology-layout-noverlap/worker.start: layout was killed.");return this.running?this:(this.matrices={nodes:n.graphToByteArray(this.graph,this.inputReducer)},this.running=!0,this.askForIterations(),this)},a.prototype.stop=function(){return this.running=!1,this},a.prototype.kill=function(){if(this.killed)return this;this.running=!1,this.killed=!0,this.matrices=null,this.worker.terminate(),this.graph.removeListener("nodeAdded",this.handleAddition),this.graph.removeListener("edgeAdded",this.handleAddition)},Ym=a,Ym}var wre=Ere();const xre=un(wre);function kre(e={}){return Js(vre,e)}function Tre(e={}){return PT(xre,e)}var Km,EO;function Are(){if(EO)return Km;EO=1;var e=au(),t=ua(),n={dimensions:["x","y"],center:.5,rng:Math.random,scale:1};function r(o,s,l){if(!t(s))throw new Error("graphology-layout/random: the given graph is not a valid graphology instance.");l=e(l,n);var u=l.dimensions;if(!Array.isArray(u)||u.length<1)throw new Error("graphology-layout/random: given dimensions are invalid.");var d=u.length,p=l.center,g=l.rng,m=l.scale,b=(p-.5)*m;function v(k){for(var A=0;A<d;A++)k[u[A]]=g()*m+b;return k}if(!o){var y={};return s.forEachNode(function(k){y[k]=v({})}),y}s.updateEachNodeAttributes(function(k,A){return v(A),A},{attributes:u})}var a=r.bind(null,!1);return a.assign=r.bind(null,!0),Km=a,Km}var Rre=Are();const Cre=un(Rre);function _re(e={}){return Js(Cre,e)}var wO=1,Nre=.9,Ore=.8,Ire=.17,Xm=.1,Zm=.999,Dre=.9999,Lre=.99,Mre=/[\\\/_+.#"@\[\(\{&]/,Pre=/[\\\/_+.#"@\[\(\{&]/g,Fre=/[\s-]/,v5=/[\s-]/g;function tk(e,t,n,r,a,o,s){if(o===t.length)return a===e.length?wO:Lre;var l=`${a},${o}`;if(s[l]!==void 0)return s[l];for(var u=r.charAt(o),d=n.indexOf(u,a),p=0,g,m,b,v;d>=0;)g=tk(e,t,n,r,d+1,o+1,s),g>p&&(d===a?g*=wO:Mre.test(e.charAt(d-1))?(g*=Ore,b=e.slice(a,d-1).match(Pre),b&&a>0&&(g*=Math.pow(Zm,b.length))):Fre.test(e.charAt(d-1))?(g*=Nre,v=e.slice(a,d-1).match(v5),v&&a>0&&(g*=Math.pow(Zm,v.length))):(g*=Ire,a>0&&(g*=Math.pow(Zm,d-a))),e.charAt(d)!==t.charAt(o)&&(g*=Dre)),(g<Xm&&n.charAt(d-1)===r.charAt(o+1)||r.charAt(o+1)===r.charAt(o)&&n.charAt(d-1)!==r.charAt(o))&&(m=tk(e,t,n,r,d+1,o+2,s),m*Xm>g&&(g=m*Xm)),g>p&&(p=g),d=n.indexOf(u,d+1);return s[l]=p,p}function xO(e){return e.toLowerCase().replace(v5," ")}function zre(e,t,n){return e=n&&n.length>0?`${e+" "+n.join(" ")}`:e,tk(e,t,xO(e),xO(t),0,0,{})}var Qm={exports:{}},Jm={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var kO;function Bre(){if(kO)return Jm;kO=1;var e=qf();function t(g,m){return g===m&&(g!==0||1/g===1/m)||g!==g&&m!==m}var n=typeof Object.is=="function"?Object.is:t,r=e.useState,a=e.useEffect,o=e.useLayoutEffect,s=e.useDebugValue;function l(g,m){var b=m(),v=r({inst:{value:b,getSnapshot:m}}),y=v[0].inst,k=v[1];return o(function(){y.value=b,y.getSnapshot=m,u(y)&&k({inst:y})},[g,b,m]),a(function(){return u(y)&&k({inst:y}),g(function(){u(y)&&k({inst:y})})},[g]),s(b),b}function u(g){var m=g.getSnapshot;g=g.value;try{var b=m();return!n(g,b)}catch{return!0}}function d(g,m){return m()}var p=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?d:l;return Jm.useSyncExternalStore=e.useSyncExternalStore!==void 0?e.useSyncExternalStore:p,Jm}var TO;function jre(){return TO||(TO=1,Qm.exports=Bre()),Qm.exports}var Ure=jre(),cc='[cmdk-group=""]',eb='[cmdk-group-items=""]',Gre='[cmdk-group-heading=""]',zT='[cmdk-item=""]',AO=`${zT}:not([aria-disabled="true"])`,nk="cmdk-item-select",ci="data-value",Hre=(e,t,n)=>zre(e,t,n),S5=w.createContext(void 0),ou=()=>w.useContext(S5),E5=w.createContext(void 0),BT=()=>w.useContext(E5),w5=w.createContext(void 0),x5=w.forwardRef((e,t)=>{let n=Es(()=>{var j,P;return{search:"",value:(P=(j=e.value)!=null?j:e.defaultValue)!=null?P:"",filtered:{count:0,items:new Map,groups:new Set}}}),r=Es(()=>new Set),a=Es(()=>new Map),o=Es(()=>new Map),s=Es(()=>new Set),l=k5(e),{label:u,children:d,value:p,onValueChange:g,filter:m,shouldFilter:b,loop:v,disablePointerSelection:y=!1,vimBindings:k=!0,...A}=e,x=An(),R=An(),O=An(),N=w.useRef(null),C=eae();vi(()=>{if(p!==void 0){let j=p.trim();n.current.value=j,_.emit()}},[p]),vi(()=>{C(6,B)},[]);let _=w.useMemo(()=>({subscribe:j=>(s.current.add(j),()=>s.current.delete(j)),snapshot:()=>n.current,setState:(j,P,Z)=>{var Q,oe,ae;if(!Object.is(n.current[j],P)){if(n.current[j]=P,j==="search")$(),D(),C(1,U);else if(j==="value"&&(Z||C(5,B),((Q=l.current)==null?void 0:Q.value)!==void 0)){let ce=P??"";(ae=(oe=l.current).onValueChange)==null||ae.call(oe,ce);return}_.emit()}},emit:()=>{s.current.forEach(j=>j())}}),[]),M=w.useMemo(()=>({value:(j,P,Z)=>{var Q;P!==((Q=o.current.get(j))==null?void 0:Q.value)&&(o.current.set(j,{value:P,keywords:Z}),n.current.filtered.items.set(j,I(P,Z)),C(2,()=>{D(),_.emit()}))},item:(j,P)=>(r.current.add(j),P&&(a.current.has(P)?a.current.get(P).add(j):a.current.set(P,new Set([j]))),C(3,()=>{$(),D(),n.current.value||U(),_.emit()}),()=>{o.current.delete(j),r.current.delete(j),n.current.filtered.items.delete(j);let Z=W();C(4,()=>{$(),(Z==null?void 0:Z.getAttribute("id"))===j&&U(),_.emit()})}),group:j=>(a.current.has(j)||a.current.set(j,new Set),()=>{o.current.delete(j),a.current.delete(j)}),filter:()=>l.current.shouldFilter,label:u||e["aria-label"],getDisablePointerSelection:()=>l.current.disablePointerSelection,listId:x,inputId:O,labelId:R,listInnerRef:N}),[]);function I(j,P){var Z,Q;let oe=(Q=(Z=l.current)==null?void 0:Z.filter)!=null?Q:Hre;return j?oe(j,n.current.search,P):0}function D(){if(!n.current.search||l.current.shouldFilter===!1)return;let j=n.current.filtered.items,P=[];n.current.filtered.groups.forEach(Q=>{let oe=a.current.get(Q),ae=0;oe.forEach(ce=>{let Re=j.get(ce);ae=Math.max(Re,ae)}),P.push([Q,ae])});let Z=N.current;K().sort((Q,oe)=>{var ae,ce;let Re=Q.getAttribute("id"),ie=oe.getAttribute("id");return((ae=j.get(ie))!=null?ae:0)-((ce=j.get(Re))!=null?ce:0)}).forEach(Q=>{let oe=Q.closest(eb);oe?oe.appendChild(Q.parentElement===oe?Q:Q.closest(`${eb} > *`)):Z.appendChild(Q.parentElement===Z?Q:Q.closest(`${eb} > *`))}),P.sort((Q,oe)=>oe[1]-Q[1]).forEach(Q=>{var oe;let ae=(oe=N.current)==null?void 0:oe.querySelector(`${cc}[${ci}="${encodeURIComponent(Q[0])}"]`);ae==null||ae.parentElement.appendChild(ae)})}function U(){let j=K().find(Z=>Z.getAttribute("aria-disabled")!=="true"),P=j==null?void 0:j.getAttribute(ci);_.setState("value",P||void 0)}function $(){var j,P,Z,Q;if(!n.current.search||l.current.shouldFilter===!1){n.current.filtered.count=r.current.size;return}n.current.filtered.groups=new Set;let oe=0;for(let ae of r.current){let ce=(P=(j=o.current.get(ae))==null?void 0:j.value)!=null?P:"",Re=(Q=(Z=o.current.get(ae))==null?void 0:Z.keywords)!=null?Q:[],ie=I(ce,Re);n.current.filtered.items.set(ae,ie),ie>0&&oe++}for(let[ae,ce]of a.current)for(let Re of ce)if(n.current.filtered.items.get(Re)>0){n.current.filtered.groups.add(ae);break}n.current.filtered.count=oe}function B(){var j,P,Z;let Q=W();Q&&(((j=Q.parentElement)==null?void 0:j.firstChild)===Q&&((Z=(P=Q.closest(cc))==null?void 0:P.querySelector(Gre))==null||Z.scrollIntoView({block:"nearest"})),Q.scrollIntoView({block:"nearest"}))}function W(){var j;return(j=N.current)==null?void 0:j.querySelector(`${zT}[aria-selected="true"]`)}function K(){var j;return Array.from(((j=N.current)==null?void 0:j.querySelectorAll(AO))||[])}function H(j){let P=K()[j];P&&_.setState("value",P.getAttribute(ci))}function G(j){var P;let Z=W(),Q=K(),oe=Q.findIndex(ce=>ce===Z),ae=Q[oe+j];(P=l.current)!=null&&P.loop&&(ae=oe+j<0?Q[Q.length-1]:oe+j===Q.length?Q[0]:Q[oe+j]),ae&&_.setState("value",ae.getAttribute(ci))}function z(j){let P=W(),Z=P==null?void 0:P.closest(cc),Q;for(;Z&&!Q;)Z=j>0?Qre(Z,cc):Jre(Z,cc),Q=Z==null?void 0:Z.querySelector(AO);Q?_.setState("value",Q.getAttribute(ci)):G(j)}let Y=()=>H(K().length-1),L=j=>{j.preventDefault(),j.metaKey?Y():j.altKey?z(1):G(1)},V=j=>{j.preventDefault(),j.metaKey?H(0):j.altKey?z(-1):G(-1)};return w.createElement(Je.div,{ref:t,tabIndex:-1,...A,"cmdk-root":"",onKeyDown:j=>{var P;if((P=A.onKeyDown)==null||P.call(A,j),!j.defaultPrevented)switch(j.key){case"n":case"j":{k&&j.ctrlKey&&L(j);break}case"ArrowDown":{L(j);break}case"p":case"k":{k&&j.ctrlKey&&V(j);break}case"ArrowUp":{V(j);break}case"Home":{j.preventDefault(),H(0);break}case"End":{j.preventDefault(),Y();break}case"Enter":if(!j.nativeEvent.isComposing&&j.keyCode!==229){j.preventDefault();let Z=W();if(Z){let Q=new Event(nk);Z.dispatchEvent(Q)}}}}},w.createElement("label",{"cmdk-label":"",htmlFor:M.inputId,id:M.labelId,style:nae},u),Tp(e,j=>w.createElement(E5.Provider,{value:_},w.createElement(S5.Provider,{value:M},j))))}),$re=w.forwardRef((e,t)=>{var n,r;let a=An(),o=w.useRef(null),s=w.useContext(w5),l=ou(),u=k5(e),d=(r=(n=u.current)==null?void 0:n.forceMount)!=null?r:s==null?void 0:s.forceMount;vi(()=>{if(!d)return l.item(a,s==null?void 0:s.id)},[d]);let p=T5(a,o,[e.value,e.children,o],e.keywords),g=BT(),m=Si(C=>C.value&&C.value===p.current),b=Si(C=>d||l.filter()===!1?!0:C.search?C.filtered.items.get(a)>0:!0);w.useEffect(()=>{let C=o.current;if(!(!C||e.disabled))return C.addEventListener(nk,v),()=>C.removeEventListener(nk,v)},[b,e.onSelect,e.disabled]);function v(){var C,_;y(),(_=(C=u.current).onSelect)==null||_.call(C,p.current)}function y(){g.setState("value",p.current,!0)}if(!b)return null;let{disabled:k,value:A,onSelect:x,forceMount:R,keywords:O,...N}=e;return w.createElement(Je.div,{ref:Cc([o,t]),...N,id:a,"cmdk-item":"",role:"option","aria-disabled":!!k,"aria-selected":!!m,"data-disabled":!!k,"data-selected":!!m,onPointerMove:k||l.getDisablePointerSelection()?void 0:y,onClick:k?void 0:v},e.children)}),qre=w.forwardRef((e,t)=>{let{heading:n,children:r,forceMount:a,...o}=e,s=An(),l=w.useRef(null),u=w.useRef(null),d=An(),p=ou(),g=Si(b=>a||p.filter()===!1?!0:b.search?b.filtered.groups.has(s):!0);vi(()=>p.group(s),[]),T5(s,l,[e.value,e.heading,u]);let m=w.useMemo(()=>({id:s,forceMount:a}),[a]);return w.createElement(Je.div,{ref:Cc([l,t]),...o,"cmdk-group":"",role:"presentation",hidden:g?void 0:!0},n&&w.createElement("div",{ref:u,"cmdk-group-heading":"","aria-hidden":!0,id:d},n),Tp(e,b=>w.createElement("div",{"cmdk-group-items":"",role:"group","aria-labelledby":n?d:void 0},w.createElement(w5.Provider,{value:m},b))))}),Vre=w.forwardRef((e,t)=>{let{alwaysRender:n,...r}=e,a=w.useRef(null),o=Si(s=>!s.search);return!n&&!o?null:w.createElement(Je.div,{ref:Cc([a,t]),...r,"cmdk-separator":"",role:"separator"})}),Wre=w.forwardRef((e,t)=>{let{onValueChange:n,...r}=e,a=e.value!=null,o=BT(),s=Si(p=>p.search),l=Si(p=>p.value),u=ou(),d=w.useMemo(()=>{var p;let g=(p=u.listInnerRef.current)==null?void 0:p.querySelector(`${zT}[${ci}="${encodeURIComponent(l)}"]`);return g==null?void 0:g.getAttribute("id")},[]);return w.useEffect(()=>{e.value!=null&&o.setState("search",e.value)},[e.value]),w.createElement(Je.input,{ref:t,...r,"cmdk-input":"",autoComplete:"off",autoCorrect:"off",spellCheck:!1,"aria-autocomplete":"list",role:"combobox","aria-expanded":!0,"aria-controls":u.listId,"aria-labelledby":u.labelId,"aria-activedescendant":d,id:u.inputId,type:"text",value:a?e.value:s,onChange:p=>{a||o.setState("search",p.target.value),n==null||n(p.target.value)}})}),Yre=w.forwardRef((e,t)=>{let{children:n,label:r="Suggestions",...a}=e,o=w.useRef(null),s=w.useRef(null),l=ou();return w.useEffect(()=>{if(s.current&&o.current){let u=s.current,d=o.current,p,g=new ResizeObserver(()=>{p=requestAnimationFrame(()=>{let m=u.offsetHeight;d.style.setProperty("--cmdk-list-height",m.toFixed(1)+"px")})});return g.observe(u),()=>{cancelAnimationFrame(p),g.unobserve(u)}}},[]),w.createElement(Je.div,{ref:Cc([o,t]),...a,"cmdk-list":"",role:"listbox","aria-label":r,id:l.listId},Tp(e,u=>w.createElement("div",{ref:Cc([s,l.listInnerRef]),"cmdk-list-sizer":""},u)))}),Kre=w.forwardRef((e,t)=>{let{open:n,onOpenChange:r,overlayClassName:a,contentClassName:o,container:s,...l}=e;return w.createElement(Zk,{open:n,onOpenChange:r},w.createElement(Qk,{container:s},w.createElement(ap,{"cmdk-overlay":"",className:a}),w.createElement(op,{"aria-label":e.label,"cmdk-dialog":"",className:o},w.createElement(x5,{ref:t,...l}))))}),Xre=w.forwardRef((e,t)=>Si(n=>n.filtered.count===0)?w.createElement(Je.div,{ref:t,...e,"cmdk-empty":"",role:"presentation"}):null),Zre=w.forwardRef((e,t)=>{let{progress:n,children:r,label:a="Loading...",...o}=e;return w.createElement(Je.div,{ref:t,...o,"cmdk-loading":"",role:"progressbar","aria-valuenow":n,"aria-valuemin":0,"aria-valuemax":100,"aria-label":a},Tp(e,s=>w.createElement("div",{"aria-hidden":!0},s)))}),Vn=Object.assign(x5,{List:Yre,Item:$re,Input:Wre,Group:qre,Separator:Vre,Dialog:Kre,Empty:Xre,Loading:Zre});function Qre(e,t){let n=e.nextElementSibling;for(;n;){if(n.matches(t))return n;n=n.nextElementSibling}}function Jre(e,t){let n=e.previousElementSibling;for(;n;){if(n.matches(t))return n;n=n.previousElementSibling}}function k5(e){let t=w.useRef(e);return vi(()=>{t.current=e}),t}var vi=typeof window>"u"?w.useEffect:w.useLayoutEffect;function Es(e){let t=w.useRef();return t.current===void 0&&(t.current=e()),t}function Cc(e){return t=>{e.forEach(n=>{typeof n=="function"?n(t):n!=null&&(n.current=t)})}}function Si(e){let t=BT(),n=()=>e(t.snapshot());return Ure.useSyncExternalStore(t.subscribe,n,n)}function T5(e,t,n,r=[]){let a=w.useRef(),o=ou();return vi(()=>{var s;let l=(()=>{var d;for(let p of n){if(typeof p=="string")return p.trim();if(typeof p=="object"&&"current"in p)return p.current?(d=p.current.textContent)==null?void 0:d.trim():a.current}})(),u=r.map(d=>d.trim());o.value(e,l,u),(s=t.current)==null||s.setAttribute(ci,l),a.current=l}),a}var eae=()=>{let[e,t]=w.useState(),n=Es(()=>new Map);return vi(()=>{n.current.forEach(r=>r()),n.current=new Map},[e]),(r,a)=>{n.current.set(r,a),t({})}};function tae(e){let t=e.type;return typeof t=="function"?t(e.props):"render"in t?t.render(e.props):e}function Tp({asChild:e,children:t},n){return e&&w.isValidElement(t)?w.cloneElement(tae(t),{ref:t.ref},n(t.props.children)):n(t)}var nae={position:"absolute",width:"1px",height:"1px",padding:"0",margin:"-1px",overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",borderWidth:"0"};const Ap=w.forwardRef(({className:e,...t},n)=>E.jsx(Vn,{ref:n,className:Me("bg-popover text-popover-foreground flex h-full w-full flex-col overflow-hidden rounded-md",e),...t}));Ap.displayName=Vn.displayName;const jT=w.forwardRef(({className:e,...t},n)=>E.jsxs("div",{className:"flex items-center border-b px-3","cmdk-input-wrapper":"",children:[E.jsx(YZ,{className:"mr-2 h-4 w-4 shrink-0 opacity-50"}),E.jsx(Vn.Input,{ref:n,className:Me("placeholder:text-muted-foreground flex h-11 w-full rounded-md bg-transparent py-3 text-sm outline-none disabled:cursor-not-allowed disabled:opacity-50",e),...t})]}));jT.displayName=Vn.Input.displayName;const Rp=w.forwardRef(({className:e,...t},n)=>E.jsx(Vn.List,{ref:n,className:Me("max-h-[300px] overflow-x-hidden overflow-y-auto",e),...t}));Rp.displayName=Vn.List.displayName;const UT=w.forwardRef((e,t)=>E.jsx(Vn.Empty,{ref:t,className:"py-6 text-center text-sm",...e}));UT.displayName=Vn.Empty.displayName;const el=w.forwardRef(({className:e,...t},n)=>E.jsx(Vn.Group,{ref:n,className:Me("text-foreground [&_[cmdk-group-heading]]:text-muted-foreground overflow-hidden p-1 [&_[cmdk-group-heading]]:px-2 [&_[cmdk-group-heading]]:py-1.5 [&_[cmdk-group-heading]]:text-xs [&_[cmdk-group-heading]]:font-medium",e),...t}));el.displayName=Vn.Group.displayName;const rae=w.forwardRef(({className:e,...t},n)=>E.jsx(Vn.Separator,{ref:n,className:Me("bg-border -mx-1 h-px",e),...t}));rae.displayName=Vn.Separator.displayName;const tl=w.forwardRef(({className:e,...t},n)=>E.jsx(Vn.Item,{ref:n,className:Me("data-[selected='true']:bg-accent data-[selected=true]:text-accent-foreground relative flex cursor-default items-center gap-2 rounded-sm px-2 py-1.5 text-sm outline-none select-none data-[disabled=true]:pointer-events-none data-[disabled=true]:opacity-50 [&_svg]:pointer-events-none [&_svg]:size-4 [&_svg]:shrink-0",e),...t}));tl.displayName=Vn.Item.displayName;const aae=({layout:e,autoRunFor:t,mainLayout:n})=>{const r=Ar(),[a,o]=w.useState(!1),s=w.useRef(null),{t:l}=Et(),u=w.useCallback(()=>{if(r)try{const p=r.getGraph();if(!p||p.order===0)return;const g=n.positions();$4(p,g,{duration:300})}catch(p){console.error("Error updating positions:",p),s.current&&(window.clearInterval(s.current),s.current=null,o(!1))}},[r,n]),d=w.useCallback(()=>{if(a){console.log("Stopping layout animation"),s.current&&(window.clearInterval(s.current),s.current=null);try{typeof e.kill=="function"?(e.kill(),console.log("Layout algorithm killed")):typeof e.stop=="function"&&(e.stop(),console.log("Layout algorithm stopped"))}catch(p){console.error("Error stopping layout algorithm:",p)}o(!1)}else console.log("Starting layout animation"),u(),s.current=window.setInterval(()=>{u()},200),o(!0),setTimeout(()=>{if(s.current){console.log("Auto-stopping layout animation after 3 seconds"),window.clearInterval(s.current),s.current=null,o(!1);try{typeof e.kill=="function"?e.kill():typeof e.stop=="function"&&e.stop()}catch(p){console.error("Error stopping layout algorithm:",p)}}},3e3)},[a,e,u]);return w.useEffect(()=>{if(!r){console.log("No sigma instance available");return}let p=null;return t!==void 0&&t>-1&&r.getGraph().order>0&&(console.log("Auto-starting layout animation"),u(),s.current=window.setInterval(()=>{u()},200),o(!0),t>0&&(p=window.setTimeout(()=>{console.log("Auto-stopping layout animation after timeout"),s.current&&(window.clearInterval(s.current),s.current=null),o(!1)},t))),()=>{s.current&&(window.clearInterval(s.current),s.current=null),p&&window.clearTimeout(p),o(!1)}},[t,r,u]),E.jsx(nt,{size:"icon",onClick:d,tooltip:l(a?"graphPanel.sideBar.layoutsControl.stopAnimation":"graphPanel.sideBar.layoutsControl.startAnimation"),variant:Er,children:a?E.jsx(FZ,{}):E.jsx(BZ,{})})},oae=()=>{const e=Ar(),{t}=Et(),[n,r]=w.useState("Circular"),[a,o]=w.useState(!1),s=De.use.graphLayoutMaxIterations(),l=Qne(),u=Yne(),d=_re(),p=kre({maxIterations:s,settings:{margin:5,expansion:1.1,gridSize:1,ratio:1,speed:3}}),g=ore({maxIterations:s,settings:{attraction:3e-4,repulsion:.02,gravity:.02,inertia:.4,maxMove:100}}),m=m5({iterations:s}),b=Tre(),v=ire(),y=hre(),k=w.useMemo(()=>({Circular:{layout:l},Circlepack:{layout:u},Random:{layout:d},Noverlaps:{layout:p,worker:b},"Force Directed":{layout:g,worker:v},"Force Atlas":{layout:m,worker:y}}),[u,l,g,m,p,d,v,b,y]),A=w.useCallback(x=>{console.debug("Running layout:",x);const{positions:R}=k[x].layout;try{const O=e.getGraph();if(!O){console.error("No graph available");return}const N=R();console.log("Positions calculated, animating nodes"),$4(O,N,{duration:400}),r(x)}catch(O){console.error("Error running layout:",O)}},[k,e]);return E.jsxs(E.Fragment,{children:[E.jsx("div",{children:k[n]&&"worker"in k[n]&&E.jsx(aae,{layout:k[n].worker,mainLayout:k[n].layout})}),E.jsx("div",{children:E.jsxs(mp,{open:a,onOpenChange:o,children:[E.jsx(bp,{asChild:!0,children:E.jsx(nt,{size:"icon",variant:Er,onClick:()=>o(x=>!x),tooltip:t("graphPanel.sideBar.layoutsControl.layoutGraph"),children:E.jsx(kZ,{})})}),E.jsx(Qc,{side:"right",align:"center",className:"p-1",children:E.jsx(Ap,{children:E.jsx(Rp,{children:E.jsx(el,{children:Object.keys(k).map(x=>E.jsx(tl,{onSelect:()=>{A(x)},className:"cursor-pointer text-xs",children:t(`graphPanel.sideBar.layoutsControl.layouts.${x}`)},x))})})})})]})})]})},A5=()=>{const e=w.useContext(nj);if(e===void 0)throw new Error("useTheme must be used within a ThemeProvider");return e},Pd=e=>!!(e.type.startsWith("mouse")&&e.buttons!==0),iae=({disableHoverEffect:e})=>{const t=Ar(),n=K4(),r=Y4(),a=De.use.graphLayoutMaxIterations(),{assign:o}=m5({iterations:a}),{theme:s}=A5(),l=De.use.enableHideUnselectedEdges(),u=De.use.enableEdgeEvents(),d=De.use.showEdgeLabel(),p=De.use.showNodeLabel(),g=De.use.minEdgeSize(),m=De.use.maxEdgeSize(),b=ze.use.selectedNode(),v=ze.use.focusedNode(),y=ze.use.selectedEdge(),k=ze.use.focusedEdge(),A=ze.use.sigmaGraph();return w.useEffect(()=>{if(A&&t){try{typeof t.setGraph=="function"?(t.setGraph(A),console.log("Binding graph to sigma instance")):(t.graph=A,console.warn("Simgma missing setGraph function, set graph property directly"))}catch(x){console.error("Error setting graph on sigma instance:",x)}o(),console.log("Initial layout applied to graph")}},[t,A,o,a]),w.useEffect(()=>{t&&(ze.getState().sigmaInstance||(console.log("Setting sigma instance from GraphControl"),ze.getState().setSigmaInstance(t)))},[t]),w.useEffect(()=>{const{setFocusedNode:x,setSelectedNode:R,setFocusedEdge:O,setSelectedEdge:N,clearSelection:C}=ze.getState(),_={enterNode:M=>{Pd(M.event.original)||x(M.node)},leaveNode:M=>{Pd(M.event.original)||x(null)},clickNode:M=>{R(M.node),N(null)},clickStage:()=>C()};u&&(_.clickEdge=M=>{N(M.edge),R(null)},_.enterEdge=M=>{Pd(M.event.original)||O(M.edge)},_.leaveEdge=M=>{Pd(M.event.original)||O(null)}),n(_)},[n,u]),w.useEffect(()=>{if(t&&A){const x=t.getGraph();let R=Number.MAX_SAFE_INTEGER,O=0;x.forEachEdge(C=>{const _=x.getEdgeAttribute(C,"originalWeight")||1;typeof _=="number"&&(R=Math.min(R,_),O=Math.max(O,_))});const N=O-R;if(N>0){const C=m-g;x.forEachEdge(_=>{const M=x.getEdgeAttribute(_,"originalWeight")||1;if(typeof M=="number"){const I=g+C*Math.pow((M-R)/N,.5);x.setEdgeAttribute(_,"size",I)}})}else x.forEachEdge(C=>{x.setEdgeAttribute(C,"size",g)});t.refresh()}},[t,A,g,m]),w.useEffect(()=>{const x=s==="dark",R=x?lV:void 0,O=x?fV:void 0;r({enableEdgeEvents:u,renderEdgeLabels:d,renderLabels:p,nodeReducer:(N,C)=>{const _=t.getGraph(),M={...C,highlighted:C.highlighted||!1,labelColor:R};if(!e){M.highlighted=!1;const I=v||b,D=k||y;if(I&&_.hasNode(I))try{(N===I||_.neighbors(I).includes(N))&&(M.highlighted=!0,N===b&&(M.borderColor=dV))}catch(U){console.error("Error in nodeReducer:",U)}else if(D&&_.hasEdge(D))_.extremities(D).includes(N)&&(M.highlighted=!0,M.size=3);else return M;M.highlighted?x&&(M.labelColor=cV):M.color=uV}return M},edgeReducer:(N,C)=>{const _=t.getGraph(),M={...C,hidden:!1,labelColor:R,color:O};if(!e){const I=v||b;if(I&&_.hasNode(I))try{l?_.extremities(N).includes(I)||(M.hidden=!0):_.extremities(N).includes(I)&&(M.color=P_)}catch(D){console.error("Error in edgeReducer:",D)}else{const D=y&&_.hasEdge(y)?y:null,U=k&&_.hasEdge(k)?k:null;(D||U)&&(N===D?M.color=pV:N===U?M.color=P_:l&&(M.hidden=!0))}}return M}})},[b,v,y,k,r,t,e,s,l,u,d,p]),null},sae=()=>{const{zoomIn:e,zoomOut:t,reset:n}=X4({duration:200,factor:1.5}),r=Ar(),{t:a}=Et(),o=w.useCallback(()=>e(),[e]),s=w.useCallback(()=>t(),[t]),l=w.useCallback(()=>{if(r)try{r.setCustomBBox(null),r.refresh();const p=r.getGraph();if(!(p!=null&&p.order)||p.nodes().length===0){n();return}r.getCamera().animate({x:.5,y:.5,ratio:1.1},{duration:1e3})}catch(p){console.error("Error resetting zoom:",p),n()}},[r,n]),u=w.useCallback(()=>{if(!r)return;const p=r.getCamera(),m=p.angle+Math.PI/8;p.animate({angle:m},{duration:200})},[r]),d=w.useCallback(()=>{if(!r)return;const p=r.getCamera(),m=p.angle-Math.PI/8;p.animate({angle:m},{duration:200})},[r]);return E.jsxs(E.Fragment,{children:[E.jsx(nt,{variant:Er,onClick:d,tooltip:a("graphPanel.sideBar.zoomControl.rotateCameraCounterClockwise"),size:"icon",children:E.jsx(GZ,{})}),E.jsx(nt,{variant:Er,onClick:u,tooltip:a("graphPanel.sideBar.zoomControl.rotateCamera"),size:"icon",children:E.jsx($Z,{})}),E.jsx(nt,{variant:Er,onClick:l,tooltip:a("graphPanel.sideBar.zoomControl.resetZoom"),size:"icon",children:E.jsx(yZ,{})}),E.jsx(nt,{variant:Er,onClick:o,tooltip:a("graphPanel.sideBar.zoomControl.zoomIn"),size:"icon",children:E.jsx(iQ,{})}),E.jsx(nt,{variant:Er,onClick:s,tooltip:a("graphPanel.sideBar.zoomControl.zoomOut"),size:"icon",children:E.jsx(lQ,{})})]})},lae=()=>{const{isFullScreen:e,toggle:t}=$te(),{t:n}=Et();return E.jsx(E.Fragment,{children:e?E.jsx(nt,{variant:Er,onClick:t,tooltip:n("graphPanel.sideBar.fullScreenControl.windowed"),size:"icon",children:E.jsx(DZ,{})}):E.jsx(nt,{variant:Er,onClick:t,tooltip:n("graphPanel.sideBar.fullScreenControl.fullScreen"),size:"icon",children:E.jsx(OZ,{})})})};var GT="Checkbox",[cae,b0e]=$r(GT),[uae,dae]=cae(GT),R5=w.forwardRef((e,t)=>{const{__scopeCheckbox:n,name:r,checked:a,defaultChecked:o,required:s,disabled:l,value:u="on",onCheckedChange:d,form:p,...g}=e,[m,b]=w.useState(null),v=mt(t,O=>b(O)),y=w.useRef(!1),k=m?p||!!m.closest("form"):!0,[A=!1,x]=ja({prop:a,defaultProp:o,onChange:d}),R=w.useRef(A);return w.useEffect(()=>{const O=m==null?void 0:m.form;if(O){const N=()=>x(R.current);return O.addEventListener("reset",N),()=>O.removeEventListener("reset",N)}},[m,x]),E.jsxs(uae,{scope:n,state:A,disabled:l,children:[E.jsx(Je.button,{type:"button",role:"checkbox","aria-checked":Ro(A)?"mixed":A,"aria-required":s,"data-state":N5(A),"data-disabled":l?"":void 0,disabled:l,value:u,...g,ref:v,onKeyDown:Ke(e.onKeyDown,O=>{O.key==="Enter"&&O.preventDefault()}),onClick:Ke(e.onClick,O=>{x(N=>Ro(N)?!0:!N),k&&(y.current=O.isPropagationStopped(),y.current||O.stopPropagation())})}),k&&E.jsx(fae,{control:m,bubbles:!y.current,name:r,value:u,checked:A,required:s,disabled:l,form:p,style:{transform:"translateX(-100%)"},defaultChecked:Ro(o)?!1:o})]})});R5.displayName=GT;var C5="CheckboxIndicator",_5=w.forwardRef((e,t)=>{const{__scopeCheckbox:n,forceMount:r,...a}=e,o=dae(C5,n);return E.jsx(Tr,{present:r||Ro(o.state)||o.state===!0,children:E.jsx(Je.span,{"data-state":N5(o.state),"data-disabled":o.disabled?"":void 0,...a,ref:t,style:{pointerEvents:"none",...e.style}})})});_5.displayName=C5;var fae=e=>{const{control:t,checked:n,bubbles:r=!0,defaultChecked:a,...o}=e,s=w.useRef(null),l=a3(n),u=pU(t);w.useEffect(()=>{const p=s.current,g=window.HTMLInputElement.prototype,b=Object.getOwnPropertyDescriptor(g,"checked").set;if(l!==n&&b){const v=new Event("click",{bubbles:r});p.indeterminate=Ro(n),b.call(p,Ro(n)?!1:n),p.dispatchEvent(v)}},[l,n,r]);const d=w.useRef(Ro(n)?!1:n);return E.jsx("input",{type:"checkbox","aria-hidden":!0,defaultChecked:a??d.current,...o,tabIndex:-1,ref:s,style:{...e.style,...u,position:"absolute",pointerEvents:"none",opacity:0,margin:0}})};function Ro(e){return e==="indeterminate"}function N5(e){return Ro(e)?"indeterminate":e?"checked":"unchecked"}var O5=R5,pae=_5;const Ns=w.forwardRef(({className:e,...t},n)=>E.jsx(O5,{ref:n,className:Me("peer border-primary ring-offset-background focus-visible:ring-ring data-[state=checked]:bg-muted data-[state=checked]:text-muted-foreground h-4 w-4 shrink-0 rounded-sm border focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none disabled:cursor-not-allowed disabled:opacity-50",e),...t,children:E.jsx(pae,{className:Me("flex items-center justify-center text-current"),children:E.jsx(vT,{className:"h-4 w-4"})})}));Ns.displayName=O5.displayName;var gae="Separator",RO="horizontal",hae=["horizontal","vertical"],I5=w.forwardRef((e,t)=>{const{decorative:n,orientation:r=RO,...a}=e,o=mae(r)?r:RO,l=n?{role:"none"}:{"aria-orientation":o==="vertical"?o:void 0,role:"separator"};return E.jsx(Je.div,{"data-orientation":o,...l,...a,ref:t})});I5.displayName=gae;function mae(e){return hae.includes(e)}var D5=I5;const ws=w.forwardRef(({className:e,orientation:t="horizontal",decorative:n=!0,...r},a)=>E.jsx(D5,{ref:a,decorative:n,orientation:t,className:Me("bg-border shrink-0",t==="horizontal"?"h-[1px] w-full":"h-full w-[1px]",e),...r}));ws.displayName=D5.displayName;const vo=({checked:e,onCheckedChange:t,label:n})=>{const r=`checkbox-${n.toLowerCase().replace(/\s+/g,"-")}`;return E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx(Ns,{id:r,checked:e,onCheckedChange:t}),E.jsx("label",{htmlFor:r,className:"text-sm leading-none font-medium peer-disabled:cursor-not-allowed peer-disabled:opacity-70",children:n})]})},tb=({value:e,onEditFinished:t,label:n,min:r,max:a,defaultValue:o})=>{const{t:s}=Et(),[l,u]=w.useState(e),d=`input-${n.toLowerCase().replace(/\s+/g,"-")}`,p=w.useCallback(b=>{const v=b.target.value.trim();if(v.length===0){u(null);return}const y=Number.parseInt(v);if(!isNaN(y)&&y!==l){if(r!==void 0&&y<r||a!==void 0&&y>a)return;u(y)}},[l,r,a]),g=w.useCallback(()=>{l!==null&&e!==l&&t(l)},[e,l,t]),m=w.useCallback(()=>{o!==void 0&&e!==o&&(u(o),t(o))},[o,e,t]);return E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsx("label",{htmlFor:d,className:"text-sm leading-none font-medium peer-disabled:cursor-not-allowed peer-disabled:opacity-70",children:n}),E.jsxs("div",{className:"flex items-center gap-1",children:[E.jsx(kr,{id:d,type:"number",value:l===null?"":l,onChange:p,className:"h-6 w-full min-w-0 pr-1",min:r,max:a,onBlur:g,onKeyDown:b=>{b.key==="Enter"&&g()}}),o!==void 0&&E.jsx(nt,{variant:"ghost",size:"icon",className:"h-6 w-6 flex-shrink-0 hover:bg-muted text-muted-foreground hover:text-foreground",onClick:m,type:"button",title:s("graphPanel.sideBar.settings.resetToDefault"),children:E.jsx(GU,{className:"h-3.5 w-3.5"})})]})]})};function bae(){const[e,t]=w.useState(!1),n=De.use.showPropertyPanel(),r=De.use.showNodeSearchBar(),a=De.use.showNodeLabel(),o=De.use.enableEdgeEvents(),s=De.use.enableNodeDrag(),l=De.use.enableHideUnselectedEdges(),u=De.use.showEdgeLabel(),d=De.use.minEdgeSize(),p=De.use.maxEdgeSize(),g=De.use.graphQueryMaxDepth(),m=De.use.graphMaxNodes(),b=De.use.graphLayoutMaxIterations(),v=De.use.enableHealthCheck(),y=w.useCallback(()=>De.setState($=>({enableNodeDrag:!$.enableNodeDrag})),[]),k=w.useCallback(()=>De.setState($=>({enableEdgeEvents:!$.enableEdgeEvents})),[]),A=w.useCallback(()=>De.setState($=>({enableHideUnselectedEdges:!$.enableHideUnselectedEdges})),[]),x=w.useCallback(()=>De.setState($=>({showEdgeLabel:!$.showEdgeLabel})),[]),R=w.useCallback(()=>De.setState($=>({showPropertyPanel:!$.showPropertyPanel})),[]),O=w.useCallback(()=>De.setState($=>({showNodeSearchBar:!$.showNodeSearchBar})),[]),N=w.useCallback(()=>De.setState($=>({showNodeLabel:!$.showNodeLabel})),[]),C=w.useCallback(()=>De.setState($=>({enableHealthCheck:!$.enableHealthCheck})),[]),_=w.useCallback($=>{if($<1)return;De.setState({graphQueryMaxDepth:$});const B=De.getState().queryLabel;De.getState().setQueryLabel(""),setTimeout(()=>{De.getState().setQueryLabel(B)},300)},[]),M=w.useCallback($=>{if($<1||$>1e3)return;De.setState({graphMaxNodes:$});const B=De.getState().queryLabel;De.getState().setQueryLabel(""),setTimeout(()=>{De.getState().setQueryLabel(B)},300)},[]),I=w.useCallback($=>{$<1||De.setState({graphLayoutMaxIterations:$})},[]),{t:D}=Et(),U=()=>t(!1);return E.jsx(E.Fragment,{children:E.jsxs(mp,{open:e,onOpenChange:t,children:[E.jsx(bp,{asChild:!0,children:E.jsx(nt,{variant:Er,tooltip:D("graphPanel.sideBar.settings.settings"),size:"icon",children:E.jsx(QZ,{})})}),E.jsx(Qc,{side:"right",align:"start",className:"mb-2 p-2",onCloseAutoFocus:$=>$.preventDefault(),children:E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsx(vo,{checked:v,onCheckedChange:C,label:D("graphPanel.sideBar.settings.healthCheck")}),E.jsx(ws,{}),E.jsx(vo,{checked:n,onCheckedChange:R,label:D("graphPanel.sideBar.settings.showPropertyPanel")}),E.jsx(vo,{checked:r,onCheckedChange:O,label:D("graphPanel.sideBar.settings.showSearchBar")}),E.jsx(ws,{}),E.jsx(vo,{checked:a,onCheckedChange:N,label:D("graphPanel.sideBar.settings.showNodeLabel")}),E.jsx(vo,{checked:s,onCheckedChange:y,label:D("graphPanel.sideBar.settings.nodeDraggable")}),E.jsx(ws,{}),E.jsx(vo,{checked:u,onCheckedChange:x,label:D("graphPanel.sideBar.settings.showEdgeLabel")}),E.jsx(vo,{checked:l,onCheckedChange:A,label:D("graphPanel.sideBar.settings.hideUnselectedEdges")}),E.jsx(vo,{checked:o,onCheckedChange:k,label:D("graphPanel.sideBar.settings.edgeEvents")}),E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsx("label",{htmlFor:"edge-size-min",className:"text-sm leading-none font-medium peer-disabled:cursor-not-allowed peer-disabled:opacity-70",children:D("graphPanel.sideBar.settings.edgeSizeRange")}),E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx(kr,{id:"edge-size-min",type:"number",value:d,onChange:$=>{const B=Number($.target.value);!isNaN(B)&&B>=1&&B<=p&&De.setState({minEdgeSize:B})},className:"h-6 w-16 min-w-0 pr-1",min:1,max:Math.min(p,10)}),E.jsx("span",{children:"-"}),E.jsxs("div",{className:"flex items-center gap-1",children:[E.jsx(kr,{id:"edge-size-max",type:"number",value:p,onChange:$=>{const B=Number($.target.value);!isNaN(B)&&B>=d&&B>=1&&B<=10&&De.setState({maxEdgeSize:B})},className:"h-6 w-16 min-w-0 pr-1",min:d,max:10}),E.jsx(nt,{variant:"ghost",size:"icon",className:"h-6 w-6 flex-shrink-0 hover:bg-muted text-muted-foreground hover:text-foreground",onClick:()=>De.setState({minEdgeSize:1,maxEdgeSize:5}),type:"button",title:D("graphPanel.sideBar.settings.resetToDefault"),children:E.jsx(GU,{className:"h-3.5 w-3.5"})})]})]})]}),E.jsx(ws,{}),E.jsx(tb,{label:D("graphPanel.sideBar.settings.maxQueryDepth"),min:1,value:g,defaultValue:3,onEditFinished:_}),E.jsx(tb,{label:D("graphPanel.sideBar.settings.maxNodes"),min:1,max:1e3,value:m,defaultValue:1e3,onEditFinished:M}),E.jsx(tb,{label:D("graphPanel.sideBar.settings.maxLayoutIterations"),min:1,max:30,value:b,defaultValue:15,onEditFinished:I}),E.jsx(ws,{}),E.jsx(nt,{onClick:U,variant:"outline",size:"sm",className:"ml-auto px-4",children:D("graphPanel.sideBar.settings.save")})]})})]})})}const yae="ENTRIES",L5="KEYS",M5="VALUES",bn="";class nb{constructor(t,n){const r=t._tree,a=Array.from(r.keys());this.set=t,this._type=n,this._path=a.length>0?[{node:r,keys:a}]:[]}next(){const t=this.dive();return this.backtrack(),t}dive(){if(this._path.length===0)return{done:!0,value:void 0};const{node:t,keys:n}=hs(this._path);if(hs(n)===bn)return{done:!1,value:this.result()};const r=t.get(hs(n));return this._path.push({node:r,keys:Array.from(r.keys())}),this.dive()}backtrack(){if(this._path.length===0)return;const t=hs(this._path).keys;t.pop(),!(t.length>0)&&(this._path.pop(),this.backtrack())}key(){return this.set._prefix+this._path.map(({keys:t})=>hs(t)).filter(t=>t!==bn).join("")}value(){return hs(this._path).node.get(bn)}result(){switch(this._type){case M5:return this.value();case L5:return this.key();default:return[this.key(),this.value()]}}[Symbol.iterator](){return this}}const hs=e=>e[e.length-1],vae=(e,t,n)=>{const r=new Map;if(t===void 0)return r;const a=t.length+1,o=a+n,s=new Uint8Array(o*a).fill(n+1);for(let l=0;l<a;++l)s[l]=l;for(let l=1;l<o;++l)s[l*a]=l;return P5(e,t,n,r,s,1,a,""),r},P5=(e,t,n,r,a,o,s,l)=>{const u=o*s;e:for(const d of e.keys())if(d===bn){const p=a[u-1];p<=n&&r.set(l,[e.get(d),p])}else{let p=o;for(let g=0;g<d.length;++g,++p){const m=d[g],b=s*p,v=b-s;let y=a[b];const k=Math.max(0,p-n-1),A=Math.min(s-1,p+n);for(let x=k;x<A;++x){const R=m!==t[x],O=a[v+x]+ +R,N=a[v+x+1]+1,C=a[b+x]+1,_=a[b+x+1]=Math.min(O,N,C);_<y&&(y=_)}if(y>n)continue e}P5(e.get(d),t,n,r,a,p,s,l+d)}};class To{constructor(t=new Map,n=""){this._size=void 0,this._tree=t,this._prefix=n}atPrefix(t){if(!t.startsWith(this._prefix))throw new Error("Mismatched prefix");const[n,r]=Of(this._tree,t.slice(this._prefix.length));if(n===void 0){const[a,o]=HT(r);for(const s of a.keys())if(s!==bn&&s.startsWith(o)){const l=new Map;return l.set(s.slice(o.length),a.get(s)),new To(l,t)}}return new To(n,t)}clear(){this._size=void 0,this._tree.clear()}delete(t){return this._size=void 0,Sae(this._tree,t)}entries(){return new nb(this,yae)}forEach(t){for(const[n,r]of this)t(n,r,this)}fuzzyGet(t,n){return vae(this._tree,t,n)}get(t){const n=rk(this._tree,t);return n!==void 0?n.get(bn):void 0}has(t){const n=rk(this._tree,t);return n!==void 0&&n.has(bn)}keys(){return new nb(this,L5)}set(t,n){if(typeof t!="string")throw new Error("key must be a string");return this._size=void 0,rb(this._tree,t).set(bn,n),this}get size(){if(this._size)return this._size;this._size=0;const t=this.entries();for(;!t.next().done;)this._size+=1;return this._size}update(t,n){if(typeof t!="string")throw new Error("key must be a string");this._size=void 0;const r=rb(this._tree,t);return r.set(bn,n(r.get(bn))),this}fetch(t,n){if(typeof t!="string")throw new Error("key must be a string");this._size=void 0;const r=rb(this._tree,t);let a=r.get(bn);return a===void 0&&r.set(bn,a=n()),a}values(){return new nb(this,M5)}[Symbol.iterator](){return this.entries()}static from(t){const n=new To;for(const[r,a]of t)n.set(r,a);return n}static fromObject(t){return To.from(Object.entries(t))}}const Of=(e,t,n=[])=>{if(t.length===0||e==null)return[e,n];for(const r of e.keys())if(r!==bn&&t.startsWith(r))return n.push([e,r]),Of(e.get(r),t.slice(r.length),n);return n.push([e,t]),Of(void 0,"",n)},rk=(e,t)=>{if(t.length===0||e==null)return e;for(const n of e.keys())if(n!==bn&&t.startsWith(n))return rk(e.get(n),t.slice(n.length))},rb=(e,t)=>{const n=t.length;e:for(let r=0;e&&r<n;){for(const o of e.keys())if(o!==bn&&t[r]===o[0]){const s=Math.min(n-r,o.length);let l=1;for(;l<s&&t[r+l]===o[l];)++l;const u=e.get(o);if(l===o.length)e=u;else{const d=new Map;d.set(o.slice(l),u),e.set(t.slice(r,r+l),d),e.delete(o),e=d}r+=l;continue e}const a=new Map;return e.set(t.slice(r),a),a}return e},Sae=(e,t)=>{const[n,r]=Of(e,t);if(n!==void 0){if(n.delete(bn),n.size===0)F5(r);else if(n.size===1){const[a,o]=n.entries().next().value;z5(r,a,o)}}},F5=e=>{if(e.length===0)return;const[t,n]=HT(e);if(t.delete(n),t.size===0)F5(e.slice(0,-1));else if(t.size===1){const[r,a]=t.entries().next().value;r!==bn&&z5(e.slice(0,-1),r,a)}},z5=(e,t,n)=>{if(e.length===0)return;const[r,a]=HT(e);r.set(a+t,n),r.delete(a)},HT=e=>e[e.length-1],$T="or",B5="and",Eae="and_not";class Co{constructor(t){if((t==null?void 0:t.fields)==null)throw new Error('MiniSearch: option "fields" must be provided');const n=t.autoVacuum==null||t.autoVacuum===!0?ib:t.autoVacuum;this._options={...ob,...t,autoVacuum:n,searchOptions:{...CO,...t.searchOptions||{}},autoSuggestOptions:{...Aae,...t.autoSuggestOptions||{}}},this._index=new To,this._documentCount=0,this._documentIds=new Map,this._idToShortId=new Map,this._fieldIds={},this._fieldLength=new Map,this._avgFieldLength=[],this._nextId=0,this._storedFields=new Map,this._dirtCount=0,this._currentVacuum=null,this._enqueuedVacuum=null,this._enqueuedVacuumConditions=ok,this.addFields(this._options.fields)}add(t){const{extractField:n,tokenize:r,processTerm:a,fields:o,idField:s}=this._options,l=n(t,s);if(l==null)throw new Error(`MiniSearch: document does not have ID field "${s}"`);if(this._idToShortId.has(l))throw new Error(`MiniSearch: duplicate ID ${l}`);const u=this.addDocumentId(l);this.saveStoredFields(u,t);for(const d of o){const p=n(t,d);if(p==null)continue;const g=r(p.toString(),d),m=this._fieldIds[d],b=new Set(g).size;this.addFieldLength(u,m,this._documentCount-1,b);for(const v of g){const y=a(v,d);if(Array.isArray(y))for(const k of y)this.addTerm(m,u,k);else y&&this.addTerm(m,u,y)}}}addAll(t){for(const n of t)this.add(n)}addAllAsync(t,n={}){const{chunkSize:r=10}=n,a={chunk:[],promise:Promise.resolve()},{chunk:o,promise:s}=t.reduce(({chunk:l,promise:u},d,p)=>(l.push(d),(p+1)%r===0?{chunk:[],promise:u.then(()=>new Promise(g=>setTimeout(g,0))).then(()=>this.addAll(l))}:{chunk:l,promise:u}),a);return s.then(()=>this.addAll(o))}remove(t){const{tokenize:n,processTerm:r,extractField:a,fields:o,idField:s}=this._options,l=a(t,s);if(l==null)throw new Error(`MiniSearch: document does not have ID field "${s}"`);const u=this._idToShortId.get(l);if(u==null)throw new Error(`MiniSearch: cannot remove document with ID ${l}: it is not in the index`);for(const d of o){const p=a(t,d);if(p==null)continue;const g=n(p.toString(),d),m=this._fieldIds[d],b=new Set(g).size;this.removeFieldLength(u,m,this._documentCount,b);for(const v of g){const y=r(v,d);if(Array.isArray(y))for(const k of y)this.removeTerm(m,u,k);else y&&this.removeTerm(m,u,y)}}this._storedFields.delete(u),this._documentIds.delete(u),this._idToShortId.delete(l),this._fieldLength.delete(u),this._documentCount-=1}removeAll(t){if(t)for(const n of t)this.remove(n);else{if(arguments.length>0)throw new Error("Expected documents to be present. Omit the argument to remove all documents.");this._index=new To,this._documentCount=0,this._documentIds=new Map,this._idToShortId=new Map,this._fieldLength=new Map,this._avgFieldLength=[],this._storedFields=new Map,this._nextId=0}}discard(t){const n=this._idToShortId.get(t);if(n==null)throw new Error(`MiniSearch: cannot discard document with ID ${t}: it is not in the index`);this._idToShortId.delete(t),this._documentIds.delete(n),this._storedFields.delete(n),(this._fieldLength.get(n)||[]).forEach((r,a)=>{this.removeFieldLength(n,a,this._documentCount,r)}),this._fieldLength.delete(n),this._documentCount-=1,this._dirtCount+=1,this.maybeAutoVacuum()}maybeAutoVacuum(){if(this._options.autoVacuum===!1)return;const{minDirtFactor:t,minDirtCount:n,batchSize:r,batchWait:a}=this._options.autoVacuum;this.conditionalVacuum({batchSize:r,batchWait:a},{minDirtCount:n,minDirtFactor:t})}discardAll(t){const n=this._options.autoVacuum;try{this._options.autoVacuum=!1;for(const r of t)this.discard(r)}finally{this._options.autoVacuum=n}this.maybeAutoVacuum()}replace(t){const{idField:n,extractField:r}=this._options,a=r(t,n);this.discard(a),this.add(t)}vacuum(t={}){return this.conditionalVacuum(t)}conditionalVacuum(t,n){return this._currentVacuum?(this._enqueuedVacuumConditions=this._enqueuedVacuumConditions&&n,this._enqueuedVacuum!=null?this._enqueuedVacuum:(this._enqueuedVacuum=this._currentVacuum.then(()=>{const r=this._enqueuedVacuumConditions;return this._enqueuedVacuumConditions=ok,this.performVacuuming(t,r)}),this._enqueuedVacuum)):this.vacuumConditionsMet(n)===!1?Promise.resolve():(this._currentVacuum=this.performVacuuming(t),this._currentVacuum)}async performVacuuming(t,n){const r=this._dirtCount;if(this.vacuumConditionsMet(n)){const a=t.batchSize||ak.batchSize,o=t.batchWait||ak.batchWait;let s=1;for(const[l,u]of this._index){for(const[d,p]of u)for(const[g]of p)this._documentIds.has(g)||(p.size<=1?u.delete(d):p.delete(g));this._index.get(l).size===0&&this._index.delete(l),s%a===0&&await new Promise(d=>setTimeout(d,o)),s+=1}this._dirtCount-=r}await null,this._currentVacuum=this._enqueuedVacuum,this._enqueuedVacuum=null}vacuumConditionsMet(t){if(t==null)return!0;let{minDirtCount:n,minDirtFactor:r}=t;return n=n||ib.minDirtCount,r=r||ib.minDirtFactor,this.dirtCount>=n&&this.dirtFactor>=r}get isVacuuming(){return this._currentVacuum!=null}get dirtCount(){return this._dirtCount}get dirtFactor(){return this._dirtCount/(1+this._documentCount+this._dirtCount)}has(t){return this._idToShortId.has(t)}getStoredFields(t){const n=this._idToShortId.get(t);if(n!=null)return this._storedFields.get(n)}search(t,n={}){const{searchOptions:r}=this._options,a={...r,...n},o=this.executeQuery(t,n),s=[];for(const[l,{score:u,terms:d,match:p}]of o){const g=d.length||1,m={id:this._documentIds.get(l),score:u*g,terms:Object.keys(p),queryTerms:d,match:p};Object.assign(m,this._storedFields.get(l)),(a.filter==null||a.filter(m))&&s.push(m)}return t===Co.wildcard&&a.boostDocument==null||s.sort(NO),s}autoSuggest(t,n={}){n={...this._options.autoSuggestOptions,...n};const r=new Map;for(const{score:o,terms:s}of this.search(t,n)){const l=s.join(" "),u=r.get(l);u!=null?(u.score+=o,u.count+=1):r.set(l,{score:o,terms:s,count:1})}const a=[];for(const[o,{score:s,terms:l,count:u}]of r)a.push({suggestion:o,terms:l,score:s/u});return a.sort(NO),a}get documentCount(){return this._documentCount}get termCount(){return this._index.size}static loadJSON(t,n){if(n==null)throw new Error("MiniSearch: loadJSON should be given the same options used when serializing the index");return this.loadJS(JSON.parse(t),n)}static async loadJSONAsync(t,n){if(n==null)throw new Error("MiniSearch: loadJSON should be given the same options used when serializing the index");return this.loadJSAsync(JSON.parse(t),n)}static getDefault(t){if(ob.hasOwnProperty(t))return ab(ob,t);throw new Error(`MiniSearch: unknown option "${t}"`)}static loadJS(t,n){const{index:r,documentIds:a,fieldLength:o,storedFields:s,serializationVersion:l}=t,u=this.instantiateMiniSearch(t,n);u._documentIds=Fd(a),u._fieldLength=Fd(o),u._storedFields=Fd(s);for(const[d,p]of u._documentIds)u._idToShortId.set(p,d);for(const[d,p]of r){const g=new Map;for(const m of Object.keys(p)){let b=p[m];l===1&&(b=b.ds),g.set(parseInt(m,10),Fd(b))}u._index.set(d,g)}return u}static async loadJSAsync(t,n){const{index:r,documentIds:a,fieldLength:o,storedFields:s,serializationVersion:l}=t,u=this.instantiateMiniSearch(t,n);u._documentIds=await zd(a),u._fieldLength=await zd(o),u._storedFields=await zd(s);for(const[p,g]of u._documentIds)u._idToShortId.set(g,p);let d=0;for(const[p,g]of r){const m=new Map;for(const b of Object.keys(g)){let v=g[b];l===1&&(v=v.ds),m.set(parseInt(b,10),await zd(v))}++d%1e3===0&&await j5(0),u._index.set(p,m)}return u}static instantiateMiniSearch(t,n){const{documentCount:r,nextId:a,fieldIds:o,averageFieldLength:s,dirtCount:l,serializationVersion:u}=t;if(u!==1&&u!==2)throw new Error("MiniSearch: cannot deserialize an index created with an incompatible version");const d=new Co(n);return d._documentCount=r,d._nextId=a,d._idToShortId=new Map,d._fieldIds=o,d._avgFieldLength=s,d._dirtCount=l||0,d._index=new To,d}executeQuery(t,n={}){if(t===Co.wildcard)return this.executeWildcardQuery(n);if(typeof t!="string"){const m={...n,...t,queries:void 0},b=t.queries.map(v=>this.executeQuery(v,m));return this.combineResults(b,m.combineWith)}const{tokenize:r,processTerm:a,searchOptions:o}=this._options,s={tokenize:r,processTerm:a,...o,...n},{tokenize:l,processTerm:u}=s,g=l(t).flatMap(m=>u(m)).filter(m=>!!m).map(Tae(s)).map(m=>this.executeQuerySpec(m,s));return this.combineResults(g,s.combineWith)}executeQuerySpec(t,n){const r={...this._options.searchOptions,...n},a=(r.fields||this._options.fields).reduce((y,k)=>({...y,[k]:ab(r.boost,k)||1}),{}),{boostDocument:o,weights:s,maxFuzzy:l,bm25:u}=r,{fuzzy:d,prefix:p}={...CO.weights,...s},g=this._index.get(t.term),m=this.termResults(t.term,t.term,1,t.termBoost,g,a,o,u);let b,v;if(t.prefix&&(b=this._index.atPrefix(t.term)),t.fuzzy){const y=t.fuzzy===!0?.2:t.fuzzy,k=y<1?Math.min(l,Math.round(t.term.length*y)):y;k&&(v=this._index.fuzzyGet(t.term,k))}if(b)for(const[y,k]of b){const A=y.length-t.term.length;if(!A)continue;v==null||v.delete(y);const x=p*y.length/(y.length+.3*A);this.termResults(t.term,y,x,t.termBoost,k,a,o,u,m)}if(v)for(const y of v.keys()){const[k,A]=v.get(y);if(!A)continue;const x=d*y.length/(y.length+A);this.termResults(t.term,y,x,t.termBoost,k,a,o,u,m)}return m}executeWildcardQuery(t){const n=new Map,r={...this._options.searchOptions,...t};for(const[a,o]of this._documentIds){const s=r.boostDocument?r.boostDocument(o,"",this._storedFields.get(a)):1;n.set(a,{score:s,terms:[],match:{}})}return n}combineResults(t,n=$T){if(t.length===0)return new Map;const r=n.toLowerCase(),a=wae[r];if(!a)throw new Error(`Invalid combination operator: ${n}`);return t.reduce(a)||new Map}toJSON(){const t=[];for(const[n,r]of this._index){const a={};for(const[o,s]of r)a[o]=Object.fromEntries(s);t.push([n,a])}return{documentCount:this._documentCount,nextId:this._nextId,documentIds:Object.fromEntries(this._documentIds),fieldIds:this._fieldIds,fieldLength:Object.fromEntries(this._fieldLength),averageFieldLength:this._avgFieldLength,storedFields:Object.fromEntries(this._storedFields),dirtCount:this._dirtCount,index:t,serializationVersion:2}}termResults(t,n,r,a,o,s,l,u,d=new Map){if(o==null)return d;for(const p of Object.keys(s)){const g=s[p],m=this._fieldIds[p],b=o.get(m);if(b==null)continue;let v=b.size;const y=this._avgFieldLength[m];for(const k of b.keys()){if(!this._documentIds.has(k)){this.removeTerm(m,k,n),v-=1;continue}const A=l?l(this._documentIds.get(k),n,this._storedFields.get(k)):1;if(!A)continue;const x=b.get(k),R=this._fieldLength.get(k)[m],O=kae(x,v,this._documentCount,R,y,u),N=r*a*g*A*O,C=d.get(k);if(C){C.score+=N,Rae(C.terms,t);const _=ab(C.match,n);_?_.push(p):C.match[n]=[p]}else d.set(k,{score:N,terms:[t],match:{[n]:[p]}})}}return d}addTerm(t,n,r){const a=this._index.fetch(r,OO);let o=a.get(t);if(o==null)o=new Map,o.set(n,1),a.set(t,o);else{const s=o.get(n);o.set(n,(s||0)+1)}}removeTerm(t,n,r){if(!this._index.has(r)){this.warnDocumentChanged(n,t,r);return}const a=this._index.fetch(r,OO),o=a.get(t);o==null||o.get(n)==null?this.warnDocumentChanged(n,t,r):o.get(n)<=1?o.size<=1?a.delete(t):o.delete(n):o.set(n,o.get(n)-1),this._index.get(r).size===0&&this._index.delete(r)}warnDocumentChanged(t,n,r){for(const a of Object.keys(this._fieldIds))if(this._fieldIds[a]===n){this._options.logger("warn",`MiniSearch: document with ID ${this._documentIds.get(t)} has changed before removal: term "${r}" was not present in field "${a}". Removing a document after it has changed can corrupt the index!`,"version_conflict");return}}addDocumentId(t){const n=this._nextId;return this._idToShortId.set(t,n),this._documentIds.set(n,t),this._documentCount+=1,this._nextId+=1,n}addFields(t){for(let n=0;n<t.length;n++)this._fieldIds[t[n]]=n}addFieldLength(t,n,r,a){let o=this._fieldLength.get(t);o==null&&this._fieldLength.set(t,o=[]),o[n]=a;const l=(this._avgFieldLength[n]||0)*r+a;this._avgFieldLength[n]=l/(r+1)}removeFieldLength(t,n,r,a){if(r===1){this._avgFieldLength[n]=0;return}const o=this._avgFieldLength[n]*r-a;this._avgFieldLength[n]=o/(r-1)}saveStoredFields(t,n){const{storeFields:r,extractField:a}=this._options;if(r==null||r.length===0)return;let o=this._storedFields.get(t);o==null&&this._storedFields.set(t,o={});for(const s of r){const l=a(n,s);l!==void 0&&(o[s]=l)}}}Co.wildcard=Symbol("*");const ab=(e,t)=>Object.prototype.hasOwnProperty.call(e,t)?e[t]:void 0,wae={[$T]:(e,t)=>{for(const n of t.keys()){const r=e.get(n);if(r==null)e.set(n,t.get(n));else{const{score:a,terms:o,match:s}=t.get(n);r.score=r.score+a,r.match=Object.assign(r.match,s),_O(r.terms,o)}}return e},[B5]:(e,t)=>{const n=new Map;for(const r of t.keys()){const a=e.get(r);if(a==null)continue;const{score:o,terms:s,match:l}=t.get(r);_O(a.terms,s),n.set(r,{score:a.score+o,terms:a.terms,match:Object.assign(a.match,l)})}return n},[Eae]:(e,t)=>{for(const n of t.keys())e.delete(n);return e}},xae={k:1.2,b:.7,d:.5},kae=(e,t,n,r,a,o)=>{const{k:s,b:l,d:u}=o;return Math.log(1+(n-t+.5)/(t+.5))*(u+e*(s+1)/(e+s*(1-l+l*r/a)))},Tae=e=>(t,n,r)=>{const a=typeof e.fuzzy=="function"?e.fuzzy(t,n,r):e.fuzzy||!1,o=typeof e.prefix=="function"?e.prefix(t,n,r):e.prefix===!0,s=typeof e.boostTerm=="function"?e.boostTerm(t,n,r):1;return{term:t,fuzzy:a,prefix:o,termBoost:s}},ob={idField:"id",extractField:(e,t)=>e[t],tokenize:e=>e.split(Cae),processTerm:e=>e.toLowerCase(),fields:void 0,searchOptions:void 0,storeFields:[],logger:(e,t)=>{typeof(console==null?void 0:console[e])=="function"&&console[e](t)},autoVacuum:!0},CO={combineWith:$T,prefix:!1,fuzzy:!1,maxFuzzy:6,boost:{},weights:{fuzzy:.45,prefix:.375},bm25:xae},Aae={combineWith:B5,prefix:(e,t,n)=>t===n.length-1},ak={batchSize:1e3,batchWait:10},ok={minDirtFactor:.1,minDirtCount:20},ib={...ak,...ok},Rae=(e,t)=>{e.includes(t)||e.push(t)},_O=(e,t)=>{for(const n of t)e.includes(n)||e.push(n)},NO=({score:e},{score:t})=>t-e,OO=()=>new Map,Fd=e=>{const t=new Map;for(const n of Object.keys(e))t.set(parseInt(n,10),e[n]);return t},zd=async e=>{const t=new Map;let n=0;for(const r of Object.keys(e))t.set(parseInt(r,10),e[r]),++n%1e3===0&&await j5(0);return t},j5=e=>new Promise(t=>setTimeout(t,e)),Cae=/[\n\r\p{Z}\p{P}]+/u,_ae={index:new Co({fields:[]})};w.createContext(_ae);const ik=({label:e,color:t,hidden:n,labels:r={}})=>we.createElement("div",{className:"node"},we.createElement("span",{className:"render "+(n?"circle":"disc"),style:{backgroundColor:t||"#000"}}),we.createElement("span",{className:`label ${n?"text-muted":""} ${e?"":"text-italic"}`},e||r.no_label||"No label")),Nae=({id:e,labels:t})=>{const n=Ar(),r=w.useMemo(()=>{const a=n.getGraph().getNodeAttributes(e),o=n.getSetting("nodeReducer");return Object.assign(Object.assign({color:n.getSetting("defaultNodeColor")},a),o?o(e,a):{})},[n,e]);return we.createElement(ik,Object.assign({},r,{labels:t}))},Oae=({label:e,color:t,source:n,target:r,hidden:a,directed:o,labels:s={}})=>we.createElement("div",{className:"edge"},we.createElement(ik,Object.assign({},n,{labels:s})),we.createElement("div",{className:"body"},we.createElement("div",{className:"render"},we.createElement("span",{className:a?"dotted":"dash",style:{borderColor:t||"#000"}})," ",o&&we.createElement("span",{className:"arrow",style:{borderTopColor:t||"#000"}})),we.createElement("span",{className:`label ${a?"text-muted":""} ${e?"":"fst-italic"}`},e||s.no_label||"No label")),we.createElement(ik,Object.assign({},r,{labels:s}))),Iae=({id:e,labels:t})=>{const n=Ar(),r=w.useMemo(()=>{const a=n.getGraph().getEdgeAttributes(e),o=n.getSetting("nodeReducer"),s=n.getSetting("edgeReducer"),l=n.getGraph().getNodeAttributes(n.getGraph().source(e)),u=n.getGraph().getNodeAttributes(n.getGraph().target(e));return Object.assign(Object.assign(Object.assign({color:n.getSetting("defaultEdgeColor"),directed:n.getGraph().isDirected(e)},a),s?s(e,a):{}),{source:Object.assign(Object.assign({color:n.getSetting("defaultNodeColor")},l),o?o(e,l):{}),target:Object.assign(Object.assign({color:n.getSetting("defaultNodeColor")},u),o?o(e,u):{})})},[n,e]);return we.createElement(Oae,Object.assign({},r,{labels:t}))};function qT(e,t){const[n,r]=w.useState(e);return w.useEffect(()=>{const a=setTimeout(()=>{r(e)},t);return()=>{clearTimeout(a)}},[e,t]),n}function Dae({fetcher:e,preload:t,filterFn:n,renderOption:r,getOptionValue:a,notFound:o,loadingSkeleton:s,label:l,placeholder:u="Select...",value:d,onChange:p,onFocus:g,disabled:m=!1,className:b,noResultsMessage:v}){const[y,k]=w.useState(!1),[A,x]=w.useState(!1),[R,O]=w.useState([]),[N,C]=w.useState(!1),[_,M]=w.useState(null),[I,D]=w.useState(""),U=qT(I,t?0:150),$=w.useRef(null);w.useEffect(()=>{k(!0)},[]),w.useEffect(()=>{const G=z=>{$.current&&!$.current.contains(z.target)&&A&&x(!1)};return document.addEventListener("mousedown",G),()=>{document.removeEventListener("mousedown",G)}},[A]);const B=w.useCallback(async G=>{try{C(!0),M(null);const z=await e(G);O(z)}catch(z){M(z instanceof Error?z.message:"Failed to fetch options")}finally{C(!1)}},[e]);w.useEffect(()=>{y&&(t?U&&O(G=>G.filter(z=>n?n(z,U):!0)):B(U))},[y,U,t,n,B]),w.useEffect(()=>{!y||!d||B(d)},[y,d,B]);const W=w.useCallback(G=>{p(G),requestAnimationFrame(()=>{const z=document.activeElement;z==null||z.blur(),x(!1)})},[p]),K=w.useCallback(()=>{x(!0),B(I)},[I,B]),H=w.useCallback(G=>{G.target.closest(".cmd-item")&&G.preventDefault()},[]);return E.jsx("div",{ref:$,className:Me(m&&"cursor-not-allowed opacity-50",b),onMouseDown:H,children:E.jsxs(Ap,{shouldFilter:!1,className:"bg-transparent",children:[E.jsxs("div",{children:[E.jsx(jT,{placeholder:u,value:I,className:"max-h-8",onFocus:K,onValueChange:G=>{D(G),A||x(!0)}}),N&&E.jsx("div",{className:"absolute top-1/2 right-2 flex -translate-y-1/2 transform items-center",children:E.jsx(jU,{className:"h-4 w-4 animate-spin"})})]}),E.jsxs(Rp,{hidden:!A,children:[_&&E.jsx("div",{className:"text-destructive p-4 text-center",children:_}),N&&R.length===0&&(s||E.jsx(Lae,{})),!N&&!_&&R.length===0&&(o||E.jsx(UT,{children:v??`No ${l.toLowerCase()} found.`})),E.jsx(el,{children:R.map((G,z)=>E.jsxs(we.Fragment,{children:[E.jsx(tl,{value:a(G),onSelect:W,onMouseMove:()=>g(a(G)),className:"truncate cmd-item",children:r(G)},a(G)+`${z}`),z!==R.length-1&&E.jsx("div",{className:"bg-foreground/10 h-[1px]"},`divider-${z}`)]},a(G)+`-fragment-${z}`))})]})]})})}function Lae(){return E.jsx(el,{children:E.jsx(tl,{disabled:!0,children:E.jsxs("div",{className:"flex w-full items-center gap-2",children:[E.jsx("div",{className:"bg-muted h-6 w-6 animate-pulse rounded-full"}),E.jsxs("div",{className:"flex flex-1 flex-col gap-1",children:[E.jsx("div",{className:"bg-muted h-4 w-24 animate-pulse rounded"}),E.jsx("div",{className:"bg-muted h-3 w-16 animate-pulse rounded"})]})]})})})}const sb="__message_item",Mae=({id:e})=>{const t=ze.use.sigmaGraph();return t!=null&&t.hasNode(e)?E.jsx(Nae,{id:e}):null};function Pae(e){return E.jsxs("div",{children:[e.type==="nodes"&&E.jsx(Mae,{id:e.id}),e.type==="edges"&&E.jsx(Iae,{id:e.id}),e.type==="message"&&E.jsx("div",{children:e.message})]})}const Fae=({onChange:e,onFocus:t,value:n})=>{const{t:r}=Et(),a=ze.use.sigmaGraph(),o=ze.use.searchEngine();w.useEffect(()=>{a&&ze.getState().resetSearchEngine()},[a]),w.useEffect(()=>{if(!a||a.nodes().length===0||o)return;const l=new Co({idField:"id",fields:["label"],searchOptions:{prefix:!0,fuzzy:.2,boost:{label:2}}}),u=a.nodes().map(d=>({id:d,label:a.getNodeAttribute(d,"label")}));l.addAll(u),ze.getState().setSearchEngine(l)},[a,o]);const s=w.useCallback(async l=>{if(t&&t(null),!a||!o)return[];if(a.nodes().length===0)return[];if(!l)return a.nodes().filter(p=>a.hasNode(p)).slice(0,vd).map(p=>({id:p,type:"nodes"}));const u=o.search(l).filter(d=>a.hasNode(d.id)).map(d=>({id:d.id,type:"nodes"}));return u.length<=vd?u:[...u.slice(0,vd),{type:"message",id:sb,message:r("graphPanel.search.message",{count:u.length-vd})}]},[a,o,t,r]);return E.jsx(Dae,{className:"bg-background/60 w-24 rounded-xl border-1 opacity-60 backdrop-blur-lg transition-all hover:w-fit hover:opacity-100",fetcher:s,renderOption:Pae,getOptionValue:l=>l.id,value:n&&n.type!=="message"?n.id:null,onChange:l=>{l!==sb&&e(l?{id:l,type:"nodes"}:null)},onFocus:l=>{l!==sb&&t&&t(l?{id:l,type:"nodes"}:null)},label:"item",placeholder:r("graphPanel.search.placeholder")})},zae=({...e})=>E.jsx(Fae,{...e});function Bae({fetcher:e,preload:t,filterFn:n,renderOption:r,getOptionValue:a,getDisplayValue:o,notFound:s,loadingSkeleton:l,label:u,placeholder:d="Select...",value:p,onChange:g,disabled:m=!1,className:b,triggerClassName:v,searchInputClassName:y,noResultsMessage:k,triggerTooltip:A,clearable:x=!0}){const[R,O]=w.useState(!1),[N,C]=w.useState(!1),[_,M]=w.useState([]),[I,D]=w.useState(!1),[U,$]=w.useState(null),[B,W]=w.useState(p),[K,H]=w.useState(null),[G,z]=w.useState(""),Y=qT(G,t?0:150),[L,V]=w.useState([]),[j,P]=w.useState(null);w.useEffect(()=>{O(!0),W(p)},[p]),w.useEffect(()=>{p&&(!_.length||!K)?P(E.jsx("div",{children:p})):K&&P(null)},[p,_.length,K]),w.useEffect(()=>{if(p&&_.length>0){const Q=_.find(oe=>a(oe)===p);Q&&H(Q)}},[p,_,a]),w.useEffect(()=>{R||(async()=>{try{D(!0),$(null);const oe=await e(p);V(oe),M(oe)}catch(oe){$(oe instanceof Error?oe.message:"Failed to fetch options")}finally{D(!1)}})()},[R,e,p]),w.useEffect(()=>{const Q=async()=>{try{D(!0),$(null);const oe=await e(Y);V(oe),M(oe)}catch(oe){$(oe instanceof Error?oe.message:"Failed to fetch options")}finally{D(!1)}};R&&t?t&&M(Y?L.filter(oe=>n?n(oe,Y):!0):L):Q()},[e,Y,R,t,n]);const Z=w.useCallback(Q=>{const oe=x&&Q===B?"":Q;W(oe),H(_.find(ae=>a(ae)===oe)||null),g(oe),C(!1)},[B,g,x,_,a]);return E.jsxs(mp,{open:N,onOpenChange:C,children:[E.jsx(bp,{asChild:!0,children:E.jsxs(nt,{variant:"outline",role:"combobox","aria-expanded":N,className:Me("justify-between",m&&"cursor-not-allowed opacity-50",v),disabled:m,tooltip:A,side:"bottom",children:[p==="*"?E.jsx("div",{children:"*"}):K?o(K):j||d,E.jsx(lZ,{className:"opacity-50",size:10})]})}),E.jsx(Qc,{className:Me("p-0",b),onCloseAutoFocus:Q=>Q.preventDefault(),children:E.jsxs(Ap,{shouldFilter:!1,children:[E.jsxs("div",{className:"relative w-full border-b",children:[E.jsx(jT,{placeholder:`Search ${u.toLowerCase()}...`,value:G,onValueChange:Q=>{z(Q)},className:y}),I&&_.length>0&&E.jsx("div",{className:"absolute top-1/2 right-2 flex -translate-y-1/2 transform items-center",children:E.jsx(jU,{className:"h-4 w-4 animate-spin"})})]}),E.jsxs(Rp,{children:[U&&E.jsx("div",{className:"text-destructive p-4 text-center",children:U}),I&&_.length===0&&(l||E.jsx(jae,{})),!I&&!U&&_.length===0&&(s||E.jsx(UT,{children:k??`No ${u.toLowerCase()} found.`})),E.jsx(el,{children:_.map(Q=>E.jsxs(tl,{value:a(Q),onSelect:Z,className:"truncate",children:[r(Q),E.jsx(vT,{className:Me("ml-auto h-3 w-3",B===a(Q)?"opacity-100":"opacity-0")})]},a(Q)))})]})]})})]})}function jae(){return E.jsx(el,{children:E.jsx(tl,{disabled:!0,children:E.jsxs("div",{className:"flex w-full items-center gap-2",children:[E.jsx("div",{className:"bg-muted h-6 w-6 animate-pulse rounded-full"}),E.jsxs("div",{className:"flex flex-1 flex-col gap-1",children:[E.jsx("div",{className:"bg-muted h-4 w-24 animate-pulse rounded"}),E.jsx("div",{className:"bg-muted h-3 w-16 animate-pulse rounded"})]})]})})})}const Uae=()=>{const{t:e}=Et(),t=De.use.queryLabel(),n=ze.use.allDatabaseLabels(),r=ze.use.labelsFetchAttempted(),a=w.useCallback(()=>{const l=new Co({idField:"id",fields:["value"],searchOptions:{prefix:!0,fuzzy:.2,boost:{label:2}}}),u=n.map((d,p)=>({id:p,value:d}));return l.addAll(u),{labels:n,searchEngine:l}},[n]),o=w.useCallback(async l=>{const{labels:u,searchEngine:d}=a();let p=u;return l&&(p=d.search(l).map(g=>u[g.id])),p.length<=F_?p:[...p.slice(0,F_),"..."]},[a]);w.useEffect(()=>{r&&(n.length>1?t&&t!=="*"&&!n.includes(t)?(console.log(`Label "${t}" not in available labels, setting to "*"`),De.getState().setQueryLabel("*")):console.log(`Label "${t}" is valid`):t&&n.length<=1&&t&&t!=="*"&&(console.log("Available labels list is empty, setting label to empty"),De.getState().setQueryLabel("")),ze.getState().setLabelsFetchAttempted(!1))},[n,t,r]);const s=w.useCallback(()=>{ze.getState().setLabelsFetchAttempted(!1),ze.getState().setGraphDataFetchAttempted(!1),ze.getState().setLastSuccessfulQueryLabel("");const l=De.getState().queryLabel;l?(De.getState().setQueryLabel(""),setTimeout(()=>{De.getState().setQueryLabel(l)},0)):De.getState().setQueryLabel("*")},[]);return E.jsxs("div",{className:"flex items-center",children:[E.jsx(nt,{size:"icon",variant:Er,onClick:s,tooltip:e("graphPanel.graphLabels.refreshTooltip"),className:"mr-1",children:E.jsx(UU,{className:"h-4 w-4"})}),E.jsx(Bae,{className:"ml-2",triggerClassName:"max-h-8",searchInputClassName:"max-h-8",triggerTooltip:e("graphPanel.graphLabels.selectTooltip"),fetcher:o,renderOption:l=>E.jsx("div",{children:l}),getOptionValue:l=>l,getDisplayValue:l=>E.jsx("div",{children:l}),notFound:E.jsx("div",{className:"py-6 text-center text-sm",children:"No labels found"}),label:e("graphPanel.graphLabels.label"),placeholder:e("graphPanel.graphLabels.placeholder"),value:t!==null?t:"*",onChange:l=>{const u=De.getState().queryLabel;l==="..."&&(l="*"),l===u&&l!=="*"&&(l="*"),ze.getState().setGraphDataFetchAttempted(!1),De.getState().setQueryLabel(l)},clearable:!1})]})},Jn=({text:e,className:t,tooltipClassName:n,tooltip:r,side:a,onClick:o})=>r?E.jsx(mT,{delayDuration:200,children:E.jsxs(bT,{children:[E.jsx(yT,{asChild:!0,children:E.jsx("label",{className:Me(t,o!==void 0?"cursor-pointer":void 0),onClick:o,children:e})}),E.jsx(gp,{side:a,className:n,children:r})]})}):E.jsx("label",{className:Me(t,o!==void 0?"cursor-pointer":void 0),onClick:o,children:e});var af={exports:{}},Gae=af.exports,IO;function Hae(){return IO||(IO=1,function(e){(function(t,n,r){function a(u){var d=this,p=l();d.next=function(){var g=2091639*d.s0+d.c*23283064365386963e-26;return d.s0=d.s1,d.s1=d.s2,d.s2=g-(d.c=g|0)},d.c=1,d.s0=p(" "),d.s1=p(" "),d.s2=p(" "),d.s0-=p(u),d.s0<0&&(d.s0+=1),d.s1-=p(u),d.s1<0&&(d.s1+=1),d.s2-=p(u),d.s2<0&&(d.s2+=1),p=null}function o(u,d){return d.c=u.c,d.s0=u.s0,d.s1=u.s1,d.s2=u.s2,d}function s(u,d){var p=new a(u),g=d&&d.state,m=p.next;return m.int32=function(){return p.next()*4294967296|0},m.double=function(){return m()+(m()*2097152|0)*11102230246251565e-32},m.quick=m,g&&(typeof g=="object"&&o(g,p),m.state=function(){return o(p,{})}),m}function l(){var u=4022871197,d=function(p){p=String(p);for(var g=0;g<p.length;g++){u+=p.charCodeAt(g);var m=.02519603282416938*u;u=m>>>0,m-=u,m*=u,u=m>>>0,m-=u,u+=m*4294967296}return(u>>>0)*23283064365386963e-26};return d}n&&n.exports?n.exports=s:this.alea=s})(Gae,e)}(af)),af.exports}var of={exports:{}},$ae=of.exports,DO;function qae(){return DO||(DO=1,function(e){(function(t,n,r){function a(l){var u=this,d="";u.x=0,u.y=0,u.z=0,u.w=0,u.next=function(){var g=u.x^u.x<<11;return u.x=u.y,u.y=u.z,u.z=u.w,u.w^=u.w>>>19^g^g>>>8},l===(l|0)?u.x=l:d+=l;for(var p=0;p<d.length+64;p++)u.x^=d.charCodeAt(p)|0,u.next()}function o(l,u){return u.x=l.x,u.y=l.y,u.z=l.z,u.w=l.w,u}function s(l,u){var d=new a(l),p=u&&u.state,g=function(){return(d.next()>>>0)/4294967296};return g.double=function(){do var m=d.next()>>>11,b=(d.next()>>>0)/4294967296,v=(m+b)/(1<<21);while(v===0);return v},g.int32=d.next,g.quick=g,p&&(typeof p=="object"&&o(p,d),g.state=function(){return o(d,{})}),g}n&&n.exports?n.exports=s:this.xor128=s})($ae,e)}(of)),of.exports}var sf={exports:{}},Vae=sf.exports,LO;function Wae(){return LO||(LO=1,function(e){(function(t,n,r){function a(l){var u=this,d="";u.next=function(){var g=u.x^u.x>>>2;return u.x=u.y,u.y=u.z,u.z=u.w,u.w=u.v,(u.d=u.d+362437|0)+(u.v=u.v^u.v<<4^(g^g<<1))|0},u.x=0,u.y=0,u.z=0,u.w=0,u.v=0,l===(l|0)?u.x=l:d+=l;for(var p=0;p<d.length+64;p++)u.x^=d.charCodeAt(p)|0,p==d.length&&(u.d=u.x<<10^u.x>>>4),u.next()}function o(l,u){return u.x=l.x,u.y=l.y,u.z=l.z,u.w=l.w,u.v=l.v,u.d=l.d,u}function s(l,u){var d=new a(l),p=u&&u.state,g=function(){return(d.next()>>>0)/4294967296};return g.double=function(){do var m=d.next()>>>11,b=(d.next()>>>0)/4294967296,v=(m+b)/(1<<21);while(v===0);return v},g.int32=d.next,g.quick=g,p&&(typeof p=="object"&&o(p,d),g.state=function(){return o(d,{})}),g}n&&n.exports?n.exports=s:this.xorwow=s})(Vae,e)}(sf)),sf.exports}var lf={exports:{}},Yae=lf.exports,MO;function Kae(){return MO||(MO=1,function(e){(function(t,n,r){function a(l){var u=this;u.next=function(){var p=u.x,g=u.i,m,b;return m=p[g],m^=m>>>7,b=m^m<<24,m=p[g+1&7],b^=m^m>>>10,m=p[g+3&7],b^=m^m>>>3,m=p[g+4&7],b^=m^m<<7,m=p[g+7&7],m=m^m<<13,b^=m^m<<9,p[g]=b,u.i=g+1&7,b};function d(p,g){var m,b=[];if(g===(g|0))b[0]=g;else for(g=""+g,m=0;m<g.length;++m)b[m&7]=b[m&7]<<15^g.charCodeAt(m)+b[m+1&7]<<13;for(;b.length<8;)b.push(0);for(m=0;m<8&&b[m]===0;++m);for(m==8?b[7]=-1:b[m],p.x=b,p.i=0,m=256;m>0;--m)p.next()}d(u,l)}function o(l,u){return u.x=l.x.slice(),u.i=l.i,u}function s(l,u){l==null&&(l=+new Date);var d=new a(l),p=u&&u.state,g=function(){return(d.next()>>>0)/4294967296};return g.double=function(){do var m=d.next()>>>11,b=(d.next()>>>0)/4294967296,v=(m+b)/(1<<21);while(v===0);return v},g.int32=d.next,g.quick=g,p&&(p.x&&o(p,d),g.state=function(){return o(d,{})}),g}n&&n.exports?n.exports=s:this.xorshift7=s})(Yae,e)}(lf)),lf.exports}var cf={exports:{}},Xae=cf.exports,PO;function Zae(){return PO||(PO=1,function(e){(function(t,n,r){function a(l){var u=this;u.next=function(){var p=u.w,g=u.X,m=u.i,b,v;return u.w=p=p+1640531527|0,v=g[m+34&127],b=g[m=m+1&127],v^=v<<13,b^=b<<17,v^=v>>>15,b^=b>>>12,v=g[m]=v^b,u.i=m,v+(p^p>>>16)|0};function d(p,g){var m,b,v,y,k,A=[],x=128;for(g===(g|0)?(b=g,g=null):(g=g+"\0",b=0,x=Math.max(x,g.length)),v=0,y=-32;y<x;++y)g&&(b^=g.charCodeAt((y+32)%g.length)),y===0&&(k=b),b^=b<<10,b^=b>>>15,b^=b<<4,b^=b>>>13,y>=0&&(k=k+1640531527|0,m=A[y&127]^=b+k,v=m==0?v+1:0);for(v>=128&&(A[(g&&g.length||0)&127]=-1),v=127,y=4*128;y>0;--y)b=A[v+34&127],m=A[v=v+1&127],b^=b<<13,m^=m<<17,b^=b>>>15,m^=m>>>12,A[v]=b^m;p.w=k,p.X=A,p.i=v}d(u,l)}function o(l,u){return u.i=l.i,u.w=l.w,u.X=l.X.slice(),u}function s(l,u){l==null&&(l=+new Date);var d=new a(l),p=u&&u.state,g=function(){return(d.next()>>>0)/4294967296};return g.double=function(){do var m=d.next()>>>11,b=(d.next()>>>0)/4294967296,v=(m+b)/(1<<21);while(v===0);return v},g.int32=d.next,g.quick=g,p&&(p.X&&o(p,d),g.state=function(){return o(d,{})}),g}n&&n.exports?n.exports=s:this.xor4096=s})(Xae,e)}(cf)),cf.exports}var uf={exports:{}},Qae=uf.exports,FO;function Jae(){return FO||(FO=1,function(e){(function(t,n,r){function a(l){var u=this,d="";u.next=function(){var g=u.b,m=u.c,b=u.d,v=u.a;return g=g<<25^g>>>7^m,m=m-b|0,b=b<<24^b>>>8^v,v=v-g|0,u.b=g=g<<20^g>>>12^m,u.c=m=m-b|0,u.d=b<<16^m>>>16^v,u.a=v-g|0},u.a=0,u.b=0,u.c=-1640531527,u.d=1367130551,l===Math.floor(l)?(u.a=l/4294967296|0,u.b=l|0):d+=l;for(var p=0;p<d.length+20;p++)u.b^=d.charCodeAt(p)|0,u.next()}function o(l,u){return u.a=l.a,u.b=l.b,u.c=l.c,u.d=l.d,u}function s(l,u){var d=new a(l),p=u&&u.state,g=function(){return(d.next()>>>0)/4294967296};return g.double=function(){do var m=d.next()>>>11,b=(d.next()>>>0)/4294967296,v=(m+b)/(1<<21);while(v===0);return v},g.int32=d.next,g.quick=g,p&&(typeof p=="object"&&o(p,d),g.state=function(){return o(d,{})}),g}n&&n.exports?n.exports=s:this.tychei=s})(Qae,e)}(uf)),uf.exports}var df={exports:{}};const eoe={},toe=Object.freeze(Object.defineProperty({__proto__:null,default:eoe},Symbol.toStringTag,{value:"Module"})),noe=cq(toe);var roe=df.exports,zO;function aoe(){return zO||(zO=1,function(e){(function(t,n,r){var a=256,o=6,s=52,l="random",u=r.pow(a,o),d=r.pow(2,s),p=d*2,g=a-1,m;function b(O,N,C){var _=[];N=N==!0?{entropy:!0}:N||{};var M=A(k(N.entropy?[O,R(n)]:O??x(),3),_),I=new v(_),D=function(){for(var U=I.g(o),$=u,B=0;U<d;)U=(U+B)*a,$*=a,B=I.g(1);for(;U>=p;)U/=2,$/=2,B>>>=1;return(U+B)/$};return D.int32=function(){return I.g(4)|0},D.quick=function(){return I.g(4)/4294967296},D.double=D,A(R(I.S),n),(N.pass||C||function(U,$,B,W){return W&&(W.S&&y(W,I),U.state=function(){return y(I,{})}),B?(r[l]=U,$):U})(D,M,"global"in N?N.global:this==r,N.state)}function v(O){var N,C=O.length,_=this,M=0,I=_.i=_.j=0,D=_.S=[];for(C||(O=[C++]);M<a;)D[M]=M++;for(M=0;M<a;M++)D[M]=D[I=g&I+O[M%C]+(N=D[M])],D[I]=N;(_.g=function(U){for(var $,B=0,W=_.i,K=_.j,H=_.S;U--;)$=H[W=g&W+1],B=B*a+H[g&(H[W]=H[K=g&K+$])+(H[K]=$)];return _.i=W,_.j=K,B})(a)}function y(O,N){return N.i=O.i,N.j=O.j,N.S=O.S.slice(),N}function k(O,N){var C=[],_=typeof O,M;if(N&&_=="object")for(M in O)try{C.push(k(O[M],N-1))}catch{}return C.length?C:_=="string"?O:O+"\0"}function A(O,N){for(var C=O+"",_,M=0;M<C.length;)N[g&M]=g&(_^=N[g&M]*19)+C.charCodeAt(M++);return R(N)}function x(){try{var O;return m&&(O=m.randomBytes)?O=O(a):(O=new Uint8Array(a),(t.crypto||t.msCrypto).getRandomValues(O)),R(O)}catch{var N=t.navigator,C=N&&N.plugins;return[+new Date,t,C,t.screen,R(n)]}}function R(O){return String.fromCharCode.apply(0,O)}if(A(r.random(),n),e.exports){e.exports=b;try{m=noe}catch{}}else r["seed"+l]=b})(typeof self<"u"?self:roe,[],Math)}(df)),df.exports}var lb,BO;function ooe(){if(BO)return lb;BO=1;var e=Hae(),t=qae(),n=Wae(),r=Kae(),a=Zae(),o=Jae(),s=aoe();return s.alea=e,s.xor128=t,s.xorwow=n,s.xorshift7=r,s.xor4096=a,s.tychei=o,lb=s,lb}var ioe=ooe();const sk=un(ioe),hc=["#fdd868","#e3493b","#1212a1","#0f705d","#a64dff","#f46a9b","#00bfa0","#fdcce5","#0f558a","#b2e061","#bd7ebe","#439bd6","#094338","#dc0ab4","#fd7f6f","#b04238"],lk=["#5ad45a","#5a2c6d","#6c1313","#184868","#996600","#4421af","#E67E22","#ff1a1a"],soe=[...hc,...lk],jO=e=>{const t="#5D6D7E";if(!e)return t;const n=ze.getState().typeColorMap;if(n.has(e))return n.get(e)||t;const r=new Set;n.forEach(u=>{r.add(u)});const o=(u=>{let d=0;for(let p=0;p<u.length;p++)d=(d<<5)-d+u.charCodeAt(p),d|=0;return Math.abs(d)%hc.length})(e);let s=hc[o];if(r.has(s)&&r.size<soe.length){let u=!1;for(let d=0;d<hc.length;d++){const p=hc[d];if(!r.has(p)){s=p,u=!0;break}}if(!u){s=t;for(let d=0;d<lk.length;d++){const p=lk[d];if(!r.has(p)){s=p;break}}}}const l=new Map(n);return l.set(e,s),ze.setState({typeColorMap:l}),s},loe=e=>{if(!e)return console.log("Graph validation failed: graph is null"),!1;if(!Array.isArray(e.nodes)||!Array.isArray(e.edges))return console.log("Graph validation failed: nodes or edges is not an array"),!1;if(e.nodes.length===0)return console.log("Graph validation failed: nodes array is empty"),!1;for(const t of e.nodes)if(!t.id||!t.labels||!t.properties)return console.log("Graph validation failed: invalid node structure"),!1;for(const t of e.edges)if(!t.id||!t.source||!t.target)return console.log("Graph validation failed: invalid edge structure"),!1;for(const t of e.edges){const n=e.getNode(t.source),r=e.getNode(t.target);if(n==null||r==null)return console.log("Graph validation failed: edge references non-existent node"),!1}return console.log("Graph validation passed"),!0},coe=async(e,t,n)=>{let r=null;if(!ze.getState().lastSuccessfulQueryLabel){console.log("Last successful queryLabel is empty");try{await ze.getState().fetchAllDatabaseLabels()}catch(l){console.error("Failed to fetch all database labels:",l)}}ze.getState().setLabelsFetchAttempted(!0);const o=e||"*";try{console.log(`Fetching graph label: ${o}, depth: ${t}, nodes: ${n}`),r=await QB(o,t,n)}catch(l){return rr.getState().setErrorMessage(Gn(l),"Query Graphs Error!"),null}let s=null;if(r){const l={},u={};for(let m=0;m<r.nodes.length;m++){const b=r.nodes[m];l[b.id]=m,b.x=Math.random(),b.y=Math.random(),b.degree=0,b.size=10}for(let m=0;m<r.edges.length;m++){const b=r.edges[m];u[b.id]=m;const v=l[b.source],y=l[b.target];if(v!==void 0&&v!==void 0){const k=r.nodes[v],A=r.nodes[y];if(!k){console.error(`Source node ${b.source} is undefined`);continue}if(!A){console.error(`Target node ${b.target} is undefined`);continue}k.degree+=1,A.degree+=1}}let d=Number.MAX_SAFE_INTEGER,p=0;for(const m of r.nodes)d=Math.min(d,m.degree),p=Math.max(p,m.degree);const g=p-d;if(g>0){const m=w0-li;for(const b of r.nodes)b.size=Math.round(li+m*Math.pow((b.degree-d)/g,.5))}s=new wV,s.nodes=r.nodes,s.edges=r.edges,s.nodeIdMap=l,s.edgeIdMap=u,loe(s)||(s=null,console.warn("Invalid graph data")),console.log("Graph data loaded")}return{rawGraph:s,is_truncated:r.is_truncated}},uoe=e=>{var l,u;const t=De.getState().minEdgeSize,n=De.getState().maxEdgeSize;if(!e||!e.nodes.length)return console.log("No graph data available, skipping sigma graph creation"),null;const r=new Rc;for(const d of(e==null?void 0:e.nodes)??[]){sk(d.id+Date.now().toString(),{global:!0});const p=Math.random(),g=Math.random();r.addNode(d.id,{label:d.labels.join(", "),color:d.color,x:p,y:g,size:d.size,borderColor:E0,borderSize:.2})}for(const d of(e==null?void 0:e.edges)??[]){const p=((l=d.properties)==null?void 0:l.weight)!==void 0?Number(d.properties.weight):1;d.dynamicId=r.addEdge(d.source,d.target,{label:((u=d.properties)==null?void 0:u.keywords)||void 0,size:p,originalWeight:p,type:"curvedNoArrow"})}let a=Number.MAX_SAFE_INTEGER,o=0;r.forEachEdge(d=>{const p=r.getEdgeAttribute(d,"originalWeight")||1;a=Math.min(a,p),o=Math.max(o,p)});const s=o-a;if(s>0){const d=n-t;r.forEachEdge(p=>{const g=r.getEdgeAttribute(p,"originalWeight")||1,m=t+d*Math.pow((g-a)/s,.5);r.setEdgeAttribute(p,"size",m)})}else r.forEachEdge(d=>{r.setEdgeAttribute(d,"size",t)});return r},doe=()=>{const{t:e}=Et(),t=De.use.queryLabel(),n=ze.use.rawGraph(),r=ze.use.sigmaGraph(),a=De.use.graphQueryMaxDepth(),o=De.use.graphMaxNodes(),s=ze.use.isFetching(),l=ze.use.nodeToExpand(),u=ze.use.nodeToPrune(),d=w.useRef(!1),p=w.useRef(!1),g=w.useRef(!1),m=w.useCallback(A=>(n==null?void 0:n.getNode(A))||null,[n]),b=w.useCallback((A,x=!0)=>(n==null?void 0:n.getEdge(A,x))||null,[n]),v=w.useRef(!1);w.useEffect(()=>{if(!t&&(n!==null||r!==null)){const A=ze.getState();A.reset(),A.setGraphDataFetchAttempted(!1),A.setLabelsFetchAttempted(!1),d.current=!1,p.current=!1}},[t,n,r]),w.useEffect(()=>{if(!v.current&&!(!t&&g.current)&&!s&&!ze.getState().graphDataFetchAttempted){v.current=!0,ze.getState().setGraphDataFetchAttempted(!0);const A=ze.getState();A.setIsFetching(!0),A.clearSelection(),A.sigmaGraph&&A.sigmaGraph.forEachNode(C=>{var _;(_=A.sigmaGraph)==null||_.setNodeAttribute(C,"highlighted",!1)}),console.log("Preparing graph data...");const x=t,R=a,O=o;let N;x?N=coe(x,R,O):(console.log("Query label is empty, show empty graph"),N=Promise.resolve({rawGraph:null,is_truncated:!1})),N.then(C=>{const _=ze.getState(),M=C==null?void 0:C.rawGraph;if(M&&M.nodes&&M.nodes.forEach(I=>{var U;const D=(U=I.properties)==null?void 0:U.entity_type;I.color=jO(D)}),C!=null&&C.is_truncated&&Ft.info(e("graphPanel.dataIsTruncated","Graph data is truncated to Max Nodes")),_.reset(),!M||!M.nodes||M.nodes.length===0){const I=new Rc;I.addNode("empty-graph-node",{label:e("graphPanel.emptyGraph"),color:"#5D6D7E",x:.5,y:.5,size:15,borderColor:E0,borderSize:.2}),_.setSigmaGraph(I),_.setRawGraph(null),_.setGraphIsEmpty(!0);const D=rr.getState().message,U=D&&D.includes("Authentication required");!U&&x&&De.getState().setQueryLabel(""),U?console.log("Keep queryLabel for post-login reload"):_.setLastSuccessfulQueryLabel(""),console.log(`Graph data is empty, created graph with empty graph node. Auth error: ${U}`)}else{const I=uoe(M);M.buildDynamicMap(),_.setSigmaGraph(I),_.setRawGraph(M),_.setGraphIsEmpty(!1),_.setLastSuccessfulQueryLabel(x),_.setMoveToSelectedNode(!0)}d.current=!0,p.current=!0,v.current=!1,_.setIsFetching(!1),(!M||!M.nodes||M.nodes.length===0)&&!x&&(g.current=!0)}).catch(C=>{console.error("Error fetching graph data:",C);const _=ze.getState();_.setIsFetching(!1),d.current=!1,v.current=!1,_.setGraphDataFetchAttempted(!1),_.setLastSuccessfulQueryLabel("")})}},[t,a,o,s,e]),w.useEffect(()=>{l&&((async x=>{var R,O,N,C,_,M;if(!(!x||!r||!n))try{const I=n.getNode(x);if(!I){console.error("Node not found:",x);return}const D=I.labels[0];if(!D){console.error("Node has no label:",x);return}const U=await QB(D,2,1e3);if(!U||!U.nodes||!U.edges){console.error("Failed to fetch extended graph");return}const $=[];for(const ne of U.nodes){sk(ne.id,{global:!0});const xe=(R=ne.properties)==null?void 0:R.entity_type,Se=jO(xe);$.push({id:ne.id,labels:ne.labels,properties:ne.properties,size:10,x:Math.random(),y:Math.random(),color:Se,degree:0})}const B=[];for(const ne of U.edges)B.push({id:ne.id,source:ne.source,target:ne.target,type:ne.type,properties:ne.properties,dynamicId:""});const W={};r.forEachNode(ne=>{W[ne]={x:r.getNodeAttribute(ne,"x"),y:r.getNodeAttribute(ne,"y")}});const K=new Set(r.nodes()),H=new Set,G=new Set,z=1;let Y=0,L=Number.MAX_SAFE_INTEGER,V=0;r.forEachNode(ne=>{const xe=r.degree(ne);Y=Math.max(Y,xe)}),r.forEachEdge(ne=>{const xe=r.getEdgeAttribute(ne,"originalWeight")||1;L=Math.min(L,xe),V=Math.max(V,xe)});for(const ne of $){if(K.has(ne.id))continue;B.some(Se=>Se.source===x&&Se.target===ne.id||Se.target===x&&Se.source===ne.id)&&H.add(ne.id)}const j=new Map,P=new Map,Z=new Set;for(const ne of B){const xe=K.has(ne.source)||H.has(ne.source),Se=K.has(ne.target)||H.has(ne.target);xe&&Se?(G.add(ne.id),H.has(ne.source)?j.set(ne.source,(j.get(ne.source)||0)+1):K.has(ne.source)&&P.set(ne.source,(P.get(ne.source)||0)+1),H.has(ne.target)?j.set(ne.target,(j.get(ne.target)||0)+1):K.has(ne.target)&&P.set(ne.target,(P.get(ne.target)||0)+1)):(r.hasNode(ne.source)?Z.add(ne.source):H.has(ne.source)&&(Z.add(ne.source),j.set(ne.source,(j.get(ne.source)||0)+1)),r.hasNode(ne.target)?Z.add(ne.target):H.has(ne.target)&&(Z.add(ne.target),j.set(ne.target,(j.get(ne.target)||0)+1)))}const Q=(ne,xe,Se,be)=>{const J=be-Se||1,pe=w0-li;for(const ke of xe)if(ne.hasNode(ke)){let he=ne.degree(ke);he+=1;const Ee=Math.min(he,be+1),se=Math.round(li+pe*Math.pow((Ee-Se)/J,.5)),Be=ne.getNodeAttribute(ke,"size");se>Be&&ne.setNodeAttribute(ke,"size",se)}},oe=(ne,xe,Se)=>{const be=De.getState().minEdgeSize,J=De.getState().maxEdgeSize,pe=Se-xe||1,ke=J-be;ne.forEachEdge(he=>{const Ee=ne.getEdgeAttribute(he,"originalWeight")||1,se=be+ke*Math.pow((Ee-xe)/pe,.5);ne.setEdgeAttribute(he,"size",se)})};if(H.size===0){Q(r,Z,z,Y),Ft.info(e("graphPanel.propertiesView.node.noNewNodes"));return}for(const[,ne]of j.entries())Y=Math.max(Y,ne);for(const[ne,xe]of P.entries()){const be=r.degree(ne)+xe;Y=Math.max(Y,be)}const ae=Y-z||1,ce=w0-li,Re=((O=ze.getState().sigmaInstance)==null?void 0:O.getCamera().ratio)||1,ie=Math.max(Math.sqrt(I.size)*4,Math.sqrt(H.size)*3)/Re;sk(Date.now().toString(),{global:!0});const Te=Math.random()*2*Math.PI;console.log("nodeSize:",I.size,"nodesToAdd:",H.size),console.log("cameraRatio:",Math.round(Re*100)/100,"spreadFactor:",Math.round(ie*100)/100);for(const ne of H){const xe=$.find(Ee=>Ee.id===ne),Se=j.get(ne)||0,be=Math.min(Se,Y+1),J=Math.round(li+ce*Math.pow((be-z)/ae,.5)),pe=2*Math.PI*(Array.from(H).indexOf(ne)/H.size),ke=((N=W[ne])==null?void 0:N.x)||W[I.id].x+Math.cos(Te+pe)*ie,he=((C=W[ne])==null?void 0:C.y)||W[I.id].y+Math.sin(Te+pe)*ie;r.addNode(ne,{label:xe.labels.join(", "),color:xe.color,x:ke,y:he,size:J,borderColor:E0,borderSize:.2}),n.getNode(ne)||(xe.size=J,xe.x=ke,xe.y=he,xe.degree=Se,n.nodes.push(xe),n.nodeIdMap[ne]=n.nodes.length-1)}for(const ne of G){const xe=B.find(be=>be.id===ne);if(r.hasEdge(xe.source,xe.target))continue;const Se=((_=xe.properties)==null?void 0:_.weight)!==void 0?Number(xe.properties.weight):1;L=Math.min(L,Se),V=Math.max(V,Se),xe.dynamicId=r.addEdge(xe.source,xe.target,{label:((M=xe.properties)==null?void 0:M.keywords)||void 0,size:Se,originalWeight:Se,type:"curvedNoArrow"}),n.getEdge(xe.id,!1)?console.error("Edge already exists in rawGraph:",xe.id):(n.edges.push(xe),n.edgeIdMap[xe.id]=n.edges.length-1,n.edgeDynamicIdMap[xe.dynamicId]=n.edges.length-1)}if(n.buildDynamicMap(),ze.getState().resetSearchEngine(),Q(r,Z,z,Y),oe(r,L,V),r.hasNode(x)){const ne=r.degree(x),xe=Math.min(ne,Y+1),Se=Math.round(li+ce*Math.pow((xe-z)/ae,.5));r.setNodeAttribute(x,"size",Se),I.size=Se,I.degree=ne}}catch(I){console.error("Error expanding node:",I)}})(l),window.setTimeout(()=>{ze.getState().triggerNodeExpand(null)},0))},[l,r,n,e]);const y=w.useCallback((A,x)=>{const R=new Set([A]);return x.forEachNode(O=>{if(O===A)return;const N=x.neighbors(O);N.length===1&&N[0]===A&&R.add(O)}),R},[]);return w.useEffect(()=>{u&&((x=>{if(!(!x||!r||!n))try{const R=ze.getState();if(!r.hasNode(x)){console.error("Node not found:",x);return}const O=y(x,r);if(O.size===r.nodes().length){Ft.error(e("graphPanel.propertiesView.node.deleteAllNodesError"));return}R.clearSelection();for(const N of O){r.dropNode(N);const C=n.nodeIdMap[N];if(C!==void 0){const _=n.edges.filter(M=>M.source===N||M.target===N);for(const M of _){const I=n.edgeIdMap[M.id];if(I!==void 0){n.edges.splice(I,1);for(const[D,U]of Object.entries(n.edgeIdMap))U>I&&(n.edgeIdMap[D]=U-1);delete n.edgeIdMap[M.id],delete n.edgeDynamicIdMap[M.dynamicId]}}n.nodes.splice(C,1);for(const[M,I]of Object.entries(n.nodeIdMap))I>C&&(n.nodeIdMap[M]=I-1);delete n.nodeIdMap[N]}}n.buildDynamicMap(),ze.getState().resetSearchEngine(),O.size>1&&Ft.info(e("graphPanel.propertiesView.node.nodesRemoved",{count:O.size}))}catch(R){console.error("Error pruning node:",R)}})(u),window.setTimeout(()=>{ze.getState().triggerNodePrune(null)},0))},[u,r,n,y,e]),{lightrageGraph:w.useCallback(()=>{if(r)return r;console.log("Creating new Sigma graph instance");const A=new Rc;return ze.getState().setSigmaGraph(A),A},[r]),getNode:m,getEdge:b}},foe=()=>{const{getNode:e,getEdge:t}=doe(),n=ze.use.selectedNode(),r=ze.use.focusedNode(),a=ze.use.selectedEdge(),o=ze.use.focusedEdge(),[s,l]=w.useState(null),[u,d]=w.useState(null);return w.useEffect(()=>{let p=null,g=null;r?(p="node",g=e(r)):n?(p="node",g=e(n)):o?(p="edge",g=t(o,!0)):a&&(p="edge",g=t(a,!0)),g?(p=="node"?l(poe(g)):l(goe(g)),d(p)):(l(null),d(null))},[r,n,o,a,l,d,e,t]),s?E.jsx("div",{className:"bg-background/80 max-w-xs rounded-lg border-2 p-2 text-xs backdrop-blur-lg",children:u=="node"?E.jsx(hoe,{node:s}):E.jsx(moe,{edge:s})}):E.jsx(E.Fragment,{})},poe=e=>{const t=ze.getState(),n=[];if(t.sigmaGraph&&t.rawGraph)try{if(!t.sigmaGraph.hasNode(e.id))return{...e,relationships:[]};const r=t.sigmaGraph.edges(e.id);for(const a of r){if(!t.sigmaGraph.hasEdge(a))continue;const o=t.rawGraph.getEdge(a,!0);if(o){const l=e.id===o.source?o.target:o.source;if(!t.sigmaGraph.hasNode(l))continue;const u=t.rawGraph.getNode(l);u&&n.push({type:"Neighbour",id:l,label:u.properties.entity_id?u.properties.entity_id:u.labels.join(", ")})}}}catch(r){console.error("Error refining node properties:",r)}return{...e,relationships:n}},goe=e=>{const t=ze.getState();let n,r;if(t.sigmaGraph&&t.rawGraph)try{if(!t.sigmaGraph.hasEdge(e.id))return{...e,sourceNode:void 0,targetNode:void 0};t.sigmaGraph.hasNode(e.source)&&(n=t.rawGraph.getNode(e.source)),t.sigmaGraph.hasNode(e.target)&&(r=t.rawGraph.getNode(e.target))}catch(a){console.error("Error refining edge properties:",a)}return{...e,sourceNode:n,targetNode:r}},ra=({name:e,value:t,onClick:n,tooltip:r})=>{const{t:a}=Et(),o=s=>{const l=`graphPanel.propertiesView.node.propertyNames.${s}`,u=a(l);return u===l?s:u};return E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("span",{className:"text-primary/60 tracking-wide whitespace-nowrap",children:o(e)}),":",E.jsx(Jn,{className:"hover:bg-primary/20 rounded p-1 overflow-hidden text-ellipsis",tooltipClassName:"max-w-80",text:t,tooltip:r||(typeof t=="string"?t:JSON.stringify(t,null,2)),side:"left",onClick:n})]})},hoe=({node:e})=>{const{t}=Et(),n=()=>{ze.getState().triggerNodeExpand(e.id)},r=()=>{ze.getState().triggerNodePrune(e.id)};return E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsxs("div",{className:"flex justify-between items-center",children:[E.jsx("h3",{className:"text-md pl-1 font-bold tracking-wide text-blue-700",children:t("graphPanel.propertiesView.node.title")}),E.jsxs("div",{className:"flex gap-3",children:[E.jsx(nt,{size:"icon",variant:"ghost",className:"h-7 w-7 border border-gray-400 hover:bg-gray-200 dark:border-gray-600 dark:hover:bg-gray-700",onClick:n,tooltip:t("graphPanel.propertiesView.node.expandNode"),children:E.jsx(SZ,{className:"h-4 w-4 text-gray-700 dark:text-gray-300"})}),E.jsx(nt,{size:"icon",variant:"ghost",className:"h-7 w-7 border border-gray-400 hover:bg-gray-200 dark:border-gray-600 dark:hover:bg-gray-700",onClick:r,tooltip:t("graphPanel.propertiesView.node.pruneNode"),children:E.jsx(VZ,{className:"h-4 w-4 text-gray-900 dark:text-gray-300"})})]})]}),E.jsxs("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:[E.jsx(ra,{name:t("graphPanel.propertiesView.node.id"),value:e.id}),E.jsx(ra,{name:t("graphPanel.propertiesView.node.labels"),value:e.labels.join(", "),onClick:()=>{ze.getState().setSelectedNode(e.id,!0)}}),E.jsx(ra,{name:t("graphPanel.propertiesView.node.degree"),value:e.degree})]}),E.jsx("h3",{className:"text-md pl-1 font-bold tracking-wide text-amber-700",children:t("graphPanel.propertiesView.node.properties")}),E.jsx("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:Object.keys(e.properties).sort().map(a=>E.jsx(ra,{name:a,value:e.properties[a]},a))}),e.relationships.length>0&&E.jsxs(E.Fragment,{children:[E.jsx("h3",{className:"text-md pl-1 font-bold tracking-wide text-emerald-700",children:t("graphPanel.propertiesView.node.relationships")}),E.jsx("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:e.relationships.map(({type:a,id:o,label:s})=>E.jsx(ra,{name:a,value:s,onClick:()=>{ze.getState().setSelectedNode(o,!0)}},o))})]})]})},moe=({edge:e})=>{const{t}=Et();return E.jsxs("div",{className:"flex flex-col gap-2",children:[E.jsx("h3",{className:"text-md pl-1 font-bold tracking-wide text-violet-700",children:t("graphPanel.propertiesView.edge.title")}),E.jsxs("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:[E.jsx(ra,{name:t("graphPanel.propertiesView.edge.id"),value:e.id}),e.type&&E.jsx(ra,{name:t("graphPanel.propertiesView.edge.type"),value:e.type}),E.jsx(ra,{name:t("graphPanel.propertiesView.edge.source"),value:e.sourceNode?e.sourceNode.labels.join(", "):e.source,onClick:()=>{ze.getState().setSelectedNode(e.source,!0)}}),E.jsx(ra,{name:t("graphPanel.propertiesView.edge.target"),value:e.targetNode?e.targetNode.labels.join(", "):e.target,onClick:()=>{ze.getState().setSelectedNode(e.target,!0)}})]}),E.jsx("h3",{className:"text-md pl-1 font-bold tracking-wide text-amber-700",children:t("graphPanel.propertiesView.edge.properties")}),E.jsx("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:Object.keys(e.properties).sort().map(n=>E.jsx(ra,{name:n,value:e.properties[n]},n))})]})},boe=()=>{const{t:e}=Et(),t=De.use.graphQueryMaxDepth(),n=De.use.graphMaxNodes();return E.jsxs("div",{className:"absolute bottom-4 left-[calc(1rem+2.5rem)] flex items-center gap-2 text-xs text-gray-400",children:[E.jsxs("div",{children:[e("graphPanel.sideBar.settings.depth"),": ",t]}),E.jsxs("div",{children:[e("graphPanel.sideBar.settings.max"),": ",n]})]})},Ei=w.forwardRef(({className:e,...t},n)=>E.jsx("div",{ref:n,className:Me("bg-card text-card-foreground rounded-xl border shadow",e),...t}));Ei.displayName="Card";const _c=w.forwardRef(({className:e,...t},n)=>E.jsx("div",{ref:n,className:Me("flex flex-col space-y-1.5 p-6",e),...t}));_c.displayName="CardHeader";const Nc=w.forwardRef(({className:e,...t},n)=>E.jsx("div",{ref:n,className:Me("leading-none font-semibold tracking-tight",e),...t}));Nc.displayName="CardTitle";const Cp=w.forwardRef(({className:e,...t},n)=>E.jsx("div",{ref:n,className:Me("text-muted-foreground text-sm",e),...t}));Cp.displayName="CardDescription";const Oc=w.forwardRef(({className:e,...t},n)=>E.jsx("div",{ref:n,className:Me("p-6 pt-0",e),...t}));Oc.displayName="CardContent";const yoe=w.forwardRef(({className:e,...t},n)=>E.jsx("div",{ref:n,className:Me("flex items-center p-6 pt-0",e),...t}));yoe.displayName="CardFooter";function voe(e,t){return w.useReducer((n,r)=>t[n][r]??n,e)}var VT="ScrollArea",[U5,y0e]=$r(VT),[Soe,Rr]=U5(VT),G5=w.forwardRef((e,t)=>{const{__scopeScrollArea:n,type:r="hover",dir:a,scrollHideDelay:o=600,...s}=e,[l,u]=w.useState(null),[d,p]=w.useState(null),[g,m]=w.useState(null),[b,v]=w.useState(null),[y,k]=w.useState(null),[A,x]=w.useState(0),[R,O]=w.useState(0),[N,C]=w.useState(!1),[_,M]=w.useState(!1),I=mt(t,U=>u(U)),D=yp(a);return E.jsx(Soe,{scope:n,type:r,dir:D,scrollHideDelay:o,scrollArea:l,viewport:d,onViewportChange:p,content:g,onContentChange:m,scrollbarX:b,onScrollbarXChange:v,scrollbarXEnabled:N,onScrollbarXEnabledChange:C,scrollbarY:y,onScrollbarYChange:k,scrollbarYEnabled:_,onScrollbarYEnabledChange:M,onCornerWidthChange:x,onCornerHeightChange:O,children:E.jsx(Je.div,{dir:D,...s,ref:I,style:{position:"relative","--radix-scroll-area-corner-width":A+"px","--radix-scroll-area-corner-height":R+"px",...e.style}})})});G5.displayName=VT;var H5="ScrollAreaViewport",$5=w.forwardRef((e,t)=>{const{__scopeScrollArea:n,children:r,nonce:a,...o}=e,s=Rr(H5,n),l=w.useRef(null),u=mt(t,l,s.onViewportChange);return E.jsxs(E.Fragment,{children:[E.jsx("style",{dangerouslySetInnerHTML:{__html:"[data-radix-scroll-area-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-scroll-area-viewport]::-webkit-scrollbar{display:none}"},nonce:a}),E.jsx(Je.div,{"data-radix-scroll-area-viewport":"",...o,ref:u,style:{overflowX:s.scrollbarXEnabled?"scroll":"hidden",overflowY:s.scrollbarYEnabled?"scroll":"hidden",...e.style},children:E.jsx("div",{ref:s.onContentChange,style:{minWidth:"100%",display:"table"},children:r})})]})});$5.displayName=H5;var da="ScrollAreaScrollbar",WT=w.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=Rr(da,e.__scopeScrollArea),{onScrollbarXEnabledChange:o,onScrollbarYEnabledChange:s}=a,l=e.orientation==="horizontal";return w.useEffect(()=>(l?o(!0):s(!0),()=>{l?o(!1):s(!1)}),[l,o,s]),a.type==="hover"?E.jsx(Eoe,{...r,ref:t,forceMount:n}):a.type==="scroll"?E.jsx(woe,{...r,ref:t,forceMount:n}):a.type==="auto"?E.jsx(q5,{...r,ref:t,forceMount:n}):a.type==="always"?E.jsx(YT,{...r,ref:t}):null});WT.displayName=da;var Eoe=w.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=Rr(da,e.__scopeScrollArea),[o,s]=w.useState(!1);return w.useEffect(()=>{const l=a.scrollArea;let u=0;if(l){const d=()=>{window.clearTimeout(u),s(!0)},p=()=>{u=window.setTimeout(()=>s(!1),a.scrollHideDelay)};return l.addEventListener("pointerenter",d),l.addEventListener("pointerleave",p),()=>{window.clearTimeout(u),l.removeEventListener("pointerenter",d),l.removeEventListener("pointerleave",p)}}},[a.scrollArea,a.scrollHideDelay]),E.jsx(Tr,{present:n||o,children:E.jsx(q5,{"data-state":o?"visible":"hidden",...r,ref:t})})}),woe=w.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=Rr(da,e.__scopeScrollArea),o=e.orientation==="horizontal",s=Np(()=>u("SCROLL_END"),100),[l,u]=voe("hidden",{hidden:{SCROLL:"scrolling"},scrolling:{SCROLL_END:"idle",POINTER_ENTER:"interacting"},interacting:{SCROLL:"interacting",POINTER_LEAVE:"idle"},idle:{HIDE:"hidden",SCROLL:"scrolling",POINTER_ENTER:"interacting"}});return w.useEffect(()=>{if(l==="idle"){const d=window.setTimeout(()=>u("HIDE"),a.scrollHideDelay);return()=>window.clearTimeout(d)}},[l,a.scrollHideDelay,u]),w.useEffect(()=>{const d=a.viewport,p=o?"scrollLeft":"scrollTop";if(d){let g=d[p];const m=()=>{const b=d[p];g!==b&&(u("SCROLL"),s()),g=b};return d.addEventListener("scroll",m),()=>d.removeEventListener("scroll",m)}},[a.viewport,o,u,s]),E.jsx(Tr,{present:n||l!=="hidden",children:E.jsx(YT,{"data-state":l==="hidden"?"hidden":"visible",...r,ref:t,onPointerEnter:Ke(e.onPointerEnter,()=>u("POINTER_ENTER")),onPointerLeave:Ke(e.onPointerLeave,()=>u("POINTER_LEAVE"))})})}),q5=w.forwardRef((e,t)=>{const n=Rr(da,e.__scopeScrollArea),{forceMount:r,...a}=e,[o,s]=w.useState(!1),l=e.orientation==="horizontal",u=Np(()=>{if(n.viewport){const d=n.viewport.offsetWidth<n.viewport.scrollWidth,p=n.viewport.offsetHeight<n.viewport.scrollHeight;s(l?d:p)}},10);return zs(n.viewport,u),zs(n.content,u),E.jsx(Tr,{present:r||o,children:E.jsx(YT,{"data-state":o?"visible":"hidden",...a,ref:t})})}),YT=w.forwardRef((e,t)=>{const{orientation:n="vertical",...r}=e,a=Rr(da,e.__scopeScrollArea),o=w.useRef(null),s=w.useRef(0),[l,u]=w.useState({content:0,viewport:0,scrollbar:{size:0,paddingStart:0,paddingEnd:0}}),d=X5(l.viewport,l.content),p={...r,sizes:l,onSizesChange:u,hasThumb:d>0&&d<1,onThumbChange:m=>o.current=m,onThumbPointerUp:()=>s.current=0,onThumbPointerDown:m=>s.current=m};function g(m,b){return Coe(m,s.current,l,b)}return n==="horizontal"?E.jsx(xoe,{...p,ref:t,onThumbPositionChange:()=>{if(a.viewport&&o.current){const m=a.viewport.scrollLeft,b=UO(m,l,a.dir);o.current.style.transform=`translate3d(${b}px, 0, 0)`}},onWheelScroll:m=>{a.viewport&&(a.viewport.scrollLeft=m)},onDragScroll:m=>{a.viewport&&(a.viewport.scrollLeft=g(m,a.dir))}}):n==="vertical"?E.jsx(koe,{...p,ref:t,onThumbPositionChange:()=>{if(a.viewport&&o.current){const m=a.viewport.scrollTop,b=UO(m,l);o.current.style.transform=`translate3d(0, ${b}px, 0)`}},onWheelScroll:m=>{a.viewport&&(a.viewport.scrollTop=m)},onDragScroll:m=>{a.viewport&&(a.viewport.scrollTop=g(m))}}):null}),xoe=w.forwardRef((e,t)=>{const{sizes:n,onSizesChange:r,...a}=e,o=Rr(da,e.__scopeScrollArea),[s,l]=w.useState(),u=w.useRef(null),d=mt(t,u,o.onScrollbarXChange);return w.useEffect(()=>{u.current&&l(getComputedStyle(u.current))},[u]),E.jsx(W5,{"data-orientation":"horizontal",...a,ref:d,sizes:n,style:{bottom:0,left:o.dir==="rtl"?"var(--radix-scroll-area-corner-width)":0,right:o.dir==="ltr"?"var(--radix-scroll-area-corner-width)":0,"--radix-scroll-area-thumb-width":_p(n)+"px",...e.style},onThumbPointerDown:p=>e.onThumbPointerDown(p.x),onDragScroll:p=>e.onDragScroll(p.x),onWheelScroll:(p,g)=>{if(o.viewport){const m=o.viewport.scrollLeft+p.deltaX;e.onWheelScroll(m),Q5(m,g)&&p.preventDefault()}},onResize:()=>{u.current&&o.viewport&&s&&r({content:o.viewport.scrollWidth,viewport:o.viewport.offsetWidth,scrollbar:{size:u.current.clientWidth,paddingStart:Df(s.paddingLeft),paddingEnd:Df(s.paddingRight)}})}})}),koe=w.forwardRef((e,t)=>{const{sizes:n,onSizesChange:r,...a}=e,o=Rr(da,e.__scopeScrollArea),[s,l]=w.useState(),u=w.useRef(null),d=mt(t,u,o.onScrollbarYChange);return w.useEffect(()=>{u.current&&l(getComputedStyle(u.current))},[u]),E.jsx(W5,{"data-orientation":"vertical",...a,ref:d,sizes:n,style:{top:0,right:o.dir==="ltr"?0:void 0,left:o.dir==="rtl"?0:void 0,bottom:"var(--radix-scroll-area-corner-height)","--radix-scroll-area-thumb-height":_p(n)+"px",...e.style},onThumbPointerDown:p=>e.onThumbPointerDown(p.y),onDragScroll:p=>e.onDragScroll(p.y),onWheelScroll:(p,g)=>{if(o.viewport){const m=o.viewport.scrollTop+p.deltaY;e.onWheelScroll(m),Q5(m,g)&&p.preventDefault()}},onResize:()=>{u.current&&o.viewport&&s&&r({content:o.viewport.scrollHeight,viewport:o.viewport.offsetHeight,scrollbar:{size:u.current.clientHeight,paddingStart:Df(s.paddingTop),paddingEnd:Df(s.paddingBottom)}})}})}),[Toe,V5]=U5(da),W5=w.forwardRef((e,t)=>{const{__scopeScrollArea:n,sizes:r,hasThumb:a,onThumbChange:o,onThumbPointerUp:s,onThumbPointerDown:l,onThumbPositionChange:u,onDragScroll:d,onWheelScroll:p,onResize:g,...m}=e,b=Rr(da,n),[v,y]=w.useState(null),k=mt(t,I=>y(I)),A=w.useRef(null),x=w.useRef(""),R=b.viewport,O=r.content-r.viewport,N=yn(p),C=yn(u),_=Np(g,10);function M(I){if(A.current){const D=I.clientX-A.current.left,U=I.clientY-A.current.top;d({x:D,y:U})}}return w.useEffect(()=>{const I=D=>{const U=D.target;(v==null?void 0:v.contains(U))&&N(D,O)};return document.addEventListener("wheel",I,{passive:!1}),()=>document.removeEventListener("wheel",I,{passive:!1})},[R,v,O,N]),w.useEffect(C,[r,C]),zs(v,_),zs(b.content,_),E.jsx(Toe,{scope:n,scrollbar:v,hasThumb:a,onThumbChange:yn(o),onThumbPointerUp:yn(s),onThumbPositionChange:C,onThumbPointerDown:yn(l),children:E.jsx(Je.div,{...m,ref:k,style:{position:"absolute",...m.style},onPointerDown:Ke(e.onPointerDown,I=>{I.button===0&&(I.target.setPointerCapture(I.pointerId),A.current=v.getBoundingClientRect(),x.current=document.body.style.webkitUserSelect,document.body.style.webkitUserSelect="none",b.viewport&&(b.viewport.style.scrollBehavior="auto"),M(I))}),onPointerMove:Ke(e.onPointerMove,M),onPointerUp:Ke(e.onPointerUp,I=>{const D=I.target;D.hasPointerCapture(I.pointerId)&&D.releasePointerCapture(I.pointerId),document.body.style.webkitUserSelect=x.current,b.viewport&&(b.viewport.style.scrollBehavior=""),A.current=null})})})}),If="ScrollAreaThumb",Y5=w.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=V5(If,e.__scopeScrollArea);return E.jsx(Tr,{present:n||a.hasThumb,children:E.jsx(Aoe,{ref:t,...r})})}),Aoe=w.forwardRef((e,t)=>{const{__scopeScrollArea:n,style:r,...a}=e,o=Rr(If,n),s=V5(If,n),{onThumbPositionChange:l}=s,u=mt(t,g=>s.onThumbChange(g)),d=w.useRef(void 0),p=Np(()=>{d.current&&(d.current(),d.current=void 0)},100);return w.useEffect(()=>{const g=o.viewport;if(g){const m=()=>{if(p(),!d.current){const b=_oe(g,l);d.current=b,l()}};return l(),g.addEventListener("scroll",m),()=>g.removeEventListener("scroll",m)}},[o.viewport,p,l]),E.jsx(Je.div,{"data-state":s.hasThumb?"visible":"hidden",...a,ref:u,style:{width:"var(--radix-scroll-area-thumb-width)",height:"var(--radix-scroll-area-thumb-height)",...r},onPointerDownCapture:Ke(e.onPointerDownCapture,g=>{const b=g.target.getBoundingClientRect(),v=g.clientX-b.left,y=g.clientY-b.top;s.onThumbPointerDown({x:v,y})}),onPointerUp:Ke(e.onPointerUp,s.onThumbPointerUp)})});Y5.displayName=If;var KT="ScrollAreaCorner",K5=w.forwardRef((e,t)=>{const n=Rr(KT,e.__scopeScrollArea),r=!!(n.scrollbarX&&n.scrollbarY);return n.type!=="scroll"&&r?E.jsx(Roe,{...e,ref:t}):null});K5.displayName=KT;var Roe=w.forwardRef((e,t)=>{const{__scopeScrollArea:n,...r}=e,a=Rr(KT,n),[o,s]=w.useState(0),[l,u]=w.useState(0),d=!!(o&&l);return zs(a.scrollbarX,()=>{var g;const p=((g=a.scrollbarX)==null?void 0:g.offsetHeight)||0;a.onCornerHeightChange(p),u(p)}),zs(a.scrollbarY,()=>{var g;const p=((g=a.scrollbarY)==null?void 0:g.offsetWidth)||0;a.onCornerWidthChange(p),s(p)}),d?E.jsx(Je.div,{...r,ref:t,style:{width:o,height:l,position:"absolute",right:a.dir==="ltr"?0:void 0,left:a.dir==="rtl"?0:void 0,bottom:0,...e.style}}):null});function Df(e){return e?parseInt(e,10):0}function X5(e,t){const n=e/t;return isNaN(n)?0:n}function _p(e){const t=X5(e.viewport,e.content),n=e.scrollbar.paddingStart+e.scrollbar.paddingEnd,r=(e.scrollbar.size-n)*t;return Math.max(r,18)}function Coe(e,t,n,r="ltr"){const a=_p(n),o=a/2,s=t||o,l=a-s,u=n.scrollbar.paddingStart+s,d=n.scrollbar.size-n.scrollbar.paddingEnd-l,p=n.content-n.viewport,g=r==="ltr"?[0,p]:[p*-1,0];return Z5([u,d],g)(e)}function UO(e,t,n="ltr"){const r=_p(t),a=t.scrollbar.paddingStart+t.scrollbar.paddingEnd,o=t.scrollbar.size-a,s=t.content-t.viewport,l=o-r,u=n==="ltr"?[0,s]:[s*-1,0],d=z0(e,u);return Z5([0,s],[0,l])(d)}function Z5(e,t){return n=>{if(e[0]===e[1]||t[0]===t[1])return t[0];const r=(t[1]-t[0])/(e[1]-e[0]);return t[0]+r*(n-e[0])}}function Q5(e,t){return e>0&&e<t}var _oe=(e,t=()=>{})=>{let n={left:e.scrollLeft,top:e.scrollTop},r=0;return function a(){const o={left:e.scrollLeft,top:e.scrollTop},s=n.left!==o.left,l=n.top!==o.top;(s||l)&&t(),n=o,r=window.requestAnimationFrame(a)}(),()=>window.cancelAnimationFrame(r)};function Np(e,t){const n=yn(e),r=w.useRef(0);return w.useEffect(()=>()=>window.clearTimeout(r.current),[]),w.useCallback(()=>{window.clearTimeout(r.current),r.current=window.setTimeout(n,t)},[n,t])}function zs(e,t){const n=yn(t);Rn(()=>{let r=0;if(e){const a=new ResizeObserver(()=>{cancelAnimationFrame(r),r=window.requestAnimationFrame(n)});return a.observe(e),()=>{window.cancelAnimationFrame(r),a.unobserve(e)}}},[e,n])}var J5=G5,Noe=$5,Ooe=K5;const XT=w.forwardRef(({className:e,children:t,...n},r)=>E.jsxs(J5,{ref:r,className:Me("relative overflow-hidden",e),...n,children:[E.jsx(Noe,{className:"h-full w-full rounded-[inherit]",children:t}),E.jsx(eG,{}),E.jsx(Ooe,{})]}));XT.displayName=J5.displayName;const eG=w.forwardRef(({className:e,orientation:t="vertical",...n},r)=>E.jsx(WT,{ref:r,orientation:t,className:Me("flex touch-none transition-colors select-none",t==="vertical"&&"h-full w-2.5 border-l border-l-transparent p-[1px]",t==="horizontal"&&"h-2.5 flex-col border-t border-t-transparent p-[1px]",e),...n,children:E.jsx(Y5,{className:"bg-border relative flex-1 rounded-full"})}));eG.displayName=WT.displayName;const Ioe=["person","category","geo","location","organization","event","equipment","weapon","animal","unknown","technology"],Doe=({className:e})=>{const{t}=Et(),n=ze.use.typeColorMap();return!n||n.size===0?null:E.jsxs(Ei,{className:`p-2 max-w-xs ${e}`,children:[E.jsx("h3",{className:"text-sm font-medium mb-2",children:t("graphPanel.legend")}),E.jsx(XT,{className:"max-h-40",children:E.jsx("div",{className:"flex flex-col gap-1",children:Array.from(n.entries()).map(([r,a])=>E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("div",{className:"w-4 h-4 rounded-full",style:{backgroundColor:a}}),E.jsx("span",{className:"text-xs truncate",title:r,children:Ioe.includes(r.toLowerCase())?t(`graphPanel.nodeTypes.${r.toLowerCase()}`):r})]},r))})})]})},Loe=()=>{const{t:e}=Et(),t=De.use.showLegend(),n=De.use.setShowLegend(),r=w.useCallback(()=>{n(!t)},[t,n]);return E.jsx(nt,{variant:Er,onClick:r,tooltip:e("graphPanel.sideBar.legendControl.toggleLegend"),size:"icon",children:E.jsx(rZ,{})})},GO={allowInvalidContainer:!0,defaultNodeType:"default",defaultEdgeType:"curvedNoArrow",renderEdgeLabels:!1,edgeProgramClasses:{arrow:j4,curvedArrow:Une,curvedNoArrow:jne},nodeProgramClasses:{default:xne,circel:tu,point:Zte},labelGridCellSize:60,labelRenderedSizeThreshold:12,enableEdgeEvents:!0,labelColor:{color:"#000",attribute:"labelColor"},edgeLabelColor:{color:"#000",attribute:"labelColor"},edgeLabelSize:8,labelSize:12},Moe=()=>{const e=K4(),t=Ar(),[n,r]=w.useState(null);return w.useEffect(()=>{e({downNode:a=>{r(a.node),t.getGraph().setNodeAttribute(a.node,"highlighted",!0)},mousemovebody:a=>{if(!n)return;const o=t.viewportToGraph(a);t.getGraph().setNodeAttribute(n,"x",o.x),t.getGraph().setNodeAttribute(n,"y",o.y),a.preventSigmaDefault(),a.original.preventDefault(),a.original.stopPropagation()},mouseup:()=>{n&&(r(null),t.getGraph().removeNodeAttribute(n,"highlighted"))},mousedown:a=>{a.original.buttons!==0&&!t.getCustomBBox()&&t.setCustomBBox(t.getBBox())}})},[e,t,n]),null},Poe=()=>{const[e,t]=w.useState(GO),n=w.useRef(null),r=ze.use.selectedNode(),a=ze.use.focusedNode(),o=ze.use.moveToSelectedNode(),s=ze.use.isFetching(),l=De.use.showPropertyPanel(),u=De.use.showNodeSearchBar(),d=De.use.enableNodeDrag(),p=De.use.showLegend();w.useEffect(()=>{t(GO),console.log("Initialized sigma settings")},[]),w.useEffect(()=>()=>{const y=ze.getState().sigmaInstance;if(y)try{y.kill(),ze.getState().setSigmaInstance(null),console.log("Cleared sigma instance on Graphviewer unmount")}catch(k){console.error("Error cleaning up sigma instance:",k)}},[]);const g=w.useCallback(y=>{y===null?ze.getState().setFocusedNode(null):y.type==="nodes"&&ze.getState().setFocusedNode(y.id)},[]),m=w.useCallback(y=>{y===null?ze.getState().setSelectedNode(null):y.type==="nodes"&&ze.getState().setSelectedNode(y.id,!0)},[]),b=w.useMemo(()=>a??r,[a,r]),v=w.useMemo(()=>r?{type:"nodes",id:r}:null,[r]);return E.jsxs("div",{className:"relative h-full w-full overflow-hidden",children:[E.jsxs(qte,{settings:e,className:"!bg-background !size-full overflow-hidden",ref:n,children:[E.jsx(iae,{}),d&&E.jsx(Moe,{}),E.jsx(Gne,{node:b,move:o}),E.jsxs("div",{className:"absolute top-2 left-2 flex items-start gap-2",children:[E.jsx(Uae,{}),u&&E.jsx(zae,{value:v,onFocus:g,onChange:m})]}),E.jsxs("div",{className:"bg-background/60 absolute bottom-2 left-2 flex flex-col rounded-xl border-2 backdrop-blur-lg",children:[E.jsx(oae,{}),E.jsx(sae,{}),E.jsx(lae,{}),E.jsx(Loe,{}),E.jsx(bae,{})]}),l&&E.jsx("div",{className:"absolute top-2 right-2",children:E.jsx(foe,{})}),p&&E.jsx("div",{className:"absolute bottom-10 right-2",children:E.jsx(Doe,{className:"bg-background/60 backdrop-blur-lg"})}),E.jsx(boe,{})]}),s&&E.jsx("div",{className:"absolute inset-0 flex items-center justify-center bg-background/80 z-10",children:E.jsxs("div",{className:"text-center",children:[E.jsx("div",{className:"mb-2 h-8 w-8 animate-spin rounded-full border-4 border-primary border-t-transparent"}),E.jsx("p",{children:"Loading Graph Data..."})]})})]})},tG=w.forwardRef(({className:e,...t},n)=>E.jsx("div",{className:"relative w-full overflow-auto",children:E.jsx("table",{ref:n,className:Me("w-full caption-bottom text-sm",e),...t})}));tG.displayName="Table";const nG=w.forwardRef(({className:e,...t},n)=>E.jsx("thead",{ref:n,className:Me("[&_tr]:border-b",e),...t}));nG.displayName="TableHeader";const rG=w.forwardRef(({className:e,...t},n)=>E.jsx("tbody",{ref:n,className:Me("[&_tr:last-child]:border-0",e),...t}));rG.displayName="TableBody";const Foe=w.forwardRef(({className:e,...t},n)=>E.jsx("tfoot",{ref:n,className:Me("bg-muted/50 border-t font-medium [&>tr]:last:border-b-0",e),...t}));Foe.displayName="TableFooter";const ck=w.forwardRef(({className:e,...t},n)=>E.jsx("tr",{ref:n,className:Me("hover:bg-muted/50 data-[state=selected]:bg-muted border-b transition-colors",e),...t}));ck.displayName="TableRow";const wo=w.forwardRef(({className:e,...t},n)=>E.jsx("th",{ref:n,className:Me("text-muted-foreground h-10 px-2 text-left align-middle font-medium [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",e),...t}));wo.displayName="TableHead";const xo=w.forwardRef(({className:e,...t},n)=>E.jsx("td",{ref:n,className:Me("p-2 align-middle [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",e),...t}));xo.displayName="TableCell";const zoe=w.forwardRef(({className:e,...t},n)=>E.jsx("caption",{ref:n,className:Me("text-muted-foreground mt-4 text-sm",e),...t}));zoe.displayName="TableCaption";function Boe({title:e,description:t,icon:n=gZ,action:r,className:a,...o}){return E.jsxs(Ei,{className:Me("flex w-full flex-col items-center justify-center space-y-6 bg-transparent p-16",a),...o,children:[E.jsx("div",{className:"mr-4 shrink-0 rounded-full border border-dashed p-4",children:E.jsx(n,{className:"text-muted-foreground size-8","aria-hidden":"true"})}),E.jsxs("div",{className:"flex flex-col items-center gap-1.5 text-center",children:[E.jsx(Nc,{children:e}),t?E.jsx(Cp,{children:t}):null]}),r||null]})}var cb={exports:{}},ub,HO;function joe(){if(HO)return ub;HO=1;var e="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED";return ub=e,ub}var db,$O;function Uoe(){if($O)return db;$O=1;var e=joe();function t(){}function n(){}return n.resetWarningCache=t,db=function(){function r(s,l,u,d,p,g){if(g!==e){var m=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw m.name="Invariant Violation",m}}r.isRequired=r;function a(){return r}var o={array:r,bigint:r,bool:r,func:r,number:r,object:r,string:r,symbol:r,any:r,arrayOf:a,element:r,elementType:r,instanceOf:a,node:r,objectOf:a,oneOf:a,oneOfType:a,shape:a,exact:a,checkPropTypes:n,resetWarningCache:t};return o.PropTypes=o,o},db}var qO;function Goe(){return qO||(qO=1,cb.exports=Uoe()()),cb.exports}var Hoe=Goe();const It=un(Hoe),$oe=new Map([["1km","application/vnd.1000minds.decision-model+xml"],["3dml","text/vnd.in3d.3dml"],["3ds","image/x-3ds"],["3g2","video/3gpp2"],["3gp","video/3gp"],["3gpp","video/3gpp"],["3mf","model/3mf"],["7z","application/x-7z-compressed"],["7zip","application/x-7z-compressed"],["123","application/vnd.lotus-1-2-3"],["aab","application/x-authorware-bin"],["aac","audio/x-acc"],["aam","application/x-authorware-map"],["aas","application/x-authorware-seg"],["abw","application/x-abiword"],["ac","application/vnd.nokia.n-gage.ac+xml"],["ac3","audio/ac3"],["acc","application/vnd.americandynamics.acc"],["ace","application/x-ace-compressed"],["acu","application/vnd.acucobol"],["acutc","application/vnd.acucorp"],["adp","audio/adpcm"],["aep","application/vnd.audiograph"],["afm","application/x-font-type1"],["afp","application/vnd.ibm.modcap"],["ahead","application/vnd.ahead.space"],["ai","application/pdf"],["aif","audio/x-aiff"],["aifc","audio/x-aiff"],["aiff","audio/x-aiff"],["air","application/vnd.adobe.air-application-installer-package+zip"],["ait","application/vnd.dvb.ait"],["ami","application/vnd.amiga.ami"],["amr","audio/amr"],["apk","application/vnd.android.package-archive"],["apng","image/apng"],["appcache","text/cache-manifest"],["application","application/x-ms-application"],["apr","application/vnd.lotus-approach"],["arc","application/x-freearc"],["arj","application/x-arj"],["asc","application/pgp-signature"],["asf","video/x-ms-asf"],["asm","text/x-asm"],["aso","application/vnd.accpac.simply.aso"],["asx","video/x-ms-asf"],["atc","application/vnd.acucorp"],["atom","application/atom+xml"],["atomcat","application/atomcat+xml"],["atomdeleted","application/atomdeleted+xml"],["atomsvc","application/atomsvc+xml"],["atx","application/vnd.antix.game-component"],["au","audio/x-au"],["avi","video/x-msvideo"],["avif","image/avif"],["aw","application/applixware"],["azf","application/vnd.airzip.filesecure.azf"],["azs","application/vnd.airzip.filesecure.azs"],["azv","image/vnd.airzip.accelerator.azv"],["azw","application/vnd.amazon.ebook"],["b16","image/vnd.pco.b16"],["bat","application/x-msdownload"],["bcpio","application/x-bcpio"],["bdf","application/x-font-bdf"],["bdm","application/vnd.syncml.dm+wbxml"],["bdoc","application/x-bdoc"],["bed","application/vnd.realvnc.bed"],["bh2","application/vnd.fujitsu.oasysprs"],["bin","application/octet-stream"],["blb","application/x-blorb"],["blorb","application/x-blorb"],["bmi","application/vnd.bmi"],["bmml","application/vnd.balsamiq.bmml+xml"],["bmp","image/bmp"],["book","application/vnd.framemaker"],["box","application/vnd.previewsystems.box"],["boz","application/x-bzip2"],["bpk","application/octet-stream"],["bpmn","application/octet-stream"],["bsp","model/vnd.valve.source.compiled-map"],["btif","image/prs.btif"],["buffer","application/octet-stream"],["bz","application/x-bzip"],["bz2","application/x-bzip2"],["c","text/x-c"],["c4d","application/vnd.clonk.c4group"],["c4f","application/vnd.clonk.c4group"],["c4g","application/vnd.clonk.c4group"],["c4p","application/vnd.clonk.c4group"],["c4u","application/vnd.clonk.c4group"],["c11amc","application/vnd.cluetrust.cartomobile-config"],["c11amz","application/vnd.cluetrust.cartomobile-config-pkg"],["cab","application/vnd.ms-cab-compressed"],["caf","audio/x-caf"],["cap","application/vnd.tcpdump.pcap"],["car","application/vnd.curl.car"],["cat","application/vnd.ms-pki.seccat"],["cb7","application/x-cbr"],["cba","application/x-cbr"],["cbr","application/x-cbr"],["cbt","application/x-cbr"],["cbz","application/x-cbr"],["cc","text/x-c"],["cco","application/x-cocoa"],["cct","application/x-director"],["ccxml","application/ccxml+xml"],["cdbcmsg","application/vnd.contact.cmsg"],["cda","application/x-cdf"],["cdf","application/x-netcdf"],["cdfx","application/cdfx+xml"],["cdkey","application/vnd.mediastation.cdkey"],["cdmia","application/cdmi-capability"],["cdmic","application/cdmi-container"],["cdmid","application/cdmi-domain"],["cdmio","application/cdmi-object"],["cdmiq","application/cdmi-queue"],["cdr","application/cdr"],["cdx","chemical/x-cdx"],["cdxml","application/vnd.chemdraw+xml"],["cdy","application/vnd.cinderella"],["cer","application/pkix-cert"],["cfs","application/x-cfs-compressed"],["cgm","image/cgm"],["chat","application/x-chat"],["chm","application/vnd.ms-htmlhelp"],["chrt","application/vnd.kde.kchart"],["cif","chemical/x-cif"],["cii","application/vnd.anser-web-certificate-issue-initiation"],["cil","application/vnd.ms-artgalry"],["cjs","application/node"],["cla","application/vnd.claymore"],["class","application/octet-stream"],["clkk","application/vnd.crick.clicker.keyboard"],["clkp","application/vnd.crick.clicker.palette"],["clkt","application/vnd.crick.clicker.template"],["clkw","application/vnd.crick.clicker.wordbank"],["clkx","application/vnd.crick.clicker"],["clp","application/x-msclip"],["cmc","application/vnd.cosmocaller"],["cmdf","chemical/x-cmdf"],["cml","chemical/x-cml"],["cmp","application/vnd.yellowriver-custom-menu"],["cmx","image/x-cmx"],["cod","application/vnd.rim.cod"],["coffee","text/coffeescript"],["com","application/x-msdownload"],["conf","text/plain"],["cpio","application/x-cpio"],["cpp","text/x-c"],["cpt","application/mac-compactpro"],["crd","application/x-mscardfile"],["crl","application/pkix-crl"],["crt","application/x-x509-ca-cert"],["crx","application/x-chrome-extension"],["cryptonote","application/vnd.rig.cryptonote"],["csh","application/x-csh"],["csl","application/vnd.citationstyles.style+xml"],["csml","chemical/x-csml"],["csp","application/vnd.commonspace"],["csr","application/octet-stream"],["css","text/css"],["cst","application/x-director"],["csv","text/csv"],["cu","application/cu-seeme"],["curl","text/vnd.curl"],["cww","application/prs.cww"],["cxt","application/x-director"],["cxx","text/x-c"],["dae","model/vnd.collada+xml"],["daf","application/vnd.mobius.daf"],["dart","application/vnd.dart"],["dataless","application/vnd.fdsn.seed"],["davmount","application/davmount+xml"],["dbf","application/vnd.dbf"],["dbk","application/docbook+xml"],["dcr","application/x-director"],["dcurl","text/vnd.curl.dcurl"],["dd2","application/vnd.oma.dd2+xml"],["ddd","application/vnd.fujixerox.ddd"],["ddf","application/vnd.syncml.dmddf+xml"],["dds","image/vnd.ms-dds"],["deb","application/x-debian-package"],["def","text/plain"],["deploy","application/octet-stream"],["der","application/x-x509-ca-cert"],["dfac","application/vnd.dreamfactory"],["dgc","application/x-dgc-compressed"],["dic","text/x-c"],["dir","application/x-director"],["dis","application/vnd.mobius.dis"],["disposition-notification","message/disposition-notification"],["dist","application/octet-stream"],["distz","application/octet-stream"],["djv","image/vnd.djvu"],["djvu","image/vnd.djvu"],["dll","application/octet-stream"],["dmg","application/x-apple-diskimage"],["dmn","application/octet-stream"],["dmp","application/vnd.tcpdump.pcap"],["dms","application/octet-stream"],["dna","application/vnd.dna"],["doc","application/msword"],["docm","application/vnd.ms-word.template.macroEnabled.12"],["docx","application/vnd.openxmlformats-officedocument.wordprocessingml.document"],["dot","application/msword"],["dotm","application/vnd.ms-word.template.macroEnabled.12"],["dotx","application/vnd.openxmlformats-officedocument.wordprocessingml.template"],["dp","application/vnd.osgi.dp"],["dpg","application/vnd.dpgraph"],["dra","audio/vnd.dra"],["drle","image/dicom-rle"],["dsc","text/prs.lines.tag"],["dssc","application/dssc+der"],["dtb","application/x-dtbook+xml"],["dtd","application/xml-dtd"],["dts","audio/vnd.dts"],["dtshd","audio/vnd.dts.hd"],["dump","application/octet-stream"],["dvb","video/vnd.dvb.file"],["dvi","application/x-dvi"],["dwd","application/atsc-dwd+xml"],["dwf","model/vnd.dwf"],["dwg","image/vnd.dwg"],["dxf","image/vnd.dxf"],["dxp","application/vnd.spotfire.dxp"],["dxr","application/x-director"],["ear","application/java-archive"],["ecelp4800","audio/vnd.nuera.ecelp4800"],["ecelp7470","audio/vnd.nuera.ecelp7470"],["ecelp9600","audio/vnd.nuera.ecelp9600"],["ecma","application/ecmascript"],["edm","application/vnd.novadigm.edm"],["edx","application/vnd.novadigm.edx"],["efif","application/vnd.picsel"],["ei6","application/vnd.pg.osasli"],["elc","application/octet-stream"],["emf","image/emf"],["eml","message/rfc822"],["emma","application/emma+xml"],["emotionml","application/emotionml+xml"],["emz","application/x-msmetafile"],["eol","audio/vnd.digital-winds"],["eot","application/vnd.ms-fontobject"],["eps","application/postscript"],["epub","application/epub+zip"],["es","application/ecmascript"],["es3","application/vnd.eszigno3+xml"],["esa","application/vnd.osgi.subsystem"],["esf","application/vnd.epson.esf"],["et3","application/vnd.eszigno3+xml"],["etx","text/x-setext"],["eva","application/x-eva"],["evy","application/x-envoy"],["exe","application/octet-stream"],["exi","application/exi"],["exp","application/express"],["exr","image/aces"],["ext","application/vnd.novadigm.ext"],["ez","application/andrew-inset"],["ez2","application/vnd.ezpix-album"],["ez3","application/vnd.ezpix-package"],["f","text/x-fortran"],["f4v","video/mp4"],["f77","text/x-fortran"],["f90","text/x-fortran"],["fbs","image/vnd.fastbidsheet"],["fcdt","application/vnd.adobe.formscentral.fcdt"],["fcs","application/vnd.isac.fcs"],["fdf","application/vnd.fdf"],["fdt","application/fdt+xml"],["fe_launch","application/vnd.denovo.fcselayout-link"],["fg5","application/vnd.fujitsu.oasysgp"],["fgd","application/x-director"],["fh","image/x-freehand"],["fh4","image/x-freehand"],["fh5","image/x-freehand"],["fh7","image/x-freehand"],["fhc","image/x-freehand"],["fig","application/x-xfig"],["fits","image/fits"],["flac","audio/x-flac"],["fli","video/x-fli"],["flo","application/vnd.micrografx.flo"],["flv","video/x-flv"],["flw","application/vnd.kde.kivio"],["flx","text/vnd.fmi.flexstor"],["fly","text/vnd.fly"],["fm","application/vnd.framemaker"],["fnc","application/vnd.frogans.fnc"],["fo","application/vnd.software602.filler.form+xml"],["for","text/x-fortran"],["fpx","image/vnd.fpx"],["frame","application/vnd.framemaker"],["fsc","application/vnd.fsc.weblaunch"],["fst","image/vnd.fst"],["ftc","application/vnd.fluxtime.clip"],["fti","application/vnd.anser-web-funds-transfer-initiation"],["fvt","video/vnd.fvt"],["fxp","application/vnd.adobe.fxp"],["fxpl","application/vnd.adobe.fxp"],["fzs","application/vnd.fuzzysheet"],["g2w","application/vnd.geoplan"],["g3","image/g3fax"],["g3w","application/vnd.geospace"],["gac","application/vnd.groove-account"],["gam","application/x-tads"],["gbr","application/rpki-ghostbusters"],["gca","application/x-gca-compressed"],["gdl","model/vnd.gdl"],["gdoc","application/vnd.google-apps.document"],["geo","application/vnd.dynageo"],["geojson","application/geo+json"],["gex","application/vnd.geometry-explorer"],["ggb","application/vnd.geogebra.file"],["ggt","application/vnd.geogebra.tool"],["ghf","application/vnd.groove-help"],["gif","image/gif"],["gim","application/vnd.groove-identity-message"],["glb","model/gltf-binary"],["gltf","model/gltf+json"],["gml","application/gml+xml"],["gmx","application/vnd.gmx"],["gnumeric","application/x-gnumeric"],["gpg","application/gpg-keys"],["gph","application/vnd.flographit"],["gpx","application/gpx+xml"],["gqf","application/vnd.grafeq"],["gqs","application/vnd.grafeq"],["gram","application/srgs"],["gramps","application/x-gramps-xml"],["gre","application/vnd.geometry-explorer"],["grv","application/vnd.groove-injector"],["grxml","application/srgs+xml"],["gsf","application/x-font-ghostscript"],["gsheet","application/vnd.google-apps.spreadsheet"],["gslides","application/vnd.google-apps.presentation"],["gtar","application/x-gtar"],["gtm","application/vnd.groove-tool-message"],["gtw","model/vnd.gtw"],["gv","text/vnd.graphviz"],["gxf","application/gxf"],["gxt","application/vnd.geonext"],["gz","application/gzip"],["gzip","application/gzip"],["h","text/x-c"],["h261","video/h261"],["h263","video/h263"],["h264","video/h264"],["hal","application/vnd.hal+xml"],["hbci","application/vnd.hbci"],["hbs","text/x-handlebars-template"],["hdd","application/x-virtualbox-hdd"],["hdf","application/x-hdf"],["heic","image/heic"],["heics","image/heic-sequence"],["heif","image/heif"],["heifs","image/heif-sequence"],["hej2","image/hej2k"],["held","application/atsc-held+xml"],["hh","text/x-c"],["hjson","application/hjson"],["hlp","application/winhlp"],["hpgl","application/vnd.hp-hpgl"],["hpid","application/vnd.hp-hpid"],["hps","application/vnd.hp-hps"],["hqx","application/mac-binhex40"],["hsj2","image/hsj2"],["htc","text/x-component"],["htke","application/vnd.kenameaapp"],["htm","text/html"],["html","text/html"],["hvd","application/vnd.yamaha.hv-dic"],["hvp","application/vnd.yamaha.hv-voice"],["hvs","application/vnd.yamaha.hv-script"],["i2g","application/vnd.intergeo"],["icc","application/vnd.iccprofile"],["ice","x-conference/x-cooltalk"],["icm","application/vnd.iccprofile"],["ico","image/x-icon"],["ics","text/calendar"],["ief","image/ief"],["ifb","text/calendar"],["ifm","application/vnd.shana.informed.formdata"],["iges","model/iges"],["igl","application/vnd.igloader"],["igm","application/vnd.insors.igm"],["igs","model/iges"],["igx","application/vnd.micrografx.igx"],["iif","application/vnd.shana.informed.interchange"],["img","application/octet-stream"],["imp","application/vnd.accpac.simply.imp"],["ims","application/vnd.ms-ims"],["in","text/plain"],["ini","text/plain"],["ink","application/inkml+xml"],["inkml","application/inkml+xml"],["install","application/x-install-instructions"],["iota","application/vnd.astraea-software.iota"],["ipfix","application/ipfix"],["ipk","application/vnd.shana.informed.package"],["irm","application/vnd.ibm.rights-management"],["irp","application/vnd.irepository.package+xml"],["iso","application/x-iso9660-image"],["itp","application/vnd.shana.informed.formtemplate"],["its","application/its+xml"],["ivp","application/vnd.immervision-ivp"],["ivu","application/vnd.immervision-ivu"],["jad","text/vnd.sun.j2me.app-descriptor"],["jade","text/jade"],["jam","application/vnd.jam"],["jar","application/java-archive"],["jardiff","application/x-java-archive-diff"],["java","text/x-java-source"],["jhc","image/jphc"],["jisp","application/vnd.jisp"],["jls","image/jls"],["jlt","application/vnd.hp-jlyt"],["jng","image/x-jng"],["jnlp","application/x-java-jnlp-file"],["joda","application/vnd.joost.joda-archive"],["jp2","image/jp2"],["jpe","image/jpeg"],["jpeg","image/jpeg"],["jpf","image/jpx"],["jpg","image/jpeg"],["jpg2","image/jp2"],["jpgm","video/jpm"],["jpgv","video/jpeg"],["jph","image/jph"],["jpm","video/jpm"],["jpx","image/jpx"],["js","application/javascript"],["json","application/json"],["json5","application/json5"],["jsonld","application/ld+json"],["jsonl","application/jsonl"],["jsonml","application/jsonml+json"],["jsx","text/jsx"],["jxr","image/jxr"],["jxra","image/jxra"],["jxrs","image/jxrs"],["jxs","image/jxs"],["jxsc","image/jxsc"],["jxsi","image/jxsi"],["jxss","image/jxss"],["kar","audio/midi"],["karbon","application/vnd.kde.karbon"],["kdb","application/octet-stream"],["kdbx","application/x-keepass2"],["key","application/x-iwork-keynote-sffkey"],["kfo","application/vnd.kde.kformula"],["kia","application/vnd.kidspiration"],["kml","application/vnd.google-earth.kml+xml"],["kmz","application/vnd.google-earth.kmz"],["kne","application/vnd.kinar"],["knp","application/vnd.kinar"],["kon","application/vnd.kde.kontour"],["kpr","application/vnd.kde.kpresenter"],["kpt","application/vnd.kde.kpresenter"],["kpxx","application/vnd.ds-keypoint"],["ksp","application/vnd.kde.kspread"],["ktr","application/vnd.kahootz"],["ktx","image/ktx"],["ktx2","image/ktx2"],["ktz","application/vnd.kahootz"],["kwd","application/vnd.kde.kword"],["kwt","application/vnd.kde.kword"],["lasxml","application/vnd.las.las+xml"],["latex","application/x-latex"],["lbd","application/vnd.llamagraphics.life-balance.desktop"],["lbe","application/vnd.llamagraphics.life-balance.exchange+xml"],["les","application/vnd.hhe.lesson-player"],["less","text/less"],["lgr","application/lgr+xml"],["lha","application/octet-stream"],["link66","application/vnd.route66.link66+xml"],["list","text/plain"],["list3820","application/vnd.ibm.modcap"],["listafp","application/vnd.ibm.modcap"],["litcoffee","text/coffeescript"],["lnk","application/x-ms-shortcut"],["log","text/plain"],["lostxml","application/lost+xml"],["lrf","application/octet-stream"],["lrm","application/vnd.ms-lrm"],["ltf","application/vnd.frogans.ltf"],["lua","text/x-lua"],["luac","application/x-lua-bytecode"],["lvp","audio/vnd.lucent.voice"],["lwp","application/vnd.lotus-wordpro"],["lzh","application/octet-stream"],["m1v","video/mpeg"],["m2a","audio/mpeg"],["m2v","video/mpeg"],["m3a","audio/mpeg"],["m3u","text/plain"],["m3u8","application/vnd.apple.mpegurl"],["m4a","audio/x-m4a"],["m4p","application/mp4"],["m4s","video/iso.segment"],["m4u","application/vnd.mpegurl"],["m4v","video/x-m4v"],["m13","application/x-msmediaview"],["m14","application/x-msmediaview"],["m21","application/mp21"],["ma","application/mathematica"],["mads","application/mads+xml"],["maei","application/mmt-aei+xml"],["mag","application/vnd.ecowin.chart"],["maker","application/vnd.framemaker"],["man","text/troff"],["manifest","text/cache-manifest"],["map","application/json"],["mar","application/octet-stream"],["markdown","text/markdown"],["mathml","application/mathml+xml"],["mb","application/mathematica"],["mbk","application/vnd.mobius.mbk"],["mbox","application/mbox"],["mc1","application/vnd.medcalcdata"],["mcd","application/vnd.mcd"],["mcurl","text/vnd.curl.mcurl"],["md","text/markdown"],["mdb","application/x-msaccess"],["mdi","image/vnd.ms-modi"],["mdx","text/mdx"],["me","text/troff"],["mesh","model/mesh"],["meta4","application/metalink4+xml"],["metalink","application/metalink+xml"],["mets","application/mets+xml"],["mfm","application/vnd.mfmp"],["mft","application/rpki-manifest"],["mgp","application/vnd.osgeo.mapguide.package"],["mgz","application/vnd.proteus.magazine"],["mid","audio/midi"],["midi","audio/midi"],["mie","application/x-mie"],["mif","application/vnd.mif"],["mime","message/rfc822"],["mj2","video/mj2"],["mjp2","video/mj2"],["mjs","application/javascript"],["mk3d","video/x-matroska"],["mka","audio/x-matroska"],["mkd","text/x-markdown"],["mks","video/x-matroska"],["mkv","video/x-matroska"],["mlp","application/vnd.dolby.mlp"],["mmd","application/vnd.chipnuts.karaoke-mmd"],["mmf","application/vnd.smaf"],["mml","text/mathml"],["mmr","image/vnd.fujixerox.edmics-mmr"],["mng","video/x-mng"],["mny","application/x-msmoney"],["mobi","application/x-mobipocket-ebook"],["mods","application/mods+xml"],["mov","video/quicktime"],["movie","video/x-sgi-movie"],["mp2","audio/mpeg"],["mp2a","audio/mpeg"],["mp3","audio/mpeg"],["mp4","video/mp4"],["mp4a","audio/mp4"],["mp4s","application/mp4"],["mp4v","video/mp4"],["mp21","application/mp21"],["mpc","application/vnd.mophun.certificate"],["mpd","application/dash+xml"],["mpe","video/mpeg"],["mpeg","video/mpeg"],["mpg","video/mpeg"],["mpg4","video/mp4"],["mpga","audio/mpeg"],["mpkg","application/vnd.apple.installer+xml"],["mpm","application/vnd.blueice.multipass"],["mpn","application/vnd.mophun.application"],["mpp","application/vnd.ms-project"],["mpt","application/vnd.ms-project"],["mpy","application/vnd.ibm.minipay"],["mqy","application/vnd.mobius.mqy"],["mrc","application/marc"],["mrcx","application/marcxml+xml"],["ms","text/troff"],["mscml","application/mediaservercontrol+xml"],["mseed","application/vnd.fdsn.mseed"],["mseq","application/vnd.mseq"],["msf","application/vnd.epson.msf"],["msg","application/vnd.ms-outlook"],["msh","model/mesh"],["msi","application/x-msdownload"],["msl","application/vnd.mobius.msl"],["msm","application/octet-stream"],["msp","application/octet-stream"],["msty","application/vnd.muvee.style"],["mtl","model/mtl"],["mts","model/vnd.mts"],["mus","application/vnd.musician"],["musd","application/mmt-usd+xml"],["musicxml","application/vnd.recordare.musicxml+xml"],["mvb","application/x-msmediaview"],["mvt","application/vnd.mapbox-vector-tile"],["mwf","application/vnd.mfer"],["mxf","application/mxf"],["mxl","application/vnd.recordare.musicxml"],["mxmf","audio/mobile-xmf"],["mxml","application/xv+xml"],["mxs","application/vnd.triscape.mxs"],["mxu","video/vnd.mpegurl"],["n-gage","application/vnd.nokia.n-gage.symbian.install"],["n3","text/n3"],["nb","application/mathematica"],["nbp","application/vnd.wolfram.player"],["nc","application/x-netcdf"],["ncx","application/x-dtbncx+xml"],["nfo","text/x-nfo"],["ngdat","application/vnd.nokia.n-gage.data"],["nitf","application/vnd.nitf"],["nlu","application/vnd.neurolanguage.nlu"],["nml","application/vnd.enliven"],["nnd","application/vnd.noblenet-directory"],["nns","application/vnd.noblenet-sealer"],["nnw","application/vnd.noblenet-web"],["npx","image/vnd.net-fpx"],["nq","application/n-quads"],["nsc","application/x-conference"],["nsf","application/vnd.lotus-notes"],["nt","application/n-triples"],["ntf","application/vnd.nitf"],["numbers","application/x-iwork-numbers-sffnumbers"],["nzb","application/x-nzb"],["oa2","application/vnd.fujitsu.oasys2"],["oa3","application/vnd.fujitsu.oasys3"],["oas","application/vnd.fujitsu.oasys"],["obd","application/x-msbinder"],["obgx","application/vnd.openblox.game+xml"],["obj","model/obj"],["oda","application/oda"],["odb","application/vnd.oasis.opendocument.database"],["odc","application/vnd.oasis.opendocument.chart"],["odf","application/vnd.oasis.opendocument.formula"],["odft","application/vnd.oasis.opendocument.formula-template"],["odg","application/vnd.oasis.opendocument.graphics"],["odi","application/vnd.oasis.opendocument.image"],["odm","application/vnd.oasis.opendocument.text-master"],["odp","application/vnd.oasis.opendocument.presentation"],["ods","application/vnd.oasis.opendocument.spreadsheet"],["odt","application/vnd.oasis.opendocument.text"],["oga","audio/ogg"],["ogex","model/vnd.opengex"],["ogg","audio/ogg"],["ogv","video/ogg"],["ogx","application/ogg"],["omdoc","application/omdoc+xml"],["onepkg","application/onenote"],["onetmp","application/onenote"],["onetoc","application/onenote"],["onetoc2","application/onenote"],["opf","application/oebps-package+xml"],["opml","text/x-opml"],["oprc","application/vnd.palm"],["opus","audio/ogg"],["org","text/x-org"],["osf","application/vnd.yamaha.openscoreformat"],["osfpvg","application/vnd.yamaha.openscoreformat.osfpvg+xml"],["osm","application/vnd.openstreetmap.data+xml"],["otc","application/vnd.oasis.opendocument.chart-template"],["otf","font/otf"],["otg","application/vnd.oasis.opendocument.graphics-template"],["oth","application/vnd.oasis.opendocument.text-web"],["oti","application/vnd.oasis.opendocument.image-template"],["otp","application/vnd.oasis.opendocument.presentation-template"],["ots","application/vnd.oasis.opendocument.spreadsheet-template"],["ott","application/vnd.oasis.opendocument.text-template"],["ova","application/x-virtualbox-ova"],["ovf","application/x-virtualbox-ovf"],["owl","application/rdf+xml"],["oxps","application/oxps"],["oxt","application/vnd.openofficeorg.extension"],["p","text/x-pascal"],["p7a","application/x-pkcs7-signature"],["p7b","application/x-pkcs7-certificates"],["p7c","application/pkcs7-mime"],["p7m","application/pkcs7-mime"],["p7r","application/x-pkcs7-certreqresp"],["p7s","application/pkcs7-signature"],["p8","application/pkcs8"],["p10","application/x-pkcs10"],["p12","application/x-pkcs12"],["pac","application/x-ns-proxy-autoconfig"],["pages","application/x-iwork-pages-sffpages"],["pas","text/x-pascal"],["paw","application/vnd.pawaafile"],["pbd","application/vnd.powerbuilder6"],["pbm","image/x-portable-bitmap"],["pcap","application/vnd.tcpdump.pcap"],["pcf","application/x-font-pcf"],["pcl","application/vnd.hp-pcl"],["pclxl","application/vnd.hp-pclxl"],["pct","image/x-pict"],["pcurl","application/vnd.curl.pcurl"],["pcx","image/x-pcx"],["pdb","application/x-pilot"],["pde","text/x-processing"],["pdf","application/pdf"],["pem","application/x-x509-user-cert"],["pfa","application/x-font-type1"],["pfb","application/x-font-type1"],["pfm","application/x-font-type1"],["pfr","application/font-tdpfr"],["pfx","application/x-pkcs12"],["pgm","image/x-portable-graymap"],["pgn","application/x-chess-pgn"],["pgp","application/pgp"],["php","application/x-httpd-php"],["php3","application/x-httpd-php"],["php4","application/x-httpd-php"],["phps","application/x-httpd-php-source"],["phtml","application/x-httpd-php"],["pic","image/x-pict"],["pkg","application/octet-stream"],["pki","application/pkixcmp"],["pkipath","application/pkix-pkipath"],["pkpass","application/vnd.apple.pkpass"],["pl","application/x-perl"],["plb","application/vnd.3gpp.pic-bw-large"],["plc","application/vnd.mobius.plc"],["plf","application/vnd.pocketlearn"],["pls","application/pls+xml"],["pm","application/x-perl"],["pml","application/vnd.ctc-posml"],["png","image/png"],["pnm","image/x-portable-anymap"],["portpkg","application/vnd.macports.portpkg"],["pot","application/vnd.ms-powerpoint"],["potm","application/vnd.ms-powerpoint.presentation.macroEnabled.12"],["potx","application/vnd.openxmlformats-officedocument.presentationml.template"],["ppa","application/vnd.ms-powerpoint"],["ppam","application/vnd.ms-powerpoint.addin.macroEnabled.12"],["ppd","application/vnd.cups-ppd"],["ppm","image/x-portable-pixmap"],["pps","application/vnd.ms-powerpoint"],["ppsm","application/vnd.ms-powerpoint.slideshow.macroEnabled.12"],["ppsx","application/vnd.openxmlformats-officedocument.presentationml.slideshow"],["ppt","application/powerpoint"],["pptm","application/vnd.ms-powerpoint.presentation.macroEnabled.12"],["pptx","application/vnd.openxmlformats-officedocument.presentationml.presentation"],["pqa","application/vnd.palm"],["prc","application/x-pilot"],["pre","application/vnd.lotus-freelance"],["prf","application/pics-rules"],["provx","application/provenance+xml"],["ps","application/postscript"],["psb","application/vnd.3gpp.pic-bw-small"],["psd","application/x-photoshop"],["psf","application/x-font-linux-psf"],["pskcxml","application/pskc+xml"],["pti","image/prs.pti"],["ptid","application/vnd.pvi.ptid1"],["pub","application/x-mspublisher"],["pvb","application/vnd.3gpp.pic-bw-var"],["pwn","application/vnd.3m.post-it-notes"],["pya","audio/vnd.ms-playready.media.pya"],["pyv","video/vnd.ms-playready.media.pyv"],["qam","application/vnd.epson.quickanime"],["qbo","application/vnd.intu.qbo"],["qfx","application/vnd.intu.qfx"],["qps","application/vnd.publishare-delta-tree"],["qt","video/quicktime"],["qwd","application/vnd.quark.quarkxpress"],["qwt","application/vnd.quark.quarkxpress"],["qxb","application/vnd.quark.quarkxpress"],["qxd","application/vnd.quark.quarkxpress"],["qxl","application/vnd.quark.quarkxpress"],["qxt","application/vnd.quark.quarkxpress"],["ra","audio/x-realaudio"],["ram","audio/x-pn-realaudio"],["raml","application/raml+yaml"],["rapd","application/route-apd+xml"],["rar","application/x-rar"],["ras","image/x-cmu-raster"],["rcprofile","application/vnd.ipunplugged.rcprofile"],["rdf","application/rdf+xml"],["rdz","application/vnd.data-vision.rdz"],["relo","application/p2p-overlay+xml"],["rep","application/vnd.businessobjects"],["res","application/x-dtbresource+xml"],["rgb","image/x-rgb"],["rif","application/reginfo+xml"],["rip","audio/vnd.rip"],["ris","application/x-research-info-systems"],["rl","application/resource-lists+xml"],["rlc","image/vnd.fujixerox.edmics-rlc"],["rld","application/resource-lists-diff+xml"],["rm","audio/x-pn-realaudio"],["rmi","audio/midi"],["rmp","audio/x-pn-realaudio-plugin"],["rms","application/vnd.jcp.javame.midlet-rms"],["rmvb","application/vnd.rn-realmedia-vbr"],["rnc","application/relax-ng-compact-syntax"],["rng","application/xml"],["roa","application/rpki-roa"],["roff","text/troff"],["rp9","application/vnd.cloanto.rp9"],["rpm","audio/x-pn-realaudio-plugin"],["rpss","application/vnd.nokia.radio-presets"],["rpst","application/vnd.nokia.radio-preset"],["rq","application/sparql-query"],["rs","application/rls-services+xml"],["rsa","application/x-pkcs7"],["rsat","application/atsc-rsat+xml"],["rsd","application/rsd+xml"],["rsheet","application/urc-ressheet+xml"],["rss","application/rss+xml"],["rtf","text/rtf"],["rtx","text/richtext"],["run","application/x-makeself"],["rusd","application/route-usd+xml"],["rv","video/vnd.rn-realvideo"],["s","text/x-asm"],["s3m","audio/s3m"],["saf","application/vnd.yamaha.smaf-audio"],["sass","text/x-sass"],["sbml","application/sbml+xml"],["sc","application/vnd.ibm.secure-container"],["scd","application/x-msschedule"],["scm","application/vnd.lotus-screencam"],["scq","application/scvp-cv-request"],["scs","application/scvp-cv-response"],["scss","text/x-scss"],["scurl","text/vnd.curl.scurl"],["sda","application/vnd.stardivision.draw"],["sdc","application/vnd.stardivision.calc"],["sdd","application/vnd.stardivision.impress"],["sdkd","application/vnd.solent.sdkm+xml"],["sdkm","application/vnd.solent.sdkm+xml"],["sdp","application/sdp"],["sdw","application/vnd.stardivision.writer"],["sea","application/octet-stream"],["see","application/vnd.seemail"],["seed","application/vnd.fdsn.seed"],["sema","application/vnd.sema"],["semd","application/vnd.semd"],["semf","application/vnd.semf"],["senmlx","application/senml+xml"],["sensmlx","application/sensml+xml"],["ser","application/java-serialized-object"],["setpay","application/set-payment-initiation"],["setreg","application/set-registration-initiation"],["sfd-hdstx","application/vnd.hydrostatix.sof-data"],["sfs","application/vnd.spotfire.sfs"],["sfv","text/x-sfv"],["sgi","image/sgi"],["sgl","application/vnd.stardivision.writer-global"],["sgm","text/sgml"],["sgml","text/sgml"],["sh","application/x-sh"],["shar","application/x-shar"],["shex","text/shex"],["shf","application/shf+xml"],["shtml","text/html"],["sid","image/x-mrsid-image"],["sieve","application/sieve"],["sig","application/pgp-signature"],["sil","audio/silk"],["silo","model/mesh"],["sis","application/vnd.symbian.install"],["sisx","application/vnd.symbian.install"],["sit","application/x-stuffit"],["sitx","application/x-stuffitx"],["siv","application/sieve"],["skd","application/vnd.koan"],["skm","application/vnd.koan"],["skp","application/vnd.koan"],["skt","application/vnd.koan"],["sldm","application/vnd.ms-powerpoint.slide.macroenabled.12"],["sldx","application/vnd.openxmlformats-officedocument.presentationml.slide"],["slim","text/slim"],["slm","text/slim"],["sls","application/route-s-tsid+xml"],["slt","application/vnd.epson.salt"],["sm","application/vnd.stepmania.stepchart"],["smf","application/vnd.stardivision.math"],["smi","application/smil"],["smil","application/smil"],["smv","video/x-smv"],["smzip","application/vnd.stepmania.package"],["snd","audio/basic"],["snf","application/x-font-snf"],["so","application/octet-stream"],["spc","application/x-pkcs7-certificates"],["spdx","text/spdx"],["spf","application/vnd.yamaha.smaf-phrase"],["spl","application/x-futuresplash"],["spot","text/vnd.in3d.spot"],["spp","application/scvp-vp-response"],["spq","application/scvp-vp-request"],["spx","audio/ogg"],["sql","application/x-sql"],["src","application/x-wais-source"],["srt","application/x-subrip"],["sru","application/sru+xml"],["srx","application/sparql-results+xml"],["ssdl","application/ssdl+xml"],["sse","application/vnd.kodak-descriptor"],["ssf","application/vnd.epson.ssf"],["ssml","application/ssml+xml"],["sst","application/octet-stream"],["st","application/vnd.sailingtracker.track"],["stc","application/vnd.sun.xml.calc.template"],["std","application/vnd.sun.xml.draw.template"],["stf","application/vnd.wt.stf"],["sti","application/vnd.sun.xml.impress.template"],["stk","application/hyperstudio"],["stl","model/stl"],["stpx","model/step+xml"],["stpxz","model/step-xml+zip"],["stpz","model/step+zip"],["str","application/vnd.pg.format"],["stw","application/vnd.sun.xml.writer.template"],["styl","text/stylus"],["stylus","text/stylus"],["sub","text/vnd.dvb.subtitle"],["sus","application/vnd.sus-calendar"],["susp","application/vnd.sus-calendar"],["sv4cpio","application/x-sv4cpio"],["sv4crc","application/x-sv4crc"],["svc","application/vnd.dvb.service"],["svd","application/vnd.svd"],["svg","image/svg+xml"],["svgz","image/svg+xml"],["swa","application/x-director"],["swf","application/x-shockwave-flash"],["swi","application/vnd.aristanetworks.swi"],["swidtag","application/swid+xml"],["sxc","application/vnd.sun.xml.calc"],["sxd","application/vnd.sun.xml.draw"],["sxg","application/vnd.sun.xml.writer.global"],["sxi","application/vnd.sun.xml.impress"],["sxm","application/vnd.sun.xml.math"],["sxw","application/vnd.sun.xml.writer"],["t","text/troff"],["t3","application/x-t3vm-image"],["t38","image/t38"],["taglet","application/vnd.mynfc"],["tao","application/vnd.tao.intent-module-archive"],["tap","image/vnd.tencent.tap"],["tar","application/x-tar"],["tcap","application/vnd.3gpp2.tcap"],["tcl","application/x-tcl"],["td","application/urc-targetdesc+xml"],["teacher","application/vnd.smart.teacher"],["tei","application/tei+xml"],["teicorpus","application/tei+xml"],["tex","application/x-tex"],["texi","application/x-texinfo"],["texinfo","application/x-texinfo"],["text","text/plain"],["tfi","application/thraud+xml"],["tfm","application/x-tex-tfm"],["tfx","image/tiff-fx"],["tga","image/x-tga"],["tgz","application/x-tar"],["thmx","application/vnd.ms-officetheme"],["tif","image/tiff"],["tiff","image/tiff"],["tk","application/x-tcl"],["tmo","application/vnd.tmobile-livetv"],["toml","application/toml"],["torrent","application/x-bittorrent"],["tpl","application/vnd.groove-tool-template"],["tpt","application/vnd.trid.tpt"],["tr","text/troff"],["tra","application/vnd.trueapp"],["trig","application/trig"],["trm","application/x-msterminal"],["ts","video/mp2t"],["tsd","application/timestamped-data"],["tsv","text/tab-separated-values"],["ttc","font/collection"],["ttf","font/ttf"],["ttl","text/turtle"],["ttml","application/ttml+xml"],["twd","application/vnd.simtech-mindmapper"],["twds","application/vnd.simtech-mindmapper"],["txd","application/vnd.genomatix.tuxedo"],["txf","application/vnd.mobius.txf"],["txt","text/plain"],["u8dsn","message/global-delivery-status"],["u8hdr","message/global-headers"],["u8mdn","message/global-disposition-notification"],["u8msg","message/global"],["u32","application/x-authorware-bin"],["ubj","application/ubjson"],["udeb","application/x-debian-package"],["ufd","application/vnd.ufdl"],["ufdl","application/vnd.ufdl"],["ulx","application/x-glulx"],["umj","application/vnd.umajin"],["unityweb","application/vnd.unity"],["uoml","application/vnd.uoml+xml"],["uri","text/uri-list"],["uris","text/uri-list"],["urls","text/uri-list"],["usdz","model/vnd.usdz+zip"],["ustar","application/x-ustar"],["utz","application/vnd.uiq.theme"],["uu","text/x-uuencode"],["uva","audio/vnd.dece.audio"],["uvd","application/vnd.dece.data"],["uvf","application/vnd.dece.data"],["uvg","image/vnd.dece.graphic"],["uvh","video/vnd.dece.hd"],["uvi","image/vnd.dece.graphic"],["uvm","video/vnd.dece.mobile"],["uvp","video/vnd.dece.pd"],["uvs","video/vnd.dece.sd"],["uvt","application/vnd.dece.ttml+xml"],["uvu","video/vnd.uvvu.mp4"],["uvv","video/vnd.dece.video"],["uvva","audio/vnd.dece.audio"],["uvvd","application/vnd.dece.data"],["uvvf","application/vnd.dece.data"],["uvvg","image/vnd.dece.graphic"],["uvvh","video/vnd.dece.hd"],["uvvi","image/vnd.dece.graphic"],["uvvm","video/vnd.dece.mobile"],["uvvp","video/vnd.dece.pd"],["uvvs","video/vnd.dece.sd"],["uvvt","application/vnd.dece.ttml+xml"],["uvvu","video/vnd.uvvu.mp4"],["uvvv","video/vnd.dece.video"],["uvvx","application/vnd.dece.unspecified"],["uvvz","application/vnd.dece.zip"],["uvx","application/vnd.dece.unspecified"],["uvz","application/vnd.dece.zip"],["vbox","application/x-virtualbox-vbox"],["vbox-extpack","application/x-virtualbox-vbox-extpack"],["vcard","text/vcard"],["vcd","application/x-cdlink"],["vcf","text/x-vcard"],["vcg","application/vnd.groove-vcard"],["vcs","text/x-vcalendar"],["vcx","application/vnd.vcx"],["vdi","application/x-virtualbox-vdi"],["vds","model/vnd.sap.vds"],["vhd","application/x-virtualbox-vhd"],["vis","application/vnd.visionary"],["viv","video/vnd.vivo"],["vlc","application/videolan"],["vmdk","application/x-virtualbox-vmdk"],["vob","video/x-ms-vob"],["vor","application/vnd.stardivision.writer"],["vox","application/x-authorware-bin"],["vrml","model/vrml"],["vsd","application/vnd.visio"],["vsf","application/vnd.vsf"],["vss","application/vnd.visio"],["vst","application/vnd.visio"],["vsw","application/vnd.visio"],["vtf","image/vnd.valve.source.texture"],["vtt","text/vtt"],["vtu","model/vnd.vtu"],["vxml","application/voicexml+xml"],["w3d","application/x-director"],["wad","application/x-doom"],["wadl","application/vnd.sun.wadl+xml"],["war","application/java-archive"],["wasm","application/wasm"],["wav","audio/x-wav"],["wax","audio/x-ms-wax"],["wbmp","image/vnd.wap.wbmp"],["wbs","application/vnd.criticaltools.wbs+xml"],["wbxml","application/wbxml"],["wcm","application/vnd.ms-works"],["wdb","application/vnd.ms-works"],["wdp","image/vnd.ms-photo"],["weba","audio/webm"],["webapp","application/x-web-app-manifest+json"],["webm","video/webm"],["webmanifest","application/manifest+json"],["webp","image/webp"],["wg","application/vnd.pmi.widget"],["wgt","application/widget"],["wks","application/vnd.ms-works"],["wm","video/x-ms-wm"],["wma","audio/x-ms-wma"],["wmd","application/x-ms-wmd"],["wmf","image/wmf"],["wml","text/vnd.wap.wml"],["wmlc","application/wmlc"],["wmls","text/vnd.wap.wmlscript"],["wmlsc","application/vnd.wap.wmlscriptc"],["wmv","video/x-ms-wmv"],["wmx","video/x-ms-wmx"],["wmz","application/x-msmetafile"],["woff","font/woff"],["woff2","font/woff2"],["word","application/msword"],["wpd","application/vnd.wordperfect"],["wpl","application/vnd.ms-wpl"],["wps","application/vnd.ms-works"],["wqd","application/vnd.wqd"],["wri","application/x-mswrite"],["wrl","model/vrml"],["wsc","message/vnd.wfa.wsc"],["wsdl","application/wsdl+xml"],["wspolicy","application/wspolicy+xml"],["wtb","application/vnd.webturbo"],["wvx","video/x-ms-wvx"],["x3d","model/x3d+xml"],["x3db","model/x3d+fastinfoset"],["x3dbz","model/x3d+binary"],["x3dv","model/x3d-vrml"],["x3dvz","model/x3d+vrml"],["x3dz","model/x3d+xml"],["x32","application/x-authorware-bin"],["x_b","model/vnd.parasolid.transmit.binary"],["x_t","model/vnd.parasolid.transmit.text"],["xaml","application/xaml+xml"],["xap","application/x-silverlight-app"],["xar","application/vnd.xara"],["xav","application/xcap-att+xml"],["xbap","application/x-ms-xbap"],["xbd","application/vnd.fujixerox.docuworks.binder"],["xbm","image/x-xbitmap"],["xca","application/xcap-caps+xml"],["xcs","application/calendar+xml"],["xdf","application/xcap-diff+xml"],["xdm","application/vnd.syncml.dm+xml"],["xdp","application/vnd.adobe.xdp+xml"],["xdssc","application/dssc+xml"],["xdw","application/vnd.fujixerox.docuworks"],["xel","application/xcap-el+xml"],["xenc","application/xenc+xml"],["xer","application/patch-ops-error+xml"],["xfdf","application/vnd.adobe.xfdf"],["xfdl","application/vnd.xfdl"],["xht","application/xhtml+xml"],["xhtml","application/xhtml+xml"],["xhvml","application/xv+xml"],["xif","image/vnd.xiff"],["xl","application/excel"],["xla","application/vnd.ms-excel"],["xlam","application/vnd.ms-excel.addin.macroEnabled.12"],["xlc","application/vnd.ms-excel"],["xlf","application/xliff+xml"],["xlm","application/vnd.ms-excel"],["xls","application/vnd.ms-excel"],["xlsb","application/vnd.ms-excel.sheet.binary.macroEnabled.12"],["xlsm","application/vnd.ms-excel.sheet.macroEnabled.12"],["xlsx","application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"],["xlt","application/vnd.ms-excel"],["xltm","application/vnd.ms-excel.template.macroEnabled.12"],["xltx","application/vnd.openxmlformats-officedocument.spreadsheetml.template"],["xlw","application/vnd.ms-excel"],["xm","audio/xm"],["xml","application/xml"],["xns","application/xcap-ns+xml"],["xo","application/vnd.olpc-sugar"],["xop","application/xop+xml"],["xpi","application/x-xpinstall"],["xpl","application/xproc+xml"],["xpm","image/x-xpixmap"],["xpr","application/vnd.is-xpr"],["xps","application/vnd.ms-xpsdocument"],["xpw","application/vnd.intercon.formnet"],["xpx","application/vnd.intercon.formnet"],["xsd","application/xml"],["xsl","application/xml"],["xslt","application/xslt+xml"],["xsm","application/vnd.syncml+xml"],["xspf","application/xspf+xml"],["xul","application/vnd.mozilla.xul+xml"],["xvm","application/xv+xml"],["xvml","application/xv+xml"],["xwd","image/x-xwindowdump"],["xyz","chemical/x-xyz"],["xz","application/x-xz"],["yaml","text/yaml"],["yang","application/yang"],["yin","application/yin+xml"],["yml","text/yaml"],["ymp","text/x-suse-ymp"],["z","application/x-compress"],["z1","application/x-zmachine"],["z2","application/x-zmachine"],["z3","application/x-zmachine"],["z4","application/x-zmachine"],["z5","application/x-zmachine"],["z6","application/x-zmachine"],["z7","application/x-zmachine"],["z8","application/x-zmachine"],["zaz","application/vnd.zzazz.deck+xml"],["zip","application/zip"],["zir","application/vnd.zul"],["zirz","application/vnd.zul"],["zmm","application/vnd.handheld-entertainment+xml"],["zsh","text/x-scriptzsh"]]);function Bs(e,t,n){const r=qoe(e),{webkitRelativePath:a}=e,o=typeof t=="string"?t:typeof a=="string"&&a.length>0?a:`./${e.name}`;return typeof r.path!="string"&&VO(r,"path",o),VO(r,"relativePath",o),r}function qoe(e){const{name:t}=e;if(t&&t.lastIndexOf(".")!==-1&&!e.type){const r=t.split(".").pop().toLowerCase(),a=$oe.get(r);a&&Object.defineProperty(e,"type",{value:a,writable:!1,configurable:!1,enumerable:!0})}return e}function VO(e,t,n){Object.defineProperty(e,t,{value:n,writable:!1,configurable:!1,enumerable:!0})}const Voe=[".DS_Store","Thumbs.db"];function Woe(e){return Ti(this,void 0,void 0,function*(){return Lf(e)&&Yoe(e.dataTransfer)?Qoe(e.dataTransfer,e.type):Koe(e)?Xoe(e):Array.isArray(e)&&e.every(t=>"getFile"in t&&typeof t.getFile=="function")?Zoe(e):[]})}function Yoe(e){return Lf(e)}function Koe(e){return Lf(e)&&Lf(e.target)}function Lf(e){return typeof e=="object"&&e!==null}function Xoe(e){return uk(e.target.files).map(t=>Bs(t))}function Zoe(e){return Ti(this,void 0,void 0,function*(){return(yield Promise.all(e.map(n=>n.getFile()))).map(n=>Bs(n))})}function Qoe(e,t){return Ti(this,void 0,void 0,function*(){if(e.items){const n=uk(e.items).filter(a=>a.kind==="file");if(t!=="drop")return n;const r=yield Promise.all(n.map(Joe));return WO(aG(r))}return WO(uk(e.files).map(n=>Bs(n)))})}function WO(e){return e.filter(t=>Voe.indexOf(t.name)===-1)}function uk(e){if(e===null)return[];const t=[];for(let n=0;n<e.length;n++){const r=e[n];t.push(r)}return t}function Joe(e){if(typeof e.webkitGetAsEntry!="function")return YO(e);const t=e.webkitGetAsEntry();return t&&t.isDirectory?oG(t):YO(e,t)}function aG(e){return e.reduce((t,n)=>[...t,...Array.isArray(n)?aG(n):[n]],[])}function YO(e,t){return Ti(this,void 0,void 0,function*(){var n;if(globalThis.isSecureContext&&typeof e.getAsFileSystemHandle=="function"){const o=yield e.getAsFileSystemHandle();if(o===null)throw new Error(`${e} is not a File`);if(o!==void 0){const s=yield o.getFile();return s.handle=o,Bs(s)}}const r=e.getAsFile();if(!r)throw new Error(`${e} is not a File`);return Bs(r,(n=t==null?void 0:t.fullPath)!==null&&n!==void 0?n:void 0)})}function eie(e){return Ti(this,void 0,void 0,function*(){return e.isDirectory?oG(e):tie(e)})}function oG(e){const t=e.createReader();return new Promise((n,r)=>{const a=[];function o(){t.readEntries(s=>Ti(this,void 0,void 0,function*(){if(s.length){const l=Promise.all(s.map(eie));a.push(l),o()}else try{const l=yield Promise.all(a);n(l)}catch(l){r(l)}}),s=>{r(s)})}o()})}function tie(e){return Ti(this,void 0,void 0,function*(){return new Promise((t,n)=>{e.file(r=>{const a=Bs(r,e.fullPath);t(a)},r=>{n(r)})})})}var Bd={},KO;function nie(){return KO||(KO=1,Bd.__esModule=!0,Bd.default=function(e,t){if(e&&t){var n=Array.isArray(t)?t:t.split(",");if(n.length===0)return!0;var r=e.name||"",a=(e.type||"").toLowerCase(),o=a.replace(/\/.*$/,"");return n.some(function(s){var l=s.trim().toLowerCase();return l.charAt(0)==="."?r.toLowerCase().endsWith(l):l.endsWith("/*")?o===l.replace(/\/.*$/,""):a===l})}return!0}),Bd}var rie=nie();const fb=un(rie);function XO(e){return iie(e)||oie(e)||sG(e)||aie()}function aie(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function oie(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function iie(e){if(Array.isArray(e))return dk(e)}function ZO(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function QO(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?ZO(Object(n),!0).forEach(function(r){iG(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):ZO(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function iG(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Ic(e,t){return cie(e)||lie(e,t)||sG(e,t)||sie()}function sie(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function sG(e,t){if(e){if(typeof e=="string")return dk(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if(n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set")return Array.from(e);if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return dk(e,t)}}function dk(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function lie(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r=[],a=!0,o=!1,s,l;try{for(n=n.call(e);!(a=(s=n.next()).done)&&(r.push(s.value),!(t&&r.length===t));a=!0);}catch(u){o=!0,l=u}finally{try{!a&&n.return!=null&&n.return()}finally{if(o)throw l}}return r}}function cie(e){if(Array.isArray(e))return e}var uie=typeof fb=="function"?fb:fb.default,die="file-invalid-type",fie="file-too-large",pie="file-too-small",gie="too-many-files",hie=function(){var t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"",n=t.split(","),r=n.length>1?"one of ".concat(n.join(", ")):n[0];return{code:die,message:"File type must be ".concat(r)}},JO=function(t){return{code:fie,message:"File is larger than ".concat(t," ").concat(t===1?"byte":"bytes")}},eI=function(t){return{code:pie,message:"File is smaller than ".concat(t," ").concat(t===1?"byte":"bytes")}},mie={code:gie,message:"Too many files"};function lG(e,t){var n=e.type==="application/x-moz-file"||uie(e,t);return[n,n?null:hie(t)]}function cG(e,t,n){if(ui(e.size))if(ui(t)&&ui(n)){if(e.size>n)return[!1,JO(n)];if(e.size<t)return[!1,eI(t)]}else{if(ui(t)&&e.size<t)return[!1,eI(t)];if(ui(n)&&e.size>n)return[!1,JO(n)]}return[!0,null]}function ui(e){return e!=null}function bie(e){var t=e.files,n=e.accept,r=e.minSize,a=e.maxSize,o=e.multiple,s=e.maxFiles,l=e.validator;return!o&&t.length>1||o&&s>=1&&t.length>s?!1:t.every(function(u){var d=lG(u,n),p=Ic(d,1),g=p[0],m=cG(u,r,a),b=Ic(m,1),v=b[0],y=l?l(u):null;return g&&v&&!y})}function Mf(e){return typeof e.isPropagationStopped=="function"?e.isPropagationStopped():typeof e.cancelBubble<"u"?e.cancelBubble:!1}function jd(e){return e.dataTransfer?Array.prototype.some.call(e.dataTransfer.types,function(t){return t==="Files"||t==="application/x-moz-file"}):!!e.target&&!!e.target.files}function tI(e){e.preventDefault()}function yie(e){return e.indexOf("MSIE")!==-1||e.indexOf("Trident/")!==-1}function vie(e){return e.indexOf("Edge/")!==-1}function Sie(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:window.navigator.userAgent;return yie(e)||vie(e)}function ea(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return function(r){for(var a=arguments.length,o=new Array(a>1?a-1:0),s=1;s<a;s++)o[s-1]=arguments[s];return t.some(function(l){return!Mf(r)&&l&&l.apply(void 0,[r].concat(o)),Mf(r)})}}function Eie(){return"showOpenFilePicker"in window}function wie(e){if(ui(e)){var t=Object.entries(e).filter(function(n){var r=Ic(n,2),a=r[0],o=r[1],s=!0;return uG(a)||(console.warn('Skipped "'.concat(a,'" because it is not a valid MIME type. Check https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Common_types for a list of valid MIME types.')),s=!1),(!Array.isArray(o)||!o.every(dG))&&(console.warn('Skipped "'.concat(a,'" because an invalid file extension was provided.')),s=!1),s}).reduce(function(n,r){var a=Ic(r,2),o=a[0],s=a[1];return QO(QO({},n),{},iG({},o,s))},{});return[{description:"Files",accept:t}]}return e}function xie(e){if(ui(e))return Object.entries(e).reduce(function(t,n){var r=Ic(n,2),a=r[0],o=r[1];return[].concat(XO(t),[a],XO(o))},[]).filter(function(t){return uG(t)||dG(t)}).join(",")}function kie(e){return e instanceof DOMException&&(e.name==="AbortError"||e.code===e.ABORT_ERR)}function Tie(e){return e instanceof DOMException&&(e.name==="SecurityError"||e.code===e.SECURITY_ERR)}function uG(e){return e==="audio/*"||e==="video/*"||e==="image/*"||e==="text/*"||e==="application/*"||/\w+\/[-+.\w]+/g.test(e)}function dG(e){return/^.*\.[\w]+$/.test(e)}var Aie=["children"],Rie=["open"],Cie=["refKey","role","onKeyDown","onFocus","onBlur","onClick","onDragEnter","onDragOver","onDragLeave","onDrop"],_ie=["refKey","onChange","onClick"];function Nie(e){return Die(e)||Iie(e)||fG(e)||Oie()}function Oie(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Iie(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function Die(e){if(Array.isArray(e))return fk(e)}function pb(e,t){return Pie(e)||Mie(e,t)||fG(e,t)||Lie()}function Lie(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function fG(e,t){if(e){if(typeof e=="string")return fk(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if(n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set")return Array.from(e);if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return fk(e,t)}}function fk(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function Mie(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r=[],a=!0,o=!1,s,l;try{for(n=n.call(e);!(a=(s=n.next()).done)&&(r.push(s.value),!(t&&r.length===t));a=!0);}catch(u){o=!0,l=u}finally{try{!a&&n.return!=null&&n.return()}finally{if(o)throw l}}return r}}function Pie(e){if(Array.isArray(e))return e}function nI(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ut(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?nI(Object(n),!0).forEach(function(r){pk(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):nI(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function pk(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Pf(e,t){if(e==null)return{};var n=Fie(e,t),r,a;if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);for(a=0;a<o.length;a++)r=o[a],!(t.indexOf(r)>=0)&&Object.prototype.propertyIsEnumerable.call(e,r)&&(n[r]=e[r])}return n}function Fie(e,t){if(e==null)return{};var n={},r=Object.keys(e),a,o;for(o=0;o<r.length;o++)a=r[o],!(t.indexOf(a)>=0)&&(n[a]=e[a]);return n}var Op=w.forwardRef(function(e,t){var n=e.children,r=Pf(e,Aie),a=zie(r),o=a.open,s=Pf(a,Rie);return w.useImperativeHandle(t,function(){return{open:o}},[o]),we.createElement(w.Fragment,null,n(Ut(Ut({},s),{},{open:o})))});Op.displayName="Dropzone";var pG={disabled:!1,getFilesFromEvent:Woe,maxSize:1/0,minSize:0,multiple:!0,maxFiles:0,preventDropOnDocument:!0,noClick:!1,noKeyboard:!1,noDrag:!1,noDragEventsBubbling:!1,validator:null,useFsAccessApi:!1,autoFocus:!1};Op.defaultProps=pG;Op.propTypes={children:It.func,accept:It.objectOf(It.arrayOf(It.string)),multiple:It.bool,preventDropOnDocument:It.bool,noClick:It.bool,noKeyboard:It.bool,noDrag:It.bool,noDragEventsBubbling:It.bool,minSize:It.number,maxSize:It.number,maxFiles:It.number,disabled:It.bool,getFilesFromEvent:It.func,onFileDialogCancel:It.func,onFileDialogOpen:It.func,useFsAccessApi:It.bool,autoFocus:It.bool,onDragEnter:It.func,onDragLeave:It.func,onDragOver:It.func,onDrop:It.func,onDropAccepted:It.func,onDropRejected:It.func,onError:It.func,validator:It.func};var gk={isFocused:!1,isFileDialogActive:!1,isDragActive:!1,isDragAccept:!1,isDragReject:!1,acceptedFiles:[],fileRejections:[]};function zie(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},t=Ut(Ut({},pG),e),n=t.accept,r=t.disabled,a=t.getFilesFromEvent,o=t.maxSize,s=t.minSize,l=t.multiple,u=t.maxFiles,d=t.onDragEnter,p=t.onDragLeave,g=t.onDragOver,m=t.onDrop,b=t.onDropAccepted,v=t.onDropRejected,y=t.onFileDialogCancel,k=t.onFileDialogOpen,A=t.useFsAccessApi,x=t.autoFocus,R=t.preventDropOnDocument,O=t.noClick,N=t.noKeyboard,C=t.noDrag,_=t.noDragEventsBubbling,M=t.onError,I=t.validator,D=w.useMemo(function(){return xie(n)},[n]),U=w.useMemo(function(){return wie(n)},[n]),$=w.useMemo(function(){return typeof k=="function"?k:rI},[k]),B=w.useMemo(function(){return typeof y=="function"?y:rI},[y]),W=w.useRef(null),K=w.useRef(null),H=w.useReducer(Bie,gk),G=pb(H,2),z=G[0],Y=G[1],L=z.isFocused,V=z.isFileDialogActive,j=w.useRef(typeof window<"u"&&window.isSecureContext&&A&&Eie()),P=function(){!j.current&&V&&setTimeout(function(){if(K.current){var Oe=K.current.files;Oe.length||(Y({type:"closeDialog"}),B())}},300)};w.useEffect(function(){return window.addEventListener("focus",P,!1),function(){window.removeEventListener("focus",P,!1)}},[K,V,B,j]);var Z=w.useRef([]),Q=function(Oe){W.current&&W.current.contains(Oe.target)||(Oe.preventDefault(),Z.current=[])};w.useEffect(function(){return R&&(document.addEventListener("dragover",tI,!1),document.addEventListener("drop",Q,!1)),function(){R&&(document.removeEventListener("dragover",tI),document.removeEventListener("drop",Q))}},[W,R]),w.useEffect(function(){return!r&&x&&W.current&&W.current.focus(),function(){}},[W,x,r]);var oe=w.useCallback(function(ye){M?M(ye):console.error(ye)},[M]),ae=w.useCallback(function(ye){ye.preventDefault(),ye.persist(),Ee(ye),Z.current=[].concat(Nie(Z.current),[ye.target]),jd(ye)&&Promise.resolve(a(ye)).then(function(Oe){if(!(Mf(ye)&&!_)){var ee=Oe.length,de=ee>0&&bie({files:Oe,accept:D,minSize:s,maxSize:o,multiple:l,maxFiles:u,validator:I}),Ne=ee>0&&!de;Y({isDragAccept:de,isDragReject:Ne,isDragActive:!0,type:"setDraggedFiles"}),d&&d(ye)}}).catch(function(Oe){return oe(Oe)})},[a,d,oe,_,D,s,o,l,u,I]),ce=w.useCallback(function(ye){ye.preventDefault(),ye.persist(),Ee(ye);var Oe=jd(ye);if(Oe&&ye.dataTransfer)try{ye.dataTransfer.dropEffect="copy"}catch{}return Oe&&g&&g(ye),!1},[g,_]),Re=w.useCallback(function(ye){ye.preventDefault(),ye.persist(),Ee(ye);var Oe=Z.current.filter(function(de){return W.current&&W.current.contains(de)}),ee=Oe.indexOf(ye.target);ee!==-1&&Oe.splice(ee,1),Z.current=Oe,!(Oe.length>0)&&(Y({type:"setDraggedFiles",isDragActive:!1,isDragAccept:!1,isDragReject:!1}),jd(ye)&&p&&p(ye))},[W,p,_]),ie=w.useCallback(function(ye,Oe){var ee=[],de=[];ye.forEach(function(Ne){var Fe=lG(Ne,D),We=pb(Fe,2),St=We[0],Tt=We[1],bt=cG(Ne,s,o),et=pb(bt,2),At=et[0],st=et[1],wt=I?I(Ne):null;if(St&&At&&!wt)ee.push(Ne);else{var Ht=[Tt,st];wt&&(Ht=Ht.concat(wt)),de.push({file:Ne,errors:Ht.filter(function(pn){return pn})})}}),(!l&&ee.length>1||l&&u>=1&&ee.length>u)&&(ee.forEach(function(Ne){de.push({file:Ne,errors:[mie]})}),ee.splice(0)),Y({acceptedFiles:ee,fileRejections:de,isDragReject:de.length>0,type:"setFiles"}),m&&m(ee,de,Oe),de.length>0&&v&&v(de,Oe),ee.length>0&&b&&b(ee,Oe)},[Y,l,D,s,o,u,m,b,v,I]),Te=w.useCallback(function(ye){ye.preventDefault(),ye.persist(),Ee(ye),Z.current=[],jd(ye)&&Promise.resolve(a(ye)).then(function(Oe){Mf(ye)&&!_||ie(Oe,ye)}).catch(function(Oe){return oe(Oe)}),Y({type:"reset"})},[a,ie,oe,_]),ne=w.useCallback(function(){if(j.current){Y({type:"openDialog"}),$();var ye={multiple:l,types:U};window.showOpenFilePicker(ye).then(function(Oe){return a(Oe)}).then(function(Oe){ie(Oe,null),Y({type:"closeDialog"})}).catch(function(Oe){kie(Oe)?(B(Oe),Y({type:"closeDialog"})):Tie(Oe)?(j.current=!1,K.current?(K.current.value=null,K.current.click()):oe(new Error("Cannot open the file picker because the https://developer.mozilla.org/en-US/docs/Web/API/File_System_Access_API is not supported and no <input> was provided."))):oe(Oe)});return}K.current&&(Y({type:"openDialog"}),$(),K.current.value=null,K.current.click())},[Y,$,B,A,ie,oe,U,l]),xe=w.useCallback(function(ye){!W.current||!W.current.isEqualNode(ye.target)||(ye.key===" "||ye.key==="Enter"||ye.keyCode===32||ye.keyCode===13)&&(ye.preventDefault(),ne())},[W,ne]),Se=w.useCallback(function(){Y({type:"focus"})},[]),be=w.useCallback(function(){Y({type:"blur"})},[]),J=w.useCallback(function(){O||(Sie()?setTimeout(ne,0):ne())},[O,ne]),pe=function(Oe){return r?null:Oe},ke=function(Oe){return N?null:pe(Oe)},he=function(Oe){return C?null:pe(Oe)},Ee=function(Oe){_&&Oe.stopPropagation()},se=w.useMemo(function(){return function(){var ye=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},Oe=ye.refKey,ee=Oe===void 0?"ref":Oe,de=ye.role,Ne=ye.onKeyDown,Fe=ye.onFocus,We=ye.onBlur,St=ye.onClick,Tt=ye.onDragEnter,bt=ye.onDragOver,et=ye.onDragLeave,At=ye.onDrop,st=Pf(ye,Cie);return Ut(Ut(pk({onKeyDown:ke(ea(Ne,xe)),onFocus:ke(ea(Fe,Se)),onBlur:ke(ea(We,be)),onClick:pe(ea(St,J)),onDragEnter:he(ea(Tt,ae)),onDragOver:he(ea(bt,ce)),onDragLeave:he(ea(et,Re)),onDrop:he(ea(At,Te)),role:typeof de=="string"&&de!==""?de:"presentation"},ee,W),!r&&!N?{tabIndex:0}:{}),st)}},[W,xe,Se,be,J,ae,ce,Re,Te,N,C,r]),Be=w.useCallback(function(ye){ye.stopPropagation()},[]),je=w.useMemo(function(){return function(){var ye=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},Oe=ye.refKey,ee=Oe===void 0?"ref":Oe,de=ye.onChange,Ne=ye.onClick,Fe=Pf(ye,_ie),We=pk({accept:D,multiple:l,type:"file",style:{border:0,clip:"rect(0, 0, 0, 0)",clipPath:"inset(50%)",height:"1px",margin:"0 -1px -1px 0",overflow:"hidden",padding:0,position:"absolute",width:"1px",whiteSpace:"nowrap"},onChange:pe(ea(de,Te)),onClick:pe(ea(Ne,Be)),tabIndex:-1},ee,K);return Ut(Ut({},We),Fe)}},[K,n,l,Te,r]);return Ut(Ut({},z),{},{isFocused:L&&!r,getRootProps:se,getInputProps:je,rootRef:W,inputRef:K,open:pe(ne)})}function Bie(e,t){switch(t.type){case"focus":return Ut(Ut({},e),{},{isFocused:!0});case"blur":return Ut(Ut({},e),{},{isFocused:!1});case"openDialog":return Ut(Ut({},gk),{},{isFileDialogActive:!0});case"closeDialog":return Ut(Ut({},e),{},{isFileDialogActive:!1});case"setDraggedFiles":return Ut(Ut({},e),{},{isDragActive:t.isDragActive,isDragAccept:t.isDragAccept,isDragReject:t.isDragReject});case"setFiles":return Ut(Ut({},e),{},{acceptedFiles:t.acceptedFiles,fileRejections:t.fileRejections,isDragReject:t.isDragReject});case"reset":return Ut({},gk);default:return e}}function rI(){}function hk(e,t={}){const{decimals:n=0,sizeType:r="normal"}=t,a=["Bytes","KB","MB","GB","TB"],o=["Bytes","KiB","MiB","GiB","TiB"];if(e===0)return"0 Byte";const s=Math.floor(Math.log(e)/Math.log(1024));return`${(e/Math.pow(1024,s)).toFixed(n)} ${r==="accurate"?o[s]??"Bytes":a[s]??"Bytes"}`}function jie(e){const{t}=Et(),{value:n,onValueChange:r,onUpload:a,onReject:o,progresses:s,fileErrors:l,accept:u=hV,maxSize:d=1024*1024*200,maxFileCount:p=1,multiple:g=!1,disabled:m=!1,description:b,className:v,...y}=e,[k,A]=ja({prop:n,onChange:r}),x=w.useCallback((N,C)=>{const _=((k==null?void 0:k.length)??0)+N.length+C.length;if(!g&&p===1&&N.length+C.length>1){Ft.error(t("documentPanel.uploadDocuments.fileUploader.singleFileLimit"));return}if(_>p){Ft.error(t("documentPanel.uploadDocuments.fileUploader.maxFilesLimit",{count:p}));return}C.length>0&&(o?o(C):C.forEach(({file:$})=>{Ft.error(t("documentPanel.uploadDocuments.fileUploader.fileRejected",{name:$.name}))}));const M=N.map($=>Object.assign($,{preview:URL.createObjectURL($)})),I=C.map(({file:$})=>Object.assign($,{preview:URL.createObjectURL($),rejected:!0})),D=[...M,...I],U=k?[...k,...D]:D;if(A(U),a&&N.length>0){const $=N.filter(B=>{var G;if(!B.name)return!1;const W=`.${((G=B.name.split(".").pop())==null?void 0:G.toLowerCase())||""}`,K=Object.entries(u||{}).some(([z,Y])=>B.type===z||Array.isArray(Y)&&Y.includes(W)),H=B.size<=d;return K&&H});$.length>0&&a($)}},[k,p,g,a,o,A,t,u,d]);function R(N){if(!k)return;const C=k.filter((_,M)=>M!==N);A(C),r==null||r(C)}w.useEffect(()=>()=>{k&&k.forEach(N=>{gG(N)&&URL.revokeObjectURL(N.preview)})},[]);const O=m||((k==null?void 0:k.length)??0)>=p;return E.jsxs("div",{className:"relative flex flex-col gap-6 overflow-hidden",children:[E.jsx(Op,{onDrop:x,noClick:!1,noKeyboard:!1,maxSize:d,maxFiles:p,multiple:p>1||g,disabled:O,validator:N=>{var M;if(!N.name)return{code:"invalid-file-name",message:t("documentPanel.uploadDocuments.fileUploader.invalidFileName",{fallback:"Invalid file name"})};const C=`.${((M=N.name.split(".").pop())==null?void 0:M.toLowerCase())||""}`;return Object.entries(u||{}).some(([I,D])=>N.type===I||Array.isArray(D)&&D.includes(C))?N.size>d?{code:"file-too-large",message:t("documentPanel.uploadDocuments.fileUploader.fileTooLarge",{maxSize:hk(d)})}:null:{code:"file-invalid-type",message:t("documentPanel.uploadDocuments.fileUploader.unsupportedType")}},children:({getRootProps:N,getInputProps:C,isDragActive:_})=>E.jsxs("div",{...N(),className:Me("group border-muted-foreground/25 hover:bg-muted/25 relative grid h-52 w-full cursor-pointer place-items-center rounded-lg border-2 border-dashed px-5 py-2.5 text-center transition","ring-offset-background focus-visible:ring-ring focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none",_&&"border-muted-foreground/50",O&&"pointer-events-none opacity-60",v),...y,children:[E.jsx("input",{...C()}),_?E.jsxs("div",{className:"flex flex-col items-center justify-center gap-4 sm:px-5",children:[E.jsx("div",{className:"rounded-full border border-dashed p-3",children:E.jsx(F0,{className:"text-muted-foreground size-7","aria-hidden":"true"})}),E.jsx("p",{className:"text-muted-foreground font-medium",children:t("documentPanel.uploadDocuments.fileUploader.dropHere")})]}):E.jsxs("div",{className:"flex flex-col items-center justify-center gap-4 sm:px-5",children:[E.jsx("div",{className:"rounded-full border border-dashed p-3",children:E.jsx(F0,{className:"text-muted-foreground size-7","aria-hidden":"true"})}),E.jsxs("div",{className:"flex flex-col gap-px",children:[E.jsx("p",{className:"text-muted-foreground font-medium",children:t("documentPanel.uploadDocuments.fileUploader.dragAndDrop")}),b?E.jsx("p",{className:"text-muted-foreground/70 text-sm",children:b}):E.jsxs("p",{className:"text-muted-foreground/70 text-sm",children:[t("documentPanel.uploadDocuments.fileUploader.uploadDescription",{count:p,isMultiple:p===1/0,maxSize:hk(d)}),t("documentPanel.uploadDocuments.fileTypes")]})]})]})]})}),k!=null&&k.length?E.jsx(XT,{className:"h-fit w-full px-3",children:E.jsx("div",{className:"flex max-h-48 flex-col gap-4",children:k==null?void 0:k.map((N,C)=>E.jsx(Uie,{file:N,onRemove:()=>R(C),progress:s==null?void 0:s[N.name],error:l==null?void 0:l[N.name]},C))})}):null]})}function aI({value:e,error:t}){return E.jsx("div",{className:"relative h-2 w-full",children:E.jsx("div",{className:"h-full w-full overflow-hidden rounded-full bg-secondary",children:E.jsx("div",{className:Me("h-full transition-all",t?"bg-red-400":"bg-primary"),style:{width:`${e}%`}})})})}function Uie({file:e,progress:t,error:n,onRemove:r}){const{t:a}=Et();return E.jsxs("div",{className:"relative flex items-center gap-2.5",children:[E.jsxs("div",{className:"flex flex-1 gap-2.5",children:[n?E.jsx(BU,{className:"text-red-400 size-10","aria-hidden":"true"}):gG(e)?E.jsx(Gie,{file:e}):null,E.jsxs("div",{className:"flex w-full flex-col gap-2",children:[E.jsxs("div",{className:"flex flex-col gap-px",children:[E.jsx("p",{className:"text-foreground/80 line-clamp-1 text-sm font-medium",children:e.name}),E.jsx("p",{className:"text-muted-foreground text-xs",children:hk(e.size)})]}),n?E.jsxs("div",{className:"text-red-400 text-sm",children:[E.jsx("div",{className:"relative mb-2",children:E.jsx(aI,{value:100,error:!0})}),E.jsx("p",{children:n})]}):t?E.jsx(aI,{value:t}):null]})]}),E.jsx("div",{className:"flex items-center gap-2",children:E.jsxs(nt,{type:"button",variant:"outline",size:"icon",className:"size-7",onClick:r,children:[E.jsx(HU,{className:"size-4","aria-hidden":"true"}),E.jsx("span",{className:"sr-only",children:a("documentPanel.uploadDocuments.fileUploader.removeFile")})]})})]})}function gG(e){return"preview"in e&&typeof e.preview=="string"}function Gie({file:e}){return e.type.startsWith("image/")?E.jsx("div",{className:"aspect-square shrink-0 rounded-md object-cover"}):E.jsx(BU,{className:"text-muted-foreground size-10","aria-hidden":"true"})}function Hie({onDocumentsUploaded:e}){const{t}=Et(),[n,r]=w.useState(!1),[a,o]=w.useState(!1),[s,l]=w.useState({}),[u,d]=w.useState({}),p=w.useCallback(m=>{m.forEach(({file:b,errors:v})=>{var k;let y=((k=v[0])==null?void 0:k.message)||t("documentPanel.uploadDocuments.fileUploader.fileRejected",{name:b.name});y.includes("file-invalid-type")&&(y=t("documentPanel.uploadDocuments.fileUploader.unsupportedType")),l(A=>({...A,[b.name]:100})),d(A=>({...A,[b.name]:y}))})},[l,d,t]),g=w.useCallback(async m=>{o(!0);let b=!1;d(y=>{const k={...y};return m.forEach(A=>{delete k[A.name]}),k});const v=Ft.loading(t("documentPanel.uploadDocuments.batch.uploading"));try{const y={};await Promise.all(m.map(async A=>{var x,R;try{l(N=>({...N,[A.name]:0}));const O=await OV(A,N=>{console.debug(t("documentPanel.uploadDocuments.single.uploading",{name:A.name,percent:N})),l(C=>({...C,[A.name]:N}))});O.status==="duplicated"?(y[A.name]=t("documentPanel.uploadDocuments.fileUploader.duplicateFile"),d(N=>({...N,[A.name]:t("documentPanel.uploadDocuments.fileUploader.duplicateFile")}))):O.status!=="success"?(y[A.name]=O.message,d(N=>({...N,[A.name]:O.message}))):b=!0}catch(O){console.error(`Upload failed for ${A.name}:`,O);let N=Gn(O);if(O&&typeof O=="object"&&"response"in O){const C=O;((x=C.response)==null?void 0:x.status)===400&&(N=((R=C.response.data)==null?void 0:R.detail)||N),l(_=>({..._,[A.name]:100}))}y[A.name]=N,d(C=>({...C,[A.name]:N}))}})),Object.keys(y).length>0?Ft.error(t("documentPanel.uploadDocuments.batch.error"),{id:v}):Ft.success(t("documentPanel.uploadDocuments.batch.success"),{id:v}),b&&e&&e().catch(A=>{console.error("Error refreshing documents:",A)})}catch(y){console.error("Unexpected error during upload:",y),Ft.error(t("documentPanel.uploadDocuments.generalError",{error:Gn(y)}),{id:v})}finally{o(!1)}},[o,l,d,t,e]);return E.jsxs(hp,{open:n,onOpenChange:m=>{a||(m||(l({}),d({})),r(m))},children:[E.jsx($U,{asChild:!0,children:E.jsxs(nt,{variant:"default",side:"bottom",tooltip:t("documentPanel.uploadDocuments.tooltip"),size:"sm",children:[E.jsx(F0,{})," ",t("documentPanel.uploadDocuments.button")]})}),E.jsxs(Wc,{className:"sm:max-w-xl",onCloseAutoFocus:m=>m.preventDefault(),children:[E.jsxs(Yc,{children:[E.jsx(Kc,{children:t("documentPanel.uploadDocuments.title")}),E.jsx(Xc,{children:t("documentPanel.uploadDocuments.description")})]}),E.jsx(jie,{maxFileCount:1/0,maxSize:200*1024*1024,description:t("documentPanel.uploadDocuments.fileTypes"),onUpload:g,onReject:p,progresses:s,fileErrors:u,disabled:a})]})]})}const oI=({htmlFor:e,className:t,children:n,...r})=>E.jsx("label",{htmlFor:e,className:t,...r,children:n});function $ie({onDocumentsCleared:e}){const{t}=Et(),[n,r]=w.useState(!1),[a,o]=w.useState(""),[s,l]=w.useState(!1),u=a.toLowerCase()==="yes";w.useEffect(()=>{n||(o(""),l(!1))},[n]);const d=w.useCallback(async()=>{if(u)try{const p=await IV();if(p.status!=="success"){Ft.error(t("documentPanel.clearDocuments.failed",{message:p.message})),o("");return}if(Ft.success(t("documentPanel.clearDocuments.success")),s)try{await DV(),Ft.success(t("documentPanel.clearDocuments.cacheCleared"))}catch(g){Ft.error(t("documentPanel.clearDocuments.cacheClearFailed",{error:Gn(g)}))}e&&e().catch(console.error),r(!1)}catch(p){Ft.error(t("documentPanel.clearDocuments.error",{error:Gn(p)})),o("")}},[u,s,r,t,e]);return E.jsxs(hp,{open:n,onOpenChange:r,children:[E.jsx($U,{asChild:!0,children:E.jsxs(nt,{variant:"outline",side:"bottom",tooltip:t("documentPanel.clearDocuments.tooltip"),size:"sm",children:[E.jsx(zU,{})," ",t("documentPanel.clearDocuments.button")]})}),E.jsxs(Wc,{className:"sm:max-w-xl",onCloseAutoFocus:p=>p.preventDefault(),children:[E.jsxs(Yc,{children:[E.jsxs(Kc,{className:"flex items-center gap-2 text-red-500 dark:text-red-400 font-bold",children:[E.jsx(eQ,{className:"h-5 w-5"}),t("documentPanel.clearDocuments.title")]}),E.jsx(Xc,{className:"pt-2",children:t("documentPanel.clearDocuments.description")})]}),E.jsx("div",{className:"text-red-500 dark:text-red-400 font-semibold mb-4",children:t("documentPanel.clearDocuments.warning")}),E.jsx("div",{className:"mb-4",children:t("documentPanel.clearDocuments.confirm")}),E.jsxs("div",{className:"space-y-4",children:[E.jsxs("div",{className:"space-y-2",children:[E.jsx(oI,{htmlFor:"confirm-text",className:"text-sm font-medium",children:t("documentPanel.clearDocuments.confirmPrompt")}),E.jsx(kr,{id:"confirm-text",value:a,onChange:p=>o(p.target.value),placeholder:t("documentPanel.clearDocuments.confirmPlaceholder"),className:"w-full"})]}),E.jsxs("div",{className:"flex items-center space-x-2",children:[E.jsx(Ns,{id:"clear-cache",checked:s,onCheckedChange:p=>l(p===!0)}),E.jsx(oI,{htmlFor:"clear-cache",className:"text-sm font-medium cursor-pointer",children:t("documentPanel.clearDocuments.clearCache")})]})]}),E.jsxs(VU,{children:[E.jsx(nt,{variant:"outline",onClick:()=>r(!1),children:t("common.cancel")}),E.jsx(nt,{variant:"destructive",onClick:d,disabled:!u,children:t("documentPanel.clearDocuments.confirmButton")})]})]})]})}function qie({open:e,onOpenChange:t}){var g;const{t:n}=Et(),[r,a]=w.useState(null),[o,s]=w.useState("center"),[l,u]=w.useState(!1),d=w.useRef(null);w.useEffect(()=>{e&&(s("center"),u(!1))},[e]),w.useEffect(()=>{const m=d.current;!m||l||(m.scrollTop=m.scrollHeight)},[r==null?void 0:r.history_messages,l]);const p=()=>{const m=d.current;if(!m)return;const b=Math.abs(m.scrollHeight-m.scrollTop-m.clientHeight)<1;u(!b)};return w.useEffect(()=>{if(!e)return;const m=async()=>{try{const v=await LV();a(v)}catch(v){Ft.error(n("documentPanel.pipelineStatus.errors.fetchFailed",{error:Gn(v)}))}};m();const b=setInterval(m,2e3);return()=>clearInterval(b)},[e,n]),E.jsx(hp,{open:e,onOpenChange:t,children:E.jsxs(Wc,{className:Me("sm:max-w-[600px] transition-all duration-200 fixed",o==="left"&&"!left-[25%] !translate-x-[-50%] !mx-4",o==="center"&&"!left-1/2 !-translate-x-1/2",o==="right"&&"!left-[75%] !translate-x-[-50%] !mx-4"),children:[E.jsx(Xc,{className:"sr-only",children:r!=null&&r.job_name?`${n("documentPanel.pipelineStatus.jobName")}: ${r.job_name}, ${n("documentPanel.pipelineStatus.progress")}: ${r.cur_batch}/${r.batchs}`:n("documentPanel.pipelineStatus.noActiveJob")}),E.jsxs(Yc,{className:"flex flex-row items-center",children:[E.jsx(Kc,{className:"flex-1",children:n("documentPanel.pipelineStatus.title")}),E.jsxs("div",{className:"flex items-center gap-2 mr-8",children:[E.jsx(nt,{variant:"ghost",size:"icon",className:Me("h-6 w-6",o==="left"&&"bg-zinc-200 text-zinc-800 hover:bg-zinc-300 dark:bg-zinc-700 dark:text-zinc-200 dark:hover:bg-zinc-600"),onClick:()=>s("left"),children:E.jsx(ZX,{className:"h-4 w-4"})}),E.jsx(nt,{variant:"ghost",size:"icon",className:Me("h-6 w-6",o==="center"&&"bg-zinc-200 text-zinc-800 hover:bg-zinc-300 dark:bg-zinc-700 dark:text-zinc-200 dark:hover:bg-zinc-600"),onClick:()=>s("center"),children:E.jsx(KX,{className:"h-4 w-4"})}),E.jsx(nt,{variant:"ghost",size:"icon",className:Me("h-6 w-6",o==="right"&&"bg-zinc-200 text-zinc-800 hover:bg-zinc-300 dark:bg-zinc-700 dark:text-zinc-200 dark:hover:bg-zinc-600"),onClick:()=>s("right"),children:E.jsx(JX,{className:"h-4 w-4"})})]})]}),E.jsxs("div",{className:"space-y-4 pt-4",children:[E.jsxs("div",{className:"flex items-center gap-4",children:[E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsxs("div",{className:"text-sm font-medium",children:[n("documentPanel.pipelineStatus.busy"),":"]}),E.jsx("div",{className:`h-2 w-2 rounded-full ${r!=null&&r.busy?"bg-green-500":"bg-gray-300"}`})]}),E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsxs("div",{className:"text-sm font-medium",children:[n("documentPanel.pipelineStatus.requestPending"),":"]}),E.jsx("div",{className:`h-2 w-2 rounded-full ${r!=null&&r.request_pending?"bg-green-500":"bg-gray-300"}`})]})]}),E.jsxs("div",{className:"rounded-md border p-3 space-y-2",children:[E.jsxs("div",{children:[n("documentPanel.pipelineStatus.jobName"),": ",(r==null?void 0:r.job_name)||"-"]}),E.jsxs("div",{className:"flex justify-between",children:[E.jsxs("span",{children:[n("documentPanel.pipelineStatus.startTime"),": ",r!=null&&r.job_start?new Date(r.job_start).toLocaleString():"-"]}),E.jsxs("span",{children:[n("documentPanel.pipelineStatus.progress"),": ",r?`${r.cur_batch}/${r.batchs} ${n("documentPanel.pipelineStatus.unit")}`:"-"]})]})]}),E.jsxs("div",{className:"space-y-2",children:[E.jsxs("div",{className:"text-sm font-medium",children:[n("documentPanel.pipelineStatus.latestMessage"),":"]}),E.jsx("div",{className:"font-mono text-sm rounded-md bg-zinc-800 text-zinc-100 p-3",children:(r==null?void 0:r.latest_message)||"-"})]}),E.jsxs("div",{className:"space-y-2",children:[E.jsxs("div",{className:"text-sm font-medium",children:[n("documentPanel.pipelineStatus.historyMessages"),":"]}),E.jsx("div",{ref:d,onScroll:p,className:"font-mono text-sm rounded-md bg-zinc-800 text-zinc-100 p-3 overflow-y-auto min-h-[7.5em] max-h-[40vh]",children:(g=r==null?void 0:r.history_messages)!=null&&g.length?r.history_messages.map((m,b)=>E.jsx("div",{children:m},b)):"-"})]})]})]})})}const gb=(e,t=20)=>{if(!e.file_path||typeof e.file_path!="string"||e.file_path.trim()==="")return e.id;const n=e.file_path.split("/"),r=n[n.length-1];return!r||r.trim()===""?e.id:r.length>t?r.slice(0,t)+"...":r},Vie=`
/* Tooltip styles */
.tooltip-container {
  position: relative;
  overflow: visible !important;
}

.tooltip {
  position: fixed; /* Use fixed positioning to escape overflow constraints */
  z-index: 9999; /* Ensure tooltip appears above all other elements */
  max-width: 600px;
  white-space: normal;
  border-radius: 0.375rem;
  padding: 0.5rem 0.75rem;
  background-color: rgba(0, 0, 0, 0.95);
  color: white;
  box-shadow: 0 2px 4px rgba(0, 0, 0, 0.1);
  pointer-events: none; /* Prevent tooltip from interfering with mouse events */
  opacity: 0;
  visibility: hidden;
  transition: opacity 0.15s, visibility 0.15s;
}

.tooltip.visible {
  opacity: 1;
  visibility: visible;
}

.dark .tooltip {
  background-color: rgba(255, 255, 255, 0.95);
  color: black;
}

/* Position tooltip helper class */
.tooltip-helper {
  position: absolute;
  visibility: hidden;
  pointer-events: none;
  top: 0;
  left: 0;
  width: 100%;
  height: 0;
}

@keyframes pulse {
  0% {
    background-color: rgb(255 0 0 / 0.1);
    border-color: rgb(255 0 0 / 0.2);
  }
  50% {
    background-color: rgb(255 0 0 / 0.2);
    border-color: rgb(255 0 0 / 0.4);
  }
  100% {
    background-color: rgb(255 0 0 / 0.1);
    border-color: rgb(255 0 0 / 0.2);
  }
}

.dark .pipeline-busy {
  animation: dark-pulse 2s infinite;
}

@keyframes dark-pulse {
  0% {
    background-color: rgb(255 0 0 / 0.2);
    border-color: rgb(255 0 0 / 0.4);
  }
  50% {
    background-color: rgb(255 0 0 / 0.3);
    border-color: rgb(255 0 0 / 0.6);
  }
  100% {
    background-color: rgb(255 0 0 / 0.2);
    border-color: rgb(255 0 0 / 0.4);
  }
}

.pipeline-busy {
  animation: pulse 2s infinite;
  border: 1px solid;
}
`;function Wie(){const e=w.useRef(!0);w.useEffect(()=>{e.current=!0;const I=()=>{e.current=!1};return window.addEventListener("beforeunload",I),()=>{e.current=!1,window.removeEventListener("beforeunload",I)}},[]);const[t,n]=w.useState(!1),{t:r}=Et(),a=rr.use.health(),o=rr.use.pipelineBusy(),[s,l]=w.useState(null),u=De.use.currentTab(),d=De.use.showFileName(),p=De.use.setShowFileName(),[g,m]=w.useState("updated_at"),[b,v]=w.useState("desc"),[y,k]=w.useState("all"),A=I=>{g===I?v(D=>D==="asc"?"desc":"asc"):(m(I),v("desc"))},x=w.useCallback(I=>[...I].sort((D,U)=>{let $,B;g==="id"&&d?($=gb(D),B=gb(U)):g==="id"?($=D.id,B=U.id):($=new Date(D[g]).getTime(),B=new Date(U[g]).getTime());const W=b==="asc"?1:-1;return typeof $=="string"&&typeof B=="string"?W*$.localeCompare(B):W*($>B?1:$<B?-1:0)}),[g,b,d]),R=w.useMemo(()=>{if(!s)return null;let I={...s};if(y!=="all"&&(I={...s,statuses:{pending:[],processing:[],processed:[],failed:[],[y]:s.statuses[y]||[]}}),!g||!b)return I;const D=Object.entries(I.statuses).reduce((U,[$,B])=>{const W=x(B);return U[$]=W,U},{});return{...I,statuses:D}},[s,g,b,y,x]),O=w.useMemo(()=>{if(!s)return{all:0};const I={all:0};return Object.entries(s.statuses).forEach(([D,U])=>{I[D]=U.length,I.all+=U.length}),I},[s]),N=w.useRef({processed:0,processing:0,pending:0,failed:0});w.useEffect(()=>{const I=document.createElement("style");return I.textContent=Vie,document.head.appendChild(I),()=>{document.head.removeChild(I)}},[]);const C=w.useRef(null);w.useEffect(()=>{if(!s)return;const I=()=>{document.querySelectorAll(".tooltip-container").forEach(B=>{const W=B.querySelector(".tooltip");if(!W||!W.classList.contains("visible"))return;const K=B.getBoundingClientRect();W.style.left=`${K.left}px`,W.style.top=`${K.top-5}px`,W.style.transform="translateY(-100%)"})},D=$=>{const W=$.target.closest(".tooltip-container");if(!W)return;const K=W.querySelector(".tooltip");K&&(K.classList.add("visible"),I())},U=$=>{const W=$.target.closest(".tooltip-container");if(!W)return;const K=W.querySelector(".tooltip");K&&K.classList.remove("visible")};return document.addEventListener("mouseover",D),document.addEventListener("mouseout",U),()=>{document.removeEventListener("mouseover",D),document.removeEventListener("mouseout",U)}},[s]);const _=w.useCallback(async()=>{var I,D,U,$,B,W,K,H;try{if(!e.current)return;const G=await RV();if(!e.current)return;const z={processed:((D=(I=G==null?void 0:G.statuses)==null?void 0:I.processed)==null?void 0:D.length)||0,processing:(($=(U=G==null?void 0:G.statuses)==null?void 0:U.processing)==null?void 0:$.length)||0,pending:((W=(B=G==null?void 0:G.statuses)==null?void 0:B.pending)==null?void 0:W.length)||0,failed:((H=(K=G==null?void 0:G.statuses)==null?void 0:K.failed)==null?void 0:H.length)||0};Object.keys(z).some(L=>z[L]!==N.current[L])&&e.current&&rr.getState().check(),e.current&&(N.current=z,G&&G.statuses&&Object.values(G.statuses).reduce((V,j)=>V+j.length,0)>0?l(G):l(null))}catch(G){e.current&&Ft.error(r("documentPanel.documentManager.errors.loadFailed",{error:Gn(G)}))}},[l,r]);w.useEffect(()=>{u==="documents"&&_()},[u,_]);const M=w.useCallback(async()=>{try{if(!e.current)return;const{status:I}=await CV();if(!e.current)return;Ft.message(I)}catch(I){e.current&&Ft.error(r("documentPanel.documentManager.errors.scanFailed",{error:Gn(I)}))}},[r]);return w.useEffect(()=>{if(u!=="documents"||!a)return;const I=setInterval(async()=>{try{e.current&&await _()}catch(D){e.current&&Ft.error(r("documentPanel.documentManager.errors.scanProgressFailed",{error:Gn(D)}))}},5e3);return()=>{clearInterval(I)}},[a,_,r,u]),w.useEffect(()=>{},[g,b]),E.jsxs(Ei,{className:"!rounded-none !overflow-hidden flex flex-col h-full min-h-0",children:[E.jsx(_c,{className:"py-2 px-6",children:E.jsx(Nc,{className:"text-lg",children:r("documentPanel.documentManager.title")})}),E.jsxs(Oc,{className:"flex-1 flex flex-col min-h-0 overflow-auto",children:[E.jsxs("div",{className:"flex gap-2 mb-2",children:[E.jsxs("div",{className:"flex gap-2",children:[E.jsxs(nt,{variant:"outline",onClick:M,side:"bottom",tooltip:r("documentPanel.documentManager.scanTooltip"),size:"sm",children:[E.jsx(UU,{})," ",r("documentPanel.documentManager.scanButton")]}),E.jsxs(nt,{variant:"outline",onClick:()=>n(!0),side:"bottom",tooltip:r("documentPanel.documentManager.pipelineStatusTooltip"),size:"sm",className:Me(o&&"pipeline-busy"),children:[E.jsx(WX,{})," ",r("documentPanel.documentManager.pipelineStatusButton")]})]}),E.jsx("div",{className:"flex-1"}),E.jsx($ie,{onDocumentsCleared:_}),E.jsx(Hie,{onDocumentsUploaded:_}),E.jsx(qie,{open:t,onOpenChange:n})]}),E.jsxs(Ei,{className:"flex-1 flex flex-col border rounded-md min-h-0 mb-2",children:[E.jsxs(_c,{className:"flex-none py-2 px-4",children:[E.jsxs("div",{className:"flex justify-between items-center",children:[E.jsx(Nc,{children:r("documentPanel.documentManager.uploadedTitle")}),E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx(mZ,{className:"h-4 w-4"}),E.jsxs("div",{className:"flex gap-1",children:[E.jsxs(nt,{size:"sm",variant:y==="all"?"secondary":"outline",onClick:()=>k("all"),className:Me(y==="all"&&"bg-gray-100 dark:bg-gray-900 font-medium border border-gray-400 dark:border-gray-500 shadow-sm"),children:[r("documentPanel.documentManager.status.all")," (",O.all,")"]}),E.jsxs(nt,{size:"sm",variant:y==="processed"?"secondary":"outline",onClick:()=>k("processed"),className:Me(O.processed>0?"text-green-600":"text-gray-500",y==="processed"&&"bg-green-100 dark:bg-green-900/30 font-medium border border-green-400 dark:border-green-600 shadow-sm"),children:[r("documentPanel.documentManager.status.completed")," (",O.processed||0,")"]}),E.jsxs(nt,{size:"sm",variant:y==="processing"?"secondary":"outline",onClick:()=>k("processing"),className:Me(O.processing>0?"text-blue-600":"text-gray-500",y==="processing"&&"bg-blue-100 dark:bg-blue-900/30 font-medium border border-blue-400 dark:border-blue-600 shadow-sm"),children:[r("documentPanel.documentManager.status.processing")," (",O.processing||0,")"]}),E.jsxs(nt,{size:"sm",variant:y==="pending"?"secondary":"outline",onClick:()=>k("pending"),className:Me(O.pending>0?"text-yellow-600":"text-gray-500",y==="pending"&&"bg-yellow-100 dark:bg-yellow-900/30 font-medium border border-yellow-400 dark:border-yellow-600 shadow-sm"),children:[r("documentPanel.documentManager.status.pending")," (",O.pending||0,")"]}),E.jsxs(nt,{size:"sm",variant:y==="failed"?"secondary":"outline",onClick:()=>k("failed"),className:Me(O.failed>0?"text-red-600":"text-gray-500",y==="failed"&&"bg-red-100 dark:bg-red-900/30 font-medium border border-red-400 dark:border-red-600 shadow-sm"),children:[r("documentPanel.documentManager.status.failed")," (",O.failed||0,")"]})]})]}),E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("label",{htmlFor:"toggle-filename-btn",className:"text-sm text-gray-500",children:r("documentPanel.documentManager.fileNameLabel")}),E.jsx(nt,{id:"toggle-filename-btn",variant:"outline",size:"sm",onClick:()=>p(!d),className:"border-gray-200 dark:border-gray-700 hover:bg-gray-100 dark:hover:bg-gray-800",children:r(d?"documentPanel.documentManager.hideButton":"documentPanel.documentManager.showButton")})]})]}),E.jsx(Cp,{"aria-hidden":"true",className:"hidden",children:r("documentPanel.documentManager.uploadedDescription")})]}),E.jsxs(Oc,{className:"flex-1 relative p-0",ref:C,children:[!s&&E.jsx("div",{className:"absolute inset-0 p-0",children:E.jsx(Boe,{title:r("documentPanel.documentManager.emptyTitle"),description:r("documentPanel.documentManager.emptyDescription")})}),s&&E.jsx("div",{className:"absolute inset-0 flex flex-col p-0",children:E.jsx("div",{className:"absolute inset-[-1px] flex flex-col p-0 border rounded-md border-gray-200 dark:border-gray-700 overflow-hidden",children:E.jsxs(tG,{className:"w-full",children:[E.jsx(nG,{className:"sticky top-0 bg-background z-10 shadow-sm",children:E.jsxs(ck,{className:"border-b bg-card/95 backdrop-blur supports-[backdrop-filter]:bg-card/75 shadow-[inset_0_-1px_0_rgba(0,0,0,0.1)]",children:[E.jsx(wo,{onClick:()=>A("id"),className:"cursor-pointer hover:bg-gray-200 dark:hover:bg-gray-800 select-none",children:E.jsxs("div",{className:"flex items-center",children:[r("documentPanel.documentManager.columns.id"),g==="id"&&E.jsx("span",{className:"ml-1",children:b==="asc"?E.jsx(mm,{size:14}):E.jsx(hm,{size:14})})]})}),E.jsx(wo,{children:r("documentPanel.documentManager.columns.summary")}),E.jsx(wo,{children:r("documentPanel.documentManager.columns.status")}),E.jsx(wo,{children:r("documentPanel.documentManager.columns.length")}),E.jsx(wo,{children:r("documentPanel.documentManager.columns.chunks")}),E.jsx(wo,{onClick:()=>A("created_at"),className:"cursor-pointer hover:bg-gray-200 dark:hover:bg-gray-800 select-none",children:E.jsxs("div",{className:"flex items-center",children:[r("documentPanel.documentManager.columns.created"),g==="created_at"&&E.jsx("span",{className:"ml-1",children:b==="asc"?E.jsx(mm,{size:14}):E.jsx(hm,{size:14})})]})}),E.jsx(wo,{onClick:()=>A("updated_at"),className:"cursor-pointer hover:bg-gray-200 dark:hover:bg-gray-800 select-none",children:E.jsxs("div",{className:"flex items-center",children:[r("documentPanel.documentManager.columns.updated"),g==="updated_at"&&E.jsx("span",{className:"ml-1",children:b==="asc"?E.jsx(mm,{size:14}):E.jsx(hm,{size:14})})]})})]})}),E.jsx(rG,{className:"text-sm overflow-auto",children:(R==null?void 0:R.statuses)&&Object.entries(R.statuses).flatMap(([I,D])=>D.map(U=>E.jsxs(ck,{children:[E.jsx(xo,{className:"truncate font-mono overflow-visible max-w-[250px]",children:d?E.jsxs(E.Fragment,{children:[E.jsxs("div",{className:"group relative overflow-visible tooltip-container",children:[E.jsx("div",{className:"truncate",children:gb(U,30)}),E.jsx("div",{className:"invisible group-hover:visible tooltip",children:U.file_path})]}),E.jsx("div",{className:"text-xs text-gray-500",children:U.id})]}):E.jsxs("div",{className:"group relative overflow-visible tooltip-container",children:[E.jsx("div",{className:"truncate",children:U.id}),E.jsx("div",{className:"invisible group-hover:visible tooltip",children:U.file_path})]})}),E.jsx(xo,{className:"max-w-xs min-w-45 truncate overflow-visible",children:E.jsxs("div",{className:"group relative overflow-visible tooltip-container",children:[E.jsx("div",{className:"truncate",children:U.content_summary}),E.jsx("div",{className:"invisible group-hover:visible tooltip",children:U.content_summary})]})}),E.jsxs(xo,{children:[I==="processed"&&E.jsx("span",{className:"text-green-600",children:r("documentPanel.documentManager.status.completed")}),I==="processing"&&E.jsx("span",{className:"text-blue-600",children:r("documentPanel.documentManager.status.processing")}),I==="pending"&&E.jsx("span",{className:"text-yellow-600",children:r("documentPanel.documentManager.status.pending")}),I==="failed"&&E.jsx("span",{className:"text-red-600",children:r("documentPanel.documentManager.status.failed")}),U.error&&E.jsx("span",{className:"ml-2 text-red-500",title:U.error,children:"⚠️"})]}),E.jsx(xo,{children:U.content_length??"-"}),E.jsx(xo,{children:U.chunks_count??"-"}),E.jsx(xo,{className:"truncate",children:new Date(U.created_at).toLocaleString()}),E.jsx(xo,{className:"truncate",children:new Date(U.updated_at).toLocaleString()})]},U.id)))})]})})})]})]})]})]})}function hG(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var a=0,r=Object.getOwnPropertySymbols(e);a<r.length;a++)t.indexOf(r[a])<0&&Object.prototype.propertyIsEnumerable.call(e,r[a])&&(n[r[a]]=e[r[a]]);return n}var Dc;(function(e){e.event="event",e.props="prop"})(Dc||(Dc={}));function ko(){}function Yie(e){var t,n=void 0;return function(){for(var r=[],a=arguments.length;a--;)r[a]=arguments[a];return t&&r.length===t.length&&r.every(function(o,s){return o===t[s]})||(t=r,n=e.apply(void 0,r)),n}}function Lc(e){return!!(e||"").match(/\d/)}function Os(e){return e==null}function Kie(e){return typeof e=="number"&&isNaN(e)}function mG(e){return Os(e)||Kie(e)||typeof e=="number"&&!isFinite(e)}function bG(e){return e.replace(/[-[\]/{}()*+?.\\^$|]/g,"\\$&")}function Xie(e){switch(e){case"lakh":return/(\d+?)(?=(\d\d)+(\d)(?!\d))(\.\d+)?/g;case"wan":return/(\d)(?=(\d{4})+(?!\d))/g;case"thousand":default:return/(\d)(?=(\d{3})+(?!\d))/g}}function Zie(e,t,n){var r=Xie(n),a=e.search(/[1-9]/);return a=a===-1?e.length:a,e.substring(0,a)+e.substring(a,e.length).replace(r,"$1"+t)}function Qie(e){var t=w.useRef(e);t.current=e;var n=w.useRef(function(){for(var r=[],a=arguments.length;a--;)r[a]=arguments[a];return t.current.apply(t,r)});return n.current}function ZT(e,t){t===void 0&&(t=!0);var n=e[0]==="-",r=n&&t;e=e.replace("-","");var a=e.split("."),o=a[0],s=a[1]||"";return{beforeDecimal:o,afterDecimal:s,hasNegation:n,addNegation:r}}function Jie(e){if(!e)return e;var t=e[0]==="-";t&&(e=e.substring(1,e.length));var n=e.split("."),r=n[0].replace(/^0+/,"")||"0",a=n[1]||"";return(t?"-":"")+r+(a?"."+a:"")}function yG(e,t,n){for(var r="",a=n?"0":"",o=0;o<=t-1;o++)r+=e[o]||a;return r}function iI(e,t){return Array(t+1).join(e)}function vG(e){var t=e+"",n=t[0]==="-"?"-":"";n&&(t=t.substring(1));var r=t.split(/[eE]/g),a=r[0],o=r[1];if(o=Number(o),!o)return n+a;a=a.replace(".","");var s=1+o,l=a.length;return s<0?a="0."+iI("0",Math.abs(s))+a:s>=l?a=a+iI("0",s-l):a=(a.substring(0,s)||"0")+"."+a.substring(s),n+a}function sI(e,t,n){if(["","-"].indexOf(e)!==-1)return e;var r=(e.indexOf(".")!==-1||n)&&t,a=ZT(e),o=a.beforeDecimal,s=a.afterDecimal,l=a.hasNegation,u=parseFloat("0."+(s||"0")),d=s.length<=t?"0."+s:u.toFixed(t),p=d.split("."),g=o;o&&Number(p[0])&&(g=o.split("").reverse().reduce(function(y,k,A){return y.length>A?(Number(y[0])+Number(k)).toString()+y.substring(1,y.length):k+y},p[0]));var m=yG(p[1]||"",t,n),b=l?"-":"",v=r?".":"";return""+b+g+v+m}function di(e,t){if(e.value=e.value,e!==null){if(e.createTextRange){var n=e.createTextRange();return n.move("character",t),n.select(),!0}return e.selectionStart||e.selectionStart===0?(e.focus(),e.setSelectionRange(t,t),!0):(e.focus(),!1)}}var SG=Yie(function(e,t){for(var n=0,r=0,a=e.length,o=t.length;e[n]===t[n]&&n<a;)n++;for(;e[a-1-r]===t[o-1-r]&&o-r>n&&a-r>n;)r++;return{from:{start:n,end:a-r},to:{start:n,end:o-r}}}),ese=function(e,t){var n=Math.min(e.selectionStart,t);return{from:{start:n,end:e.selectionEnd},to:{start:n,end:t}}};function tse(e,t,n){return Math.min(Math.max(e,t),n)}function hb(e){return Math.max(e.selectionStart,e.selectionEnd)}function nse(){return typeof navigator<"u"&&!(navigator.platform&&/iPhone|iPod/.test(navigator.platform))}function rse(e){return{from:{start:0,end:0},to:{start:0,end:e.length},lastValue:""}}function ase(e){var t=e.currentValue,n=e.formattedValue,r=e.currentValueIndex,a=e.formattedValueIndex;return t[r]===n[a]}function ose(e,t,n,r,a,o,s){s===void 0&&(s=ase);var l=a.findIndex(function(O){return O}),u=e.slice(0,l);!t&&!n.startsWith(u)&&(t=u,n=u+n,r=r+u.length);for(var d=n.length,p=e.length,g={},m=new Array(d),b=0;b<d;b++){m[b]=-1;for(var v=0,y=p;v<y;v++){var k=s({currentValue:n,lastValue:t,formattedValue:e,currentValueIndex:b,formattedValueIndex:v});if(k&&g[v]!==!0){m[b]=v,g[v]=!0;break}}}for(var A=r;A<d&&(m[A]===-1||!o(n[A]));)A++;var x=A===d||m[A]===-1?p:m[A];for(A=r-1;A>0&&m[A]===-1;)A--;var R=A===-1||m[A]===-1?0:m[A]+1;return R>x?x:r-R<x-r?R:x}function lI(e,t,n,r){var a=e.length;if(t=tse(t,0,a),r==="left"){for(;t>=0&&!n[t];)t--;t===-1&&(t=n.indexOf(!0))}else{for(;t<=a&&!n[t];)t++;t>a&&(t=n.lastIndexOf(!0))}return t===-1&&(t=a),t}function ise(e){for(var t=Array.from({length:e.length+1}).map(function(){return!0}),n=0,r=t.length;n<r;n++)t[n]=!!(Lc(e[n])||Lc(e[n-1]));return t}function EG(e,t,n,r,a,o){o===void 0&&(o=ko);var s=Qie(function(v,y){var k,A;return mG(v)?(A="",k=""):typeof v=="number"||y?(A=typeof v=="number"?vG(v):v,k=r(A)):(A=a(v,void 0),k=r(A)),{formattedValue:k,numAsString:A}}),l=w.useState(function(){return s(Os(e)?t:e,n)}),u=l[0],d=l[1],p=function(v,y){v.formattedValue!==u.formattedValue&&d({formattedValue:v.formattedValue,numAsString:v.value}),o(v,y)},g=e,m=n;Os(e)&&(g=u.numAsString,m=!0);var b=s(g,m);return w.useMemo(function(){d(b)},[b.formattedValue]),[u,p]}function sse(e){return e.replace(/[^0-9]/g,"")}function lse(e){return e}function cse(e){var t=e.type;t===void 0&&(t="text");var n=e.displayType;n===void 0&&(n="input");var r=e.customInput,a=e.renderText,o=e.getInputRef,s=e.format;s===void 0&&(s=lse);var l=e.removeFormatting;l===void 0&&(l=sse);var u=e.defaultValue,d=e.valueIsNumericString,p=e.onValueChange,g=e.isAllowed,m=e.onChange;m===void 0&&(m=ko);var b=e.onKeyDown;b===void 0&&(b=ko);var v=e.onMouseUp;v===void 0&&(v=ko);var y=e.onFocus;y===void 0&&(y=ko);var k=e.onBlur;k===void 0&&(k=ko);var A=e.value,x=e.getCaretBoundary;x===void 0&&(x=ise);var R=e.isValidInputCharacter;R===void 0&&(R=Lc);var O=e.isCharacterSame,N=hG(e,["type","displayType","customInput","renderText","getInputRef","format","removeFormatting","defaultValue","valueIsNumericString","onValueChange","isAllowed","onChange","onKeyDown","onMouseUp","onFocus","onBlur","value","getCaretBoundary","isValidInputCharacter","isCharacterSame"]),C=EG(A,u,!!d,s,l,p),_=C[0],M=_.formattedValue,I=_.numAsString,D=C[1],U=w.useRef(),$=w.useRef({formattedValue:M,numAsString:I}),B=function(pe,ke){$.current={formattedValue:pe.formattedValue,numAsString:pe.value},D(pe,ke)},W=w.useState(!1),K=W[0],H=W[1],G=w.useRef(null),z=w.useRef({setCaretTimeout:null,focusTimeout:null});w.useEffect(function(){return H(!0),function(){clearTimeout(z.current.setCaretTimeout),clearTimeout(z.current.focusTimeout)}},[]);var Y=s,L=function(pe,ke){var he=parseFloat(ke);return{formattedValue:pe,value:ke,floatValue:isNaN(he)?void 0:he}},V=function(pe,ke,he){pe.selectionStart===0&&pe.selectionEnd===pe.value.length||(di(pe,ke),z.current.setCaretTimeout=setTimeout(function(){pe.value===he&&pe.selectionStart!==ke&&di(pe,ke)},0))},j=function(pe,ke,he){return lI(pe,ke,x(pe),he)},P=function(pe,ke,he){var Ee=x(ke),se=ose(ke,M,pe,he,Ee,R,O);return se=lI(ke,se,Ee),se},Z=function(pe){var ke=pe.formattedValue;ke===void 0&&(ke="");var he=pe.input,Ee=pe.source,se=pe.event,Be=pe.numAsString,je;if(he){var ye=pe.inputValue||he.value,Oe=hb(he);he.value=ke,je=P(ye,ke,Oe),je!==void 0&&V(he,je,ke)}ke!==M&&B(L(ke,Be),{event:se,source:Ee})};w.useEffect(function(){var pe=$.current,ke=pe.formattedValue,he=pe.numAsString;(M!==ke||I!==he)&&B(L(M,I),{event:void 0,source:Dc.props})},[M,I]);var Q=G.current?hb(G.current):void 0,oe=typeof window<"u"?w.useLayoutEffect:w.useEffect;oe(function(){var pe=G.current;if(M!==$.current.formattedValue&&pe){var ke=P($.current.formattedValue,M,Q);pe.value=M,V(pe,ke,M)}},[M]);var ae=function(pe,ke,he){var Ee=ke.target,se=U.current?ese(U.current,Ee.selectionEnd):SG(M,pe),Be=Object.assign(Object.assign({},se),{lastValue:M}),je=l(pe,Be),ye=Y(je);if(je=l(ye,void 0),g&&!g(L(ye,je))){var Oe=ke.target,ee=hb(Oe),de=P(pe,M,ee);return Oe.value=M,V(Oe,de,M),!1}return Z({formattedValue:ye,numAsString:je,inputValue:pe,event:ke,source:he,input:ke.target}),!0},ce=function(pe,ke){ke===void 0&&(ke=0);var he=pe.selectionStart,Ee=pe.selectionEnd;U.current={selectionStart:he,selectionEnd:Ee+ke}},Re=function(pe){var ke=pe.target,he=ke.value,Ee=ae(he,pe,Dc.event);Ee&&m(pe),U.current=void 0},ie=function(pe){var ke=pe.target,he=pe.key,Ee=ke.selectionStart,se=ke.selectionEnd,Be=ke.value;Be===void 0&&(Be="");var je;he==="ArrowLeft"||he==="Backspace"?je=Math.max(Ee-1,0):he==="ArrowRight"?je=Math.min(Ee+1,Be.length):he==="Delete"&&(je=Ee);var ye=0;he==="Delete"&&Ee===se&&(ye=1);var Oe=he==="ArrowLeft"||he==="ArrowRight";if(je===void 0||Ee!==se&&!Oe){b(pe),ce(ke,ye);return}var ee=je;if(Oe){var de=he==="ArrowLeft"?"left":"right";ee=j(Be,je,de),ee!==je&&pe.preventDefault()}else he==="Delete"&&!R(Be[je])?ee=j(Be,je,"right"):he==="Backspace"&&!R(Be[je])&&(ee=j(Be,je,"left"));ee!==je&&V(ke,ee,Be),b(pe),ce(ke,ye)},Te=function(pe){var ke=pe.target,he=function(){var Ee=ke.selectionStart,se=ke.selectionEnd,Be=ke.value;if(Be===void 0&&(Be=""),Ee===se){var je=j(Be,Ee);je!==Ee&&V(ke,je,Be)}};he(),requestAnimationFrame(function(){he()}),v(pe),ce(ke)},ne=function(pe){pe.persist&&pe.persist();var ke=pe.target,he=pe.currentTarget;G.current=ke,z.current.focusTimeout=setTimeout(function(){var Ee=ke.selectionStart,se=ke.selectionEnd,Be=ke.value;Be===void 0&&(Be="");var je=j(Be,Ee);je!==Ee&&!(Ee===0&&se===Be.length)&&V(ke,je,Be),y(Object.assign(Object.assign({},pe),{currentTarget:he}))},0)},xe=function(pe){G.current=null,clearTimeout(z.current.focusTimeout),clearTimeout(z.current.setCaretTimeout),k(pe)},Se=K&&nse()?"numeric":void 0,be=Object.assign({inputMode:Se},N,{type:t,value:M,onChange:Re,onKeyDown:ie,onMouseUp:Te,onFocus:ne,onBlur:xe});if(n==="text")return a?we.createElement(we.Fragment,null,a(M,N)||null):we.createElement("span",Object.assign({},N,{ref:o}),M);if(r){var J=r;return we.createElement(J,Object.assign({},be,{ref:o}))}return we.createElement("input",Object.assign({},be,{ref:o}))}function cI(e,t){var n=t.decimalScale,r=t.fixedDecimalScale,a=t.prefix;a===void 0&&(a="");var o=t.suffix;o===void 0&&(o="");var s=t.allowNegative,l=t.thousandsGroupStyle;if(l===void 0&&(l="thousand"),e===""||e==="-")return e;var u=Ip(t),d=u.thousandSeparator,p=u.decimalSeparator,g=n!==0&&e.indexOf(".")!==-1||n&&r,m=ZT(e,s),b=m.beforeDecimal,v=m.afterDecimal,y=m.addNegation;return n!==void 0&&(v=yG(v,n,!!r)),d&&(b=Zie(b,d,l)),a&&(b=a+b),o&&(v=v+o),y&&(b="-"+b),e=b+(g&&p||"")+v,e}function Ip(e){var t=e.decimalSeparator;t===void 0&&(t=".");var n=e.thousandSeparator,r=e.allowedDecimalSeparators;return n===!0&&(n=","),r||(r=[t,"."]),{decimalSeparator:t,thousandSeparator:n,allowedDecimalSeparators:r}}function use(e,t){e===void 0&&(e="");var n=new RegExp("(-)"),r=new RegExp("(-)(.)*(-)"),a=n.test(e),o=r.test(e);return e=e.replace(/-/g,""),a&&!o&&t&&(e="-"+e),e}function dse(e,t){return new RegExp("(^-)|[0-9]|"+bG(e),"g")}function fse(e,t,n){return e===""?!0:!(t!=null&&t.match(/\d/))&&!(n!=null&&n.match(/\d/))&&typeof e=="string"&&!isNaN(Number(e))}function pse(e,t,n){var r;t===void 0&&(t=rse(e));var a=n.allowNegative,o=n.prefix;o===void 0&&(o="");var s=n.suffix;s===void 0&&(s="");var l=n.decimalScale,u=t.from,d=t.to,p=d.start,g=d.end,m=Ip(n),b=m.allowedDecimalSeparators,v=m.decimalSeparator,y=e[g]===v;if(Lc(e)&&(e===o||e===s)&&t.lastValue==="")return e;if(g-p===1&&b.indexOf(e[p])!==-1){var k=l===0?"":v;e=e.substring(0,p)+k+e.substring(p+1,e.length)}var A=function(G,z,Y){var L=!1,V=!1;o.startsWith("-")?L=!1:G.startsWith("--")?(L=!1,V=!0):s.startsWith("-")&&G.length===s.length?L=!1:G[0]==="-"&&(L=!0);var j=L?1:0;return V&&(j=2),j&&(G=G.substring(j),z-=j,Y-=j),{value:G,start:z,end:Y,hasNegation:L}},x=A(e,p,g),R=x.hasNegation;r=x,e=r.value,p=r.start,g=r.end;var O=A(t.lastValue,u.start,u.end),N=O.start,C=O.end,_=O.value,M=e.substring(p,g);e.length&&_.length&&(N>_.length-s.length||C<o.length)&&!(M&&s.startsWith(M))&&(e=_);var I=0;e.startsWith(o)?I+=o.length:p<o.length&&(I=p),e=e.substring(I),g-=I;var D=e.length,U=e.length-s.length;e.endsWith(s)?D=U:(g>U||g>e.length-s.length)&&(D=g),e=e.substring(0,D),e=use(R?"-"+e:e,a),e=(e.match(dse(v))||[]).join("");var $=e.indexOf(v);e=e.replace(new RegExp(bG(v),"g"),function(G,z){return z===$?".":""});var B=ZT(e,a),W=B.beforeDecimal,K=B.afterDecimal,H=B.addNegation;return d.end-d.start<u.end-u.start&&W===""&&y&&!parseFloat(K)&&(e=H?"-":""),e}function gse(e,t){var n=t.prefix;n===void 0&&(n="");var r=t.suffix;r===void 0&&(r="");var a=Array.from({length:e.length+1}).map(function(){return!0}),o=e[0]==="-";a.fill(!1,0,n.length+(o?1:0));var s=e.length;return a.fill(!1,s-r.length+1,s+1),a}function hse(e){var t=Ip(e),n=t.thousandSeparator,r=t.decimalSeparator,a=e.prefix;a===void 0&&(a="");var o=e.allowNegative;if(o===void 0&&(o=!0),n===r)throw new Error(`
        Decimal separator can't be same as thousand separator.
        thousandSeparator: `+n+` (thousandSeparator = {true} is same as thousandSeparator = ",")
        decimalSeparator: `+r+` (default value for decimalSeparator is .)
     `);return a.startsWith("-")&&o&&(console.error(`
      Prefix can't start with '-' when allowNegative is true.
      prefix: `+a+`
      allowNegative: `+o+`
    `),o=!1),Object.assign(Object.assign({},e),{allowNegative:o})}function mse(e){e=hse(e),e.decimalSeparator,e.allowedDecimalSeparators,e.thousandsGroupStyle;var t=e.suffix,n=e.allowNegative,r=e.allowLeadingZeros,a=e.onKeyDown;a===void 0&&(a=ko);var o=e.onBlur;o===void 0&&(o=ko);var s=e.thousandSeparator,l=e.decimalScale,u=e.fixedDecimalScale,d=e.prefix;d===void 0&&(d="");var p=e.defaultValue,g=e.value,m=e.valueIsNumericString,b=e.onValueChange,v=hG(e,["decimalSeparator","allowedDecimalSeparators","thousandsGroupStyle","suffix","allowNegative","allowLeadingZeros","onKeyDown","onBlur","thousandSeparator","decimalScale","fixedDecimalScale","prefix","defaultValue","value","valueIsNumericString","onValueChange"]),y=Ip(e),k=y.decimalSeparator,A=y.allowedDecimalSeparators,x=function(H){return cI(H,e)},R=function(H,G){return pse(H,G,e)},O=Os(g)?p:g,N=m??fse(O,d,t);Os(g)?Os(p)||(N=N||typeof p=="number"):N=N||typeof g=="number";var C=function(H){return mG(H)?H:(typeof H=="number"&&(H=vG(H)),N&&typeof l=="number"?sI(H,l,!!u):H)},_=EG(C(g),C(p),!!N,x,R,b),M=_[0],I=M.numAsString,D=M.formattedValue,U=_[1],$=function(H){var G=H.target,z=H.key,Y=G.selectionStart,L=G.selectionEnd,V=G.value;if(V===void 0&&(V=""),(z==="Backspace"||z==="Delete")&&L<d.length){H.preventDefault();return}if(Y!==L){a(H);return}z==="Backspace"&&V[0]==="-"&&Y===d.length+1&&n&&di(G,1),l&&u&&(z==="Backspace"&&V[Y-1]===k?(di(G,Y-1),H.preventDefault()):z==="Delete"&&V[Y]===k&&H.preventDefault()),A!=null&&A.includes(z)&&V[Y]===k&&di(G,Y+1);var j=s===!0?",":s;z==="Backspace"&&V[Y-1]===j&&di(G,Y-1),z==="Delete"&&V[Y]===j&&di(G,Y+1),a(H)},B=function(H){var G=I;if(G.match(/\d/g)||(G=""),r||(G=Jie(G)),u&&l&&(G=sI(G,l,u)),G!==I){var z=cI(G,e);U({formattedValue:z,value:G,floatValue:parseFloat(G)},{event:H,source:Dc.event})}o(H)},W=function(H){return H===k?!0:Lc(H)},K=function(H){var G=H.currentValue,z=H.lastValue,Y=H.formattedValue,L=H.currentValueIndex,V=H.formattedValueIndex,j=G[L],P=Y[V],Z=SG(z,G),Q=Z.to,oe=function(ae){return R(ae).indexOf(".")+d.length};return g===0&&u&&l&&G[Q.start]===k&&oe(G)<L&&oe(Y)>V?!1:L>=Q.start&&L<Q.end&&A&&A.includes(j)&&P===k?!0:j===P};return Object.assign(Object.assign({},v),{value:D,valueIsNumericString:!1,isValidInputCharacter:W,isCharacterSame:K,onValueChange:U,format:x,removeFormatting:R,getCaretBoundary:function(H){return gse(H,e)},onKeyDown:$,onBlur:B})}function bse(e){var t=mse(e);return we.createElement(cse,Object.assign({},t))}const xs=w.forwardRef(({stepper:e,thousandSeparator:t,placeholder:n,defaultValue:r,min:a=-1/0,max:o=1/0,onValueChange:s,fixedDecimalScale:l=!1,decimalScale:u=0,className:d=void 0,suffix:p,prefix:g,value:m,...b},v)=>{const[y,k]=w.useState(m??r),A=w.useCallback(()=>{k(N=>N===void 0?e??1:Math.min(N+(e??1),o))},[e,o]),x=w.useCallback(()=>{k(N=>N===void 0?-(e??1):Math.max(N-(e??1),a))},[e,a]);w.useEffect(()=>{m!==void 0&&k(m)},[m]);const R=N=>{const C=N.floatValue===void 0?void 0:N.floatValue;k(C),s&&s(C)},O=()=>{y!==void 0&&(y<a?(k(a),v.current.value=String(a)):y>o&&(k(o),v.current.value=String(o)))};return E.jsxs("div",{className:"relative flex",children:[E.jsx(bse,{value:y,onValueChange:R,thousandSeparator:t,decimalScale:u,fixedDecimalScale:l,allowNegative:a<0,valueIsNumericString:!0,onBlur:O,max:o,min:a,suffix:p,prefix:g,customInput:N=>E.jsx(kr,{...N,className:Me("w-full",d)}),placeholder:n,className:"[appearance:textfield] [&::-webkit-inner-spin-button]:appearance-none [&::-webkit-outer-spin-button]:appearance-none",getInputRef:v,...b}),E.jsxs("div",{className:"absolute top-0 right-0 bottom-0 flex flex-col",children:[E.jsx(nt,{"aria-label":"Increase value",className:"border-input h-1/2 rounded-l-none rounded-br-none border-b border-l px-2 focus-visible:relative",variant:"outline",onClick:A,disabled:y===o,children:E.jsx(FU,{size:15})}),E.jsx(nt,{"aria-label":"Decrease value",className:"border-input h-1/2 rounded-l-none rounded-tr-none border-b border-l px-2 focus-visible:relative",variant:"outline",onClick:x,disabled:y===a,children:E.jsx(ST,{size:15})})]})]})});xs.displayName="NumberInput";function yse(){var r,a;const{t:e}=Et(),t=De(o=>o.querySettings),n=w.useCallback((o,s)=>{De.getState().updateQuerySettings({[o]:s})},[]);return E.jsxs(Ei,{className:"flex shrink-0 flex-col min-w-[180px]",children:[E.jsxs(_c,{className:"px-4 pt-4 pb-2",children:[E.jsx(Nc,{children:e("retrievePanel.querySettings.parametersTitle")}),E.jsx(Cp,{children:e("retrievePanel.querySettings.parametersDescription")})]}),E.jsx(Oc,{className:"m-0 flex grow flex-col p-0 text-xs",children:E.jsx("div",{className:"relative size-full",children:E.jsxs("div",{className:"absolute inset-0 flex flex-col gap-2 overflow-auto px-2",children:[E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.queryMode"),tooltip:e("retrievePanel.querySettings.queryModeTooltip"),side:"left"}),E.jsxs(Tf,{value:t.mode,onValueChange:o=>n("mode",o),children:[E.jsx(Tc,{className:"hover:bg-primary/5 h-9 cursor-pointer focus:ring-0 focus:ring-offset-0 focus:outline-0 active:right-0",children:E.jsx(Af,{})}),E.jsx(Ac,{children:E.jsxs(pN,{children:[E.jsx(xn,{value:"naive",children:e("retrievePanel.querySettings.queryModeOptions.naive")}),E.jsx(xn,{value:"local",children:e("retrievePanel.querySettings.queryModeOptions.local")}),E.jsx(xn,{value:"global",children:e("retrievePanel.querySettings.queryModeOptions.global")}),E.jsx(xn,{value:"hybrid",children:e("retrievePanel.querySettings.queryModeOptions.hybrid")}),E.jsx(xn,{value:"mix",children:e("retrievePanel.querySettings.queryModeOptions.mix")})]})})]})]}),E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.responseFormat"),tooltip:e("retrievePanel.querySettings.responseFormatTooltip"),side:"left"}),E.jsxs(Tf,{value:t.response_type,onValueChange:o=>n("response_type",o),children:[E.jsx(Tc,{className:"hover:bg-primary/5 h-9 cursor-pointer focus:ring-0 focus:ring-offset-0 focus:outline-0 active:right-0",children:E.jsx(Af,{})}),E.jsx(Ac,{children:E.jsxs(pN,{children:[E.jsx(xn,{value:"Multiple Paragraphs",children:e("retrievePanel.querySettings.responseFormatOptions.multipleParagraphs")}),E.jsx(xn,{value:"Single Paragraph",children:e("retrievePanel.querySettings.responseFormatOptions.singleParagraph")}),E.jsx(xn,{value:"Bullet Points",children:e("retrievePanel.querySettings.responseFormatOptions.bulletPoints")})]})})]})]}),E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.topK"),tooltip:e("retrievePanel.querySettings.topKTooltip"),side:"left"}),E.jsxs("div",{children:[E.jsx("label",{htmlFor:"top_k",className:"sr-only",children:e("retrievePanel.querySettings.topK")}),E.jsx(xs,{id:"top_k",stepper:1,value:t.top_k,onValueChange:o=>n("top_k",o),min:1,placeholder:e("retrievePanel.querySettings.topKPlaceholder")})]})]}),E.jsxs(E.Fragment,{children:[E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.maxTokensTextUnit"),tooltip:e("retrievePanel.querySettings.maxTokensTextUnitTooltip"),side:"left"}),E.jsxs("div",{children:[E.jsx("label",{htmlFor:"max_token_for_text_unit",className:"sr-only",children:e("retrievePanel.querySettings.maxTokensTextUnit")}),E.jsx(xs,{id:"max_token_for_text_unit",stepper:500,value:t.max_token_for_text_unit,onValueChange:o=>n("max_token_for_text_unit",o),min:1,placeholder:e("retrievePanel.querySettings.maxTokensTextUnit")})]})]}),E.jsxs(E.Fragment,{children:[E.jsx(Jn,{text:e("retrievePanel.querySettings.maxTokensGlobalContext"),tooltip:e("retrievePanel.querySettings.maxTokensGlobalContextTooltip"),side:"left"}),E.jsxs("div",{children:[E.jsx("label",{htmlFor:"max_token_for_global_context",className:"sr-only",children:e("retrievePanel.querySettings.maxTokensGlobalContext")}),E.jsx(xs,{id:"max_token_for_global_context",stepper:500,value:t.max_token_for_global_context,onValueChange:o=>n("max_token_for_global_context",o),min:1,placeholder:e("retrievePanel.querySettings.maxTokensGlobalContext")})]})]}),E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.maxTokensLocalContext"),tooltip:e("retrievePanel.querySettings.maxTokensLocalContextTooltip"),side:"left"}),E.jsxs("div",{children:[E.jsx("label",{htmlFor:"max_token_for_local_context",className:"sr-only",children:e("retrievePanel.querySettings.maxTokensLocalContext")}),E.jsx(xs,{id:"max_token_for_local_context",stepper:500,value:t.max_token_for_local_context,onValueChange:o=>n("max_token_for_local_context",o),min:1,placeholder:e("retrievePanel.querySettings.maxTokensLocalContext")})]})]})]}),E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.historyTurns"),tooltip:e("retrievePanel.querySettings.historyTurnsTooltip"),side:"left"}),E.jsxs("div",{children:[E.jsx("label",{htmlFor:"history_turns",className:"sr-only",children:e("retrievePanel.querySettings.historyTurns")}),E.jsx(xs,{className:"!border-input",id:"history_turns",stepper:1,type:"text",value:t.history_turns,onValueChange:o=>n("history_turns",o),min:0,placeholder:e("retrievePanel.querySettings.historyTurnsPlaceholder")})]})]}),E.jsxs(E.Fragment,{children:[E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.hlKeywords"),tooltip:e("retrievePanel.querySettings.hlKeywordsTooltip"),side:"left"}),E.jsxs("div",{children:[E.jsx("label",{htmlFor:"hl_keywords",className:"sr-only",children:e("retrievePanel.querySettings.hlKeywords")}),E.jsx(kr,{id:"hl_keywords",type:"text",value:(r=t.hl_keywords)==null?void 0:r.join(", "),onChange:o=>{const s=o.target.value.split(",").map(l=>l.trim()).filter(l=>l!=="");n("hl_keywords",s)},placeholder:e("retrievePanel.querySettings.hlkeywordsPlaceHolder")})]})]}),E.jsxs(E.Fragment,{children:[E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.llKeywords"),tooltip:e("retrievePanel.querySettings.llKeywordsTooltip"),side:"left"}),E.jsxs("div",{children:[E.jsx("label",{htmlFor:"ll_keywords",className:"sr-only",children:e("retrievePanel.querySettings.llKeywords")}),E.jsx(kr,{id:"ll_keywords",type:"text",value:(a=t.ll_keywords)==null?void 0:a.join(", "),onChange:o=>{const s=o.target.value.split(",").map(l=>l.trim()).filter(l=>l!=="");n("ll_keywords",s)},placeholder:e("retrievePanel.querySettings.hlkeywordsPlaceHolder")})]})]})]}),E.jsxs(E.Fragment,{children:[E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("label",{htmlFor:"only_need_context",className:"flex-1",children:E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.onlyNeedContext"),tooltip:e("retrievePanel.querySettings.onlyNeedContextTooltip"),side:"left"})}),E.jsx(Ns,{className:"mr-1 cursor-pointer",id:"only_need_context",checked:t.only_need_context,onCheckedChange:o=>n("only_need_context",o)})]}),E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("label",{htmlFor:"only_need_prompt",className:"flex-1",children:E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.onlyNeedPrompt"),tooltip:e("retrievePanel.querySettings.onlyNeedPromptTooltip"),side:"left"})}),E.jsx(Ns,{className:"mr-1 cursor-pointer",id:"only_need_prompt",checked:t.only_need_prompt,onCheckedChange:o=>n("only_need_prompt",o)})]}),E.jsxs("div",{className:"flex items-center gap-2",children:[E.jsx("label",{htmlFor:"stream",className:"flex-1",children:E.jsx(Jn,{className:"ml-1",text:e("retrievePanel.querySettings.streamResponse"),tooltip:e("retrievePanel.querySettings.streamResponseTooltip"),side:"left"})}),E.jsx(Ns,{className:"mr-1 cursor-pointer",id:"stream",checked:t.stream,onCheckedChange:o=>n("stream",o)})]})]})]})})})]})}function vse(e,t){const n={};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}const Sse=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,Ese=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,wse={};function uI(e,t){return(wse.jsx?Ese:Sse).test(e)}const xse=/[ \t\n\f\r]/g;function kse(e){return typeof e=="object"?e.type==="text"?dI(e.value):!1:dI(e)}function dI(e){return e.replace(xse,"")===""}class iu{constructor(t,n,r){this.property=t,this.normal=n,r&&(this.space=r)}}iu.prototype.property={};iu.prototype.normal={};iu.prototype.space=null;function wG(e,t){const n={},r={};let a=-1;for(;++a<e.length;)Object.assign(n,e[a].property),Object.assign(r,e[a].normal);return new iu(n,r,t)}function mk(e){return e.toLowerCase()}class Cr{constructor(t,n){this.property=t,this.attribute=n}}Cr.prototype.space=null;Cr.prototype.boolean=!1;Cr.prototype.booleanish=!1;Cr.prototype.overloadedBoolean=!1;Cr.prototype.number=!1;Cr.prototype.commaSeparated=!1;Cr.prototype.spaceSeparated=!1;Cr.prototype.commaOrSpaceSeparated=!1;Cr.prototype.mustUseProperty=!1;Cr.prototype.defined=!1;let Tse=0;const at=Ri(),Qt=Ri(),xG=Ri(),Ie=Ri(),Pt=Ri(),Is=Ri(),er=Ri();function Ri(){return 2**++Tse}const bk=Object.freeze(Object.defineProperty({__proto__:null,boolean:at,booleanish:Qt,commaOrSpaceSeparated:er,commaSeparated:Is,number:Ie,overloadedBoolean:xG,spaceSeparated:Pt},Symbol.toStringTag,{value:"Module"})),mb=Object.keys(bk);class QT extends Cr{constructor(t,n,r,a){let o=-1;if(super(t,n),fI(this,"space",a),typeof r=="number")for(;++o<mb.length;){const s=mb[o];fI(this,mb[o],(r&bk[s])===bk[s])}}}QT.prototype.defined=!0;function fI(e,t,n){n&&(e[t]=n)}const Ase={}.hasOwnProperty;function nl(e){const t={},n={};let r;for(r in e.properties)if(Ase.call(e.properties,r)){const a=e.properties[r],o=new QT(r,e.transform(e.attributes||{},r),a,e.space);e.mustUseProperty&&e.mustUseProperty.includes(r)&&(o.mustUseProperty=!0),t[r]=o,n[mk(r)]=r,n[mk(o.attribute)]=r}return new iu(t,n,e.space)}const kG=nl({space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()},properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null}}),TG=nl({space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()},properties:{xmlLang:null,xmlBase:null,xmlSpace:null}});function AG(e,t){return t in e?e[t]:t}function RG(e,t){return AG(e,t.toLowerCase())}const CG=nl({space:"xmlns",attributes:{xmlnsxlink:"xmlns:xlink"},transform:RG,properties:{xmlns:null,xmlnsXLink:null}}),_G=nl({transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()},properties:{ariaActiveDescendant:null,ariaAtomic:Qt,ariaAutoComplete:null,ariaBusy:Qt,ariaChecked:Qt,ariaColCount:Ie,ariaColIndex:Ie,ariaColSpan:Ie,ariaControls:Pt,ariaCurrent:null,ariaDescribedBy:Pt,ariaDetails:null,ariaDisabled:Qt,ariaDropEffect:Pt,ariaErrorMessage:null,ariaExpanded:Qt,ariaFlowTo:Pt,ariaGrabbed:Qt,ariaHasPopup:null,ariaHidden:Qt,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:Pt,ariaLevel:Ie,ariaLive:null,ariaModal:Qt,ariaMultiLine:Qt,ariaMultiSelectable:Qt,ariaOrientation:null,ariaOwns:Pt,ariaPlaceholder:null,ariaPosInSet:Ie,ariaPressed:Qt,ariaReadOnly:Qt,ariaRelevant:null,ariaRequired:Qt,ariaRoleDescription:Pt,ariaRowCount:Ie,ariaRowIndex:Ie,ariaRowSpan:Ie,ariaSelected:Qt,ariaSetSize:Ie,ariaSort:null,ariaValueMax:Ie,ariaValueMin:Ie,ariaValueNow:Ie,ariaValueText:null,role:null}}),Rse=nl({space:"html",attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},transform:RG,mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:Is,acceptCharset:Pt,accessKey:Pt,action:null,allow:null,allowFullScreen:at,allowPaymentRequest:at,allowUserMedia:at,alt:null,as:null,async:at,autoCapitalize:null,autoComplete:Pt,autoFocus:at,autoPlay:at,blocking:Pt,capture:null,charSet:null,checked:at,cite:null,className:Pt,cols:Ie,colSpan:null,content:null,contentEditable:Qt,controls:at,controlsList:Pt,coords:Ie|Is,crossOrigin:null,data:null,dateTime:null,decoding:null,default:at,defer:at,dir:null,dirName:null,disabled:at,download:xG,draggable:Qt,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:at,formTarget:null,headers:Pt,height:Ie,hidden:at,high:Ie,href:null,hrefLang:null,htmlFor:Pt,httpEquiv:Pt,id:null,imageSizes:null,imageSrcSet:null,inert:at,inputMode:null,integrity:null,is:null,isMap:at,itemId:null,itemProp:Pt,itemRef:Pt,itemScope:at,itemType:Pt,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:at,low:Ie,manifest:null,max:null,maxLength:Ie,media:null,method:null,min:null,minLength:Ie,multiple:at,muted:at,name:null,nonce:null,noModule:at,noValidate:at,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:at,optimum:Ie,pattern:null,ping:Pt,placeholder:null,playsInline:at,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:at,referrerPolicy:null,rel:Pt,required:at,reversed:at,rows:Ie,rowSpan:Ie,sandbox:Pt,scope:null,scoped:at,seamless:at,selected:at,shadowRootClonable:at,shadowRootDelegatesFocus:at,shadowRootMode:null,shape:null,size:Ie,sizes:null,slot:null,span:Ie,spellCheck:Qt,src:null,srcDoc:null,srcLang:null,srcSet:null,start:Ie,step:null,style:null,tabIndex:Ie,target:null,title:null,translate:null,type:null,typeMustMatch:at,useMap:null,value:Qt,width:Ie,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:Pt,axis:null,background:null,bgColor:null,border:Ie,borderColor:null,bottomMargin:Ie,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:at,declare:at,event:null,face:null,frame:null,frameBorder:null,hSpace:Ie,leftMargin:Ie,link:null,longDesc:null,lowSrc:null,marginHeight:Ie,marginWidth:Ie,noResize:at,noHref:at,noShade:at,noWrap:at,object:null,profile:null,prompt:null,rev:null,rightMargin:Ie,rules:null,scheme:null,scrolling:Qt,standby:null,summary:null,text:null,topMargin:Ie,valueType:null,version:null,vAlign:null,vLink:null,vSpace:Ie,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:at,disableRemotePlayback:at,prefix:null,property:null,results:Ie,security:null,unselectable:null}}),Cse=nl({space:"svg",attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},transform:AG,properties:{about:er,accentHeight:Ie,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:Ie,amplitude:Ie,arabicForm:null,ascent:Ie,attributeName:null,attributeType:null,azimuth:Ie,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:Ie,by:null,calcMode:null,capHeight:Ie,className:Pt,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:Ie,diffuseConstant:Ie,direction:null,display:null,dur:null,divisor:Ie,dominantBaseline:null,download:at,dx:null,dy:null,edgeMode:null,editable:null,elevation:Ie,enableBackground:null,end:null,event:null,exponent:Ie,externalResourcesRequired:null,fill:null,fillOpacity:Ie,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:Is,g2:Is,glyphName:Is,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:Ie,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:Ie,horizOriginX:Ie,horizOriginY:Ie,id:null,ideographic:Ie,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:Ie,k:Ie,k1:Ie,k2:Ie,k3:Ie,k4:Ie,kernelMatrix:er,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:Ie,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:Ie,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:Ie,overlineThickness:Ie,paintOrder:null,panose1:null,path:null,pathLength:Ie,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:Pt,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:Ie,pointsAtY:Ie,pointsAtZ:Ie,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:er,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:er,rev:er,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:er,requiredFeatures:er,requiredFonts:er,requiredFormats:er,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:Ie,specularExponent:Ie,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:Ie,strikethroughThickness:Ie,string:null,stroke:null,strokeDashArray:er,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:Ie,strokeOpacity:Ie,strokeWidth:null,style:null,surfaceScale:Ie,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:er,tabIndex:Ie,tableValues:null,target:null,targetX:Ie,targetY:Ie,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:er,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:Ie,underlineThickness:Ie,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:Ie,values:null,vAlphabetic:Ie,vMathematical:Ie,vectorEffect:null,vHanging:Ie,vIdeographic:Ie,version:null,vertAdvY:Ie,vertOriginX:Ie,vertOriginY:Ie,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:Ie,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null}}),_se=/^data[-\w.:]+$/i,pI=/-[a-z]/g,Nse=/[A-Z]/g;function Ose(e,t){const n=mk(t);let r=t,a=Cr;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&_se.test(t)){if(t.charAt(4)==="-"){const o=t.slice(5).replace(pI,Dse);r="data"+o.charAt(0).toUpperCase()+o.slice(1)}else{const o=t.slice(4);if(!pI.test(o)){let s=o.replace(Nse,Ise);s.charAt(0)!=="-"&&(s="-"+s),t="data"+s}}a=QT}return new a(r,t)}function Ise(e){return"-"+e.toLowerCase()}function Dse(e){return e.charAt(1).toUpperCase()}const Lse={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},Mse=wG([TG,kG,CG,_G,Rse],"html"),JT=wG([TG,kG,CG,_G,Cse],"svg");function Pse(e){return e.join(" ").trim()}var ms={},bb,gI;function Fse(){if(gI)return bb;gI=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,a=/^:\s*/,o=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,s=/^[;\s]*/,l=/^\s+|\s+$/g,u=`
`,d="/",p="*",g="",m="comment",b="declaration";bb=function(y,k){if(typeof y!="string")throw new TypeError("First argument must be a string");if(!y)return[];k=k||{};var A=1,x=1;function R(B){var W=B.match(t);W&&(A+=W.length);var K=B.lastIndexOf(u);x=~K?B.length-K:x+B.length}function O(){var B={line:A,column:x};return function(W){return W.position=new N(B),M(),W}}function N(B){this.start=B,this.end={line:A,column:x},this.source=k.source}N.prototype.content=y;function C(B){var W=new Error(k.source+":"+A+":"+x+": "+B);if(W.reason=B,W.filename=k.source,W.line=A,W.column=x,W.source=y,!k.silent)throw W}function _(B){var W=B.exec(y);if(W){var K=W[0];return R(K),y=y.slice(K.length),W}}function M(){_(n)}function I(B){var W;for(B=B||[];W=D();)W!==!1&&B.push(W);return B}function D(){var B=O();if(!(d!=y.charAt(0)||p!=y.charAt(1))){for(var W=2;g!=y.charAt(W)&&(p!=y.charAt(W)||d!=y.charAt(W+1));)++W;if(W+=2,g===y.charAt(W-1))return C("End of comment missing");var K=y.slice(2,W-2);return x+=2,R(K),y=y.slice(W),x+=2,B({type:m,comment:K})}}function U(){var B=O(),W=_(r);if(W){if(D(),!_(a))return C("property missing ':'");var K=_(o),H=B({type:b,property:v(W[0].replace(e,g)),value:K?v(K[0].replace(e,g)):g});return _(s),H}}function $(){var B=[];I(B);for(var W;W=U();)W!==!1&&(B.push(W),I(B));return B}return M(),$()};function v(y){return y?y.replace(l,g):g}return bb}var hI;function zse(){if(hI)return ms;hI=1;var e=ms&&ms.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(ms,"__esModule",{value:!0}),ms.default=n;var t=e(Fse());function n(r,a){var o=null;if(!r||typeof r!="string")return o;var s=(0,t.default)(r),l=typeof a=="function";return s.forEach(function(u){if(u.type==="declaration"){var d=u.property,p=u.value;l?a(d,p,u):p&&(o=o||{},o[d]=p)}}),o}return ms}var Bse=zse();const mI=un(Bse),jse=mI.default||mI,NG=OG("end"),eA=OG("start");function OG(e){return t;function t(n){const r=n&&n.position&&n.position[e]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function Use(e){const t=eA(e),n=NG(e);if(t&&n)return{start:t,end:n}}function bc(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?bI(e.position):"start"in e||"end"in e?bI(e):"line"in e||"column"in e?yk(e):""}function yk(e){return yI(e&&e.line)+":"+yI(e&&e.column)}function bI(e){return yk(e&&e.start)+"-"+yk(e&&e.end)}function yI(e){return e&&typeof e=="number"?e:1}class Cn extends Error{constructor(t,n,r){super(),typeof n=="string"&&(r=n,n=void 0);let a="",o={},s=!1;if(n&&("line"in n&&"column"in n?o={place:n}:"start"in n&&"end"in n?o={place:n}:"type"in n?o={ancestors:[n],place:n.position}:o={...n}),typeof t=="string"?a=t:!o.cause&&t&&(s=!0,a=t.message,o.cause=t),!o.ruleId&&!o.source&&typeof r=="string"){const u=r.indexOf(":");u===-1?o.ruleId=r:(o.source=r.slice(0,u),o.ruleId=r.slice(u+1))}if(!o.place&&o.ancestors&&o.ancestors){const u=o.ancestors[o.ancestors.length-1];u&&(o.place=u.position)}const l=o.place&&"start"in o.place?o.place.start:o.place;this.ancestors=o.ancestors||void 0,this.cause=o.cause||void 0,this.column=l?l.column:void 0,this.fatal=void 0,this.file,this.message=a,this.line=l?l.line:void 0,this.name=bc(o.place)||"1:1",this.place=o.place||void 0,this.reason=this.message,this.ruleId=o.ruleId||void 0,this.source=o.source||void 0,this.stack=s&&o.cause&&typeof o.cause.stack=="string"?o.cause.stack:"",this.actual,this.expected,this.note,this.url}}Cn.prototype.file="";Cn.prototype.name="";Cn.prototype.reason="";Cn.prototype.message="";Cn.prototype.stack="";Cn.prototype.column=void 0;Cn.prototype.line=void 0;Cn.prototype.ancestors=void 0;Cn.prototype.cause=void 0;Cn.prototype.fatal=void 0;Cn.prototype.place=void 0;Cn.prototype.ruleId=void 0;Cn.prototype.source=void 0;const tA={}.hasOwnProperty,Gse=new Map,Hse=/[A-Z]/g,$se=/-([a-z])/g,qse=new Set(["table","tbody","thead","tfoot","tr"]),Vse=new Set(["td","th"]),IG="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function DG(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let r;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=ele(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=Jse(n,t.jsx,t.jsxs)}const a={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:r,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?JT:Mse,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},o=LG(a,e,void 0);return o&&typeof o!="string"?o:a.create(e,a.Fragment,{children:o||void 0},void 0)}function LG(e,t,n){if(t.type==="element")return Wse(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return Yse(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return Xse(e,t,n);if(t.type==="mdxjsEsm")return Kse(e,t);if(t.type==="root")return Zse(e,t,n);if(t.type==="text")return Qse(e,t)}function Wse(e,t,n){const r=e.schema;let a=r;t.tagName.toLowerCase()==="svg"&&r.space==="html"&&(a=JT,e.schema=a),e.ancestors.push(t);const o=PG(e,t.tagName,!1),s=tle(e,t);let l=rA(e,t);return qse.has(t.tagName)&&(l=l.filter(function(u){return typeof u=="string"?!kse(u):!0})),MG(e,s,o,t),nA(s,l),e.ancestors.pop(),e.schema=r,e.create(t,o,s,n)}function Yse(e,t){if(t.data&&t.data.estree&&e.evaluater){const r=t.data.estree.body[0];return r.type,e.evaluater.evaluateExpression(r.expression)}Mc(e,t.position)}function Kse(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);Mc(e,t.position)}function Xse(e,t,n){const r=e.schema;let a=r;t.name==="svg"&&r.space==="html"&&(a=JT,e.schema=a),e.ancestors.push(t);const o=t.name===null?e.Fragment:PG(e,t.name,!0),s=nle(e,t),l=rA(e,t);return MG(e,s,o,t),nA(s,l),e.ancestors.pop(),e.schema=r,e.create(t,o,s,n)}function Zse(e,t,n){const r={};return nA(r,rA(e,t)),e.create(t,e.Fragment,r,n)}function Qse(e,t){return t.value}function MG(e,t,n,r){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=r)}function nA(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function Jse(e,t,n){return r;function r(a,o,s,l){const d=Array.isArray(s.children)?n:t;return l?d(o,s,l):d(o,s)}}function ele(e,t){return n;function n(r,a,o,s){const l=Array.isArray(o.children),u=eA(r);return t(a,o,s,l,{columnNumber:u?u.column-1:void 0,fileName:e,lineNumber:u?u.line:void 0},void 0)}}function tle(e,t){const n={};let r,a;for(a in t.properties)if(a!=="children"&&tA.call(t.properties,a)){const o=rle(e,a,t.properties[a]);if(o){const[s,l]=o;e.tableCellAlignToStyle&&s==="align"&&typeof l=="string"&&Vse.has(t.tagName)?r=l:n[s]=l}}if(r){const o=n.style||(n.style={});o[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return n}function nle(e,t){const n={};for(const r of t.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&e.evaluater){const o=r.data.estree.body[0];o.type;const s=o.expression;s.type;const l=s.properties[0];l.type,Object.assign(n,e.evaluater.evaluateExpression(l.argument))}else Mc(e,t.position);else{const a=r.name;let o;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&e.evaluater){const l=r.value.data.estree.body[0];l.type,o=e.evaluater.evaluateExpression(l.expression)}else Mc(e,t.position);else o=r.value===null?!0:r.value;n[a]=o}return n}function rA(e,t){const n=[];let r=-1;const a=e.passKeys?new Map:Gse;for(;++r<t.children.length;){const o=t.children[r];let s;if(e.passKeys){const u=o.type==="element"?o.tagName:o.type==="mdxJsxFlowElement"||o.type==="mdxJsxTextElement"?o.name:void 0;if(u){const d=a.get(u)||0;s=u+"-"+d,a.set(u,d+1)}}const l=LG(e,o,s);l!==void 0&&n.push(l)}return n}function rle(e,t,n){const r=Ose(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=r.commaSeparated?vse(n):Pse(n)),r.property==="style"){let a=typeof n=="object"?n:ale(e,String(n));return e.stylePropertyNameCase==="css"&&(a=ole(a)),["style",a]}return[e.elementAttributeNameCase==="react"&&r.space?Lse[r.property]||r.property:r.attribute,n]}}function ale(e,t){const n={};try{jse(t,r)}catch(a){if(!e.ignoreInvalidStyle){const o=a,s=new Cn("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:o,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw s.file=e.filePath||void 0,s.url=IG+"#cannot-parse-style-attribute",s}}return n;function r(a,o){let s=a;s.slice(0,2)!=="--"&&(s.slice(0,4)==="-ms-"&&(s="ms-"+s.slice(4)),s=s.replace($se,sle)),n[s]=o}}function PG(e,t,n){let r;if(!n)r={type:"Literal",value:t};else if(t.includes(".")){const a=t.split(".");let o=-1,s;for(;++o<a.length;){const l=uI(a[o])?{type:"Identifier",name:a[o]}:{type:"Literal",value:a[o]};s=s?{type:"MemberExpression",object:s,property:l,computed:!!(o&&l.type==="Literal"),optional:!1}:l}r=s}else r=uI(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(r.type==="Literal"){const a=r.value;return tA.call(e.components,a)?e.components[a]:a}if(e.evaluater)return e.evaluater.evaluateExpression(r);Mc(e)}function Mc(e,t){const n=new Cn("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=IG+"#cannot-handle-mdx-estrees-without-createevaluater",n}function ole(e){const t={};let n;for(n in e)tA.call(e,n)&&(t[ile(n)]=e[n]);return t}function ile(e){let t=e.replace(Hse,lle);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function sle(e,t){return t.toUpperCase()}function lle(e){return"-"+e.toLowerCase()}const yb={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},cle={};function aA(e,t){const n=cle,r=typeof n.includeImageAlt=="boolean"?n.includeImageAlt:!0,a=typeof n.includeHtml=="boolean"?n.includeHtml:!0;return FG(e,r,a)}function FG(e,t,n){if(ule(e)){if("value"in e)return e.type==="html"&&!n?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return vI(e.children,t,n)}return Array.isArray(e)?vI(e,t,n):""}function vI(e,t,n){const r=[];let a=-1;for(;++a<e.length;)r[a]=FG(e[a],t,n);return r.join("")}function ule(e){return!!(e&&typeof e=="object")}const SI=document.createElement("i");function oA(e){const t="&"+e+";";SI.innerHTML=t;const n=SI.textContent;return n.charCodeAt(n.length-1)===59&&e!=="semi"||n===t?!1:n}function or(e,t,n,r){const a=e.length;let o=0,s;if(t<0?t=-t>a?0:a+t:t=t>a?a:t,n=n>0?n:0,r.length<1e4)s=Array.from(r),s.unshift(t,n),e.splice(...s);else for(n&&e.splice(t,n);o<r.length;)s=r.slice(o,o+1e4),s.unshift(t,0),e.splice(...s),o+=1e4,t+=1e4}function Sr(e,t){return e.length>0?(or(e,e.length,0,t),e):t}const EI={}.hasOwnProperty;function zG(e){const t={};let n=-1;for(;++n<e.length;)dle(t,e[n]);return t}function dle(e,t){let n;for(n in t){const a=(EI.call(e,n)?e[n]:void 0)||(e[n]={}),o=t[n];let s;if(o)for(s in o){EI.call(a,s)||(a[s]=[]);const l=o[s];fle(a[s],Array.isArray(l)?l:l?[l]:[])}}}function fle(e,t){let n=-1;const r=[];for(;++n<t.length;)(t[n].add==="after"?e:r).push(t[n]);or(e,0,0,r)}function BG(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}function Br(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const In=Mo(/[A-Za-z]/),Tn=Mo(/[\dA-Za-z]/),ple=Mo(/[#-'*+\--9=?A-Z^-~]/);function Ff(e){return e!==null&&(e<32||e===127)}const vk=Mo(/\d/),gle=Mo(/[\dA-Fa-f]/),hle=Mo(/[!-/:-@[-`{-~]/);function Ve(e){return e!==null&&e<-2}function Dt(e){return e!==null&&(e<0||e===32)}function pt(e){return e===-2||e===-1||e===32}const Dp=Mo(new RegExp("\\p{P}|\\p{S}","u")),wi=Mo(/\s/);function Mo(e){return t;function t(n){return n!==null&&n>-1&&e.test(String.fromCharCode(n))}}function rl(e){const t=[];let n=-1,r=0,a=0;for(;++n<e.length;){const o=e.charCodeAt(n);let s="";if(o===37&&Tn(e.charCodeAt(n+1))&&Tn(e.charCodeAt(n+2)))a=2;else if(o<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(o))||(s=String.fromCharCode(o));else if(o>55295&&o<57344){const l=e.charCodeAt(n+1);o<56320&&l>56319&&l<57344?(s=String.fromCharCode(o,l),a=1):s="�"}else s=String.fromCharCode(o);s&&(t.push(e.slice(r,n),encodeURIComponent(s)),r=n+a+1,s=""),a&&(n+=a,a=0)}return t.join("")+e.slice(r)}function dt(e,t,n,r){const a=r?r-1:Number.POSITIVE_INFINITY;let o=0;return s;function s(u){return pt(u)?(e.enter(n),l(u)):t(u)}function l(u){return pt(u)&&o++<a?(e.consume(u),l):(e.exit(n),t(u))}}const mle={tokenize:ble};function ble(e){const t=e.attempt(this.parser.constructs.contentInitial,r,a);let n;return t;function r(l){if(l===null){e.consume(l);return}return e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),dt(e,t,"linePrefix")}function a(l){return e.enter("paragraph"),o(l)}function o(l){const u=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=u),n=u,s(l)}function s(l){if(l===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(l);return}return Ve(l)?(e.consume(l),e.exit("chunkText"),o):(e.consume(l),s)}}const yle={tokenize:vle},wI={tokenize:Sle};function vle(e){const t=this,n=[];let r=0,a,o,s;return l;function l(R){if(r<n.length){const O=n[r];return t.containerState=O[1],e.attempt(O[0].continuation,u,d)(R)}return d(R)}function u(R){if(r++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,a&&x();const O=t.events.length;let N=O,C;for(;N--;)if(t.events[N][0]==="exit"&&t.events[N][1].type==="chunkFlow"){C=t.events[N][1].end;break}A(r);let _=O;for(;_<t.events.length;)t.events[_][1].end={...C},_++;return or(t.events,N+1,0,t.events.slice(O)),t.events.length=_,d(R)}return l(R)}function d(R){if(r===n.length){if(!a)return m(R);if(a.currentConstruct&&a.currentConstruct.concrete)return v(R);t.interrupt=!!(a.currentConstruct&&!a._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(wI,p,g)(R)}function p(R){return a&&x(),A(r),m(R)}function g(R){return t.parser.lazy[t.now().line]=r!==n.length,s=t.now().offset,v(R)}function m(R){return t.containerState={},e.attempt(wI,b,v)(R)}function b(R){return r++,n.push([t.currentConstruct,t.containerState]),m(R)}function v(R){if(R===null){a&&x(),A(0),e.consume(R);return}return a=a||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:a,contentType:"flow",previous:o}),y(R)}function y(R){if(R===null){k(e.exit("chunkFlow"),!0),A(0),e.consume(R);return}return Ve(R)?(e.consume(R),k(e.exit("chunkFlow")),r=0,t.interrupt=void 0,l):(e.consume(R),y)}function k(R,O){const N=t.sliceStream(R);if(O&&N.push(null),R.previous=o,o&&(o.next=R),o=R,a.defineSkip(R.start),a.write(N),t.parser.lazy[R.start.line]){let C=a.events.length;for(;C--;)if(a.events[C][1].start.offset<s&&(!a.events[C][1].end||a.events[C][1].end.offset>s))return;const _=t.events.length;let M=_,I,D;for(;M--;)if(t.events[M][0]==="exit"&&t.events[M][1].type==="chunkFlow"){if(I){D=t.events[M][1].end;break}I=!0}for(A(r),C=_;C<t.events.length;)t.events[C][1].end={...D},C++;or(t.events,M+1,0,t.events.slice(_)),t.events.length=C}}function A(R){let O=n.length;for(;O-- >R;){const N=n[O];t.containerState=N[1],N[0].exit.call(t,e)}n.length=R}function x(){a.write([null]),o=void 0,a=void 0,t.containerState._closeFlow=void 0}}function Sle(e,t,n){return dt(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function js(e){if(e===null||Dt(e)||wi(e))return 1;if(Dp(e))return 2}function Lp(e,t,n){const r=[];let a=-1;for(;++a<e.length;){const o=e[a].resolveAll;o&&!r.includes(o)&&(t=o(t,n),r.push(o))}return t}const Sk={name:"attention",resolveAll:Ele,tokenize:wle};function Ele(e,t){let n=-1,r,a,o,s,l,u,d,p;for(;++n<e.length;)if(e[n][0]==="enter"&&e[n][1].type==="attentionSequence"&&e[n][1]._close){for(r=n;r--;)if(e[r][0]==="exit"&&e[r][1].type==="attentionSequence"&&e[r][1]._open&&t.sliceSerialize(e[r][1]).charCodeAt(0)===t.sliceSerialize(e[n][1]).charCodeAt(0)){if((e[r][1]._close||e[n][1]._open)&&(e[n][1].end.offset-e[n][1].start.offset)%3&&!((e[r][1].end.offset-e[r][1].start.offset+e[n][1].end.offset-e[n][1].start.offset)%3))continue;u=e[r][1].end.offset-e[r][1].start.offset>1&&e[n][1].end.offset-e[n][1].start.offset>1?2:1;const g={...e[r][1].end},m={...e[n][1].start};xI(g,-u),xI(m,u),s={type:u>1?"strongSequence":"emphasisSequence",start:g,end:{...e[r][1].end}},l={type:u>1?"strongSequence":"emphasisSequence",start:{...e[n][1].start},end:m},o={type:u>1?"strongText":"emphasisText",start:{...e[r][1].end},end:{...e[n][1].start}},a={type:u>1?"strong":"emphasis",start:{...s.start},end:{...l.end}},e[r][1].end={...s.start},e[n][1].start={...l.end},d=[],e[r][1].end.offset-e[r][1].start.offset&&(d=Sr(d,[["enter",e[r][1],t],["exit",e[r][1],t]])),d=Sr(d,[["enter",a,t],["enter",s,t],["exit",s,t],["enter",o,t]]),d=Sr(d,Lp(t.parser.constructs.insideSpan.null,e.slice(r+1,n),t)),d=Sr(d,[["exit",o,t],["enter",l,t],["exit",l,t],["exit",a,t]]),e[n][1].end.offset-e[n][1].start.offset?(p=2,d=Sr(d,[["enter",e[n][1],t],["exit",e[n][1],t]])):p=0,or(e,r-1,n-r+3,d),n=r+d.length-p-2;break}}for(n=-1;++n<e.length;)e[n][1].type==="attentionSequence"&&(e[n][1].type="data");return e}function wle(e,t){const n=this.parser.constructs.attentionMarkers.null,r=this.previous,a=js(r);let o;return s;function s(u){return o=u,e.enter("attentionSequence"),l(u)}function l(u){if(u===o)return e.consume(u),l;const d=e.exit("attentionSequence"),p=js(u),g=!p||p===2&&a||n.includes(u),m=!a||a===2&&p||n.includes(r);return d._open=!!(o===42?g:g&&(a||!m)),d._close=!!(o===42?m:m&&(p||!g)),t(u)}}function xI(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const xle={name:"autolink",tokenize:kle};function kle(e,t,n){let r=0;return a;function a(b){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(b),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),o}function o(b){return In(b)?(e.consume(b),s):b===64?n(b):d(b)}function s(b){return b===43||b===45||b===46||Tn(b)?(r=1,l(b)):d(b)}function l(b){return b===58?(e.consume(b),r=0,u):(b===43||b===45||b===46||Tn(b))&&r++<32?(e.consume(b),l):(r=0,d(b))}function u(b){return b===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(b),e.exit("autolinkMarker"),e.exit("autolink"),t):b===null||b===32||b===60||Ff(b)?n(b):(e.consume(b),u)}function d(b){return b===64?(e.consume(b),p):ple(b)?(e.consume(b),d):n(b)}function p(b){return Tn(b)?g(b):n(b)}function g(b){return b===46?(e.consume(b),r=0,p):b===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(b),e.exit("autolinkMarker"),e.exit("autolink"),t):m(b)}function m(b){if((b===45||Tn(b))&&r++<63){const v=b===45?m:g;return e.consume(b),v}return n(b)}}const su={partial:!0,tokenize:Tle};function Tle(e,t,n){return r;function r(o){return pt(o)?dt(e,a,"linePrefix")(o):a(o)}function a(o){return o===null||Ve(o)?t(o):n(o)}}const jG={continuation:{tokenize:Rle},exit:Cle,name:"blockQuote",tokenize:Ale};function Ale(e,t,n){const r=this;return a;function a(s){if(s===62){const l=r.containerState;return l.open||(e.enter("blockQuote",{_container:!0}),l.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(s),e.exit("blockQuoteMarker"),o}return n(s)}function o(s){return pt(s)?(e.enter("blockQuotePrefixWhitespace"),e.consume(s),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(s))}}function Rle(e,t,n){const r=this;return a;function a(s){return pt(s)?dt(e,o,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(s):o(s)}function o(s){return e.attempt(jG,t,n)(s)}}function Cle(e){e.exit("blockQuote")}const UG={name:"characterEscape",tokenize:_le};function _le(e,t,n){return r;function r(o){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(o),e.exit("escapeMarker"),a}function a(o){return hle(o)?(e.enter("characterEscapeValue"),e.consume(o),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(o)}}const GG={name:"characterReference",tokenize:Nle};function Nle(e,t,n){const r=this;let a=0,o,s;return l;function l(g){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(g),e.exit("characterReferenceMarker"),u}function u(g){return g===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(g),e.exit("characterReferenceMarkerNumeric"),d):(e.enter("characterReferenceValue"),o=31,s=Tn,p(g))}function d(g){return g===88||g===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(g),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),o=6,s=gle,p):(e.enter("characterReferenceValue"),o=7,s=vk,p(g))}function p(g){if(g===59&&a){const m=e.exit("characterReferenceValue");return s===Tn&&!oA(r.sliceSerialize(m))?n(g):(e.enter("characterReferenceMarker"),e.consume(g),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return s(g)&&a++<o?(e.consume(g),p):n(g)}}const kI={partial:!0,tokenize:Ile},TI={concrete:!0,name:"codeFenced",tokenize:Ole};function Ole(e,t,n){const r=this,a={partial:!0,tokenize:N};let o=0,s=0,l;return u;function u(C){return d(C)}function d(C){const _=r.events[r.events.length-1];return o=_&&_[1].type==="linePrefix"?_[2].sliceSerialize(_[1],!0).length:0,l=C,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),p(C)}function p(C){return C===l?(s++,e.consume(C),p):s<3?n(C):(e.exit("codeFencedFenceSequence"),pt(C)?dt(e,g,"whitespace")(C):g(C))}function g(C){return C===null||Ve(C)?(e.exit("codeFencedFence"),r.interrupt?t(C):e.check(kI,y,O)(C)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),m(C))}function m(C){return C===null||Ve(C)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),g(C)):pt(C)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),dt(e,b,"whitespace")(C)):C===96&&C===l?n(C):(e.consume(C),m)}function b(C){return C===null||Ve(C)?g(C):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),v(C))}function v(C){return C===null||Ve(C)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),g(C)):C===96&&C===l?n(C):(e.consume(C),v)}function y(C){return e.attempt(a,O,k)(C)}function k(C){return e.enter("lineEnding"),e.consume(C),e.exit("lineEnding"),A}function A(C){return o>0&&pt(C)?dt(e,x,"linePrefix",o+1)(C):x(C)}function x(C){return C===null||Ve(C)?e.check(kI,y,O)(C):(e.enter("codeFlowValue"),R(C))}function R(C){return C===null||Ve(C)?(e.exit("codeFlowValue"),x(C)):(e.consume(C),R)}function O(C){return e.exit("codeFenced"),t(C)}function N(C,_,M){let I=0;return D;function D(K){return C.enter("lineEnding"),C.consume(K),C.exit("lineEnding"),U}function U(K){return C.enter("codeFencedFence"),pt(K)?dt(C,$,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(K):$(K)}function $(K){return K===l?(C.enter("codeFencedFenceSequence"),B(K)):M(K)}function B(K){return K===l?(I++,C.consume(K),B):I>=s?(C.exit("codeFencedFenceSequence"),pt(K)?dt(C,W,"whitespace")(K):W(K)):M(K)}function W(K){return K===null||Ve(K)?(C.exit("codeFencedFence"),_(K)):M(K)}}}function Ile(e,t,n){const r=this;return a;function a(s){return s===null?n(s):(e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),o)}function o(s){return r.parser.lazy[r.now().line]?n(s):t(s)}}const vb={name:"codeIndented",tokenize:Lle},Dle={partial:!0,tokenize:Mle};function Lle(e,t,n){const r=this;return a;function a(d){return e.enter("codeIndented"),dt(e,o,"linePrefix",5)(d)}function o(d){const p=r.events[r.events.length-1];return p&&p[1].type==="linePrefix"&&p[2].sliceSerialize(p[1],!0).length>=4?s(d):n(d)}function s(d){return d===null?u(d):Ve(d)?e.attempt(Dle,s,u)(d):(e.enter("codeFlowValue"),l(d))}function l(d){return d===null||Ve(d)?(e.exit("codeFlowValue"),s(d)):(e.consume(d),l)}function u(d){return e.exit("codeIndented"),t(d)}}function Mle(e,t,n){const r=this;return a;function a(s){return r.parser.lazy[r.now().line]?n(s):Ve(s)?(e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),a):dt(e,o,"linePrefix",5)(s)}function o(s){const l=r.events[r.events.length-1];return l&&l[1].type==="linePrefix"&&l[2].sliceSerialize(l[1],!0).length>=4?t(s):Ve(s)?a(s):n(s)}}const Ple={name:"codeText",previous:zle,resolve:Fle,tokenize:Ble};function Fle(e){let t=e.length-4,n=3,r,a;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="codeTextData"){e[n][1].type="codeTextPadding",e[t][1].type="codeTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)a===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(a=r):(r===t||e[r][1].type==="lineEnding")&&(e[a][1].type="codeTextData",r!==a+2&&(e[a][1].end=e[r-1][1].end,e.splice(a+2,r-a-2),t-=r-a-2,r=a+2),a=void 0);return e}function zle(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function Ble(e,t,n){let r=0,a,o;return s;function s(g){return e.enter("codeText"),e.enter("codeTextSequence"),l(g)}function l(g){return g===96?(e.consume(g),r++,l):(e.exit("codeTextSequence"),u(g))}function u(g){return g===null?n(g):g===32?(e.enter("space"),e.consume(g),e.exit("space"),u):g===96?(o=e.enter("codeTextSequence"),a=0,p(g)):Ve(g)?(e.enter("lineEnding"),e.consume(g),e.exit("lineEnding"),u):(e.enter("codeTextData"),d(g))}function d(g){return g===null||g===32||g===96||Ve(g)?(e.exit("codeTextData"),u(g)):(e.consume(g),d)}function p(g){return g===96?(e.consume(g),a++,p):a===r?(e.exit("codeTextSequence"),e.exit("codeText"),t(g)):(o.type="codeTextData",d(g))}}class jle{constructor(t){this.left=t?[...t]:[],this.right=[]}get(t){if(t<0||t>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+t+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return t<this.left.length?this.left[t]:this.right[this.right.length-t+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(t,n){const r=n??Number.POSITIVE_INFINITY;return r<this.left.length?this.left.slice(t,r):t>this.left.length?this.right.slice(this.right.length-r+this.left.length,this.right.length-t+this.left.length).reverse():this.left.slice(t).concat(this.right.slice(this.right.length-r+this.left.length).reverse())}splice(t,n,r){const a=n||0;this.setCursor(Math.trunc(t));const o=this.right.splice(this.right.length-a,Number.POSITIVE_INFINITY);return r&&uc(this.left,r),o.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(t){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(t)}pushMany(t){this.setCursor(Number.POSITIVE_INFINITY),uc(this.left,t)}unshift(t){this.setCursor(0),this.right.push(t)}unshiftMany(t){this.setCursor(0),uc(this.right,t.reverse())}setCursor(t){if(!(t===this.left.length||t>this.left.length&&this.right.length===0||t<0&&this.left.length===0))if(t<this.left.length){const n=this.left.splice(t,Number.POSITIVE_INFINITY);uc(this.right,n.reverse())}else{const n=this.right.splice(this.left.length+this.right.length-t,Number.POSITIVE_INFINITY);uc(this.left,n.reverse())}}}function uc(e,t){let n=0;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),n+=1e4}function HG(e){const t={};let n=-1,r,a,o,s,l,u,d;const p=new jle(e);for(;++n<p.length;){for(;n in t;)n=t[n];if(r=p.get(n),n&&r[1].type==="chunkFlow"&&p.get(n-1)[1].type==="listItemPrefix"&&(u=r[1]._tokenizer.events,o=0,o<u.length&&u[o][1].type==="lineEndingBlank"&&(o+=2),o<u.length&&u[o][1].type==="content"))for(;++o<u.length&&u[o][1].type!=="content";)u[o][1].type==="chunkText"&&(u[o][1]._isInFirstContentOfListItem=!0,o++);if(r[0]==="enter")r[1].contentType&&(Object.assign(t,Ule(p,n)),n=t[n],d=!0);else if(r[1]._container){for(o=n,a=void 0;o--;)if(s=p.get(o),s[1].type==="lineEnding"||s[1].type==="lineEndingBlank")s[0]==="enter"&&(a&&(p.get(a)[1].type="lineEndingBlank"),s[1].type="lineEnding",a=o);else if(s[1].type!=="linePrefix")break;a&&(r[1].end={...p.get(a)[1].start},l=p.slice(a,n),l.unshift(r),p.splice(a,n-a+1,l))}}return or(e,0,Number.POSITIVE_INFINITY,p.slice(0)),!d}function Ule(e,t){const n=e.get(t)[1],r=e.get(t)[2];let a=t-1;const o=[],s=n._tokenizer||r.parser[n.contentType](n.start),l=s.events,u=[],d={};let p,g,m=-1,b=n,v=0,y=0;const k=[y];for(;b;){for(;e.get(++a)[1]!==b;);o.push(a),b._tokenizer||(p=r.sliceStream(b),b.next||p.push(null),g&&s.defineSkip(b.start),b._isInFirstContentOfListItem&&(s._gfmTasklistFirstContentOfListItem=!0),s.write(p),b._isInFirstContentOfListItem&&(s._gfmTasklistFirstContentOfListItem=void 0)),g=b,b=b.next}for(b=n;++m<l.length;)l[m][0]==="exit"&&l[m-1][0]==="enter"&&l[m][1].type===l[m-1][1].type&&l[m][1].start.line!==l[m][1].end.line&&(y=m+1,k.push(y),b._tokenizer=void 0,b.previous=void 0,b=b.next);for(s.events=[],b?(b._tokenizer=void 0,b.previous=void 0):k.pop(),m=k.length;m--;){const A=l.slice(k[m],k[m+1]),x=o.pop();u.push([x,x+A.length-1]),e.splice(x,2,A)}for(u.reverse(),m=-1;++m<u.length;)d[v+u[m][0]]=v+u[m][1],v+=u[m][1]-u[m][0]-1;return d}const Gle={resolve:$le,tokenize:qle},Hle={partial:!0,tokenize:Vle};function $le(e){return HG(e),e}function qle(e,t){let n;return r;function r(l){return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),a(l)}function a(l){return l===null?o(l):Ve(l)?e.check(Hle,s,o)(l):(e.consume(l),a)}function o(l){return e.exit("chunkContent"),e.exit("content"),t(l)}function s(l){return e.consume(l),e.exit("chunkContent"),n.next=e.enter("chunkContent",{contentType:"content",previous:n}),n=n.next,a}}function Vle(e,t,n){const r=this;return a;function a(s){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),dt(e,o,"linePrefix")}function o(s){if(s===null||Ve(s))return n(s);const l=r.events[r.events.length-1];return!r.parser.constructs.disable.null.includes("codeIndented")&&l&&l[1].type==="linePrefix"&&l[2].sliceSerialize(l[1],!0).length>=4?t(s):e.interrupt(r.parser.constructs.flow,n,t)(s)}}function $G(e,t,n,r,a,o,s,l,u){const d=u||Number.POSITIVE_INFINITY;let p=0;return g;function g(A){return A===60?(e.enter(r),e.enter(a),e.enter(o),e.consume(A),e.exit(o),m):A===null||A===32||A===41||Ff(A)?n(A):(e.enter(r),e.enter(s),e.enter(l),e.enter("chunkString",{contentType:"string"}),y(A))}function m(A){return A===62?(e.enter(o),e.consume(A),e.exit(o),e.exit(a),e.exit(r),t):(e.enter(l),e.enter("chunkString",{contentType:"string"}),b(A))}function b(A){return A===62?(e.exit("chunkString"),e.exit(l),m(A)):A===null||A===60||Ve(A)?n(A):(e.consume(A),A===92?v:b)}function v(A){return A===60||A===62||A===92?(e.consume(A),b):b(A)}function y(A){return!p&&(A===null||A===41||Dt(A))?(e.exit("chunkString"),e.exit(l),e.exit(s),e.exit(r),t(A)):p<d&&A===40?(e.consume(A),p++,y):A===41?(e.consume(A),p--,y):A===null||A===32||A===40||Ff(A)?n(A):(e.consume(A),A===92?k:y)}function k(A){return A===40||A===41||A===92?(e.consume(A),y):y(A)}}function qG(e,t,n,r,a,o){const s=this;let l=0,u;return d;function d(b){return e.enter(r),e.enter(a),e.consume(b),e.exit(a),e.enter(o),p}function p(b){return l>999||b===null||b===91||b===93&&!u||b===94&&!l&&"_hiddenFootnoteSupport"in s.parser.constructs?n(b):b===93?(e.exit(o),e.enter(a),e.consume(b),e.exit(a),e.exit(r),t):Ve(b)?(e.enter("lineEnding"),e.consume(b),e.exit("lineEnding"),p):(e.enter("chunkString",{contentType:"string"}),g(b))}function g(b){return b===null||b===91||b===93||Ve(b)||l++>999?(e.exit("chunkString"),p(b)):(e.consume(b),u||(u=!pt(b)),b===92?m:g)}function m(b){return b===91||b===92||b===93?(e.consume(b),l++,g):g(b)}}function VG(e,t,n,r,a,o){let s;return l;function l(m){return m===34||m===39||m===40?(e.enter(r),e.enter(a),e.consume(m),e.exit(a),s=m===40?41:m,u):n(m)}function u(m){return m===s?(e.enter(a),e.consume(m),e.exit(a),e.exit(r),t):(e.enter(o),d(m))}function d(m){return m===s?(e.exit(o),u(s)):m===null?n(m):Ve(m)?(e.enter("lineEnding"),e.consume(m),e.exit("lineEnding"),dt(e,d,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),p(m))}function p(m){return m===s||m===null||Ve(m)?(e.exit("chunkString"),d(m)):(e.consume(m),m===92?g:p)}function g(m){return m===s||m===92?(e.consume(m),p):p(m)}}function yc(e,t){let n;return r;function r(a){return Ve(a)?(e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),n=!0,r):pt(a)?dt(e,r,n?"linePrefix":"lineSuffix")(a):t(a)}}const Wle={name:"definition",tokenize:Kle},Yle={partial:!0,tokenize:Xle};function Kle(e,t,n){const r=this;let a;return o;function o(b){return e.enter("definition"),s(b)}function s(b){return qG.call(r,e,l,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(b)}function l(b){return a=Br(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),b===58?(e.enter("definitionMarker"),e.consume(b),e.exit("definitionMarker"),u):n(b)}function u(b){return Dt(b)?yc(e,d)(b):d(b)}function d(b){return $G(e,p,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(b)}function p(b){return e.attempt(Yle,g,g)(b)}function g(b){return pt(b)?dt(e,m,"whitespace")(b):m(b)}function m(b){return b===null||Ve(b)?(e.exit("definition"),r.parser.defined.push(a),t(b)):n(b)}}function Xle(e,t,n){return r;function r(l){return Dt(l)?yc(e,a)(l):n(l)}function a(l){return VG(e,o,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(l)}function o(l){return pt(l)?dt(e,s,"whitespace")(l):s(l)}function s(l){return l===null||Ve(l)?t(l):n(l)}}const Zle={name:"hardBreakEscape",tokenize:Qle};function Qle(e,t,n){return r;function r(o){return e.enter("hardBreakEscape"),e.consume(o),a}function a(o){return Ve(o)?(e.exit("hardBreakEscape"),t(o)):n(o)}}const Jle={name:"headingAtx",resolve:ece,tokenize:tce};function ece(e,t){let n=e.length-2,r=3,a,o;return e[r][1].type==="whitespace"&&(r+=2),n-2>r&&e[n][1].type==="whitespace"&&(n-=2),e[n][1].type==="atxHeadingSequence"&&(r===n-1||n-4>r&&e[n-2][1].type==="whitespace")&&(n-=r+1===n?2:4),n>r&&(a={type:"atxHeadingText",start:e[r][1].start,end:e[n][1].end},o={type:"chunkText",start:e[r][1].start,end:e[n][1].end,contentType:"text"},or(e,r,n-r+1,[["enter",a,t],["enter",o,t],["exit",o,t],["exit",a,t]])),e}function tce(e,t,n){let r=0;return a;function a(p){return e.enter("atxHeading"),o(p)}function o(p){return e.enter("atxHeadingSequence"),s(p)}function s(p){return p===35&&r++<6?(e.consume(p),s):p===null||Dt(p)?(e.exit("atxHeadingSequence"),l(p)):n(p)}function l(p){return p===35?(e.enter("atxHeadingSequence"),u(p)):p===null||Ve(p)?(e.exit("atxHeading"),t(p)):pt(p)?dt(e,l,"whitespace")(p):(e.enter("atxHeadingText"),d(p))}function u(p){return p===35?(e.consume(p),u):(e.exit("atxHeadingSequence"),l(p))}function d(p){return p===null||p===35||Dt(p)?(e.exit("atxHeadingText"),l(p)):(e.consume(p),d)}}const nce=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],AI=["pre","script","style","textarea"],rce={concrete:!0,name:"htmlFlow",resolveTo:ice,tokenize:sce},ace={partial:!0,tokenize:cce},oce={partial:!0,tokenize:lce};function ice(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function sce(e,t,n){const r=this;let a,o,s,l,u;return d;function d(P){return p(P)}function p(P){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(P),g}function g(P){return P===33?(e.consume(P),m):P===47?(e.consume(P),o=!0,y):P===63?(e.consume(P),a=3,r.interrupt?t:L):In(P)?(e.consume(P),s=String.fromCharCode(P),k):n(P)}function m(P){return P===45?(e.consume(P),a=2,b):P===91?(e.consume(P),a=5,l=0,v):In(P)?(e.consume(P),a=4,r.interrupt?t:L):n(P)}function b(P){return P===45?(e.consume(P),r.interrupt?t:L):n(P)}function v(P){const Z="CDATA[";return P===Z.charCodeAt(l++)?(e.consume(P),l===Z.length?r.interrupt?t:$:v):n(P)}function y(P){return In(P)?(e.consume(P),s=String.fromCharCode(P),k):n(P)}function k(P){if(P===null||P===47||P===62||Dt(P)){const Z=P===47,Q=s.toLowerCase();return!Z&&!o&&AI.includes(Q)?(a=1,r.interrupt?t(P):$(P)):nce.includes(s.toLowerCase())?(a=6,Z?(e.consume(P),A):r.interrupt?t(P):$(P)):(a=7,r.interrupt&&!r.parser.lazy[r.now().line]?n(P):o?x(P):R(P))}return P===45||Tn(P)?(e.consume(P),s+=String.fromCharCode(P),k):n(P)}function A(P){return P===62?(e.consume(P),r.interrupt?t:$):n(P)}function x(P){return pt(P)?(e.consume(P),x):D(P)}function R(P){return P===47?(e.consume(P),D):P===58||P===95||In(P)?(e.consume(P),O):pt(P)?(e.consume(P),R):D(P)}function O(P){return P===45||P===46||P===58||P===95||Tn(P)?(e.consume(P),O):N(P)}function N(P){return P===61?(e.consume(P),C):pt(P)?(e.consume(P),N):R(P)}function C(P){return P===null||P===60||P===61||P===62||P===96?n(P):P===34||P===39?(e.consume(P),u=P,_):pt(P)?(e.consume(P),C):M(P)}function _(P){return P===u?(e.consume(P),u=null,I):P===null||Ve(P)?n(P):(e.consume(P),_)}function M(P){return P===null||P===34||P===39||P===47||P===60||P===61||P===62||P===96||Dt(P)?N(P):(e.consume(P),M)}function I(P){return P===47||P===62||pt(P)?R(P):n(P)}function D(P){return P===62?(e.consume(P),U):n(P)}function U(P){return P===null||Ve(P)?$(P):pt(P)?(e.consume(P),U):n(P)}function $(P){return P===45&&a===2?(e.consume(P),H):P===60&&a===1?(e.consume(P),G):P===62&&a===4?(e.consume(P),V):P===63&&a===3?(e.consume(P),L):P===93&&a===5?(e.consume(P),Y):Ve(P)&&(a===6||a===7)?(e.exit("htmlFlowData"),e.check(ace,j,B)(P)):P===null||Ve(P)?(e.exit("htmlFlowData"),B(P)):(e.consume(P),$)}function B(P){return e.check(oce,W,j)(P)}function W(P){return e.enter("lineEnding"),e.consume(P),e.exit("lineEnding"),K}function K(P){return P===null||Ve(P)?B(P):(e.enter("htmlFlowData"),$(P))}function H(P){return P===45?(e.consume(P),L):$(P)}function G(P){return P===47?(e.consume(P),s="",z):$(P)}function z(P){if(P===62){const Z=s.toLowerCase();return AI.includes(Z)?(e.consume(P),V):$(P)}return In(P)&&s.length<8?(e.consume(P),s+=String.fromCharCode(P),z):$(P)}function Y(P){return P===93?(e.consume(P),L):$(P)}function L(P){return P===62?(e.consume(P),V):P===45&&a===2?(e.consume(P),L):$(P)}function V(P){return P===null||Ve(P)?(e.exit("htmlFlowData"),j(P)):(e.consume(P),V)}function j(P){return e.exit("htmlFlow"),t(P)}}function lce(e,t,n){const r=this;return a;function a(s){return Ve(s)?(e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),o):n(s)}function o(s){return r.parser.lazy[r.now().line]?n(s):t(s)}}function cce(e,t,n){return r;function r(a){return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),e.attempt(su,t,n)}}const uce={name:"htmlText",tokenize:dce};function dce(e,t,n){const r=this;let a,o,s;return l;function l(L){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(L),u}function u(L){return L===33?(e.consume(L),d):L===47?(e.consume(L),N):L===63?(e.consume(L),R):In(L)?(e.consume(L),M):n(L)}function d(L){return L===45?(e.consume(L),p):L===91?(e.consume(L),o=0,v):In(L)?(e.consume(L),x):n(L)}function p(L){return L===45?(e.consume(L),b):n(L)}function g(L){return L===null?n(L):L===45?(e.consume(L),m):Ve(L)?(s=g,G(L)):(e.consume(L),g)}function m(L){return L===45?(e.consume(L),b):g(L)}function b(L){return L===62?H(L):L===45?m(L):g(L)}function v(L){const V="CDATA[";return L===V.charCodeAt(o++)?(e.consume(L),o===V.length?y:v):n(L)}function y(L){return L===null?n(L):L===93?(e.consume(L),k):Ve(L)?(s=y,G(L)):(e.consume(L),y)}function k(L){return L===93?(e.consume(L),A):y(L)}function A(L){return L===62?H(L):L===93?(e.consume(L),A):y(L)}function x(L){return L===null||L===62?H(L):Ve(L)?(s=x,G(L)):(e.consume(L),x)}function R(L){return L===null?n(L):L===63?(e.consume(L),O):Ve(L)?(s=R,G(L)):(e.consume(L),R)}function O(L){return L===62?H(L):R(L)}function N(L){return In(L)?(e.consume(L),C):n(L)}function C(L){return L===45||Tn(L)?(e.consume(L),C):_(L)}function _(L){return Ve(L)?(s=_,G(L)):pt(L)?(e.consume(L),_):H(L)}function M(L){return L===45||Tn(L)?(e.consume(L),M):L===47||L===62||Dt(L)?I(L):n(L)}function I(L){return L===47?(e.consume(L),H):L===58||L===95||In(L)?(e.consume(L),D):Ve(L)?(s=I,G(L)):pt(L)?(e.consume(L),I):H(L)}function D(L){return L===45||L===46||L===58||L===95||Tn(L)?(e.consume(L),D):U(L)}function U(L){return L===61?(e.consume(L),$):Ve(L)?(s=U,G(L)):pt(L)?(e.consume(L),U):I(L)}function $(L){return L===null||L===60||L===61||L===62||L===96?n(L):L===34||L===39?(e.consume(L),a=L,B):Ve(L)?(s=$,G(L)):pt(L)?(e.consume(L),$):(e.consume(L),W)}function B(L){return L===a?(e.consume(L),a=void 0,K):L===null?n(L):Ve(L)?(s=B,G(L)):(e.consume(L),B)}function W(L){return L===null||L===34||L===39||L===60||L===61||L===96?n(L):L===47||L===62||Dt(L)?I(L):(e.consume(L),W)}function K(L){return L===47||L===62||Dt(L)?I(L):n(L)}function H(L){return L===62?(e.consume(L),e.exit("htmlTextData"),e.exit("htmlText"),t):n(L)}function G(L){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(L),e.exit("lineEnding"),z}function z(L){return pt(L)?dt(e,Y,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(L):Y(L)}function Y(L){return e.enter("htmlTextData"),s(L)}}const iA={name:"labelEnd",resolveAll:hce,resolveTo:mce,tokenize:bce},fce={tokenize:yce},pce={tokenize:vce},gce={tokenize:Sce};function hce(e){let t=-1;const n=[];for(;++t<e.length;){const r=e[t][1];if(n.push(e[t]),r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd"){const a=r.type==="labelImage"?4:2;r.type="data",t+=a}}return e.length!==n.length&&or(e,0,e.length,n),e}function mce(e,t){let n=e.length,r=0,a,o,s,l;for(;n--;)if(a=e[n][1],o){if(a.type==="link"||a.type==="labelLink"&&a._inactive)break;e[n][0]==="enter"&&a.type==="labelLink"&&(a._inactive=!0)}else if(s){if(e[n][0]==="enter"&&(a.type==="labelImage"||a.type==="labelLink")&&!a._balanced&&(o=n,a.type!=="labelLink")){r=2;break}}else a.type==="labelEnd"&&(s=n);const u={type:e[o][1].type==="labelLink"?"link":"image",start:{...e[o][1].start},end:{...e[e.length-1][1].end}},d={type:"label",start:{...e[o][1].start},end:{...e[s][1].end}},p={type:"labelText",start:{...e[o+r+2][1].end},end:{...e[s-2][1].start}};return l=[["enter",u,t],["enter",d,t]],l=Sr(l,e.slice(o+1,o+r+3)),l=Sr(l,[["enter",p,t]]),l=Sr(l,Lp(t.parser.constructs.insideSpan.null,e.slice(o+r+4,s-3),t)),l=Sr(l,[["exit",p,t],e[s-2],e[s-1],["exit",d,t]]),l=Sr(l,e.slice(s+1)),l=Sr(l,[["exit",u,t]]),or(e,o,e.length,l),e}function bce(e,t,n){const r=this;let a=r.events.length,o,s;for(;a--;)if((r.events[a][1].type==="labelImage"||r.events[a][1].type==="labelLink")&&!r.events[a][1]._balanced){o=r.events[a][1];break}return l;function l(m){return o?o._inactive?g(m):(s=r.parser.defined.includes(Br(r.sliceSerialize({start:o.end,end:r.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(m),e.exit("labelMarker"),e.exit("labelEnd"),u):n(m)}function u(m){return m===40?e.attempt(fce,p,s?p:g)(m):m===91?e.attempt(pce,p,s?d:g)(m):s?p(m):g(m)}function d(m){return e.attempt(gce,p,g)(m)}function p(m){return t(m)}function g(m){return o._balanced=!0,n(m)}}function yce(e,t,n){return r;function r(g){return e.enter("resource"),e.enter("resourceMarker"),e.consume(g),e.exit("resourceMarker"),a}function a(g){return Dt(g)?yc(e,o)(g):o(g)}function o(g){return g===41?p(g):$G(e,s,l,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(g)}function s(g){return Dt(g)?yc(e,u)(g):p(g)}function l(g){return n(g)}function u(g){return g===34||g===39||g===40?VG(e,d,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(g):p(g)}function d(g){return Dt(g)?yc(e,p)(g):p(g)}function p(g){return g===41?(e.enter("resourceMarker"),e.consume(g),e.exit("resourceMarker"),e.exit("resource"),t):n(g)}}function vce(e,t,n){const r=this;return a;function a(l){return qG.call(r,e,o,s,"reference","referenceMarker","referenceString")(l)}function o(l){return r.parser.defined.includes(Br(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?t(l):n(l)}function s(l){return n(l)}}function Sce(e,t,n){return r;function r(o){return e.enter("reference"),e.enter("referenceMarker"),e.consume(o),e.exit("referenceMarker"),a}function a(o){return o===93?(e.enter("referenceMarker"),e.consume(o),e.exit("referenceMarker"),e.exit("reference"),t):n(o)}}const Ece={name:"labelStartImage",resolveAll:iA.resolveAll,tokenize:wce};function wce(e,t,n){const r=this;return a;function a(l){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(l),e.exit("labelImageMarker"),o}function o(l){return l===91?(e.enter("labelMarker"),e.consume(l),e.exit("labelMarker"),e.exit("labelImage"),s):n(l)}function s(l){return l===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(l):t(l)}}const xce={name:"labelStartLink",resolveAll:iA.resolveAll,tokenize:kce};function kce(e,t,n){const r=this;return a;function a(s){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(s),e.exit("labelMarker"),e.exit("labelLink"),o}function o(s){return s===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(s):t(s)}}const Sb={name:"lineEnding",tokenize:Tce};function Tce(e,t){return n;function n(r){return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),dt(e,t,"linePrefix")}}const ff={name:"thematicBreak",tokenize:Ace};function Ace(e,t,n){let r=0,a;return o;function o(d){return e.enter("thematicBreak"),s(d)}function s(d){return a=d,l(d)}function l(d){return d===a?(e.enter("thematicBreakSequence"),u(d)):r>=3&&(d===null||Ve(d))?(e.exit("thematicBreak"),t(d)):n(d)}function u(d){return d===a?(e.consume(d),r++,u):(e.exit("thematicBreakSequence"),pt(d)?dt(e,l,"whitespace")(d):l(d))}}const jn={continuation:{tokenize:Nce},exit:Ice,name:"list",tokenize:_ce},Rce={partial:!0,tokenize:Dce},Cce={partial:!0,tokenize:Oce};function _ce(e,t,n){const r=this,a=r.events[r.events.length-1];let o=a&&a[1].type==="linePrefix"?a[2].sliceSerialize(a[1],!0).length:0,s=0;return l;function l(b){const v=r.containerState.type||(b===42||b===43||b===45?"listUnordered":"listOrdered");if(v==="listUnordered"?!r.containerState.marker||b===r.containerState.marker:vk(b)){if(r.containerState.type||(r.containerState.type=v,e.enter(v,{_container:!0})),v==="listUnordered")return e.enter("listItemPrefix"),b===42||b===45?e.check(ff,n,d)(b):d(b);if(!r.interrupt||b===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),u(b)}return n(b)}function u(b){return vk(b)&&++s<10?(e.consume(b),u):(!r.interrupt||s<2)&&(r.containerState.marker?b===r.containerState.marker:b===41||b===46)?(e.exit("listItemValue"),d(b)):n(b)}function d(b){return e.enter("listItemMarker"),e.consume(b),e.exit("listItemMarker"),r.containerState.marker=r.containerState.marker||b,e.check(su,r.interrupt?n:p,e.attempt(Rce,m,g))}function p(b){return r.containerState.initialBlankLine=!0,o++,m(b)}function g(b){return pt(b)?(e.enter("listItemPrefixWhitespace"),e.consume(b),e.exit("listItemPrefixWhitespace"),m):n(b)}function m(b){return r.containerState.size=o+r.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(b)}}function Nce(e,t,n){const r=this;return r.containerState._closeFlow=void 0,e.check(su,a,o);function a(l){return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,dt(e,t,"listItemIndent",r.containerState.size+1)(l)}function o(l){return r.containerState.furtherBlankLines||!pt(l)?(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,s(l)):(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,e.attempt(Cce,t,s)(l))}function s(l){return r.containerState._closeFlow=!0,r.interrupt=void 0,dt(e,e.attempt(jn,t,n),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(l)}}function Oce(e,t,n){const r=this;return dt(e,a,"listItemIndent",r.containerState.size+1);function a(o){const s=r.events[r.events.length-1];return s&&s[1].type==="listItemIndent"&&s[2].sliceSerialize(s[1],!0).length===r.containerState.size?t(o):n(o)}}function Ice(e){e.exit(this.containerState.type)}function Dce(e,t,n){const r=this;return dt(e,a,"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function a(o){const s=r.events[r.events.length-1];return!pt(o)&&s&&s[1].type==="listItemPrefixWhitespace"?t(o):n(o)}}const RI={name:"setextUnderline",resolveTo:Lce,tokenize:Mce};function Lce(e,t){let n=e.length,r,a,o;for(;n--;)if(e[n][0]==="enter"){if(e[n][1].type==="content"){r=n;break}e[n][1].type==="paragraph"&&(a=n)}else e[n][1].type==="content"&&e.splice(n,1),!o&&e[n][1].type==="definition"&&(o=n);const s={type:"setextHeading",start:{...e[a][1].start},end:{...e[e.length-1][1].end}};return e[a][1].type="setextHeadingText",o?(e.splice(a,0,["enter",s,t]),e.splice(o+1,0,["exit",e[r][1],t]),e[r][1].end={...e[o][1].end}):e[r][1]=s,e.push(["exit",s,t]),e}function Mce(e,t,n){const r=this;let a;return o;function o(d){let p=r.events.length,g;for(;p--;)if(r.events[p][1].type!=="lineEnding"&&r.events[p][1].type!=="linePrefix"&&r.events[p][1].type!=="content"){g=r.events[p][1].type==="paragraph";break}return!r.parser.lazy[r.now().line]&&(r.interrupt||g)?(e.enter("setextHeadingLine"),a=d,s(d)):n(d)}function s(d){return e.enter("setextHeadingLineSequence"),l(d)}function l(d){return d===a?(e.consume(d),l):(e.exit("setextHeadingLineSequence"),pt(d)?dt(e,u,"lineSuffix")(d):u(d))}function u(d){return d===null||Ve(d)?(e.exit("setextHeadingLine"),t(d)):n(d)}}const Pce={tokenize:Fce};function Fce(e){const t=this,n=e.attempt(su,r,e.attempt(this.parser.constructs.flowInitial,a,dt(e,e.attempt(this.parser.constructs.flow,a,e.attempt(Gle,a)),"linePrefix")));return n;function r(o){if(o===null){e.consume(o);return}return e.enter("lineEndingBlank"),e.consume(o),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function a(o){if(o===null){e.consume(o);return}return e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const zce={resolveAll:YG()},Bce=WG("string"),jce=WG("text");function WG(e){return{resolveAll:YG(e==="text"?Uce:void 0),tokenize:t};function t(n){const r=this,a=this.parser.constructs[e],o=n.attempt(a,s,l);return s;function s(p){return d(p)?o(p):l(p)}function l(p){if(p===null){n.consume(p);return}return n.enter("data"),n.consume(p),u}function u(p){return d(p)?(n.exit("data"),o(p)):(n.consume(p),u)}function d(p){if(p===null)return!0;const g=a[p];let m=-1;if(g)for(;++m<g.length;){const b=g[m];if(!b.previous||b.previous.call(r,r.previous))return!0}return!1}}}function YG(e){return t;function t(n,r){let a=-1,o;for(;++a<=n.length;)o===void 0?n[a]&&n[a][1].type==="data"&&(o=a,a++):(!n[a]||n[a][1].type!=="data")&&(a!==o+2&&(n[o][1].end=n[a-1][1].end,n.splice(o+2,a-o-2),a=o+2),o=void 0);return e?e(n,r):n}}function Uce(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const r=e[n-1][1],a=t.sliceStream(r);let o=a.length,s=-1,l=0,u;for(;o--;){const d=a[o];if(typeof d=="string"){for(s=d.length;d.charCodeAt(s-1)===32;)l++,s--;if(s)break;s=-1}else if(d===-2)u=!0,l++;else if(d!==-1){o++;break}}if(l){const d={type:n===e.length||u||l<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:o?s:r.start._bufferIndex+s,_index:r.start._index+o,line:r.end.line,column:r.end.column-l,offset:r.end.offset-l},end:{...r.end}};r.end={...d.start},r.start.offset===r.end.offset?Object.assign(r,d):(e.splice(n,0,["enter",d,t],["exit",d,t]),n+=2)}n++}return e}const Gce={42:jn,43:jn,45:jn,48:jn,49:jn,50:jn,51:jn,52:jn,53:jn,54:jn,55:jn,56:jn,57:jn,62:jG},Hce={91:Wle},$ce={[-2]:vb,[-1]:vb,32:vb},qce={35:Jle,42:ff,45:[RI,ff],60:rce,61:RI,95:ff,96:TI,126:TI},Vce={38:GG,92:UG},Wce={[-5]:Sb,[-4]:Sb,[-3]:Sb,33:Ece,38:GG,42:Sk,60:[xle,uce],91:xce,92:[Zle,UG],93:iA,95:Sk,96:Ple},Yce={null:[Sk,zce]},Kce={null:[42,95]},Xce={null:[]},Zce=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:Kce,contentInitial:Hce,disable:Xce,document:Gce,flow:qce,flowInitial:$ce,insideSpan:Yce,string:Vce,text:Wce},Symbol.toStringTag,{value:"Module"}));function Qce(e,t,n){let r={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const a={},o=[];let s=[],l=[];const u={attempt:_(N),check:_(C),consume:x,enter:R,exit:O,interrupt:_(C,{interrupt:!0})},d={code:null,containerState:{},defineSkip:y,events:[],now:v,parser:e,previous:null,sliceSerialize:m,sliceStream:b,write:g};let p=t.tokenize.call(d,u);return t.resolveAll&&o.push(t),d;function g(U){return s=Sr(s,U),k(),s[s.length-1]!==null?[]:(M(t,0),d.events=Lp(o,d.events,d),d.events)}function m(U,$){return eue(b(U),$)}function b(U){return Jce(s,U)}function v(){const{_bufferIndex:U,_index:$,line:B,column:W,offset:K}=r;return{_bufferIndex:U,_index:$,line:B,column:W,offset:K}}function y(U){a[U.line]=U.column,D()}function k(){let U;for(;r._index<s.length;){const $=s[r._index];if(typeof $=="string")for(U=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===U&&r._bufferIndex<$.length;)A($.charCodeAt(r._bufferIndex));else A($)}}function A(U){p=p(U)}function x(U){Ve(U)?(r.line++,r.column=1,r.offset+=U===-3?2:1,D()):U!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===s[r._index].length&&(r._bufferIndex=-1,r._index++)),d.previous=U}function R(U,$){const B=$||{};return B.type=U,B.start=v(),d.events.push(["enter",B,d]),l.push(B),B}function O(U){const $=l.pop();return $.end=v(),d.events.push(["exit",$,d]),$}function N(U,$){M(U,$.from)}function C(U,$){$.restore()}function _(U,$){return B;function B(W,K,H){let G,z,Y,L;return Array.isArray(W)?j(W):"tokenize"in W?j([W]):V(W);function V(oe){return ae;function ae(ce){const Re=ce!==null&&oe[ce],ie=ce!==null&&oe.null,Te=[...Array.isArray(Re)?Re:Re?[Re]:[],...Array.isArray(ie)?ie:ie?[ie]:[]];return j(Te)(ce)}}function j(oe){return G=oe,z=0,oe.length===0?H:P(oe[z])}function P(oe){return ae;function ae(ce){return L=I(),Y=oe,oe.partial||(d.currentConstruct=oe),oe.name&&d.parser.constructs.disable.null.includes(oe.name)?Q():oe.tokenize.call($?Object.assign(Object.create(d),$):d,u,Z,Q)(ce)}}function Z(oe){return U(Y,L),K}function Q(oe){return L.restore(),++z<G.length?P(G[z]):H}}}function M(U,$){U.resolveAll&&!o.includes(U)&&o.push(U),U.resolve&&or(d.events,$,d.events.length-$,U.resolve(d.events.slice($),d)),U.resolveTo&&(d.events=U.resolveTo(d.events,d))}function I(){const U=v(),$=d.previous,B=d.currentConstruct,W=d.events.length,K=Array.from(l);return{from:W,restore:H};function H(){r=U,d.previous=$,d.currentConstruct=B,d.events.length=W,l=K,D()}}function D(){r.line in a&&r.column<2&&(r.column=a[r.line],r.offset+=a[r.line]-1)}}function Jce(e,t){const n=t.start._index,r=t.start._bufferIndex,a=t.end._index,o=t.end._bufferIndex;let s;if(n===a)s=[e[n].slice(r,o)];else{if(s=e.slice(n,a),r>-1){const l=s[0];typeof l=="string"?s[0]=l.slice(r):s.shift()}o>0&&s.push(e[a].slice(0,o))}return s}function eue(e,t){let n=-1;const r=[];let a;for(;++n<e.length;){const o=e[n];let s;if(typeof o=="string")s=o;else switch(o){case-5:{s="\r";break}case-4:{s=`
`;break}case-3:{s=`\r
`;break}case-2:{s=t?" ":"	";break}case-1:{if(!t&&a)continue;s=" ";break}default:s=String.fromCharCode(o)}a=o===-2,r.push(s)}return r.join("")}function tue(e){const r={constructs:zG([Zce,...(e||{}).extensions||[]]),content:a(mle),defined:[],document:a(yle),flow:a(Pce),lazy:{},string:a(Bce),text:a(jce)};return r;function a(o){return s;function s(l){return Qce(r,o,l)}}}function nue(e){for(;!HG(e););return e}const CI=/[\0\t\n\r]/g;function rue(){let e=1,t="",n=!0,r;return a;function a(o,s,l){const u=[];let d,p,g,m,b;for(o=t+(typeof o=="string"?o.toString():new TextDecoder(s||void 0).decode(o)),g=0,t="",n&&(o.charCodeAt(0)===65279&&g++,n=void 0);g<o.length;){if(CI.lastIndex=g,d=CI.exec(o),m=d&&d.index!==void 0?d.index:o.length,b=o.charCodeAt(m),!d){t=o.slice(g);break}if(b===10&&g===m&&r)u.push(-3),r=void 0;else switch(r&&(u.push(-5),r=void 0),g<m&&(u.push(o.slice(g,m)),e+=m-g),b){case 0:{u.push(65533),e++;break}case 9:{for(p=Math.ceil(e/4)*4,u.push(-2);e++<p;)u.push(-1);break}case 10:{u.push(-4),e=1;break}default:r=!0,e=1}g=m+1}return l&&(r&&u.push(-5),t&&u.push(t),u.push(null)),u}}const aue=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function oue(e){return e.replace(aue,iue)}function iue(e,t,n){if(t)return t;if(n.charCodeAt(0)===35){const a=n.charCodeAt(1),o=a===120||a===88;return BG(n.slice(o?2:1),o?16:10)}return oA(n)||e}const KG={}.hasOwnProperty;function sue(e,t,n){return typeof t!="string"&&(n=t,t=void 0),lue(n)(nue(tue(n).document().write(rue()(e,t,!0))))}function lue(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:o(he),autolinkProtocol:I,autolinkEmail:I,atxHeading:o(be),blockQuote:o(ie),characterEscape:I,characterReference:I,codeFenced:o(Te),codeFencedFenceInfo:s,codeFencedFenceMeta:s,codeIndented:o(Te,s),codeText:o(ne,s),codeTextData:I,data:I,codeFlowValue:I,definition:o(xe),definitionDestinationString:s,definitionLabelString:s,definitionTitleString:s,emphasis:o(Se),hardBreakEscape:o(J),hardBreakTrailing:o(J),htmlFlow:o(pe,s),htmlFlowData:I,htmlText:o(pe,s),htmlTextData:I,image:o(ke),label:s,link:o(he),listItem:o(se),listItemValue:m,listOrdered:o(Ee,g),listUnordered:o(Ee),paragraph:o(Be),reference:P,referenceString:s,resourceDestinationString:s,resourceTitleString:s,setextHeading:o(be),strong:o(je),thematicBreak:o(Oe)},exit:{atxHeading:u(),atxHeadingSequence:N,autolink:u(),autolinkEmail:Re,autolinkProtocol:ce,blockQuote:u(),characterEscapeValue:D,characterReferenceMarkerHexadecimal:Q,characterReferenceMarkerNumeric:Q,characterReferenceValue:oe,characterReference:ae,codeFenced:u(k),codeFencedFence:y,codeFencedFenceInfo:b,codeFencedFenceMeta:v,codeFlowValue:D,codeIndented:u(A),codeText:u(K),codeTextData:D,data:D,definition:u(),definitionDestinationString:O,definitionLabelString:x,definitionTitleString:R,emphasis:u(),hardBreakEscape:u($),hardBreakTrailing:u($),htmlFlow:u(B),htmlFlowData:D,htmlText:u(W),htmlTextData:D,image:u(G),label:Y,labelText:z,lineEnding:U,link:u(H),listItem:u(),listOrdered:u(),listUnordered:u(),paragraph:u(),referenceString:Z,resourceDestinationString:L,resourceTitleString:V,resource:j,setextHeading:u(M),setextHeadingLineSequence:_,setextHeadingText:C,strong:u(),thematicBreak:u()}};XG(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(ee){let de={type:"root",children:[]};const Ne={stack:[de],tokenStack:[],config:t,enter:l,exit:d,buffer:s,resume:p,data:n},Fe=[];let We=-1;for(;++We<ee.length;)if(ee[We][1].type==="listOrdered"||ee[We][1].type==="listUnordered")if(ee[We][0]==="enter")Fe.push(We);else{const St=Fe.pop();We=a(ee,St,We)}for(We=-1;++We<ee.length;){const St=t[ee[We][0]];KG.call(St,ee[We][1].type)&&St[ee[We][1].type].call(Object.assign({sliceSerialize:ee[We][2].sliceSerialize},Ne),ee[We][1])}if(Ne.tokenStack.length>0){const St=Ne.tokenStack[Ne.tokenStack.length-1];(St[1]||_I).call(Ne,void 0,St[0])}for(de.position={start:So(ee.length>0?ee[0][1].start:{line:1,column:1,offset:0}),end:So(ee.length>0?ee[ee.length-2][1].end:{line:1,column:1,offset:0})},We=-1;++We<t.transforms.length;)de=t.transforms[We](de)||de;return de}function a(ee,de,Ne){let Fe=de-1,We=-1,St=!1,Tt,bt,et,At;for(;++Fe<=Ne;){const st=ee[Fe];switch(st[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{st[0]==="enter"?We++:We--,At=void 0;break}case"lineEndingBlank":{st[0]==="enter"&&(Tt&&!At&&!We&&!et&&(et=Fe),At=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:At=void 0}if(!We&&st[0]==="enter"&&st[1].type==="listItemPrefix"||We===-1&&st[0]==="exit"&&(st[1].type==="listUnordered"||st[1].type==="listOrdered")){if(Tt){let wt=Fe;for(bt=void 0;wt--;){const Ht=ee[wt];if(Ht[1].type==="lineEnding"||Ht[1].type==="lineEndingBlank"){if(Ht[0]==="exit")continue;bt&&(ee[bt][1].type="lineEndingBlank",St=!0),Ht[1].type="lineEnding",bt=wt}else if(!(Ht[1].type==="linePrefix"||Ht[1].type==="blockQuotePrefix"||Ht[1].type==="blockQuotePrefixWhitespace"||Ht[1].type==="blockQuoteMarker"||Ht[1].type==="listItemIndent"))break}et&&(!bt||et<bt)&&(Tt._spread=!0),Tt.end=Object.assign({},bt?ee[bt][1].start:st[1].end),ee.splice(bt||Fe,0,["exit",Tt,st[2]]),Fe++,Ne++}if(st[1].type==="listItemPrefix"){const wt={type:"listItem",_spread:!1,start:Object.assign({},st[1].start),end:void 0};Tt=wt,ee.splice(Fe,0,["enter",wt,st[2]]),Fe++,Ne++,et=void 0,At=!0}}}return ee[de][1]._spread=St,Ne}function o(ee,de){return Ne;function Ne(Fe){l.call(this,ee(Fe),Fe),de&&de.call(this,Fe)}}function s(){this.stack.push({type:"fragment",children:[]})}function l(ee,de,Ne){this.stack[this.stack.length-1].children.push(ee),this.stack.push(ee),this.tokenStack.push([de,Ne||void 0]),ee.position={start:So(de.start),end:void 0}}function u(ee){return de;function de(Ne){ee&&ee.call(this,Ne),d.call(this,Ne)}}function d(ee,de){const Ne=this.stack.pop(),Fe=this.tokenStack.pop();if(Fe)Fe[0].type!==ee.type&&(de?de.call(this,ee,Fe[0]):(Fe[1]||_I).call(this,ee,Fe[0]));else throw new Error("Cannot close `"+ee.type+"` ("+bc({start:ee.start,end:ee.end})+"): it’s not open");Ne.position.end=So(ee.end)}function p(){return aA(this.stack.pop())}function g(){this.data.expectingFirstListItemValue=!0}function m(ee){if(this.data.expectingFirstListItemValue){const de=this.stack[this.stack.length-2];de.start=Number.parseInt(this.sliceSerialize(ee),10),this.data.expectingFirstListItemValue=void 0}}function b(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.lang=ee}function v(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.meta=ee}function y(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function k(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.value=ee.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function A(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.value=ee.replace(/(\r?\n|\r)$/g,"")}function x(ee){const de=this.resume(),Ne=this.stack[this.stack.length-1];Ne.label=de,Ne.identifier=Br(this.sliceSerialize(ee)).toLowerCase()}function R(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.title=ee}function O(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.url=ee}function N(ee){const de=this.stack[this.stack.length-1];if(!de.depth){const Ne=this.sliceSerialize(ee).length;de.depth=Ne}}function C(){this.data.setextHeadingSlurpLineEnding=!0}function _(ee){const de=this.stack[this.stack.length-1];de.depth=this.sliceSerialize(ee).codePointAt(0)===61?1:2}function M(){this.data.setextHeadingSlurpLineEnding=void 0}function I(ee){const Ne=this.stack[this.stack.length-1].children;let Fe=Ne[Ne.length-1];(!Fe||Fe.type!=="text")&&(Fe=ye(),Fe.position={start:So(ee.start),end:void 0},Ne.push(Fe)),this.stack.push(Fe)}function D(ee){const de=this.stack.pop();de.value+=this.sliceSerialize(ee),de.position.end=So(ee.end)}function U(ee){const de=this.stack[this.stack.length-1];if(this.data.atHardBreak){const Ne=de.children[de.children.length-1];Ne.position.end=So(ee.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(de.type)&&(I.call(this,ee),D.call(this,ee))}function $(){this.data.atHardBreak=!0}function B(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.value=ee}function W(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.value=ee}function K(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.value=ee}function H(){const ee=this.stack[this.stack.length-1];if(this.data.inReference){const de=this.data.referenceType||"shortcut";ee.type+="Reference",ee.referenceType=de,delete ee.url,delete ee.title}else delete ee.identifier,delete ee.label;this.data.referenceType=void 0}function G(){const ee=this.stack[this.stack.length-1];if(this.data.inReference){const de=this.data.referenceType||"shortcut";ee.type+="Reference",ee.referenceType=de,delete ee.url,delete ee.title}else delete ee.identifier,delete ee.label;this.data.referenceType=void 0}function z(ee){const de=this.sliceSerialize(ee),Ne=this.stack[this.stack.length-2];Ne.label=oue(de),Ne.identifier=Br(de).toLowerCase()}function Y(){const ee=this.stack[this.stack.length-1],de=this.resume(),Ne=this.stack[this.stack.length-1];if(this.data.inReference=!0,Ne.type==="link"){const Fe=ee.children;Ne.children=Fe}else Ne.alt=de}function L(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.url=ee}function V(){const ee=this.resume(),de=this.stack[this.stack.length-1];de.title=ee}function j(){this.data.inReference=void 0}function P(){this.data.referenceType="collapsed"}function Z(ee){const de=this.resume(),Ne=this.stack[this.stack.length-1];Ne.label=de,Ne.identifier=Br(this.sliceSerialize(ee)).toLowerCase(),this.data.referenceType="full"}function Q(ee){this.data.characterReferenceType=ee.type}function oe(ee){const de=this.sliceSerialize(ee),Ne=this.data.characterReferenceType;let Fe;Ne?(Fe=BG(de,Ne==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):Fe=oA(de);const We=this.stack[this.stack.length-1];We.value+=Fe}function ae(ee){const de=this.stack.pop();de.position.end=So(ee.end)}function ce(ee){D.call(this,ee);const de=this.stack[this.stack.length-1];de.url=this.sliceSerialize(ee)}function Re(ee){D.call(this,ee);const de=this.stack[this.stack.length-1];de.url="mailto:"+this.sliceSerialize(ee)}function ie(){return{type:"blockquote",children:[]}}function Te(){return{type:"code",lang:null,meta:null,value:""}}function ne(){return{type:"inlineCode",value:""}}function xe(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function Se(){return{type:"emphasis",children:[]}}function be(){return{type:"heading",depth:0,children:[]}}function J(){return{type:"break"}}function pe(){return{type:"html",value:""}}function ke(){return{type:"image",title:null,url:"",alt:null}}function he(){return{type:"link",title:null,url:"",children:[]}}function Ee(ee){return{type:"list",ordered:ee.type==="listOrdered",start:null,spread:ee._spread,children:[]}}function se(ee){return{type:"listItem",spread:ee._spread,checked:null,children:[]}}function Be(){return{type:"paragraph",children:[]}}function je(){return{type:"strong",children:[]}}function ye(){return{type:"text",value:""}}function Oe(){return{type:"thematicBreak"}}}function So(e){return{line:e.line,column:e.column,offset:e.offset}}function XG(e,t){let n=-1;for(;++n<t.length;){const r=t[n];Array.isArray(r)?XG(e,r):cue(e,r)}}function cue(e,t){let n;for(n in t)if(KG.call(t,n))switch(n){case"canContainEols":{const r=t[n];r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r);break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}function _I(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+bc({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+bc({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+bc({start:t.start,end:t.end})+") is still open")}function uue(e){const t=this;t.parser=n;function n(r){return sue(r,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function due(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function fue(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function pue(e,t){const n=t.value?t.value+`
`:"",r={};t.lang&&(r.className=["language-"+t.lang]);let a={type:"element",tagName:"code",properties:r,children:[{type:"text",value:n}]};return t.meta&&(a.data={meta:t.meta}),e.patch(t,a),a=e.applyData(t,a),a={type:"element",tagName:"pre",properties:{},children:[a]},e.patch(t,a),a}function gue(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function hue(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function mue(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),a=rl(r.toLowerCase()),o=e.footnoteOrder.indexOf(r);let s,l=e.footnoteCounts.get(r);l===void 0?(l=0,e.footnoteOrder.push(r),s=e.footnoteOrder.length):s=o+1,l+=1,e.footnoteCounts.set(r,l);const u={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+a,id:n+"fnref-"+a+(l>1?"-"+l:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(s)}]};e.patch(t,u);const d={type:"element",tagName:"sup",properties:{},children:[u]};return e.patch(t,d),e.applyData(t,d)}function bue(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function yue(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function ZG(e,t){const n=t.referenceType;let r="]";if(n==="collapsed"?r+="[]":n==="full"&&(r+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+r}];const a=e.all(t),o=a[0];o&&o.type==="text"?o.value="["+o.value:a.unshift({type:"text",value:"["});const s=a[a.length-1];return s&&s.type==="text"?s.value+=r:a.push({type:"text",value:r}),a}function vue(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return ZG(e,t);const a={src:rl(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(a.title=r.title);const o={type:"element",tagName:"img",properties:a,children:[]};return e.patch(t,o),e.applyData(t,o)}function Sue(e,t){const n={src:rl(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)}function Eue(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)}function wue(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return ZG(e,t);const a={href:rl(r.url||"")};r.title!==null&&r.title!==void 0&&(a.title=r.title);const o={type:"element",tagName:"a",properties:a,children:e.all(t)};return e.patch(t,o),e.applyData(t,o)}function xue(e,t){const n={href:rl(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function kue(e,t,n){const r=e.all(t),a=n?Tue(n):QG(t),o={},s=[];if(typeof t.checked=="boolean"){const p=r[0];let g;p&&p.type==="element"&&p.tagName==="p"?g=p:(g={type:"element",tagName:"p",properties:{},children:[]},r.unshift(g)),g.children.length>0&&g.children.unshift({type:"text",value:" "}),g.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),o.className=["task-list-item"]}let l=-1;for(;++l<r.length;){const p=r[l];(a||l!==0||p.type!=="element"||p.tagName!=="p")&&s.push({type:"text",value:`
`}),p.type==="element"&&p.tagName==="p"&&!a?s.push(...p.children):s.push(p)}const u=r[r.length-1];u&&(a||u.type!=="element"||u.tagName!=="p")&&s.push({type:"text",value:`
`});const d={type:"element",tagName:"li",properties:o,children:s};return e.patch(t,d),e.applyData(t,d)}function Tue(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let r=-1;for(;!t&&++r<n.length;)t=QG(n[r])}return t}function QG(e){const t=e.spread;return t??e.children.length>1}function Aue(e,t){const n={},r=e.all(t);let a=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++a<r.length;){const s=r[a];if(s.type==="element"&&s.tagName==="li"&&s.properties&&Array.isArray(s.properties.className)&&s.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const o={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)};return e.patch(t,o),e.applyData(t,o)}function Rue(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Cue(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function _ue(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Nue(e,t){const n=e.all(t),r=n.shift(),a=[];if(r){const s={type:"element",tagName:"thead",properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],s),a.push(s)}if(n.length>0){const s={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},l=eA(t.children[1]),u=NG(t.children[t.children.length-1]);l&&u&&(s.position={start:l,end:u}),a.push(s)}const o={type:"element",tagName:"table",properties:{},children:e.wrap(a,!0)};return e.patch(t,o),e.applyData(t,o)}function Oue(e,t,n){const r=n?n.children:void 0,o=(r?r.indexOf(t):1)===0?"th":"td",s=n&&n.type==="table"?n.align:void 0,l=s?s.length:t.children.length;let u=-1;const d=[];for(;++u<l;){const g=t.children[u],m={},b=s?s[u]:void 0;b&&(m.align=b);let v={type:"element",tagName:o,properties:m,children:[]};g&&(v.children=e.all(g),e.patch(g,v),v=e.applyData(g,v)),d.push(v)}const p={type:"element",tagName:"tr",properties:{},children:e.wrap(d,!0)};return e.patch(t,p),e.applyData(t,p)}function Iue(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const NI=9,OI=32;function Due(e){const t=String(e),n=/\r?\n|\r/g;let r=n.exec(t),a=0;const o=[];for(;r;)o.push(II(t.slice(a,r.index),a>0,!0),r[0]),a=r.index+r[0].length,r=n.exec(t);return o.push(II(t.slice(a),a>0,!1)),o.join("")}function II(e,t,n){let r=0,a=e.length;if(t){let o=e.codePointAt(r);for(;o===NI||o===OI;)r++,o=e.codePointAt(r)}if(n){let o=e.codePointAt(a-1);for(;o===NI||o===OI;)a--,o=e.codePointAt(a-1)}return a>r?e.slice(r,a):""}function Lue(e,t){const n={type:"text",value:Due(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function Mue(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const Pue={blockquote:due,break:fue,code:pue,delete:gue,emphasis:hue,footnoteReference:mue,heading:bue,html:yue,imageReference:vue,image:Sue,inlineCode:Eue,linkReference:wue,link:xue,listItem:kue,list:Aue,paragraph:Rue,root:Cue,strong:_ue,table:Nue,tableCell:Iue,tableRow:Oue,text:Lue,thematicBreak:Mue,toml:Ud,yaml:Ud,definition:Ud,footnoteDefinition:Ud};function Ud(){}const JG=-1,Mp=0,vc=1,zf=2,sA=3,lA=4,cA=5,uA=6,eH=7,tH=8,DI=typeof self=="object"?self:globalThis,Fue=(e,t)=>{const n=(a,o)=>(e.set(o,a),a),r=a=>{if(e.has(a))return e.get(a);const[o,s]=t[a];switch(o){case Mp:case JG:return n(s,a);case vc:{const l=n([],a);for(const u of s)l.push(r(u));return l}case zf:{const l=n({},a);for(const[u,d]of s)l[r(u)]=r(d);return l}case sA:return n(new Date(s),a);case lA:{const{source:l,flags:u}=s;return n(new RegExp(l,u),a)}case cA:{const l=n(new Map,a);for(const[u,d]of s)l.set(r(u),r(d));return l}case uA:{const l=n(new Set,a);for(const u of s)l.add(r(u));return l}case eH:{const{name:l,message:u}=s;return n(new DI[l](u),a)}case tH:return n(BigInt(s),a);case"BigInt":return n(Object(BigInt(s)),a);case"ArrayBuffer":return n(new Uint8Array(s).buffer,s);case"DataView":{const{buffer:l}=new Uint8Array(s);return n(new DataView(l),s)}}return n(new DI[o](s),a)};return r},LI=e=>Fue(new Map,e)(0),bs="",{toString:zue}={},{keys:Bue}=Object,dc=e=>{const t=typeof e;if(t!=="object"||!e)return[Mp,t];const n=zue.call(e).slice(8,-1);switch(n){case"Array":return[vc,bs];case"Object":return[zf,bs];case"Date":return[sA,bs];case"RegExp":return[lA,bs];case"Map":return[cA,bs];case"Set":return[uA,bs];case"DataView":return[vc,n]}return n.includes("Array")?[vc,n]:n.includes("Error")?[eH,n]:[zf,n]},Gd=([e,t])=>e===Mp&&(t==="function"||t==="symbol"),jue=(e,t,n,r)=>{const a=(s,l)=>{const u=r.push(s)-1;return n.set(l,u),u},o=s=>{if(n.has(s))return n.get(s);let[l,u]=dc(s);switch(l){case Mp:{let p=s;switch(u){case"bigint":l=tH,p=s.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+u);p=null;break;case"undefined":return a([JG],s)}return a([l,p],s)}case vc:{if(u){let m=s;return u==="DataView"?m=new Uint8Array(s.buffer):u==="ArrayBuffer"&&(m=new Uint8Array(s)),a([u,[...m]],s)}const p=[],g=a([l,p],s);for(const m of s)p.push(o(m));return g}case zf:{if(u)switch(u){case"BigInt":return a([u,s.toString()],s);case"Boolean":case"Number":case"String":return a([u,s.valueOf()],s)}if(t&&"toJSON"in s)return o(s.toJSON());const p=[],g=a([l,p],s);for(const m of Bue(s))(e||!Gd(dc(s[m])))&&p.push([o(m),o(s[m])]);return g}case sA:return a([l,s.toISOString()],s);case lA:{const{source:p,flags:g}=s;return a([l,{source:p,flags:g}],s)}case cA:{const p=[],g=a([l,p],s);for(const[m,b]of s)(e||!(Gd(dc(m))||Gd(dc(b))))&&p.push([o(m),o(b)]);return g}case uA:{const p=[],g=a([l,p],s);for(const m of s)(e||!Gd(dc(m)))&&p.push(o(m));return g}}const{message:d}=s;return a([l,{name:u,message:d}],s)};return o},MI=(e,{json:t,lossy:n}={})=>{const r=[];return jue(!(t||n),!!t,new Map,r)(e),r},Bf=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?LI(MI(e,t)):structuredClone(e):(e,t)=>LI(MI(e,t));function Uue(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function Gue(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function Hue(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||Uue,r=e.options.footnoteBackLabel||Gue,a=e.options.footnoteLabel||"Footnotes",o=e.options.footnoteLabelTagName||"h2",s=e.options.footnoteLabelProperties||{className:["sr-only"]},l=[];let u=-1;for(;++u<e.footnoteOrder.length;){const d=e.footnoteById.get(e.footnoteOrder[u]);if(!d)continue;const p=e.all(d),g=String(d.identifier).toUpperCase(),m=rl(g.toLowerCase());let b=0;const v=[],y=e.footnoteCounts.get(g);for(;y!==void 0&&++b<=y;){v.length>0&&v.push({type:"text",value:" "});let x=typeof n=="string"?n:n(u,b);typeof x=="string"&&(x={type:"text",value:x}),v.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+m+(b>1?"-"+b:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(u,b),className:["data-footnote-backref"]},children:Array.isArray(x)?x:[x]})}const k=p[p.length-1];if(k&&k.type==="element"&&k.tagName==="p"){const x=k.children[k.children.length-1];x&&x.type==="text"?x.value+=" ":k.children.push({type:"text",value:" "}),k.children.push(...v)}else p.push(...v);const A={type:"element",tagName:"li",properties:{id:t+"fn-"+m},children:e.wrap(p,!0)};e.patch(d,A),l.push(A)}if(l.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:o,properties:{...Bf(s),id:"footnote-label"},children:[{type:"text",value:a}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(l,!0)},{type:"text",value:`
`}]}}const Pp=function(e){if(e==null)return Wue;if(typeof e=="function")return Fp(e);if(typeof e=="object")return Array.isArray(e)?$ue(e):que(e);if(typeof e=="string")return Vue(e);throw new Error("Expected function, string, or object as test")};function $ue(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=Pp(e[n]);return Fp(r);function r(...a){let o=-1;for(;++o<t.length;)if(t[o].apply(this,a))return!0;return!1}}function que(e){const t=e;return Fp(n);function n(r){const a=r;let o;for(o in e)if(a[o]!==t[o])return!1;return!0}}function Vue(e){return Fp(t);function t(n){return n&&n.type===e}}function Fp(e){return t;function t(n,r,a){return!!(Yue(n)&&e.call(this,n,typeof r=="number"?r:void 0,a||void 0))}}function Wue(){return!0}function Yue(e){return e!==null&&typeof e=="object"&&"type"in e}const nH=[],Kue=!0,Ek=!1,Xue="skip";function rH(e,t,n,r){let a;typeof t=="function"&&typeof n!="function"?(r=n,n=t):a=t;const o=Pp(a),s=r?-1:1;l(e,void 0,[])();function l(u,d,p){const g=u&&typeof u=="object"?u:{};if(typeof g.type=="string"){const b=typeof g.tagName=="string"?g.tagName:typeof g.name=="string"?g.name:void 0;Object.defineProperty(m,"name",{value:"node ("+(u.type+(b?"<"+b+">":""))+")"})}return m;function m(){let b=nH,v,y,k;if((!t||o(u,d,p[p.length-1]||void 0))&&(b=Zue(n(u,p)),b[0]===Ek))return b;if("children"in u&&u.children){const A=u;if(A.children&&b[0]!==Xue)for(y=(r?A.children.length:-1)+s,k=p.concat(A);y>-1&&y<A.children.length;){const x=A.children[y];if(v=l(x,y,k)(),v[0]===Ek)return v;y=typeof v[1]=="number"?v[1]:y+s}}return b}}}function Zue(e){return Array.isArray(e)?e:typeof e=="number"?[Kue,e]:e==null?nH:[e]}function dA(e,t,n,r){let a,o,s;typeof t=="function"?(o=void 0,s=t,a=n):(o=t,s=n,a=r),rH(e,o,l,a);function l(u,d){const p=d[d.length-1],g=p?p.children.indexOf(u):void 0;return s(u,g,p)}}const wk={}.hasOwnProperty,Que={};function Jue(e,t){const n=t||Que,r=new Map,a=new Map,o=new Map,s={...Pue,...n.handlers},l={all:d,applyData:tde,definitionById:r,footnoteById:a,footnoteCounts:o,footnoteOrder:[],handlers:s,one:u,options:n,patch:ede,wrap:rde};return dA(e,function(p){if(p.type==="definition"||p.type==="footnoteDefinition"){const g=p.type==="definition"?r:a,m=String(p.identifier).toUpperCase();g.has(m)||g.set(m,p)}}),l;function u(p,g){const m=p.type,b=l.handlers[m];if(wk.call(l.handlers,m)&&b)return b(l,p,g);if(l.options.passThrough&&l.options.passThrough.includes(m)){if("children"in p){const{children:y,...k}=p,A=Bf(k);return A.children=l.all(p),A}return Bf(p)}return(l.options.unknownHandler||nde)(l,p,g)}function d(p){const g=[];if("children"in p){const m=p.children;let b=-1;for(;++b<m.length;){const v=l.one(m[b],p);if(v){if(b&&m[b-1].type==="break"&&(!Array.isArray(v)&&v.type==="text"&&(v.value=PI(v.value)),!Array.isArray(v)&&v.type==="element")){const y=v.children[0];y&&y.type==="text"&&(y.value=PI(y.value))}Array.isArray(v)?g.push(...v):g.push(v)}}}return g}}function ede(e,t){e.position&&(t.position=Use(e))}function tde(e,t){let n=t;if(e&&e.data){const r=e.data.hName,a=e.data.hChildren,o=e.data.hProperties;if(typeof r=="string")if(n.type==="element")n.tagName=r;else{const s="children"in n?n.children:[n];n={type:"element",tagName:r,properties:{},children:s}}n.type==="element"&&o&&Object.assign(n.properties,Bf(o)),"children"in n&&n.children&&a!==null&&a!==void 0&&(n.children=a)}return n}function nde(e,t){const n=t.data||{},r="value"in t&&!(wk.call(n,"hProperties")||wk.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function rde(e,t){const n=[];let r=-1;for(t&&n.push({type:"text",value:`
`});++r<e.length;)r&&n.push({type:"text",value:`
`}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function PI(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function FI(e,t){const n=Jue(e,t),r=n.one(e,void 0),a=Hue(n),o=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return a&&o.children.push({type:"text",value:`
`},a),o}function ade(e,t){return e&&"run"in e?async function(n,r){const a=FI(n,{file:r,...t});await e.run(a,r)}:function(n,r){return FI(n,{file:r,...e||t})}}function zI(e){if(e)throw e}var Eb,BI;function ode(){if(BI)return Eb;BI=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,a=function(d){return typeof Array.isArray=="function"?Array.isArray(d):t.call(d)==="[object Array]"},o=function(d){if(!d||t.call(d)!=="[object Object]")return!1;var p=e.call(d,"constructor"),g=d.constructor&&d.constructor.prototype&&e.call(d.constructor.prototype,"isPrototypeOf");if(d.constructor&&!p&&!g)return!1;var m;for(m in d);return typeof m>"u"||e.call(d,m)},s=function(d,p){n&&p.name==="__proto__"?n(d,p.name,{enumerable:!0,configurable:!0,value:p.newValue,writable:!0}):d[p.name]=p.newValue},l=function(d,p){if(p==="__proto__")if(e.call(d,p)){if(r)return r(d,p).value}else return;return d[p]};return Eb=function u(){var d,p,g,m,b,v,y=arguments[0],k=1,A=arguments.length,x=!1;for(typeof y=="boolean"&&(x=y,y=arguments[1]||{},k=2),(y==null||typeof y!="object"&&typeof y!="function")&&(y={});k<A;++k)if(d=arguments[k],d!=null)for(p in d)g=l(y,p),m=l(d,p),y!==m&&(x&&m&&(o(m)||(b=a(m)))?(b?(b=!1,v=g&&a(g)?g:[]):v=g&&o(g)?g:{},s(y,{name:p,newValue:u(x,v,m)})):typeof m<"u"&&s(y,{name:p,newValue:m}));return y},Eb}var ide=ode();const wb=un(ide);function xk(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function sde(){const e=[],t={run:n,use:r};return t;function n(...a){let o=-1;const s=a.pop();if(typeof s!="function")throw new TypeError("Expected function as last argument, not "+s);l(null,...a);function l(u,...d){const p=e[++o];let g=-1;if(u){s(u);return}for(;++g<a.length;)(d[g]===null||d[g]===void 0)&&(d[g]=a[g]);a=d,p?lde(p,l)(...d):s(null,...d)}}function r(a){if(typeof a!="function")throw new TypeError("Expected `middelware` to be a function, not "+a);return e.push(a),t}}function lde(e,t){let n;return r;function r(...s){const l=e.length>s.length;let u;l&&s.push(a);try{u=e.apply(this,s)}catch(d){const p=d;if(l&&n)throw p;return a(p)}l||(u&&u.then&&typeof u.then=="function"?u.then(o,a):u instanceof Error?a(u):o(u))}function a(s,...l){n||(n=!0,t(s,...l))}function o(s){a(null,s)}}const ta={basename:cde,dirname:ude,extname:dde,join:fde,sep:"/"};function cde(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');lu(e);let n=0,r=-1,a=e.length,o;if(t===void 0||t.length===0||t.length>e.length){for(;a--;)if(e.codePointAt(a)===47){if(o){n=a+1;break}}else r<0&&(o=!0,r=a+1);return r<0?"":e.slice(n,r)}if(t===e)return"";let s=-1,l=t.length-1;for(;a--;)if(e.codePointAt(a)===47){if(o){n=a+1;break}}else s<0&&(o=!0,s=a+1),l>-1&&(e.codePointAt(a)===t.codePointAt(l--)?l<0&&(r=a):(l=-1,r=s));return n===r?r=s:r<0&&(r=e.length),e.slice(n,r)}function ude(e){if(lu(e),e.length===0)return".";let t=-1,n=e.length,r;for(;--n;)if(e.codePointAt(n)===47){if(r){t=n;break}}else r||(r=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function dde(e){lu(e);let t=e.length,n=-1,r=0,a=-1,o=0,s;for(;t--;){const l=e.codePointAt(t);if(l===47){if(s){r=t+1;break}continue}n<0&&(s=!0,n=t+1),l===46?a<0?a=t:o!==1&&(o=1):a>-1&&(o=-1)}return a<0||n<0||o===0||o===1&&a===n-1&&a===r+1?"":e.slice(a,n)}function fde(...e){let t=-1,n;for(;++t<e.length;)lu(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":pde(n)}function pde(e){lu(e);const t=e.codePointAt(0)===47;let n=gde(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function gde(e,t){let n="",r=0,a=-1,o=0,s=-1,l,u;for(;++s<=e.length;){if(s<e.length)l=e.codePointAt(s);else{if(l===47)break;l=47}if(l===47){if(!(a===s-1||o===1))if(a!==s-1&&o===2){if(n.length<2||r!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(u=n.lastIndexOf("/"),u!==n.length-1){u<0?(n="",r=0):(n=n.slice(0,u),r=n.length-1-n.lastIndexOf("/")),a=s,o=0;continue}}else if(n.length>0){n="",r=0,a=s,o=0;continue}}t&&(n=n.length>0?n+"/..":"..",r=2)}else n.length>0?n+="/"+e.slice(a+1,s):n=e.slice(a+1,s),r=s-a-1;a=s,o=0}else l===46&&o>-1?o++:o=-1}return n}function lu(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const hde={cwd:mde};function mde(){return"/"}function kk(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function bde(e){if(typeof e=="string")e=new URL(e);else if(!kk(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return yde(e)}function yde(e){if(e.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const r=t.codePointAt(n+2);if(r===70||r===102){const a=new TypeError("File URL path must not include encoded / characters");throw a.code="ERR_INVALID_FILE_URL_PATH",a}}return decodeURIComponent(t)}const xb=["history","path","basename","stem","extname","dirname"];class aH{constructor(t){let n;t?kk(t)?n={path:t}:typeof t=="string"||vde(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":hde.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<xb.length;){const o=xb[r];o in n&&n[o]!==void 0&&n[o]!==null&&(this[o]=o==="history"?[...n[o]]:n[o])}let a;for(a in n)xb.includes(a)||(this[a]=n[a])}get basename(){return typeof this.path=="string"?ta.basename(this.path):void 0}set basename(t){Tb(t,"basename"),kb(t,"basename"),this.path=ta.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?ta.dirname(this.path):void 0}set dirname(t){jI(this.basename,"dirname"),this.path=ta.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?ta.extname(this.path):void 0}set extname(t){if(kb(t,"extname"),jI(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=ta.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){kk(t)&&(t=bde(t)),Tb(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?ta.basename(this.path,this.extname):void 0}set stem(t){Tb(t,"stem"),kb(t,"stem"),this.path=ta.join(this.dirname||"",t+(this.extname||""))}fail(t,n,r){const a=this.message(t,n,r);throw a.fatal=!0,a}info(t,n,r){const a=this.message(t,n,r);return a.fatal=void 0,a}message(t,n,r){const a=new Cn(t,n,r);return this.path&&(a.name=this.path+":"+a.name,a.file=this.path),a.fatal=!1,this.messages.push(a),a}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function kb(e,t){if(e&&e.includes(ta.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+ta.sep+"`")}function Tb(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function jI(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function vde(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const Sde=function(e){const r=this.constructor.prototype,a=r[e],o=function(){return a.apply(o,arguments)};return Object.setPrototypeOf(o,r),o},Ede={}.hasOwnProperty;class fA extends Sde{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=sde()}copy(){const t=new fA;let n=-1;for(;++n<this.attachers.length;){const r=this.attachers[n];t.use(...r)}return t.data(wb(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(Cb("data",this.frozen),this.namespace[t]=n,this):Ede.call(this.namespace,t)&&this.namespace[t]||void 0:t?(Cb("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const a=n.call(t,...r);typeof a=="function"&&this.transformers.use(a)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=Hd(t),r=this.parser||this.Parser;return Ab("parse",r),r(String(n),n)}process(t,n){const r=this;return this.freeze(),Ab("process",this.parser||this.Parser),Rb("process",this.compiler||this.Compiler),n?a(void 0,n):new Promise(a);function a(o,s){const l=Hd(t),u=r.parse(l);r.run(u,l,function(p,g,m){if(p||!g||!m)return d(p);const b=g,v=r.stringify(b,m);kde(v)?m.value=v:m.result=v,d(p,m)});function d(p,g){p||!g?s(p):o?o(g):n(void 0,g)}}}processSync(t){let n=!1,r;return this.freeze(),Ab("processSync",this.parser||this.Parser),Rb("processSync",this.compiler||this.Compiler),this.process(t,a),GI("processSync","process",n),r;function a(o,s){n=!0,zI(o),r=s}}run(t,n,r){UI(t),this.freeze();const a=this.transformers;return!r&&typeof n=="function"&&(r=n,n=void 0),r?o(void 0,r):new Promise(o);function o(s,l){const u=Hd(n);a.run(t,u,d);function d(p,g,m){const b=g||t;p?l(p):s?s(b):r(void 0,b,m)}}}runSync(t,n){let r=!1,a;return this.run(t,n,o),GI("runSync","run",r),a;function o(s,l){zI(s),a=l,r=!0}}stringify(t,n){this.freeze();const r=Hd(n),a=this.compiler||this.Compiler;return Rb("stringify",a),UI(t),a(t,r)}use(t,...n){const r=this.attachers,a=this.namespace;if(Cb("use",this.frozen),t!=null)if(typeof t=="function")u(t,n);else if(typeof t=="object")Array.isArray(t)?l(t):s(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function o(d){if(typeof d=="function")u(d,[]);else if(typeof d=="object")if(Array.isArray(d)){const[p,...g]=d;u(p,g)}else s(d);else throw new TypeError("Expected usable value, not `"+d+"`")}function s(d){if(!("plugins"in d)&&!("settings"in d))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");l(d.plugins),d.settings&&(a.settings=wb(!0,a.settings,d.settings))}function l(d){let p=-1;if(d!=null)if(Array.isArray(d))for(;++p<d.length;){const g=d[p];o(g)}else throw new TypeError("Expected a list of plugins, not `"+d+"`")}function u(d,p){let g=-1,m=-1;for(;++g<r.length;)if(r[g][0]===d){m=g;break}if(m===-1)r.push([d,...p]);else if(p.length>0){let[b,...v]=p;const y=r[m][1];xk(y)&&xk(b)&&(b=wb(!0,y,b)),r[m]=[d,b,...v]}}}}const wde=new fA().freeze();function Ab(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function Rb(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function Cb(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function UI(e){if(!xk(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function GI(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function Hd(e){return xde(e)?e:new aH(e)}function xde(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function kde(e){return typeof e=="string"||Tde(e)}function Tde(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const Ade="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",HI=[],$I={allowDangerousHtml:!0},Rde=/^(https?|ircs?|mailto|xmpp)$/i,Cde=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function _de(e){const t=Nde(e),n=Ode(e);return Ide(t.runSync(t.parse(n),n),e)}function Nde(e){const t=e.rehypePlugins||HI,n=e.remarkPlugins||HI,r=e.remarkRehypeOptions?{...e.remarkRehypeOptions,...$I}:$I;return wde().use(uue).use(n).use(ade,r).use(t)}function Ode(e){const t=e.children||"",n=new aH;return typeof t=="string"&&(n.value=t),n}function Ide(e,t){const n=t.allowedElements,r=t.allowElement,a=t.components,o=t.disallowedElements,s=t.skipHtml,l=t.unwrapDisallowed,u=t.urlTransform||Dde;for(const p of Cde)Object.hasOwn(t,p.from)&&(""+p.from+(p.to?"use `"+p.to+"` instead":"remove it")+Ade+p.id,void 0);return t.className&&(e={type:"element",tagName:"div",properties:{className:t.className},children:e.type==="root"?e.children:[e]}),dA(e,d),DG(e,{Fragment:E.Fragment,components:a,ignoreInvalidStyle:!0,jsx:E.jsx,jsxs:E.jsxs,passKeys:!0,passNode:!0});function d(p,g,m){if(p.type==="raw"&&m&&typeof g=="number")return s?m.children.splice(g,1):m.children[g]={type:"text",value:p.value},g;if(p.type==="element"){let b;for(b in yb)if(Object.hasOwn(yb,b)&&Object.hasOwn(p.properties,b)){const v=p.properties[b],y=yb[b];(y===null||y.includes(p.tagName))&&(p.properties[b]=u(String(v||""),b,p))}}if(p.type==="element"){let b=n?!n.includes(p.tagName):o?o.includes(p.tagName):!1;if(!b&&r&&typeof g=="number"&&(b=!r(p,g,m)),b&&m&&typeof g=="number")return l&&p.children?m.children.splice(g,1,...p.children):m.children.splice(g,1),g}}}function Dde(e){const t=e.indexOf(":"),n=e.indexOf("?"),r=e.indexOf("#"),a=e.indexOf("/");return t===-1||a!==-1&&t>a||n!==-1&&t>n||r!==-1&&t>r||Rde.test(e.slice(0,t))?e:""}function qI(e,t){const n=String(e);if(typeof t!="string")throw new TypeError("Expected character");let r=0,a=n.indexOf(t);for(;a!==-1;)r++,a=n.indexOf(t,a+t.length);return r}function Lde(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function Mde(e,t,n){const a=Pp((n||{}).ignore||[]),o=Pde(t);let s=-1;for(;++s<o.length;)rH(e,"text",l);function l(d,p){let g=-1,m;for(;++g<p.length;){const b=p[g],v=m?m.children:void 0;if(a(b,v?v.indexOf(b):void 0,m))return;m=b}if(m)return u(d,p)}function u(d,p){const g=p[p.length-1],m=o[s][0],b=o[s][1];let v=0;const k=g.children.indexOf(d);let A=!1,x=[];m.lastIndex=0;let R=m.exec(d.value);for(;R;){const O=R.index,N={index:R.index,input:R.input,stack:[...p,d]};let C=b(...R,N);if(typeof C=="string"&&(C=C.length>0?{type:"text",value:C}:void 0),C===!1?m.lastIndex=O+1:(v!==O&&x.push({type:"text",value:d.value.slice(v,O)}),Array.isArray(C)?x.push(...C):C&&x.push(C),v=O+R[0].length,A=!0),!m.global)break;R=m.exec(d.value)}return A?(v<d.value.length&&x.push({type:"text",value:d.value.slice(v)}),g.children.splice(k,1,...x)):x=[d],k+x.length}}function Pde(e){const t=[];if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples");const n=!e[0]||Array.isArray(e[0])?e:[e];let r=-1;for(;++r<n.length;){const a=n[r];t.push([Fde(a[0]),zde(a[1])])}return t}function Fde(e){return typeof e=="string"?new RegExp(Lde(e),"g"):e}function zde(e){return typeof e=="function"?e:function(){return e}}const _b="phrasing",Nb=["autolink","link","image","label"];function Bde(){return{transforms:[Vde],enter:{literalAutolink:Ude,literalAutolinkEmail:Ob,literalAutolinkHttp:Ob,literalAutolinkWww:Ob},exit:{literalAutolink:qde,literalAutolinkEmail:$de,literalAutolinkHttp:Gde,literalAutolinkWww:Hde}}}function jde(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:_b,notInConstruct:Nb},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:_b,notInConstruct:Nb},{character:":",before:"[ps]",after:"\\/",inConstruct:_b,notInConstruct:Nb}]}}function Ude(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function Ob(e){this.config.enter.autolinkProtocol.call(this,e)}function Gde(e){this.config.exit.autolinkProtocol.call(this,e)}function Hde(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.type,t.url="http://"+this.sliceSerialize(e)}function $de(e){this.config.exit.autolinkEmail.call(this,e)}function qde(e){this.exit(e)}function Vde(e){Mde(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,Wde],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),Yde]],{ignore:["link","linkReference"]})}function Wde(e,t,n,r,a){let o="";if(!oH(a)||(/^w/i.test(t)&&(n=t+n,t="",o="http://"),!Kde(n)))return!1;const s=Xde(n+r);if(!s[0])return!1;const l={type:"link",title:null,url:o+t+s[0],children:[{type:"text",value:t+s[0]}]};return s[1]?[l,{type:"text",value:s[1]}]:l}function Yde(e,t,n,r){return!oH(r,!0)||/[-\d_]$/.test(n)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",value:t+"@"+n}]}}function Kde(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function Xde(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],r=n.indexOf(")");const a=qI(e,"(");let o=qI(e,")");for(;r!==-1&&a>o;)e+=n.slice(0,r+1),n=n.slice(r+1),r=n.indexOf(")"),o++;return[e,n]}function oH(e,t){const n=e.input.charCodeAt(e.index-1);return(e.index===0||wi(n)||Dp(n))&&(!t||n!==47)}iH.peek=ofe;function Zde(){this.buffer()}function Qde(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function Jde(){this.buffer()}function efe(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function tfe(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Br(this.sliceSerialize(e)).toLowerCase(),n.label=t}function nfe(e){this.exit(e)}function rfe(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Br(this.sliceSerialize(e)).toLowerCase(),n.label=t}function afe(e){this.exit(e)}function ofe(){return"["}function iH(e,t,n,r){const a=n.createTracker(r);let o=a.move("[^");const s=n.enter("footnoteReference"),l=n.enter("reference");return o+=a.move(n.safe(n.associationId(e),{after:"]",before:o})),l(),s(),o+=a.move("]"),o}function ife(){return{enter:{gfmFootnoteCallString:Zde,gfmFootnoteCall:Qde,gfmFootnoteDefinitionLabelString:Jde,gfmFootnoteDefinition:efe},exit:{gfmFootnoteCallString:tfe,gfmFootnoteCall:nfe,gfmFootnoteDefinitionLabelString:rfe,gfmFootnoteDefinition:afe}}}function sfe(e){let t=!1;return e&&e.firstLineBlank&&(t=!0),{handlers:{footnoteDefinition:n,footnoteReference:iH},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function n(r,a,o,s){const l=o.createTracker(s);let u=l.move("[^");const d=o.enter("footnoteDefinition"),p=o.enter("label");return u+=l.move(o.safe(o.associationId(r),{before:u,after:"]"})),p(),u+=l.move("]:"),r.children&&r.children.length>0&&(l.shift(4),u+=l.move((t?`
`:" ")+o.indentLines(o.containerFlow(r,l.current()),t?sH:lfe))),d(),u}}function lfe(e,t,n){return t===0?e:sH(e,t,n)}function sH(e,t,n){return(n?"":"    ")+e}const cfe=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];lH.peek=gfe;function ufe(){return{canContainEols:["delete"],enter:{strikethrough:ffe},exit:{strikethrough:pfe}}}function dfe(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:cfe}],handlers:{delete:lH}}}function ffe(e){this.enter({type:"delete",children:[]},e)}function pfe(e){this.exit(e)}function lH(e,t,n,r){const a=n.createTracker(r),o=n.enter("strikethrough");let s=a.move("~~");return s+=n.containerPhrasing(e,{...a.current(),before:s,after:"~"}),s+=a.move("~~"),o(),s}function gfe(){return"~"}function hfe(e){return e.length}function mfe(e,t){const n=t||{},r=(n.align||[]).concat(),a=n.stringLength||hfe,o=[],s=[],l=[],u=[];let d=0,p=-1;for(;++p<e.length;){const y=[],k=[];let A=-1;for(e[p].length>d&&(d=e[p].length);++A<e[p].length;){const x=bfe(e[p][A]);if(n.alignDelimiters!==!1){const R=a(x);k[A]=R,(u[A]===void 0||R>u[A])&&(u[A]=R)}y.push(x)}s[p]=y,l[p]=k}let g=-1;if(typeof r=="object"&&"length"in r)for(;++g<d;)o[g]=VI(r[g]);else{const y=VI(r);for(;++g<d;)o[g]=y}g=-1;const m=[],b=[];for(;++g<d;){const y=o[g];let k="",A="";y===99?(k=":",A=":"):y===108?k=":":y===114&&(A=":");let x=n.alignDelimiters===!1?1:Math.max(1,u[g]-k.length-A.length);const R=k+"-".repeat(x)+A;n.alignDelimiters!==!1&&(x=k.length+x+A.length,x>u[g]&&(u[g]=x),b[g]=x),m[g]=R}s.splice(1,0,m),l.splice(1,0,b),p=-1;const v=[];for(;++p<s.length;){const y=s[p],k=l[p];g=-1;const A=[];for(;++g<d;){const x=y[g]||"";let R="",O="";if(n.alignDelimiters!==!1){const N=u[g]-(k[g]||0),C=o[g];C===114?R=" ".repeat(N):C===99?N%2?(R=" ".repeat(N/2+.5),O=" ".repeat(N/2-.5)):(R=" ".repeat(N/2),O=R):O=" ".repeat(N)}n.delimiterStart!==!1&&!g&&A.push("|"),n.padding!==!1&&!(n.alignDelimiters===!1&&x==="")&&(n.delimiterStart!==!1||g)&&A.push(" "),n.alignDelimiters!==!1&&A.push(R),A.push(x),n.alignDelimiters!==!1&&A.push(O),n.padding!==!1&&A.push(" "),(n.delimiterEnd!==!1||g!==d-1)&&A.push("|")}v.push(n.delimiterEnd===!1?A.join("").replace(/ +$/,""):A.join(""))}return v.join(`
`)}function bfe(e){return e==null?"":String(e)}function VI(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}function yfe(e,t,n,r){const a=n.enter("blockquote"),o=n.createTracker(r);o.move("> "),o.shift(2);const s=n.indentLines(n.containerFlow(e,o.current()),vfe);return a(),s}function vfe(e,t,n){return">"+(n?"":" ")+e}function Sfe(e,t){return WI(e,t.inConstruct,!0)&&!WI(e,t.notInConstruct,!1)}function WI(e,t,n){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return n;let r=-1;for(;++r<t.length;)if(e.includes(t[r]))return!0;return!1}function YI(e,t,n,r){let a=-1;for(;++a<n.unsafe.length;)if(n.unsafe[a].character===`
`&&Sfe(n.stack,n.unsafe[a]))return/[ \t]/.test(r.before)?"":" ";return`\\
`}function cH(e,t){const n=String(e);let r=n.indexOf(t),a=r,o=0,s=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;r!==-1;)r===a?++o>s&&(s=o):o=1,a=r+t.length,r=n.indexOf(t,a);return s}function Efe(e,t){return!!(t.options.fences===!1&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))}function wfe(e){const t=e.options.fence||"`";if(t!=="`"&&t!=="~")throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`");return t}function xfe(e,t,n,r){const a=wfe(n),o=e.value||"",s=a==="`"?"GraveAccent":"Tilde";if(Efe(e,n)){const g=n.enter("codeIndented"),m=n.indentLines(o,kfe);return g(),m}const l=n.createTracker(r),u=a.repeat(Math.max(cH(o,a)+1,3)),d=n.enter("codeFenced");let p=l.move(u);if(e.lang){const g=n.enter(`codeFencedLang${s}`);p+=l.move(n.safe(e.lang,{before:p,after:" ",encode:["`"],...l.current()})),g()}if(e.lang&&e.meta){const g=n.enter(`codeFencedMeta${s}`);p+=l.move(" "),p+=l.move(n.safe(e.meta,{before:p,after:`
`,encode:["`"],...l.current()})),g()}return p+=l.move(`
`),o&&(p+=l.move(o+`
`)),p+=l.move(u),d(),p}function kfe(e,t,n){return(n?"":"    ")+e}function pA(e){const t=e.options.quote||'"';if(t!=='"'&&t!=="'")throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`");return t}function Tfe(e,t,n,r){const a=pA(n),o=a==='"'?"Quote":"Apostrophe",s=n.enter("definition");let l=n.enter("label");const u=n.createTracker(r);let d=u.move("[");return d+=u.move(n.safe(n.associationId(e),{before:d,after:"]",...u.current()})),d+=u.move("]: "),l(),!e.url||/[\0- \u007F]/.test(e.url)?(l=n.enter("destinationLiteral"),d+=u.move("<"),d+=u.move(n.safe(e.url,{before:d,after:">",...u.current()})),d+=u.move(">")):(l=n.enter("destinationRaw"),d+=u.move(n.safe(e.url,{before:d,after:e.title?" ":`
`,...u.current()}))),l(),e.title&&(l=n.enter(`title${o}`),d+=u.move(" "+a),d+=u.move(n.safe(e.title,{before:d,after:a,...u.current()})),d+=u.move(a),l()),s(),d}function Afe(e){const t=e.options.emphasis||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`");return t}function Pc(e){return"&#x"+e.toString(16).toUpperCase()+";"}function jf(e,t,n){const r=js(e),a=js(t);return r===void 0?a===void 0?n==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:r===1?a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}uH.peek=Rfe;function uH(e,t,n,r){const a=Afe(n),o=n.enter("emphasis"),s=n.createTracker(r),l=s.move(a);let u=s.move(n.containerPhrasing(e,{after:a,before:l,...s.current()}));const d=u.charCodeAt(0),p=jf(r.before.charCodeAt(r.before.length-1),d,a);p.inside&&(u=Pc(d)+u.slice(1));const g=u.charCodeAt(u.length-1),m=jf(r.after.charCodeAt(0),g,a);m.inside&&(u=u.slice(0,-1)+Pc(g));const b=s.move(a);return o(),n.attentionEncodeSurroundingInfo={after:m.outside,before:p.outside},l+u+b}function Rfe(e,t,n){return n.options.emphasis||"*"}function Cfe(e,t){let n=!1;return dA(e,function(r){if("value"in r&&/\r?\n|\r/.test(r.value)||r.type==="break")return n=!0,Ek}),!!((!e.depth||e.depth<3)&&aA(e)&&(t.options.setext||n))}function _fe(e,t,n,r){const a=Math.max(Math.min(6,e.depth||1),1),o=n.createTracker(r);if(Cfe(e,n)){const p=n.enter("headingSetext"),g=n.enter("phrasing"),m=n.containerPhrasing(e,{...o.current(),before:`
`,after:`
`});return g(),p(),m+`
`+(a===1?"=":"-").repeat(m.length-(Math.max(m.lastIndexOf("\r"),m.lastIndexOf(`
`))+1))}const s="#".repeat(a),l=n.enter("headingAtx"),u=n.enter("phrasing");o.move(s+" ");let d=n.containerPhrasing(e,{before:"# ",after:`
`,...o.current()});return/^[\t ]/.test(d)&&(d=Pc(d.charCodeAt(0))+d.slice(1)),d=d?s+" "+d:s,n.options.closeAtx&&(d+=" "+s),u(),l(),d}dH.peek=Nfe;function dH(e){return e.value||""}function Nfe(){return"<"}fH.peek=Ofe;function fH(e,t,n,r){const a=pA(n),o=a==='"'?"Quote":"Apostrophe",s=n.enter("image");let l=n.enter("label");const u=n.createTracker(r);let d=u.move("![");return d+=u.move(n.safe(e.alt,{before:d,after:"]",...u.current()})),d+=u.move("]("),l(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(l=n.enter("destinationLiteral"),d+=u.move("<"),d+=u.move(n.safe(e.url,{before:d,after:">",...u.current()})),d+=u.move(">")):(l=n.enter("destinationRaw"),d+=u.move(n.safe(e.url,{before:d,after:e.title?" ":")",...u.current()}))),l(),e.title&&(l=n.enter(`title${o}`),d+=u.move(" "+a),d+=u.move(n.safe(e.title,{before:d,after:a,...u.current()})),d+=u.move(a),l()),d+=u.move(")"),s(),d}function Ofe(){return"!"}pH.peek=Ife;function pH(e,t,n,r){const a=e.referenceType,o=n.enter("imageReference");let s=n.enter("label");const l=n.createTracker(r);let u=l.move("![");const d=n.safe(e.alt,{before:u,after:"]",...l.current()});u+=l.move(d+"]["),s();const p=n.stack;n.stack=[],s=n.enter("reference");const g=n.safe(n.associationId(e),{before:u,after:"]",...l.current()});return s(),n.stack=p,o(),a==="full"||!d||d!==g?u+=l.move(g+"]"):a==="shortcut"?u=u.slice(0,-1):u+=l.move("]"),u}function Ife(){return"!"}gH.peek=Dfe;function gH(e,t,n){let r=e.value||"",a="`",o=-1;for(;new RegExp("(^|[^`])"+a+"([^`]|$)").test(r);)a+="`";for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++o<n.unsafe.length;){const s=n.unsafe[o],l=n.compilePattern(s);let u;if(s.atBreak)for(;u=l.exec(r);){let d=u.index;r.charCodeAt(d)===10&&r.charCodeAt(d-1)===13&&d--,r=r.slice(0,d)+" "+r.slice(u.index+1)}}return a+r+a}function Dfe(){return"`"}function hH(e,t){const n=aA(e);return!!(!t.options.resourceLink&&e.url&&!e.title&&e.children&&e.children.length===1&&e.children[0].type==="text"&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))}mH.peek=Lfe;function mH(e,t,n,r){const a=pA(n),o=a==='"'?"Quote":"Apostrophe",s=n.createTracker(r);let l,u;if(hH(e,n)){const p=n.stack;n.stack=[],l=n.enter("autolink");let g=s.move("<");return g+=s.move(n.containerPhrasing(e,{before:g,after:">",...s.current()})),g+=s.move(">"),l(),n.stack=p,g}l=n.enter("link"),u=n.enter("label");let d=s.move("[");return d+=s.move(n.containerPhrasing(e,{before:d,after:"](",...s.current()})),d+=s.move("]("),u(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(u=n.enter("destinationLiteral"),d+=s.move("<"),d+=s.move(n.safe(e.url,{before:d,after:">",...s.current()})),d+=s.move(">")):(u=n.enter("destinationRaw"),d+=s.move(n.safe(e.url,{before:d,after:e.title?" ":")",...s.current()}))),u(),e.title&&(u=n.enter(`title${o}`),d+=s.move(" "+a),d+=s.move(n.safe(e.title,{before:d,after:a,...s.current()})),d+=s.move(a),u()),d+=s.move(")"),l(),d}function Lfe(e,t,n){return hH(e,n)?"<":"["}bH.peek=Mfe;function bH(e,t,n,r){const a=e.referenceType,o=n.enter("linkReference");let s=n.enter("label");const l=n.createTracker(r);let u=l.move("[");const d=n.containerPhrasing(e,{before:u,after:"]",...l.current()});u+=l.move(d+"]["),s();const p=n.stack;n.stack=[],s=n.enter("reference");const g=n.safe(n.associationId(e),{before:u,after:"]",...l.current()});return s(),n.stack=p,o(),a==="full"||!d||d!==g?u+=l.move(g+"]"):a==="shortcut"?u=u.slice(0,-1):u+=l.move("]"),u}function Mfe(){return"["}function gA(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function Pfe(e){const t=gA(e),n=e.options.bulletOther;if(!n)return t==="*"?"-":"*";if(n!=="*"&&n!=="+"&&n!=="-")throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different");return n}function Ffe(e){const t=e.options.bulletOrdered||".";if(t!=="."&&t!==")")throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`");return t}function yH(e){const t=e.options.rule||"*";if(t!=="*"&&t!=="-"&&t!=="_")throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`");return t}function zfe(e,t,n,r){const a=n.enter("list"),o=n.bulletCurrent;let s=e.ordered?Ffe(n):gA(n);const l=e.ordered?s==="."?")":".":Pfe(n);let u=t&&n.bulletLastUsed?s===n.bulletLastUsed:!1;if(!e.ordered){const p=e.children?e.children[0]:void 0;if((s==="*"||s==="-")&&p&&(!p.children||!p.children[0])&&n.stack[n.stack.length-1]==="list"&&n.stack[n.stack.length-2]==="listItem"&&n.stack[n.stack.length-3]==="list"&&n.stack[n.stack.length-4]==="listItem"&&n.indexStack[n.indexStack.length-1]===0&&n.indexStack[n.indexStack.length-2]===0&&n.indexStack[n.indexStack.length-3]===0&&(u=!0),yH(n)===s&&p){let g=-1;for(;++g<e.children.length;){const m=e.children[g];if(m&&m.type==="listItem"&&m.children&&m.children[0]&&m.children[0].type==="thematicBreak"){u=!0;break}}}}u&&(s=l),n.bulletCurrent=s;const d=n.containerFlow(e,r);return n.bulletLastUsed=s,n.bulletCurrent=o,a(),d}function Bfe(e){const t=e.options.listItemIndent||"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function jfe(e,t,n,r){const a=Bfe(n);let o=n.bulletCurrent||gA(n);t&&t.type==="list"&&t.ordered&&(o=(typeof t.start=="number"&&t.start>-1?t.start:1)+(n.options.incrementListMarker===!1?0:t.children.indexOf(e))+o);let s=o.length+1;(a==="tab"||a==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(s=Math.ceil(s/4)*4);const l=n.createTracker(r);l.move(o+" ".repeat(s-o.length)),l.shift(s);const u=n.enter("listItem"),d=n.indentLines(n.containerFlow(e,l.current()),p);return u(),d;function p(g,m,b){return m?(b?"":" ".repeat(s))+g:(b?o:o+" ".repeat(s-o.length))+g}}function Ufe(e,t,n,r){const a=n.enter("paragraph"),o=n.enter("phrasing"),s=n.containerPhrasing(e,r);return o(),a(),s}const Gfe=Pp(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function Hfe(e,t,n,r){return(e.children.some(function(s){return Gfe(s)})?n.containerPhrasing:n.containerFlow).call(n,e,r)}function $fe(e){const t=e.options.strong||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`");return t}vH.peek=qfe;function vH(e,t,n,r){const a=$fe(n),o=n.enter("strong"),s=n.createTracker(r),l=s.move(a+a);let u=s.move(n.containerPhrasing(e,{after:a,before:l,...s.current()}));const d=u.charCodeAt(0),p=jf(r.before.charCodeAt(r.before.length-1),d,a);p.inside&&(u=Pc(d)+u.slice(1));const g=u.charCodeAt(u.length-1),m=jf(r.after.charCodeAt(0),g,a);m.inside&&(u=u.slice(0,-1)+Pc(g));const b=s.move(a+a);return o(),n.attentionEncodeSurroundingInfo={after:m.outside,before:p.outside},l+u+b}function qfe(e,t,n){return n.options.strong||"*"}function Vfe(e,t,n,r){return n.safe(e.value,r)}function Wfe(e){const t=e.options.ruleRepetition||3;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more");return t}function Yfe(e,t,n){const r=(yH(n)+(n.options.ruleSpaces?" ":"")).repeat(Wfe(n));return n.options.ruleSpaces?r.slice(0,-1):r}const SH={blockquote:yfe,break:YI,code:xfe,definition:Tfe,emphasis:uH,hardBreak:YI,heading:_fe,html:dH,image:fH,imageReference:pH,inlineCode:gH,link:mH,linkReference:bH,list:zfe,listItem:jfe,paragraph:Ufe,root:Hfe,strong:vH,text:Vfe,thematicBreak:Yfe};function Kfe(){return{enter:{table:Xfe,tableData:KI,tableHeader:KI,tableRow:Qfe},exit:{codeText:Jfe,table:Zfe,tableData:Ib,tableHeader:Ib,tableRow:Ib}}}function Xfe(e){const t=e._align;this.enter({type:"table",align:t.map(function(n){return n==="none"?null:n}),children:[]},e),this.data.inTable=!0}function Zfe(e){this.exit(e),this.data.inTable=void 0}function Qfe(e){this.enter({type:"tableRow",children:[]},e)}function Ib(e){this.exit(e)}function KI(e){this.enter({type:"tableCell",children:[]},e)}function Jfe(e){let t=this.resume();this.data.inTable&&(t=t.replace(/\\([\\|])/g,epe));const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}function epe(e,t){return t==="|"?t:e}function tpe(e){const t=e||{},n=t.tableCellPadding,r=t.tablePipeAlign,a=t.stringLength,o=n?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:m,table:s,tableCell:u,tableRow:l}};function s(b,v,y,k){return d(p(b,y,k),b.align)}function l(b,v,y,k){const A=g(b,y,k),x=d([A]);return x.slice(0,x.indexOf(`
`))}function u(b,v,y,k){const A=y.enter("tableCell"),x=y.enter("phrasing"),R=y.containerPhrasing(b,{...k,before:o,after:o});return x(),A(),R}function d(b,v){return mfe(b,{align:v,alignDelimiters:r,padding:n,stringLength:a})}function p(b,v,y){const k=b.children;let A=-1;const x=[],R=v.enter("table");for(;++A<k.length;)x[A]=g(k[A],v,y);return R(),x}function g(b,v,y){const k=b.children;let A=-1;const x=[],R=v.enter("tableRow");for(;++A<k.length;)x[A]=u(k[A],b,v,y);return R(),x}function m(b,v,y){let k=SH.inlineCode(b,v,y);return y.stack.includes("tableCell")&&(k=k.replace(/\|/g,"\\$&")),k}}function npe(){return{exit:{taskListCheckValueChecked:XI,taskListCheckValueUnchecked:XI,paragraph:ape}}}function rpe(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:ope}}}function XI(e){const t=this.stack[this.stack.length-2];t.type,t.checked=e.type==="taskListCheckValueChecked"}function ape(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const n=this.stack[this.stack.length-1];n.type;const r=n.children[0];if(r&&r.type==="text"){const a=t.children;let o=-1,s;for(;++o<a.length;){const l=a[o];if(l.type==="paragraph"){s=l;break}}s===n&&(r.value=r.value.slice(1),r.value.length===0?n.children.shift():n.position&&r.position&&typeof r.position.start.offset=="number"&&(r.position.start.column++,r.position.start.offset++,n.position.start=Object.assign({},r.position.start)))}}this.exit(e)}function ope(e,t,n,r){const a=e.children[0],o=typeof e.checked=="boolean"&&a&&a.type==="paragraph",s="["+(e.checked?"x":" ")+"] ",l=n.createTracker(r);o&&l.move(s);let u=SH.listItem(e,t,n,{...r,...l.current()});return o&&(u=u.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,d)),u;function d(p){return p+s}}function ipe(){return[Bde(),ife(),ufe(),Kfe(),npe()]}function spe(e){return{extensions:[jde(),sfe(e),dfe(),tpe(e),rpe()]}}const lpe={tokenize:gpe,partial:!0},EH={tokenize:hpe,partial:!0},wH={tokenize:mpe,partial:!0},xH={tokenize:bpe,partial:!0},cpe={tokenize:ype,partial:!0},kH={name:"wwwAutolink",tokenize:fpe,previous:AH},TH={name:"protocolAutolink",tokenize:ppe,previous:RH},Va={name:"emailAutolink",tokenize:dpe,previous:CH},fa={};function upe(){return{text:fa}}let si=48;for(;si<123;)fa[si]=Va,si++,si===58?si=65:si===91&&(si=97);fa[43]=Va;fa[45]=Va;fa[46]=Va;fa[95]=Va;fa[72]=[Va,TH];fa[104]=[Va,TH];fa[87]=[Va,kH];fa[119]=[Va,kH];function dpe(e,t,n){const r=this;let a,o;return s;function s(g){return!Tk(g)||!CH.call(r,r.previous)||hA(r.events)?n(g):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),l(g))}function l(g){return Tk(g)?(e.consume(g),l):g===64?(e.consume(g),u):n(g)}function u(g){return g===46?e.check(cpe,p,d)(g):g===45||g===95||Tn(g)?(o=!0,e.consume(g),u):p(g)}function d(g){return e.consume(g),a=!0,u}function p(g){return o&&a&&In(r.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(g)):n(g)}}function fpe(e,t,n){const r=this;return a;function a(s){return s!==87&&s!==119||!AH.call(r,r.previous)||hA(r.events)?n(s):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(lpe,e.attempt(EH,e.attempt(wH,o),n),n)(s))}function o(s){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(s)}}function ppe(e,t,n){const r=this;let a="",o=!1;return s;function s(g){return(g===72||g===104)&&RH.call(r,r.previous)&&!hA(r.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),a+=String.fromCodePoint(g),e.consume(g),l):n(g)}function l(g){if(In(g)&&a.length<5)return a+=String.fromCodePoint(g),e.consume(g),l;if(g===58){const m=a.toLowerCase();if(m==="http"||m==="https")return e.consume(g),u}return n(g)}function u(g){return g===47?(e.consume(g),o?d:(o=!0,u)):n(g)}function d(g){return g===null||Ff(g)||Dt(g)||wi(g)||Dp(g)?n(g):e.attempt(EH,e.attempt(wH,p),n)(g)}function p(g){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(g)}}function gpe(e,t,n){let r=0;return a;function a(s){return(s===87||s===119)&&r<3?(r++,e.consume(s),a):s===46&&r===3?(e.consume(s),o):n(s)}function o(s){return s===null?n(s):t(s)}}function hpe(e,t,n){let r,a,o;return s;function s(d){return d===46||d===95?e.check(xH,u,l)(d):d===null||Dt(d)||wi(d)||d!==45&&Dp(d)?u(d):(o=!0,e.consume(d),s)}function l(d){return d===95?r=!0:(a=r,r=void 0),e.consume(d),s}function u(d){return a||r||!o?n(d):t(d)}}function mpe(e,t){let n=0,r=0;return a;function a(s){return s===40?(n++,e.consume(s),a):s===41&&r<n?o(s):s===33||s===34||s===38||s===39||s===41||s===42||s===44||s===46||s===58||s===59||s===60||s===63||s===93||s===95||s===126?e.check(xH,t,o)(s):s===null||Dt(s)||wi(s)?t(s):(e.consume(s),a)}function o(s){return s===41&&r++,e.consume(s),a}}function bpe(e,t,n){return r;function r(l){return l===33||l===34||l===39||l===41||l===42||l===44||l===46||l===58||l===59||l===63||l===95||l===126?(e.consume(l),r):l===38?(e.consume(l),o):l===93?(e.consume(l),a):l===60||l===null||Dt(l)||wi(l)?t(l):n(l)}function a(l){return l===null||l===40||l===91||Dt(l)||wi(l)?t(l):r(l)}function o(l){return In(l)?s(l):n(l)}function s(l){return l===59?(e.consume(l),r):In(l)?(e.consume(l),s):n(l)}}function ype(e,t,n){return r;function r(o){return e.consume(o),a}function a(o){return Tn(o)?n(o):t(o)}}function AH(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||Dt(e)}function RH(e){return!In(e)}function CH(e){return!(e===47||Tk(e))}function Tk(e){return e===43||e===45||e===46||e===95||Tn(e)}function hA(e){let t=e.length,n=!1;for(;t--;){const r=e[t][1];if((r.type==="labelLink"||r.type==="labelImage")&&!r._balanced){n=!0;break}if(r._gfmAutolinkLiteralWalkedInto){n=!1;break}}return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}const vpe={tokenize:Rpe,partial:!0};function Spe(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:kpe,continuation:{tokenize:Tpe},exit:Ape}},text:{91:{name:"gfmFootnoteCall",tokenize:xpe},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:Epe,resolveTo:wpe}}}}function Epe(e,t,n){const r=this;let a=r.events.length;const o=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let s;for(;a--;){const u=r.events[a][1];if(u.type==="labelImage"){s=u;break}if(u.type==="gfmFootnoteCall"||u.type==="labelLink"||u.type==="label"||u.type==="image"||u.type==="link")break}return l;function l(u){if(!s||!s._balanced)return n(u);const d=Br(r.sliceSerialize({start:s.end,end:r.now()}));return d.codePointAt(0)!==94||!o.includes(d.slice(1))?n(u):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(u),e.exit("gfmFootnoteCallLabelMarker"),t(u))}}function wpe(e,t){let n=e.length;for(;n--;)if(e[n][1].type==="labelImage"&&e[n][0]==="enter"){e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker";const r={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),end:Object.assign({},e[e.length-1][1].end)},a={type:"gfmFootnoteCallMarker",start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)};a.end.column++,a.end.offset++,a.end._bufferIndex++;const o={type:"gfmFootnoteCallString",start:Object.assign({},a.end),end:Object.assign({},e[e.length-1][1].start)},s={type:"chunkString",contentType:"string",start:Object.assign({},o.start),end:Object.assign({},o.end)},l=[e[n+1],e[n+2],["enter",r,t],e[n+3],e[n+4],["enter",a,t],["exit",a,t],["enter",o,t],["enter",s,t],["exit",s,t],["exit",o,t],e[e.length-2],e[e.length-1],["exit",r,t]];return e.splice(n,e.length-n+1,...l),e}function xpe(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let o=0,s;return l;function l(g){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(g),e.exit("gfmFootnoteCallLabelMarker"),u}function u(g){return g!==94?n(g):(e.enter("gfmFootnoteCallMarker"),e.consume(g),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",d)}function d(g){if(o>999||g===93&&!s||g===null||g===91||Dt(g))return n(g);if(g===93){e.exit("chunkString");const m=e.exit("gfmFootnoteCallString");return a.includes(Br(r.sliceSerialize(m)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(g),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(g)}return Dt(g)||(s=!0),o++,e.consume(g),g===92?p:d}function p(g){return g===91||g===92||g===93?(e.consume(g),o++,d):d(g)}}function kpe(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let o,s=0,l;return u;function u(v){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(v),e.exit("gfmFootnoteDefinitionLabelMarker"),d}function d(v){return v===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(v),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",p):n(v)}function p(v){if(s>999||v===93&&!l||v===null||v===91||Dt(v))return n(v);if(v===93){e.exit("chunkString");const y=e.exit("gfmFootnoteDefinitionLabelString");return o=Br(r.sliceSerialize(y)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(v),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),m}return Dt(v)||(l=!0),s++,e.consume(v),v===92?g:p}function g(v){return v===91||v===92||v===93?(e.consume(v),s++,p):p(v)}function m(v){return v===58?(e.enter("definitionMarker"),e.consume(v),e.exit("definitionMarker"),a.includes(o)||a.push(o),dt(e,b,"gfmFootnoteDefinitionWhitespace")):n(v)}function b(v){return t(v)}}function Tpe(e,t,n){return e.check(su,t,e.attempt(vpe,t,n))}function Ape(e){e.exit("gfmFootnoteDefinition")}function Rpe(e,t,n){const r=this;return dt(e,a,"gfmFootnoteDefinitionIndent",5);function a(o){const s=r.events[r.events.length-1];return s&&s[1].type==="gfmFootnoteDefinitionIndent"&&s[2].sliceSerialize(s[1],!0).length===4?t(o):n(o)}}function Cpe(e){let n=(e||{}).singleTilde;const r={name:"strikethrough",tokenize:o,resolveAll:a};return n==null&&(n=!0),{text:{126:r},insideSpan:{null:[r]},attentionMarkers:{null:[126]}};function a(s,l){let u=-1;for(;++u<s.length;)if(s[u][0]==="enter"&&s[u][1].type==="strikethroughSequenceTemporary"&&s[u][1]._close){let d=u;for(;d--;)if(s[d][0]==="exit"&&s[d][1].type==="strikethroughSequenceTemporary"&&s[d][1]._open&&s[u][1].end.offset-s[u][1].start.offset===s[d][1].end.offset-s[d][1].start.offset){s[u][1].type="strikethroughSequence",s[d][1].type="strikethroughSequence";const p={type:"strikethrough",start:Object.assign({},s[d][1].start),end:Object.assign({},s[u][1].end)},g={type:"strikethroughText",start:Object.assign({},s[d][1].end),end:Object.assign({},s[u][1].start)},m=[["enter",p,l],["enter",s[d][1],l],["exit",s[d][1],l],["enter",g,l]],b=l.parser.constructs.insideSpan.null;b&&or(m,m.length,0,Lp(b,s.slice(d+1,u),l)),or(m,m.length,0,[["exit",g,l],["enter",s[u][1],l],["exit",s[u][1],l],["exit",p,l]]),or(s,d-1,u-d+3,m),u=d+m.length-2;break}}for(u=-1;++u<s.length;)s[u][1].type==="strikethroughSequenceTemporary"&&(s[u][1].type="data");return s}function o(s,l,u){const d=this.previous,p=this.events;let g=0;return m;function m(v){return d===126&&p[p.length-1][1].type!=="characterEscape"?u(v):(s.enter("strikethroughSequenceTemporary"),b(v))}function b(v){const y=js(d);if(v===126)return g>1?u(v):(s.consume(v),g++,b);if(g<2&&!n)return u(v);const k=s.exit("strikethroughSequenceTemporary"),A=js(v);return k._open=!A||A===2&&!!y,k._close=!y||y===2&&!!A,l(v)}}}class _pe{constructor(){this.map=[]}add(t,n,r){Npe(this,t,n,r)}consume(t){if(this.map.sort(function(o,s){return o[0]-s[0]}),this.map.length===0)return;let n=this.map.length;const r=[];for(;n>0;)n-=1,r.push(t.slice(this.map[n][0]+this.map[n][1]),this.map[n][2]),t.length=this.map[n][0];r.push(t.slice()),t.length=0;let a=r.pop();for(;a;){for(const o of a)t.push(o);a=r.pop()}this.map.length=0}}function Npe(e,t,n,r){let a=0;if(!(n===0&&r.length===0)){for(;a<e.map.length;){if(e.map[a][0]===t){e.map[a][1]+=n,e.map[a][2].push(...r);return}a+=1}e.map.push([t,n,r])}}function Ope(e,t){let n=!1;const r=[];for(;t<e.length;){const a=e[t];if(n){if(a[0]==="enter")a[1].type==="tableContent"&&r.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(a[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const o=r.length-1;r[o]=r[o]==="left"?"center":"right"}}else if(a[1].type==="tableDelimiterRow")break}else a[0]==="enter"&&a[1].type==="tableDelimiterRow"&&(n=!0);t+=1}return r}function Ipe(){return{flow:{null:{name:"table",tokenize:Dpe,resolveAll:Lpe}}}}function Dpe(e,t,n){const r=this;let a=0,o=0,s;return l;function l(D){let U=r.events.length-1;for(;U>-1;){const W=r.events[U][1].type;if(W==="lineEnding"||W==="linePrefix")U--;else break}const $=U>-1?r.events[U][1].type:null,B=$==="tableHead"||$==="tableRow"?C:u;return B===C&&r.parser.lazy[r.now().line]?n(D):B(D)}function u(D){return e.enter("tableHead"),e.enter("tableRow"),d(D)}function d(D){return D===124||(s=!0,o+=1),p(D)}function p(D){return D===null?n(D):Ve(D)?o>1?(o=0,r.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(D),e.exit("lineEnding"),b):n(D):pt(D)?dt(e,p,"whitespace")(D):(o+=1,s&&(s=!1,a+=1),D===124?(e.enter("tableCellDivider"),e.consume(D),e.exit("tableCellDivider"),s=!0,p):(e.enter("data"),g(D)))}function g(D){return D===null||D===124||Dt(D)?(e.exit("data"),p(D)):(e.consume(D),D===92?m:g)}function m(D){return D===92||D===124?(e.consume(D),g):g(D)}function b(D){return r.interrupt=!1,r.parser.lazy[r.now().line]?n(D):(e.enter("tableDelimiterRow"),s=!1,pt(D)?dt(e,v,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(D):v(D))}function v(D){return D===45||D===58?k(D):D===124?(s=!0,e.enter("tableCellDivider"),e.consume(D),e.exit("tableCellDivider"),y):N(D)}function y(D){return pt(D)?dt(e,k,"whitespace")(D):k(D)}function k(D){return D===58?(o+=1,s=!0,e.enter("tableDelimiterMarker"),e.consume(D),e.exit("tableDelimiterMarker"),A):D===45?(o+=1,A(D)):D===null||Ve(D)?O(D):N(D)}function A(D){return D===45?(e.enter("tableDelimiterFiller"),x(D)):N(D)}function x(D){return D===45?(e.consume(D),x):D===58?(s=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(D),e.exit("tableDelimiterMarker"),R):(e.exit("tableDelimiterFiller"),R(D))}function R(D){return pt(D)?dt(e,O,"whitespace")(D):O(D)}function O(D){return D===124?v(D):D===null||Ve(D)?!s||a!==o?N(D):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(D)):N(D)}function N(D){return n(D)}function C(D){return e.enter("tableRow"),_(D)}function _(D){return D===124?(e.enter("tableCellDivider"),e.consume(D),e.exit("tableCellDivider"),_):D===null||Ve(D)?(e.exit("tableRow"),t(D)):pt(D)?dt(e,_,"whitespace")(D):(e.enter("data"),M(D))}function M(D){return D===null||D===124||Dt(D)?(e.exit("data"),_(D)):(e.consume(D),D===92?I:M)}function I(D){return D===92||D===124?(e.consume(D),M):M(D)}}function Lpe(e,t){let n=-1,r=!0,a=0,o=[0,0,0,0],s=[0,0,0,0],l=!1,u=0,d,p,g;const m=new _pe;for(;++n<e.length;){const b=e[n],v=b[1];b[0]==="enter"?v.type==="tableHead"?(l=!1,u!==0&&(ZI(m,t,u,d,p),p=void 0,u=0),d={type:"table",start:Object.assign({},v.start),end:Object.assign({},v.end)},m.add(n,0,[["enter",d,t]])):v.type==="tableRow"||v.type==="tableDelimiterRow"?(r=!0,g=void 0,o=[0,0,0,0],s=[0,n+1,0,0],l&&(l=!1,p={type:"tableBody",start:Object.assign({},v.start),end:Object.assign({},v.end)},m.add(n,0,[["enter",p,t]])),a=v.type==="tableDelimiterRow"?2:p?3:1):a&&(v.type==="data"||v.type==="tableDelimiterMarker"||v.type==="tableDelimiterFiller")?(r=!1,s[2]===0&&(o[1]!==0&&(s[0]=s[1],g=$d(m,t,o,a,void 0,g),o=[0,0,0,0]),s[2]=n)):v.type==="tableCellDivider"&&(r?r=!1:(o[1]!==0&&(s[0]=s[1],g=$d(m,t,o,a,void 0,g)),o=s,s=[o[1],n,0,0])):v.type==="tableHead"?(l=!0,u=n):v.type==="tableRow"||v.type==="tableDelimiterRow"?(u=n,o[1]!==0?(s[0]=s[1],g=$d(m,t,o,a,n,g)):s[1]!==0&&(g=$d(m,t,s,a,n,g)),a=0):a&&(v.type==="data"||v.type==="tableDelimiterMarker"||v.type==="tableDelimiterFiller")&&(s[3]=n)}for(u!==0&&ZI(m,t,u,d,p),m.consume(t.events),n=-1;++n<t.events.length;){const b=t.events[n];b[0]==="enter"&&b[1].type==="table"&&(b[1]._align=Ope(t.events,n))}return e}function $d(e,t,n,r,a,o){const s=r===1?"tableHeader":r===2?"tableDelimiter":"tableData",l="tableContent";n[0]!==0&&(o.end=Object.assign({},ks(t.events,n[0])),e.add(n[0],0,[["exit",o,t]]));const u=ks(t.events,n[1]);if(o={type:s,start:Object.assign({},u),end:Object.assign({},u)},e.add(n[1],0,[["enter",o,t]]),n[2]!==0){const d=ks(t.events,n[2]),p=ks(t.events,n[3]),g={type:l,start:Object.assign({},d),end:Object.assign({},p)};if(e.add(n[2],0,[["enter",g,t]]),r!==2){const m=t.events[n[2]],b=t.events[n[3]];if(m[1].end=Object.assign({},b[1].end),m[1].type="chunkText",m[1].contentType="text",n[3]>n[2]+1){const v=n[2]+1,y=n[3]-n[2]-1;e.add(v,y,[])}}e.add(n[3]+1,0,[["exit",g,t]])}return a!==void 0&&(o.end=Object.assign({},ks(t.events,a)),e.add(a,0,[["exit",o,t]]),o=void 0),o}function ZI(e,t,n,r,a){const o=[],s=ks(t.events,n);a&&(a.end=Object.assign({},s),o.push(["exit",a,t])),r.end=Object.assign({},s),o.push(["exit",r,t]),e.add(n+1,0,o)}function ks(e,t){const n=e[t],r=n[0]==="enter"?"start":"end";return n[1][r]}const Mpe={name:"tasklistCheck",tokenize:Fpe};function Ppe(){return{text:{91:Mpe}}}function Fpe(e,t,n){const r=this;return a;function a(u){return r.previous!==null||!r._gfmTasklistFirstContentOfListItem?n(u):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(u),e.exit("taskListCheckMarker"),o)}function o(u){return Dt(u)?(e.enter("taskListCheckValueUnchecked"),e.consume(u),e.exit("taskListCheckValueUnchecked"),s):u===88||u===120?(e.enter("taskListCheckValueChecked"),e.consume(u),e.exit("taskListCheckValueChecked"),s):n(u)}function s(u){return u===93?(e.enter("taskListCheckMarker"),e.consume(u),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),l):n(u)}function l(u){return Ve(u)?t(u):pt(u)?e.check({tokenize:zpe},t,n)(u):n(u)}}function zpe(e,t,n){return dt(e,r,"whitespace");function r(a){return a===null?n(a):t(a)}}function Bpe(e){return zG([upe(),Spe(),Cpe(e),Ipe(),Ppe()])}const jpe={};function Upe(e){const t=this,n=e||jpe,r=t.data(),a=r.micromarkExtensions||(r.micromarkExtensions=[]),o=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),s=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);a.push(Bpe(n)),o.push(ipe()),s.push(spe(n))}function Gpe(e){const t=this;t.compiler=n;function n(r,a){return DG(r,{filePath:a.path,...e})}}function Hpe(){return{enter:{mathFlow:e,mathFlowFenceMeta:t,mathText:o},exit:{mathFlow:a,mathFlowFence:r,mathFlowFenceMeta:n,mathFlowValue:l,mathText:s,mathTextData:l}};function e(u){const d={type:"element",tagName:"code",properties:{className:["language-math","math-display"]},children:[]};this.enter({type:"math",meta:null,value:"",data:{hName:"pre",hChildren:[d]}},u)}function t(){this.buffer()}function n(){const u=this.resume(),d=this.stack[this.stack.length-1];d.type,d.meta=u}function r(){this.data.mathFlowInside||(this.buffer(),this.data.mathFlowInside=!0)}function a(u){const d=this.resume().replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),p=this.stack[this.stack.length-1];p.type,this.exit(u),p.value=d;const g=p.data.hChildren[0];g.type,g.tagName,g.children.push({type:"text",value:d}),this.data.mathFlowInside=void 0}function o(u){this.enter({type:"inlineMath",value:"",data:{hName:"code",hProperties:{className:["language-math","math-inline"]},hChildren:[]}},u),this.buffer()}function s(u){const d=this.resume(),p=this.stack[this.stack.length-1];p.type,this.exit(u),p.value=d,p.data.hChildren.push({type:"text",value:d})}function l(u){this.config.enter.data.call(this,u),this.config.exit.data.call(this,u)}}function $pe(e){let t=(e||{}).singleDollarTextMath;return t==null&&(t=!0),r.peek=a,{unsafe:[{character:"\r",inConstruct:"mathFlowMeta"},{character:`
`,inConstruct:"mathFlowMeta"},{character:"$",after:t?void 0:"\\$",inConstruct:"phrasing"},{character:"$",inConstruct:"mathFlowMeta"},{atBreak:!0,character:"$",after:"\\$"}],handlers:{math:n,inlineMath:r}};function n(o,s,l,u){const d=o.value||"",p=l.createTracker(u),g="$".repeat(Math.max(cH(d,"$")+1,2)),m=l.enter("mathFlow");let b=p.move(g);if(o.meta){const v=l.enter("mathFlowMeta");b+=p.move(l.safe(o.meta,{after:`
`,before:b,encode:["$"],...p.current()})),v()}return b+=p.move(`
`),d&&(b+=p.move(d+`
`)),b+=p.move(g),m(),b}function r(o,s,l){let u=o.value||"",d=1;for(t||d++;new RegExp("(^|[^$])"+"\\$".repeat(d)+"([^$]|$)").test(u);)d++;const p="$".repeat(d);/[^ \r\n]/.test(u)&&(/^[ \r\n]/.test(u)&&/[ \r\n]$/.test(u)||/^\$|\$$/.test(u))&&(u=" "+u+" ");let g=-1;for(;++g<l.unsafe.length;){const m=l.unsafe[g];if(!m.atBreak)continue;const b=l.compilePattern(m);let v;for(;v=b.exec(u);){let y=v.index;u.codePointAt(y)===10&&u.codePointAt(y-1)===13&&y--,u=u.slice(0,y)+" "+u.slice(v.index+1)}}return p+u+p}function a(){return"$"}}const qpe={tokenize:Vpe,concrete:!0,name:"mathFlow"},QI={tokenize:Wpe,partial:!0};function Vpe(e,t,n){const r=this,a=r.events[r.events.length-1],o=a&&a[1].type==="linePrefix"?a[2].sliceSerialize(a[1],!0).length:0;let s=0;return l;function l(x){return e.enter("mathFlow"),e.enter("mathFlowFence"),e.enter("mathFlowFenceSequence"),u(x)}function u(x){return x===36?(e.consume(x),s++,u):s<2?n(x):(e.exit("mathFlowFenceSequence"),dt(e,d,"whitespace")(x))}function d(x){return x===null||Ve(x)?g(x):(e.enter("mathFlowFenceMeta"),e.enter("chunkString",{contentType:"string"}),p(x))}function p(x){return x===null||Ve(x)?(e.exit("chunkString"),e.exit("mathFlowFenceMeta"),g(x)):x===36?n(x):(e.consume(x),p)}function g(x){return e.exit("mathFlowFence"),r.interrupt?t(x):e.attempt(QI,m,k)(x)}function m(x){return e.attempt({tokenize:A,partial:!0},k,b)(x)}function b(x){return(o?dt(e,v,"linePrefix",o+1):v)(x)}function v(x){return x===null?k(x):Ve(x)?e.attempt(QI,m,k)(x):(e.enter("mathFlowValue"),y(x))}function y(x){return x===null||Ve(x)?(e.exit("mathFlowValue"),v(x)):(e.consume(x),y)}function k(x){return e.exit("mathFlow"),t(x)}function A(x,R,O){let N=0;return dt(x,C,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4);function C(I){return x.enter("mathFlowFence"),x.enter("mathFlowFenceSequence"),_(I)}function _(I){return I===36?(N++,x.consume(I),_):N<s?O(I):(x.exit("mathFlowFenceSequence"),dt(x,M,"whitespace")(I))}function M(I){return I===null||Ve(I)?(x.exit("mathFlowFence"),R(I)):O(I)}}}function Wpe(e,t,n){const r=this;return a;function a(s){return s===null?t(s):(e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),o)}function o(s){return r.parser.lazy[r.now().line]?n(s):t(s)}}function Ype(e){let n=(e||{}).singleDollarTextMath;return n==null&&(n=!0),{tokenize:r,resolve:Kpe,previous:Xpe,name:"mathText"};function r(a,o,s){let l=0,u,d;return p;function p(y){return a.enter("mathText"),a.enter("mathTextSequence"),g(y)}function g(y){return y===36?(a.consume(y),l++,g):l<2&&!n?s(y):(a.exit("mathTextSequence"),m(y))}function m(y){return y===null?s(y):y===36?(d=a.enter("mathTextSequence"),u=0,v(y)):y===32?(a.enter("space"),a.consume(y),a.exit("space"),m):Ve(y)?(a.enter("lineEnding"),a.consume(y),a.exit("lineEnding"),m):(a.enter("mathTextData"),b(y))}function b(y){return y===null||y===32||y===36||Ve(y)?(a.exit("mathTextData"),m(y)):(a.consume(y),b)}function v(y){return y===36?(a.consume(y),u++,v):u===l?(a.exit("mathTextSequence"),a.exit("mathText"),o(y)):(d.type="mathTextData",b(y))}}}function Kpe(e){let t=e.length-4,n=3,r,a;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="mathTextData"){e[t][1].type="mathTextPadding",e[n][1].type="mathTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)a===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(a=r):(r===t||e[r][1].type==="lineEnding")&&(e[a][1].type="mathTextData",r!==a+2&&(e[a][1].end=e[r-1][1].end,e.splice(a+2,r-a-2),t-=r-a-2,r=a+2),a=void 0);return e}function Xpe(e){return e!==36||this.events[this.events.length-1][1].type==="characterEscape"}function Zpe(e){return{flow:{36:qpe},text:{36:Ype(e)}}}const Qpe={};function Jpe(e){const t=this,n=e||Qpe,r=t.data(),a=r.micromarkExtensions||(r.micromarkExtensions=[]),o=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),s=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);a.push(Zpe(n)),o.push(Hpe()),s.push($pe(n))}function ege(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function tge(e,t){if(e==null)return{};var n,r,a=ege(e,t);if(Object.getOwnPropertySymbols){var o=Object.getOwnPropertySymbols(e);for(r=0;r<o.length;r++)n=o[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}function Ak(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function nge(e){if(Array.isArray(e))return Ak(e)}function rge(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function age(e,t){if(e){if(typeof e=="string")return Ak(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Ak(e,t):void 0}}function oge(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Rk(e){return nge(e)||rge(e)||age(e)||oge()}function Fc(e){"@babel/helpers - typeof";return Fc=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Fc(e)}function ige(e,t){if(Fc(e)!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(Fc(r)!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function sge(e){var t=ige(e,"string");return Fc(t)=="symbol"?t:t+""}function _H(e,t,n){return(t=sge(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Ck(){return Ck=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Ck.apply(null,arguments)}function JI(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ts(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?JI(Object(n),!0).forEach(function(r){_H(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):JI(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function lge(e){var t=e.length;if(t===0||t===1)return e;if(t===2)return[e[0],e[1],"".concat(e[0],".").concat(e[1]),"".concat(e[1],".").concat(e[0])];if(t===3)return[e[0],e[1],e[2],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0])];if(t>=4)return[e[0],e[1],e[2],e[3],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[2],".").concat(e[3]),"".concat(e[3],".").concat(e[0]),"".concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[0]),"".concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[3],".").concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[2],".").concat(e[1],".").concat(e[0])]}var Db={};function cge(e){if(e.length===0||e.length===1)return e;var t=e.join(".");return Db[t]||(Db[t]=lge(e)),Db[t]}function uge(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=arguments.length>2?arguments[2]:void 0,r=e.filter(function(o){return o!=="token"}),a=cge(r);return a.reduce(function(o,s){return Ts(Ts({},o),n[s])},t)}function eD(e){return e.join(" ")}function dge(e,t){var n=0;return function(r){return n+=1,r.map(function(a,o){return NH({node:a,stylesheet:e,useInlineStyles:t,key:"code-segment-".concat(n,"-").concat(o)})})}}function NH(e){var t=e.node,n=e.stylesheet,r=e.style,a=r===void 0?{}:r,o=e.useInlineStyles,s=e.key,l=t.properties,u=t.type,d=t.tagName,p=t.value;if(u==="text")return p;if(d){var g=dge(n,o),m;if(!o)m=Ts(Ts({},l),{},{className:eD(l.className)});else{var b=Object.keys(n).reduce(function(A,x){return x.split(".").forEach(function(R){A.includes(R)||A.push(R)}),A},[]),v=l.className&&l.className.includes("token")?["token"]:[],y=l.className&&v.concat(l.className.filter(function(A){return!b.includes(A)}));m=Ts(Ts({},l),{},{className:eD(y)||void 0,style:uge(l.className,Object.assign({},l.style,a),n)})}var k=g(t.children);return we.createElement(d,Ck({key:s},m),k)}}const fge=function(e,t){var n=e.listLanguages();return n.indexOf(t)!==-1};var pge=["language","children","style","customStyle","codeTagProps","useInlineStyles","showLineNumbers","showInlineLineNumbers","startingLineNumber","lineNumberContainerStyle","lineNumberStyle","wrapLines","wrapLongLines","lineProps","renderer","PreTag","CodeTag","code","astGenerator"];function tD(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ao(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?tD(Object(n),!0).forEach(function(r){_H(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):tD(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}var gge=/\n/g;function hge(e){return e.match(gge)}function mge(e){var t=e.lines,n=e.startingLineNumber,r=e.style;return t.map(function(a,o){var s=o+n;return we.createElement("span",{key:"line-".concat(o),className:"react-syntax-highlighter-line-number",style:typeof r=="function"?r(s):r},"".concat(s,`
`))})}function bge(e){var t=e.codeString,n=e.codeStyle,r=e.containerStyle,a=r===void 0?{float:"left",paddingRight:"10px"}:r,o=e.numberStyle,s=o===void 0?{}:o,l=e.startingLineNumber;return we.createElement("code",{style:Object.assign({},n,a)},mge({lines:t.replace(/\n$/,"").split(`
`),style:s,startingLineNumber:l}))}function yge(e){return"".concat(e.toString().length,".25em")}function OH(e,t){return{type:"element",tagName:"span",properties:{key:"line-number--".concat(e),className:["comment","linenumber","react-syntax-highlighter-line-number"],style:t},children:[{type:"text",value:e}]}}function IH(e,t,n){var r={display:"inline-block",minWidth:yge(n),paddingRight:"1em",textAlign:"right",userSelect:"none"},a=typeof e=="function"?e(t):e,o=Ao(Ao({},r),a);return o}function pf(e){var t=e.children,n=e.lineNumber,r=e.lineNumberStyle,a=e.largestLineNumber,o=e.showInlineLineNumbers,s=e.lineProps,l=s===void 0?{}:s,u=e.className,d=u===void 0?[]:u,p=e.showLineNumbers,g=e.wrapLongLines,m=e.wrapLines,b=m===void 0?!1:m,v=b?Ao({},typeof l=="function"?l(n):l):{};if(v.className=v.className?[].concat(Rk(v.className.trim().split(/\s+/)),Rk(d)):d,n&&o){var y=IH(r,n,a);t.unshift(OH(n,y))}return g&p&&(v.style=Ao({display:"flex"},v.style)),{type:"element",tagName:"span",properties:v,children:t}}function DH(e){for(var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[],r=0;r<e.length;r++){var a=e[r];if(a.type==="text")n.push(pf({children:[a],className:Rk(new Set(t))}));else if(a.children){var o=t.concat(a.properties.className);DH(a.children,o).forEach(function(s){return n.push(s)})}}return n}function vge(e,t,n,r,a,o,s,l,u){var d,p=DH(e.value),g=[],m=-1,b=0;function v(N,C){var _=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return pf({children:N,lineNumber:C,lineNumberStyle:l,largestLineNumber:s,showInlineLineNumbers:a,lineProps:n,className:_,showLineNumbers:r,wrapLongLines:u,wrapLines:t})}function y(N,C){if(r&&C&&a){var _=IH(l,C,s);N.unshift(OH(C,_))}return N}function k(N,C){var _=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return t||_.length>0?v(N,C,_):y(N,C)}for(var A=function(){var C=p[b],_=C.children[0].value,M=hge(_);if(M){var I=_.split(`
`);I.forEach(function(D,U){var $=r&&g.length+o,B={type:"text",value:"".concat(D,`
`)};if(U===0){var W=p.slice(m+1,b).concat(pf({children:[B],className:C.properties.className})),K=k(W,$);g.push(K)}else if(U===I.length-1){var H=p[b+1]&&p[b+1].children&&p[b+1].children[0],G={type:"text",value:"".concat(D)};if(H){var z=pf({children:[G],className:C.properties.className});p.splice(b+1,0,z)}else{var Y=[G],L=k(Y,$,C.properties.className);g.push(L)}}else{var V=[B],j=k(V,$,C.properties.className);g.push(j)}}),m=b}b++};b<p.length;)A();if(m!==p.length-1){var x=p.slice(m+1,p.length);if(x&&x.length){var R=r&&g.length+o,O=k(x,R);g.push(O)}}return t?g:(d=[]).concat.apply(d,g)}function Sge(e){var t=e.rows,n=e.stylesheet,r=e.useInlineStyles;return t.map(function(a,o){return NH({node:a,stylesheet:n,useInlineStyles:r,key:"code-segement".concat(o)})})}function LH(e){return e&&typeof e.highlightAuto<"u"}function Ege(e){var t=e.astGenerator,n=e.language,r=e.code,a=e.defaultCodeValue;if(LH(t)){var o=fge(t,n);return n==="text"?{value:a,language:"text"}:o?t.highlight(n,r):t.highlightAuto(r)}try{return n&&n!=="text"?{value:t.highlight(r,n)}:{value:a}}catch{return{value:a}}}function wge(e,t){return function(r){var a=r.language,o=r.children,s=r.style,l=s===void 0?t:s,u=r.customStyle,d=u===void 0?{}:u,p=r.codeTagProps,g=p===void 0?{className:a?"language-".concat(a):void 0,style:Ao(Ao({},l['code[class*="language-"]']),l['code[class*="language-'.concat(a,'"]')])}:p,m=r.useInlineStyles,b=m===void 0?!0:m,v=r.showLineNumbers,y=v===void 0?!1:v,k=r.showInlineLineNumbers,A=k===void 0?!0:k,x=r.startingLineNumber,R=x===void 0?1:x,O=r.lineNumberContainerStyle,N=r.lineNumberStyle,C=N===void 0?{}:N,_=r.wrapLines,M=r.wrapLongLines,I=M===void 0?!1:M,D=r.lineProps,U=D===void 0?{}:D,$=r.renderer,B=r.PreTag,W=B===void 0?"pre":B,K=r.CodeTag,H=K===void 0?"code":K,G=r.code,z=G===void 0?(Array.isArray(o)?o[0]:o)||"":G,Y=r.astGenerator,L=tge(r,pge);Y=Y||e;var V=y?we.createElement(bge,{containerStyle:O,codeStyle:g.style||{},numberStyle:C,startingLineNumber:R,codeString:z}):null,j=l.hljs||l['pre[class*="language-"]']||{backgroundColor:"#fff"},P=LH(Y)?"hljs":"prismjs",Z=b?Object.assign({},L,{style:Object.assign({},j,d)}):Object.assign({},L,{className:L.className?"".concat(P," ").concat(L.className):P,style:Object.assign({},d)});if(I?g.style=Ao({whiteSpace:"pre-wrap"},g.style):g.style=Ao({whiteSpace:"pre"},g.style),!Y)return we.createElement(W,Z,V,we.createElement(H,g,z));(_===void 0&&$||I)&&(_=!0),$=$||Sge;var Q=[{type:"text",value:z}],oe=Ege({astGenerator:Y,language:a,code:z,defaultCodeValue:Q});oe.language===null&&(oe.value=Q);var ae=oe.value.length;ae===1&&oe.value[0].type==="text"&&(ae=oe.value[0].value.split(`
`).length);var ce=ae+R,Re=vge(oe,_,U,y,A,R,ce,C,I);return we.createElement(W,Z,we.createElement(H,g,!A&&V,$({rows:Re,stylesheet:l,useInlineStyles:b})))}}const xge=["abap","abnf","actionscript","ada","agda","al","antlr4","apacheconf","apex","apl","applescript","aql","arduino","arff","asciidoc","asm6502","asmatmel","aspnet","autohotkey","autoit","avisynth","avro-idl","bash","basic","batch","bbcode","bicep","birb","bison","bnf","brainfuck","brightscript","bro","bsl","c","cfscript","chaiscript","cil","clike","clojure","cmake","cobol","coffeescript","concurnas","coq","cpp","crystal","csharp","cshtml","csp","css-extras","css","csv","cypher","d","dart","dataweave","dax","dhall","diff","django","dns-zone-file","docker","dot","ebnf","editorconfig","eiffel","ejs","elixir","elm","erb","erlang","etlua","excel-formula","factor","false","firestore-security-rules","flow","fortran","fsharp","ftl","gap","gcode","gdscript","gedcom","gherkin","git","glsl","gml","gn","go-module","go","graphql","groovy","haml","handlebars","haskell","haxe","hcl","hlsl","hoon","hpkp","hsts","http","ichigojam","icon","icu-message-format","idris","iecst","ignore","inform7","ini","io","j","java","javadoc","javadoclike","javascript","javastacktrace","jexl","jolie","jq","js-extras","js-templates","jsdoc","json","json5","jsonp","jsstacktrace","jsx","julia","keepalived","keyman","kotlin","kumir","kusto","latex","latte","less","lilypond","liquid","lisp","livescript","llvm","log","lolcode","lua","magma","makefile","markdown","markup-templating","markup","matlab","maxscript","mel","mermaid","mizar","mongodb","monkey","moonscript","n1ql","n4js","nand2tetris-hdl","naniscript","nasm","neon","nevod","nginx","nim","nix","nsis","objectivec","ocaml","opencl","openqasm","oz","parigp","parser","pascal","pascaligo","pcaxis","peoplecode","perl","php-extras","php","phpdoc","plsql","powerquery","powershell","processing","prolog","promql","properties","protobuf","psl","pug","puppet","pure","purebasic","purescript","python","q","qml","qore","qsharp","r","racket","reason","regex","rego","renpy","rest","rip","roboconf","robotframework","ruby","rust","sas","sass","scala","scheme","scss","shell-session","smali","smalltalk","smarty","sml","solidity","solution-file","soy","sparql","splunk-spl","sqf","sql","squirrel","stan","stylus","swift","systemd","t4-cs","t4-templating","t4-vb","tap","tcl","textile","toml","tremor","tsx","tt2","turtle","twig","typescript","typoscript","unrealscript","uorazor","uri","v","vala","vbnet","velocity","verilog","vhdl","vim","visual-basic","warpscript","wasm","web-idl","wiki","wolfram","wren","xeora","xml-doc","xojo","xquery","yaml","yang","zig"];var Lb,nD;function kge(){if(nD)return Lb;nD=1,Lb=t;var e=Object.prototype.hasOwnProperty;function t(){for(var n={},r=0;r<arguments.length;r++){var a=arguments[r];for(var o in a)e.call(a,o)&&(n[o]=a[o])}return n}return Lb}var Mb,rD;function MH(){if(rD)return Mb;rD=1,Mb=t;var e=t.prototype;e.space=null,e.normal={},e.property={};function t(n,r,a){this.property=n,this.normal=r,a&&(this.space=a)}return Mb}var Pb,aD;function Tge(){if(aD)return Pb;aD=1;var e=kge(),t=MH();Pb=n;function n(r){for(var a=r.length,o=[],s=[],l=-1,u,d;++l<a;)u=r[l],o.push(u.property),s.push(u.normal),d=u.space;return new t(e.apply(null,o),e.apply(null,s),d)}return Pb}var Fb,oD;function mA(){if(oD)return Fb;oD=1,Fb=e;function e(t){return t.toLowerCase()}return Fb}var zb,iD;function PH(){if(iD)return zb;iD=1,zb=t;var e=t.prototype;e.space=null,e.attribute=null,e.property=null,e.boolean=!1,e.booleanish=!1,e.overloadedBoolean=!1,e.number=!1,e.commaSeparated=!1,e.spaceSeparated=!1,e.commaOrSpaceSeparated=!1,e.mustUseProperty=!1,e.defined=!1;function t(n,r){this.property=n,this.attribute=r}return zb}var La={},sD;function bA(){if(sD)return La;sD=1;var e=0;La.boolean=t(),La.booleanish=t(),La.overloadedBoolean=t(),La.number=t(),La.spaceSeparated=t(),La.commaSeparated=t(),La.commaOrSpaceSeparated=t();function t(){return Math.pow(2,++e)}return La}var Bb,lD;function FH(){if(lD)return Bb;lD=1;var e=PH(),t=bA();Bb=a,a.prototype=new e,a.prototype.defined=!0;var n=["boolean","booleanish","overloadedBoolean","number","commaSeparated","spaceSeparated","commaOrSpaceSeparated"],r=n.length;function a(s,l,u,d){var p=-1,g;for(o(this,"space",d),e.call(this,s,l);++p<r;)g=n[p],o(this,g,(u&t[g])===t[g])}function o(s,l,u){u&&(s[l]=u)}return Bb}var jb,cD;function cu(){if(cD)return jb;cD=1;var e=mA(),t=MH(),n=FH();jb=r;function r(a){var o=a.space,s=a.mustUseProperty||[],l=a.attributes||{},u=a.properties,d=a.transform,p={},g={},m,b;for(m in u)b=new n(m,d(l,m),u[m],o),s.indexOf(m)!==-1&&(b.mustUseProperty=!0),p[m]=b,g[e(m)]=m,g[e(b.attribute)]=m;return new t(p,g,o)}return jb}var Ub,uD;function Age(){if(uD)return Ub;uD=1;var e=cu();Ub=e({space:"xlink",transform:t,properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null}});function t(n,r){return"xlink:"+r.slice(5).toLowerCase()}return Ub}var Gb,dD;function Rge(){if(dD)return Gb;dD=1;var e=cu();Gb=e({space:"xml",transform:t,properties:{xmlLang:null,xmlBase:null,xmlSpace:null}});function t(n,r){return"xml:"+r.slice(3).toLowerCase()}return Gb}var Hb,fD;function Cge(){if(fD)return Hb;fD=1,Hb=e;function e(t,n){return n in t?t[n]:n}return Hb}var $b,pD;function zH(){if(pD)return $b;pD=1;var e=Cge();$b=t;function t(n,r){return e(n,r.toLowerCase())}return $b}var qb,gD;function _ge(){if(gD)return qb;gD=1;var e=cu(),t=zH();return qb=e({space:"xmlns",attributes:{xmlnsxlink:"xmlns:xlink"},transform:t,properties:{xmlns:null,xmlnsXLink:null}}),qb}var Vb,hD;function Nge(){if(hD)return Vb;hD=1;var e=bA(),t=cu(),n=e.booleanish,r=e.number,a=e.spaceSeparated;Vb=t({transform:o,properties:{ariaActiveDescendant:null,ariaAtomic:n,ariaAutoComplete:null,ariaBusy:n,ariaChecked:n,ariaColCount:r,ariaColIndex:r,ariaColSpan:r,ariaControls:a,ariaCurrent:null,ariaDescribedBy:a,ariaDetails:null,ariaDisabled:n,ariaDropEffect:a,ariaErrorMessage:null,ariaExpanded:n,ariaFlowTo:a,ariaGrabbed:n,ariaHasPopup:null,ariaHidden:n,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:a,ariaLevel:r,ariaLive:null,ariaModal:n,ariaMultiLine:n,ariaMultiSelectable:n,ariaOrientation:null,ariaOwns:a,ariaPlaceholder:null,ariaPosInSet:r,ariaPressed:n,ariaReadOnly:n,ariaRelevant:null,ariaRequired:n,ariaRoleDescription:a,ariaRowCount:r,ariaRowIndex:r,ariaRowSpan:r,ariaSelected:n,ariaSetSize:r,ariaSort:null,ariaValueMax:r,ariaValueMin:r,ariaValueNow:r,ariaValueText:null,role:null}});function o(s,l){return l==="role"?l:"aria-"+l.slice(4).toLowerCase()}return Vb}var Wb,mD;function Oge(){if(mD)return Wb;mD=1;var e=bA(),t=cu(),n=zH(),r=e.boolean,a=e.overloadedBoolean,o=e.booleanish,s=e.number,l=e.spaceSeparated,u=e.commaSeparated;return Wb=t({space:"html",attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},transform:n,mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:u,acceptCharset:l,accessKey:l,action:null,allow:null,allowFullScreen:r,allowPaymentRequest:r,allowUserMedia:r,alt:null,as:null,async:r,autoCapitalize:null,autoComplete:l,autoFocus:r,autoPlay:r,capture:r,charSet:null,checked:r,cite:null,className:l,cols:s,colSpan:null,content:null,contentEditable:o,controls:r,controlsList:l,coords:s|u,crossOrigin:null,data:null,dateTime:null,decoding:null,default:r,defer:r,dir:null,dirName:null,disabled:r,download:a,draggable:o,encType:null,enterKeyHint:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:r,formTarget:null,headers:l,height:s,hidden:r,high:s,href:null,hrefLang:null,htmlFor:l,httpEquiv:l,id:null,imageSizes:null,imageSrcSet:u,inputMode:null,integrity:null,is:null,isMap:r,itemId:null,itemProp:l,itemRef:l,itemScope:r,itemType:l,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:r,low:s,manifest:null,max:null,maxLength:s,media:null,method:null,min:null,minLength:s,multiple:r,muted:r,name:null,nonce:null,noModule:r,noValidate:r,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforePrint:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextMenu:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:r,optimum:s,pattern:null,ping:l,placeholder:null,playsInline:r,poster:null,preload:null,readOnly:r,referrerPolicy:null,rel:l,required:r,reversed:r,rows:s,rowSpan:s,sandbox:l,scope:null,scoped:r,seamless:r,selected:r,shape:null,size:s,sizes:null,slot:null,span:s,spellCheck:o,src:null,srcDoc:null,srcLang:null,srcSet:u,start:s,step:null,style:null,tabIndex:s,target:null,title:null,translate:null,type:null,typeMustMatch:r,useMap:null,value:o,width:s,wrap:null,align:null,aLink:null,archive:l,axis:null,background:null,bgColor:null,border:s,borderColor:null,bottomMargin:s,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:r,declare:r,event:null,face:null,frame:null,frameBorder:null,hSpace:s,leftMargin:s,link:null,longDesc:null,lowSrc:null,marginHeight:s,marginWidth:s,noResize:r,noHref:r,noShade:r,noWrap:r,object:null,profile:null,prompt:null,rev:null,rightMargin:s,rules:null,scheme:null,scrolling:o,standby:null,summary:null,text:null,topMargin:s,valueType:null,version:null,vAlign:null,vLink:null,vSpace:s,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:r,disableRemotePlayback:r,prefix:null,property:null,results:s,security:null,unselectable:null}}),Wb}var Yb,bD;function Ige(){if(bD)return Yb;bD=1;var e=Tge(),t=Age(),n=Rge(),r=_ge(),a=Nge(),o=Oge();return Yb=e([n,t,r,a,o]),Yb}var Kb,yD;function Dge(){if(yD)return Kb;yD=1;var e=mA(),t=FH(),n=PH(),r="data";Kb=l;var a=/^data[-\w.:]+$/i,o=/-[a-z]/g,s=/[A-Z]/g;function l(m,b){var v=e(b),y=b,k=n;return v in m.normal?m.property[m.normal[v]]:(v.length>4&&v.slice(0,4)===r&&a.test(b)&&(b.charAt(4)==="-"?y=u(b):b=d(b),k=t),new k(y,b))}function u(m){var b=m.slice(5).replace(o,g);return r+b.charAt(0).toUpperCase()+b.slice(1)}function d(m){var b=m.slice(4);return o.test(b)?m:(b=b.replace(s,p),b.charAt(0)!=="-"&&(b="-"+b),r+b)}function p(m){return"-"+m.toLowerCase()}function g(m){return m.charAt(1).toUpperCase()}return Kb}var Xb,vD;function Lge(){if(vD)return Xb;vD=1,Xb=t;var e=/[#.]/g;function t(n,r){for(var a=n||"",o=r||"div",s={},l=0,u,d,p;l<a.length;)e.lastIndex=l,p=e.exec(a),u=a.slice(l,p?p.index:a.length),u&&(d?d==="#"?s.id=u:s.className?s.className.push(u):s.className=[u]:o=u,l+=u.length),p&&(d=p[0],l++);return{type:"element",tagName:o,properties:s,children:[]}}return Xb}var qd={},SD;function Mge(){if(SD)return qd;SD=1,qd.parse=r,qd.stringify=a;var e="",t=" ",n=/[ \t\n\r\f]+/g;function r(o){var s=String(o||e).trim();return s===e?[]:s.split(n)}function a(o){return o.join(t).trim()}return qd}var Vd={},ED;function Pge(){if(ED)return Vd;ED=1,Vd.parse=r,Vd.stringify=a;var e=",",t=" ",n="";function r(o){for(var s=[],l=String(o||n),u=l.indexOf(e),d=0,p=!1,g;!p;)u===-1&&(u=l.length,p=!0),g=l.slice(d,u).trim(),(g||!p)&&s.push(g),d=u+1,u=l.indexOf(e,d);return s}function a(o,s){var l=s||{},u=l.padLeft===!1?n:t,d=l.padRight?t:n;return o[o.length-1]===n&&(o=o.concat(n)),o.join(d+e+u).trim()}return Vd}var Zb,wD;function Fge(){if(wD)return Zb;wD=1;var e=Dge(),t=mA(),n=Lge(),r=Mge().parse,a=Pge().parse;Zb=s;var o={}.hasOwnProperty;function s(v,y,k){var A=k?b(k):null;return x;function x(O,N){var C=n(O,y),_=Array.prototype.slice.call(arguments,2),M=C.tagName.toLowerCase(),I;if(C.tagName=A&&o.call(A,M)?A[M]:M,N&&l(N,C)&&(_.unshift(N),N=null),N)for(I in N)R(C.properties,I,N[I]);return d(C.children,_),C.tagName==="template"&&(C.content={type:"root",children:C.children},C.children=[]),C}function R(O,N,C){var _,M,I;C==null||C!==C||(_=e(v,N),M=_.property,I=C,typeof I=="string"&&(_.spaceSeparated?I=r(I):_.commaSeparated?I=a(I):_.commaOrSpaceSeparated&&(I=r(a(I).join(" ")))),M==="style"&&typeof C!="string"&&(I=m(I)),M==="className"&&O.className&&(I=O.className.concat(I)),O[M]=p(_,M,I))}}function l(v,y){return typeof v=="string"||"length"in v||u(y.tagName,v)}function u(v,y){var k=y.type;return v==="input"||!k||typeof k!="string"?!1:typeof y.children=="object"&&"length"in y.children?!0:(k=k.toLowerCase(),v==="button"?k!=="menu"&&k!=="submit"&&k!=="reset"&&k!=="button":"value"in y)}function d(v,y){var k,A;if(typeof y=="string"||typeof y=="number"){v.push({type:"text",value:String(y)});return}if(typeof y=="object"&&"length"in y){for(k=-1,A=y.length;++k<A;)d(v,y[k]);return}if(typeof y!="object"||!("type"in y))throw new Error("Expected node, nodes, or string, got `"+y+"`");v.push(y)}function p(v,y,k){var A,x,R;if(typeof k!="object"||!("length"in k))return g(v,y,k);for(x=k.length,A=-1,R=[];++A<x;)R[A]=g(v,y,k[A]);return R}function g(v,y,k){var A=k;return v.number||v.positiveNumber?!isNaN(A)&&A!==""&&(A=Number(A)):(v.boolean||v.overloadedBoolean)&&typeof A=="string"&&(A===""||t(k)===t(y))&&(A=!0),A}function m(v){var y=[],k;for(k in v)y.push([k,v[k]].join(": "));return y.join("; ")}function b(v){for(var y=v.length,k=-1,A={},x;++k<y;)x=v[k],A[x.toLowerCase()]=x;return A}return Zb}var Qb,xD;function zge(){if(xD)return Qb;xD=1;var e=Ige(),t=Fge(),n=t(e,"div");return n.displayName="html",Qb=n,Qb}var Jb,kD;function Bge(){return kD||(kD=1,Jb=zge()),Jb}const jge="Æ",Uge="&",Gge="Á",Hge="Â",$ge="À",qge="Å",Vge="Ã",Wge="Ä",Yge="©",Kge="Ç",Xge="Ð",Zge="É",Qge="Ê",Jge="È",ehe="Ë",the=">",nhe="Í",rhe="Î",ahe="Ì",ohe="Ï",ihe="<",she="Ñ",lhe="Ó",che="Ô",uhe="Ò",dhe="Ø",fhe="Õ",phe="Ö",ghe='"',hhe="®",mhe="Þ",bhe="Ú",yhe="Û",vhe="Ù",She="Ü",Ehe="Ý",whe="á",xhe="â",khe="´",The="æ",Ahe="à",Rhe="&",Che="å",_he="ã",Nhe="ä",Ohe="¦",Ihe="ç",Dhe="¸",Lhe="¢",Mhe="©",Phe="¤",Fhe="°",zhe="÷",Bhe="é",jhe="ê",Uhe="è",Ghe="ð",Hhe="ë",$he="½",qhe="¼",Vhe="¾",Whe=">",Yhe="í",Khe="î",Xhe="¡",Zhe="ì",Qhe="¿",Jhe="ï",eme="«",tme="<",nme="¯",rme="µ",ame="·",ome=" ",ime="¬",sme="ñ",lme="ó",cme="ô",ume="ò",dme="ª",fme="º",pme="ø",gme="õ",hme="ö",mme="¶",bme="±",yme="£",vme='"',Sme="»",Eme="®",wme="§",xme="­",kme="¹",Tme="²",Ame="³",Rme="ß",Cme="þ",_me="×",Nme="ú",Ome="û",Ime="ù",Dme="¨",Lme="ü",Mme="ý",Pme="¥",Fme="ÿ",zme={AElig:jge,AMP:Uge,Aacute:Gge,Acirc:Hge,Agrave:$ge,Aring:qge,Atilde:Vge,Auml:Wge,COPY:Yge,Ccedil:Kge,ETH:Xge,Eacute:Zge,Ecirc:Qge,Egrave:Jge,Euml:ehe,GT:the,Iacute:nhe,Icirc:rhe,Igrave:ahe,Iuml:ohe,LT:ihe,Ntilde:she,Oacute:lhe,Ocirc:che,Ograve:uhe,Oslash:dhe,Otilde:fhe,Ouml:phe,QUOT:ghe,REG:hhe,THORN:mhe,Uacute:bhe,Ucirc:yhe,Ugrave:vhe,Uuml:She,Yacute:Ehe,aacute:whe,acirc:xhe,acute:khe,aelig:The,agrave:Ahe,amp:Rhe,aring:Che,atilde:_he,auml:Nhe,brvbar:Ohe,ccedil:Ihe,cedil:Dhe,cent:Lhe,copy:Mhe,curren:Phe,deg:Fhe,divide:zhe,eacute:Bhe,ecirc:jhe,egrave:Uhe,eth:Ghe,euml:Hhe,frac12:$he,frac14:qhe,frac34:Vhe,gt:Whe,iacute:Yhe,icirc:Khe,iexcl:Xhe,igrave:Zhe,iquest:Qhe,iuml:Jhe,laquo:eme,lt:tme,macr:nme,micro:rme,middot:ame,nbsp:ome,not:ime,ntilde:sme,oacute:lme,ocirc:cme,ograve:ume,ordf:dme,ordm:fme,oslash:pme,otilde:gme,ouml:hme,para:mme,plusmn:bme,pound:yme,quot:vme,raquo:Sme,reg:Eme,sect:wme,shy:xme,sup1:kme,sup2:Tme,sup3:Ame,szlig:Rme,thorn:Cme,times:_me,uacute:Nme,ucirc:Ome,ugrave:Ime,uml:Dme,uuml:Lme,yacute:Mme,yen:Pme,yuml:Fme},Bme={0:"�",128:"€",130:"‚",131:"ƒ",132:"„",133:"…",134:"†",135:"‡",136:"ˆ",137:"‰",138:"Š",139:"‹",140:"Œ",142:"Ž",145:"‘",146:"’",147:"“",148:"”",149:"•",150:"–",151:"—",152:"˜",153:"™",154:"š",155:"›",156:"œ",158:"ž",159:"Ÿ"};var ey,TD;function BH(){if(TD)return ey;TD=1,ey=e;function e(t){var n=typeof t=="string"?t.charCodeAt(0):t;return n>=48&&n<=57}return ey}var ty,AD;function jme(){if(AD)return ty;AD=1,ty=e;function e(t){var n=typeof t=="string"?t.charCodeAt(0):t;return n>=97&&n<=102||n>=65&&n<=70||n>=48&&n<=57}return ty}var ny,RD;function Ume(){if(RD)return ny;RD=1,ny=e;function e(t){var n=typeof t=="string"?t.charCodeAt(0):t;return n>=97&&n<=122||n>=65&&n<=90}return ny}var ry,CD;function Gme(){if(CD)return ry;CD=1;var e=Ume(),t=BH();ry=n;function n(r){return e(r)||t(r)}return ry}var ay,_D;function Hme(){if(_D)return ay;_D=1;var e,t=59;ay=n;function n(r){var a="&"+r+";",o;return e=e||document.createElement("i"),e.innerHTML=a,o=e.textContent,o.charCodeAt(o.length-1)===t&&r!=="semi"||o===a?!1:o}return ay}var oy,ND;function $me(){if(ND)return oy;ND=1;var e=zme,t=Bme,n=BH(),r=jme(),a=Gme(),o=Hme();oy=Y;var s={}.hasOwnProperty,l=String.fromCharCode,u=Function.prototype,d={warning:null,reference:null,text:null,warningContext:null,referenceContext:null,textContext:null,position:{},additional:null,attribute:!1,nonTerminated:!0},p=9,g=10,m=12,b=32,v=38,y=59,k=60,A=61,x=35,R=88,O=120,N=65533,C="named",_="hexadecimal",M="decimal",I={};I[_]=16,I[M]=10;var D={};D[C]=a,D[M]=n,D[_]=r;var U=1,$=2,B=3,W=4,K=5,H=6,G=7,z={};z[U]="Named character references must be terminated by a semicolon",z[$]="Numeric character references must be terminated by a semicolon",z[B]="Named character references cannot be empty",z[W]="Numeric character references cannot be empty",z[K]="Named character references must be known",z[H]="Numeric character references cannot be disallowed",z[G]="Numeric character references cannot be outside the permissible Unicode range";function Y(P,Z){var Q={},oe,ae;Z||(Z={});for(ae in d)oe=Z[ae],Q[ae]=oe??d[ae];return(Q.position.indent||Q.position.start)&&(Q.indent=Q.position.indent||[],Q.position=Q.position.start),L(P,Q)}function L(P,Z){var Q=Z.additional,oe=Z.nonTerminated,ae=Z.text,ce=Z.reference,Re=Z.warning,ie=Z.textContext,Te=Z.referenceContext,ne=Z.warningContext,xe=Z.position,Se=Z.indent||[],be=P.length,J=0,pe=-1,ke=xe.column||1,he=xe.line||1,Ee="",se=[],Be,je,ye,Oe,ee,de,Ne,Fe,We,St,Tt,bt,et,At,st,wt,Ht,pn,zt;for(typeof Q=="string"&&(Q=Q.charCodeAt(0)),wt=ir(),Fe=Re?Vr:u,J--,be++;++J<be;)if(ee===g&&(ke=Se[pe]||1),ee=P.charCodeAt(J),ee===v){if(Ne=P.charCodeAt(J+1),Ne===p||Ne===g||Ne===m||Ne===b||Ne===v||Ne===k||Ne!==Ne||Q&&Ne===Q){Ee+=l(ee),ke++;continue}for(et=J+1,bt=et,zt=et,Ne===x?(zt=++bt,Ne=P.charCodeAt(zt),Ne===R||Ne===O?(At=_,zt=++bt):At=M):At=C,Be="",Tt="",Oe="",st=D[At],zt--;++zt<be&&(Ne=P.charCodeAt(zt),!!st(Ne));)Oe+=l(Ne),At===C&&s.call(e,Oe)&&(Be=Oe,Tt=e[Oe]);ye=P.charCodeAt(zt)===y,ye&&(zt++,je=At===C?o(Oe):!1,je&&(Be=Oe,Tt=je)),pn=1+zt-et,!ye&&!oe||(Oe?At===C?(ye&&!Tt?Fe(K,1):(Be!==Oe&&(zt=bt+Be.length,pn=1+zt-bt,ye=!1),ye||(We=Be?U:B,Z.attribute?(Ne=P.charCodeAt(zt),Ne===A?(Fe(We,pn),Tt=null):a(Ne)?Tt=null:Fe(We,pn)):Fe(We,pn))),de=Tt):(ye||Fe($,pn),de=parseInt(Oe,I[At]),V(de)?(Fe(G,pn),de=l(N)):de in t?(Fe(H,pn),de=t[de]):(St="",j(de)&&Fe(H,pn),de>65535&&(de-=65536,St+=l(de>>>10|55296),de=56320|de&1023),de=St+l(de))):At!==C&&Fe(W,pn)),de?(Jt(),wt=ir(),J=zt-1,ke+=zt-et+1,se.push(de),Ht=ir(),Ht.offset++,ce&&ce.call(Te,de,{start:wt,end:Ht},P.slice(et-1,zt)),wt=Ht):(Oe=P.slice(et-1,zt),Ee+=Oe,ke+=Oe.length,J=zt-1)}else ee===10&&(he++,pe++,ke=0),ee===ee?(Ee+=l(ee),ke++):Jt();return se.join("");function ir(){return{line:he,column:ke,offset:J+(xe.offset||0)}}function Vr(pa,Xe){var yt=ir();yt.column+=Xe,yt.offset+=Xe,Re.call(ne,z[pa],yt,pa)}function Jt(){Ee&&(se.push(Ee),ae&&ae.call(ie,Ee,{start:wt,end:ir()}),Ee="")}}function V(P){return P>=55296&&P<=57343||P>1114111}function j(P){return P>=1&&P<=8||P===11||P>=13&&P<=31||P>=127&&P<=159||P>=64976&&P<=65007||(P&65535)===65535||(P&65535)===65534}return oy}var iy={exports:{}},OD;function qme(){return OD||(OD=1,function(e){var t=typeof window<"u"?window:typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope?self:{};/**
 * Prism: Lightweight, robust, elegant syntax highlighting
 *
 * @license MIT <https://opensource.org/licenses/MIT>
 * @author Lea Verou <https://lea.verou.me>
 * @namespace
 * @public
 */var n=function(r){var a=/(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i,o=0,s={},l={manual:r.Prism&&r.Prism.manual,disableWorkerMessageHandler:r.Prism&&r.Prism.disableWorkerMessageHandler,util:{encode:function x(R){return R instanceof u?new u(R.type,x(R.content),R.alias):Array.isArray(R)?R.map(x):R.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/\u00a0/g," ")},type:function(x){return Object.prototype.toString.call(x).slice(8,-1)},objId:function(x){return x.__id||Object.defineProperty(x,"__id",{value:++o}),x.__id},clone:function x(R,O){O=O||{};var N,C;switch(l.util.type(R)){case"Object":if(C=l.util.objId(R),O[C])return O[C];N={},O[C]=N;for(var _ in R)R.hasOwnProperty(_)&&(N[_]=x(R[_],O));return N;case"Array":return C=l.util.objId(R),O[C]?O[C]:(N=[],O[C]=N,R.forEach(function(M,I){N[I]=x(M,O)}),N);default:return R}},getLanguage:function(x){for(;x;){var R=a.exec(x.className);if(R)return R[1].toLowerCase();x=x.parentElement}return"none"},setLanguage:function(x,R){x.className=x.className.replace(RegExp(a,"gi"),""),x.classList.add("language-"+R)},currentScript:function(){if(typeof document>"u")return null;if("currentScript"in document)return document.currentScript;try{throw new Error}catch(N){var x=(/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(N.stack)||[])[1];if(x){var R=document.getElementsByTagName("script");for(var O in R)if(R[O].src==x)return R[O]}return null}},isActive:function(x,R,O){for(var N="no-"+R;x;){var C=x.classList;if(C.contains(R))return!0;if(C.contains(N))return!1;x=x.parentElement}return!!O}},languages:{plain:s,plaintext:s,text:s,txt:s,extend:function(x,R){var O=l.util.clone(l.languages[x]);for(var N in R)O[N]=R[N];return O},insertBefore:function(x,R,O,N){N=N||l.languages;var C=N[x],_={};for(var M in C)if(C.hasOwnProperty(M)){if(M==R)for(var I in O)O.hasOwnProperty(I)&&(_[I]=O[I]);O.hasOwnProperty(M)||(_[M]=C[M])}var D=N[x];return N[x]=_,l.languages.DFS(l.languages,function(U,$){$===D&&U!=x&&(this[U]=_)}),_},DFS:function x(R,O,N,C){C=C||{};var _=l.util.objId;for(var M in R)if(R.hasOwnProperty(M)){O.call(R,M,R[M],N||M);var I=R[M],D=l.util.type(I);D==="Object"&&!C[_(I)]?(C[_(I)]=!0,x(I,O,null,C)):D==="Array"&&!C[_(I)]&&(C[_(I)]=!0,x(I,O,M,C))}}},plugins:{},highlightAll:function(x,R){l.highlightAllUnder(document,x,R)},highlightAllUnder:function(x,R,O){var N={callback:O,container:x,selector:'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'};l.hooks.run("before-highlightall",N),N.elements=Array.prototype.slice.apply(N.container.querySelectorAll(N.selector)),l.hooks.run("before-all-elements-highlight",N);for(var C=0,_;_=N.elements[C++];)l.highlightElement(_,R===!0,N.callback)},highlightElement:function(x,R,O){var N=l.util.getLanguage(x),C=l.languages[N];l.util.setLanguage(x,N);var _=x.parentElement;_&&_.nodeName.toLowerCase()==="pre"&&l.util.setLanguage(_,N);var M=x.textContent,I={element:x,language:N,grammar:C,code:M};function D($){I.highlightedCode=$,l.hooks.run("before-insert",I),I.element.innerHTML=I.highlightedCode,l.hooks.run("after-highlight",I),l.hooks.run("complete",I),O&&O.call(I.element)}if(l.hooks.run("before-sanity-check",I),_=I.element.parentElement,_&&_.nodeName.toLowerCase()==="pre"&&!_.hasAttribute("tabindex")&&_.setAttribute("tabindex","0"),!I.code){l.hooks.run("complete",I),O&&O.call(I.element);return}if(l.hooks.run("before-highlight",I),!I.grammar){D(l.util.encode(I.code));return}if(R&&r.Worker){var U=new Worker(l.filename);U.onmessage=function($){D($.data)},U.postMessage(JSON.stringify({language:I.language,code:I.code,immediateClose:!0}))}else D(l.highlight(I.code,I.grammar,I.language))},highlight:function(x,R,O){var N={code:x,grammar:R,language:O};if(l.hooks.run("before-tokenize",N),!N.grammar)throw new Error('The language "'+N.language+'" has no grammar.');return N.tokens=l.tokenize(N.code,N.grammar),l.hooks.run("after-tokenize",N),u.stringify(l.util.encode(N.tokens),N.language)},tokenize:function(x,R){var O=R.rest;if(O){for(var N in O)R[N]=O[N];delete R.rest}var C=new g;return m(C,C.head,x),p(x,C,R,C.head,0),v(C)},hooks:{all:{},add:function(x,R){var O=l.hooks.all;O[x]=O[x]||[],O[x].push(R)},run:function(x,R){var O=l.hooks.all[x];if(!(!O||!O.length))for(var N=0,C;C=O[N++];)C(R)}},Token:u};r.Prism=l;function u(x,R,O,N){this.type=x,this.content=R,this.alias=O,this.length=(N||"").length|0}u.stringify=function x(R,O){if(typeof R=="string")return R;if(Array.isArray(R)){var N="";return R.forEach(function(D){N+=x(D,O)}),N}var C={type:R.type,content:x(R.content,O),tag:"span",classes:["token",R.type],attributes:{},language:O},_=R.alias;_&&(Array.isArray(_)?Array.prototype.push.apply(C.classes,_):C.classes.push(_)),l.hooks.run("wrap",C);var M="";for(var I in C.attributes)M+=" "+I+'="'+(C.attributes[I]||"").replace(/"/g,"&quot;")+'"';return"<"+C.tag+' class="'+C.classes.join(" ")+'"'+M+">"+C.content+"</"+C.tag+">"};function d(x,R,O,N){x.lastIndex=R;var C=x.exec(O);if(C&&N&&C[1]){var _=C[1].length;C.index+=_,C[0]=C[0].slice(_)}return C}function p(x,R,O,N,C,_){for(var M in O)if(!(!O.hasOwnProperty(M)||!O[M])){var I=O[M];I=Array.isArray(I)?I:[I];for(var D=0;D<I.length;++D){if(_&&_.cause==M+","+D)return;var U=I[D],$=U.inside,B=!!U.lookbehind,W=!!U.greedy,K=U.alias;if(W&&!U.pattern.global){var H=U.pattern.toString().match(/[imsuy]*$/)[0];U.pattern=RegExp(U.pattern.source,H+"g")}for(var G=U.pattern||U,z=N.next,Y=C;z!==R.tail&&!(_&&Y>=_.reach);Y+=z.value.length,z=z.next){var L=z.value;if(R.length>x.length)return;if(!(L instanceof u)){var V=1,j;if(W){if(j=d(G,Y,x,B),!j||j.index>=x.length)break;var oe=j.index,P=j.index+j[0].length,Z=Y;for(Z+=z.value.length;oe>=Z;)z=z.next,Z+=z.value.length;if(Z-=z.value.length,Y=Z,z.value instanceof u)continue;for(var Q=z;Q!==R.tail&&(Z<P||typeof Q.value=="string");Q=Q.next)V++,Z+=Q.value.length;V--,L=x.slice(Y,Z),j.index-=Y}else if(j=d(G,0,L,B),!j)continue;var oe=j.index,ae=j[0],ce=L.slice(0,oe),Re=L.slice(oe+ae.length),ie=Y+L.length;_&&ie>_.reach&&(_.reach=ie);var Te=z.prev;ce&&(Te=m(R,Te,ce),Y+=ce.length),b(R,Te,V);var ne=new u(M,$?l.tokenize(ae,$):ae,K,ae);if(z=m(R,Te,ne),Re&&m(R,z,Re),V>1){var xe={cause:M+","+D,reach:ie};p(x,R,O,z.prev,Y,xe),_&&xe.reach>_.reach&&(_.reach=xe.reach)}}}}}}function g(){var x={value:null,prev:null,next:null},R={value:null,prev:x,next:null};x.next=R,this.head=x,this.tail=R,this.length=0}function m(x,R,O){var N=R.next,C={value:O,prev:R,next:N};return R.next=C,N.prev=C,x.length++,C}function b(x,R,O){for(var N=R.next,C=0;C<O&&N!==x.tail;C++)N=N.next;R.next=N,N.prev=R,x.length-=C}function v(x){for(var R=[],O=x.head.next;O!==x.tail;)R.push(O.value),O=O.next;return R}if(!r.document)return r.addEventListener&&(l.disableWorkerMessageHandler||r.addEventListener("message",function(x){var R=JSON.parse(x.data),O=R.language,N=R.code,C=R.immediateClose;r.postMessage(l.highlight(N,l.languages[O],O)),C&&r.close()},!1)),l;var y=l.util.currentScript();y&&(l.filename=y.src,y.hasAttribute("data-manual")&&(l.manual=!0));function k(){l.manual||l.highlightAll()}if(!l.manual){var A=document.readyState;A==="loading"||A==="interactive"&&y&&y.defer?document.addEventListener("DOMContentLoaded",k):window.requestAnimationFrame?window.requestAnimationFrame(k):window.setTimeout(k,16)}return l}(t);e.exports&&(e.exports=n),typeof gf<"u"&&(gf.Prism=n)}(iy)),iy.exports}var sy,ID;function Vme(){if(ID)return sy;ID=1,sy=e,e.displayName="markup",e.aliases=["html","mathml","svg","xml","ssml","atom","rss"];function e(t){t.languages.markup={comment:{pattern:/<!--(?:(?!<!--)[\s\S])*?-->/,greedy:!0},prolog:{pattern:/<\?[\s\S]+?\?>/,greedy:!0},doctype:{pattern:/<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,greedy:!0,inside:{"internal-subset":{pattern:/(^[^\[]*\[)[\s\S]+(?=\]>$)/,lookbehind:!0,greedy:!0,inside:null},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},punctuation:/^<!|>$|[[\]]/,"doctype-tag":/^DOCTYPE/i,name:/[^\s<>'"]+/}},cdata:{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,greedy:!0},tag:{pattern:/<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,greedy:!0,inside:{tag:{pattern:/^<\/?[^\s>\/]+/,inside:{punctuation:/^<\/?/,namespace:/^[^\s>\/:]+:/}},"special-attr":[],"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,inside:{punctuation:[{pattern:/^=/,alias:"attr-equals"},/"|'/]}},punctuation:/\/?>/,"attr-name":{pattern:/[^\s>\/]+/,inside:{namespace:/^[^\s>\/:]+:/}}}},entity:[{pattern:/&[\da-z]{1,8};/i,alias:"named-entity"},/&#x?[\da-f]{1,8};/i]},t.languages.markup.tag.inside["attr-value"].inside.entity=t.languages.markup.entity,t.languages.markup.doctype.inside["internal-subset"].inside=t.languages.markup,t.hooks.add("wrap",function(n){n.type==="entity"&&(n.attributes.title=n.content.value.replace(/&amp;/,"&"))}),Object.defineProperty(t.languages.markup.tag,"addInlined",{value:function(r,a){var o={};o["language-"+a]={pattern:/(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,lookbehind:!0,inside:t.languages[a]},o.cdata=/^<!\[CDATA\[|\]\]>$/i;var s={"included-cdata":{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,inside:o}};s["language-"+a]={pattern:/[\s\S]+/,inside:t.languages[a]};var l={};l[r]={pattern:RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g,function(){return r}),"i"),lookbehind:!0,greedy:!0,inside:s},t.languages.insertBefore("markup","cdata",l)}}),Object.defineProperty(t.languages.markup.tag,"addAttribute",{value:function(n,r){t.languages.markup.tag.inside["special-attr"].push({pattern:RegExp(/(^|["'\s])/.source+"(?:"+n+")"+/\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,"i"),lookbehind:!0,inside:{"attr-name":/^[^\s=]+/,"attr-value":{pattern:/=[\s\S]+/,inside:{value:{pattern:/(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,lookbehind:!0,alias:[r,"language-"+r],inside:t.languages[r]},punctuation:[{pattern:/^=/,alias:"attr-equals"},/"|'/]}}}})}}),t.languages.html=t.languages.markup,t.languages.mathml=t.languages.markup,t.languages.svg=t.languages.markup,t.languages.xml=t.languages.extend("markup",{}),t.languages.ssml=t.languages.xml,t.languages.atom=t.languages.xml,t.languages.rss=t.languages.xml}return sy}var ly,DD;function Wme(){if(DD)return ly;DD=1,ly=e,e.displayName="css",e.aliases=[];function e(t){(function(n){var r=/(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;n.languages.css={comment:/\/\*[\s\S]*?\*\//,atrule:{pattern:/@[\w-](?:[^;{\s]|\s+(?![\s{]))*(?:;|(?=\s*\{))/,inside:{rule:/^@[\w-]+/,"selector-function-argument":{pattern:/(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,lookbehind:!0,alias:"selector"},keyword:{pattern:/(^|[^\w-])(?:and|not|only|or)(?![\w-])/,lookbehind:!0}}},url:{pattern:RegExp("\\burl\\((?:"+r.source+"|"+/(?:[^\\\r\n()"']|\\[\s\S])*/.source+")\\)","i"),greedy:!0,inside:{function:/^url/i,punctuation:/^\(|\)$/,string:{pattern:RegExp("^"+r.source+"$"),alias:"url"}}},selector:{pattern:RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|`+r.source+")*(?=\\s*\\{)"),lookbehind:!0},string:{pattern:r,greedy:!0},property:{pattern:/(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,lookbehind:!0},important:/!important\b/i,function:{pattern:/(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,lookbehind:!0},punctuation:/[(){};:,]/},n.languages.css.atrule.inside.rest=n.languages.css;var a=n.languages.markup;a&&(a.tag.addInlined("style","css"),a.tag.addAttribute("style","css"))})(t)}return ly}var cy,LD;function Yme(){if(LD)return cy;LD=1,cy=e,e.displayName="clike",e.aliases=[];function e(t){t.languages.clike={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},"class-name":{pattern:/(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,lookbehind:!0,inside:{punctuation:/[.\\]/}},keyword:/\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,boolean:/\b(?:false|true)\b/,function:/\b\w+(?=\()/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,operator:/[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,punctuation:/[{}[\];(),.:]/}}return cy}var uy,MD;function Kme(){if(MD)return uy;MD=1,uy=e,e.displayName="javascript",e.aliases=["js"];function e(t){t.languages.javascript=t.languages.extend("clike",{"class-name":[t.languages.clike["class-name"],{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,lookbehind:!0}],keyword:[{pattern:/((?:^|\})\s*)catch\b/,lookbehind:!0},{pattern:/(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,lookbehind:!0}],function:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,number:{pattern:RegExp(/(^|[^\w$])/.source+"(?:"+(/NaN|Infinity/.source+"|"+/0[bB][01]+(?:_[01]+)*n?/.source+"|"+/0[oO][0-7]+(?:_[0-7]+)*n?/.source+"|"+/0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source+"|"+/\d+(?:_\d+)*n/.source+"|"+/(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source)+")"+/(?![\w$])/.source),lookbehind:!0},operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/}),t.languages.javascript["class-name"][0].pattern=/(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/,t.languages.insertBefore("javascript","keyword",{regex:{pattern:/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)\/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/,lookbehind:!0,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:t.languages.regex},"regex-delimiter":/^\/|\/$/,"regex-flags":/^[a-z]+$/}},"function-variable":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"},parameter:[{pattern:/(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,lookbehind:!0,inside:t.languages.javascript},{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,lookbehind:!0,inside:t.languages.javascript},{pattern:/(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,lookbehind:!0,inside:t.languages.javascript},{pattern:/((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,lookbehind:!0,inside:t.languages.javascript}],constant:/\b[A-Z](?:[A-Z_]|\dx?)*\b/}),t.languages.insertBefore("javascript","string",{hashbang:{pattern:/^#!.*/,greedy:!0,alias:"comment"},"template-string":{pattern:/`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:t.languages.javascript}},string:/[\s\S]+/}},"string-property":{pattern:/((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,lookbehind:!0,greedy:!0,alias:"property"}}),t.languages.insertBefore("javascript","operator",{"literal-property":{pattern:/((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,lookbehind:!0,alias:"property"}}),t.languages.markup&&(t.languages.markup.tag.addInlined("script","javascript"),t.languages.markup.tag.addAttribute(/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,"javascript")),t.languages.js=t.languages.javascript}return uy}var dy,PD;function Xme(){if(PD)return dy;PD=1;var e=typeof globalThis=="object"?globalThis:typeof self=="object"?self:typeof window=="object"?window:typeof gf=="object"?gf:{},t=N();e.Prism={manual:!0,disableWorkerMessageHandler:!0};var n=Bge(),r=$me(),a=qme(),o=Vme(),s=Wme(),l=Yme(),u=Kme();t();var d={}.hasOwnProperty;function p(){}p.prototype=a;var g=new p;dy=g,g.highlight=v,g.register=m,g.alias=b,g.registered=y,g.listLanguages=k,m(o),m(s),m(l),m(u),g.util.encode=R,g.Token.stringify=A;function m(C){if(typeof C!="function"||!C.displayName)throw new Error("Expected `function` for `grammar`, got `"+C+"`");g.languages[C.displayName]===void 0&&C(g)}function b(C,_){var M=g.languages,I=C,D,U,$,B;_&&(I={},I[C]=_);for(D in I)for(U=I[D],U=typeof U=="string"?[U]:U,$=U.length,B=-1;++B<$;)M[U[B]]=M[D]}function v(C,_){var M=a.highlight,I;if(typeof C!="string")throw new Error("Expected `string` for `value`, got `"+C+"`");if(g.util.type(_)==="Object")I=_,_=null;else{if(typeof _!="string")throw new Error("Expected `string` for `name`, got `"+_+"`");if(d.call(g.languages,_))I=g.languages[_];else throw new Error("Unknown language: `"+_+"` is not registered")}return M.call(this,C,I,_)}function y(C){if(typeof C!="string")throw new Error("Expected `string` for `language`, got `"+C+"`");return d.call(g.languages,C)}function k(){var C=g.languages,_=[],M;for(M in C)d.call(C,M)&&typeof C[M]=="object"&&_.push(M);return _}function A(C,_,M){var I;return typeof C=="string"?{type:"text",value:C}:g.util.type(C)==="Array"?x(C,_):(I={type:C.type,content:g.Token.stringify(C.content,_,M),tag:"span",classes:["token",C.type],attributes:{},language:_,parent:M},C.alias&&(I.classes=I.classes.concat(C.alias)),g.hooks.run("wrap",I),n(I.tag+"."+I.classes.join("."),O(I.attributes),I.content))}function x(C,_){for(var M=[],I=C.length,D=-1,U;++D<I;)U=C[D],U!==""&&U!==null&&U!==void 0&&M.push(U);for(D=-1,I=M.length;++D<I;)U=M[D],M[D]=g.Token.stringify(U,_,M);return M}function R(C){return C}function O(C){var _;for(_ in C)C[_]=r(C[_]);return C}function N(){var C="Prism"in e,_=C?e.Prism:void 0;return M;function M(){C?e.Prism=_:delete e.Prism,C=void 0,_=void 0}}return dy}const Zme={'code[class*="language-"]':{color:"black",background:"none",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"black",background:"#f5f2f0",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},':not(pre) > code[class*="language-"]':{background:"#f5f2f0",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"slategray"},prolog:{color:"slategray"},doctype:{color:"slategray"},cdata:{color:"slategray"},punctuation:{color:"#999"},namespace:{Opacity:".7"},property:{color:"#905"},tag:{color:"#905"},boolean:{color:"#905"},number:{color:"#905"},constant:{color:"#905"},symbol:{color:"#905"},deleted:{color:"#905"},selector:{color:"#690"},"attr-name":{color:"#690"},string:{color:"#690"},char:{color:"#690"},builtin:{color:"#690"},inserted:{color:"#690"},operator:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},entity:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)",cursor:"help"},url:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".language-css .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".style .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},atrule:{color:"#07a"},"attr-value":{color:"#07a"},keyword:{color:"#07a"},function:{color:"#DD4A68"},"class-name":{color:"#DD4A68"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"bold"},variable:{color:"#e90"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}};var fy,FD;function Qme(){if(FD)return fy;FD=1,fy=e,e.displayName="abap",e.aliases=[];function e(t){t.languages.abap={comment:/^\*.*/m,string:/(`|')(?:\\.|(?!\1)[^\\\r\n])*\1/,"string-template":{pattern:/([|}])(?:\\.|[^\\|{\r\n])*(?=[|{])/,lookbehind:!0,alias:"string"},"eol-comment":{pattern:/(^|\s)".*/m,lookbehind:!0,alias:"comment"},keyword:{pattern:/(\s|\.|^)(?:SCIENTIFIC_WITH_LEADING_ZERO|SCALE_PRESERVING_SCIENTIFIC|RMC_COMMUNICATION_FAILURE|END-ENHANCEMENT-SECTION|MULTIPLY-CORRESPONDING|SUBTRACT-CORRESPONDING|VERIFICATION-MESSAGE|DIVIDE-CORRESPONDING|ENHANCEMENT-SECTION|CURRENCY_CONVERSION|RMC_SYSTEM_FAILURE|START-OF-SELECTION|MOVE-CORRESPONDING|RMC_INVALID_STATUS|CUSTOMER-FUNCTION|END-OF-DEFINITION|ENHANCEMENT-POINT|SYSTEM-EXCEPTIONS|ADD-CORRESPONDING|SCALE_PRESERVING|SELECTION-SCREEN|CURSOR-SELECTION|END-OF-SELECTION|LOAD-OF-PROGRAM|SCROLL-BOUNDARY|SELECTION-TABLE|EXCEPTION-TABLE|IMPLEMENTATIONS|PARAMETER-TABLE|RIGHT-JUSTIFIED|UNIT_CONVERSION|AUTHORITY-CHECK|LIST-PROCESSING|SIGN_AS_POSTFIX|COL_BACKGROUND|IMPLEMENTATION|INTERFACE-POOL|TRANSFORMATION|IDENTIFICATION|ENDENHANCEMENT|LINE-SELECTION|INITIALIZATION|LEFT-JUSTIFIED|SELECT-OPTIONS|SELECTION-SETS|COMMUNICATION|CORRESPONDING|DECIMAL_SHIFT|PRINT-CONTROL|VALUE-REQUEST|CHAIN-REQUEST|FUNCTION-POOL|FIELD-SYMBOLS|FUNCTIONALITY|INVERTED-DATE|SELECTION-SET|CLASS-METHODS|OUTPUT-LENGTH|CLASS-CODING|COL_NEGATIVE|ERRORMESSAGE|FIELD-GROUPS|HELP-REQUEST|NO-EXTENSION|NO-TOPOFPAGE|REDEFINITION|DISPLAY-MODE|ENDINTERFACE|EXIT-COMMAND|FIELD-SYMBOL|NO-SCROLLING|SHORTDUMP-ID|ACCESSPOLICY|CLASS-EVENTS|COL_POSITIVE|DECLARATIONS|ENHANCEMENTS|FILTER-TABLE|SWITCHSTATES|SYNTAX-CHECK|TRANSPORTING|ASYNCHRONOUS|SYNTAX-TRACE|TOKENIZATION|USER-COMMAND|WITH-HEADING|ABAP-SOURCE|BREAK-POINT|CHAIN-INPUT|COMPRESSION|FIXED-POINT|NEW-SECTION|NON-UNICODE|OCCURRENCES|RESPONSIBLE|SYSTEM-CALL|TRACE-TABLE|ABBREVIATED|CHAR-TO-HEX|END-OF-FILE|ENDFUNCTION|ENVIRONMENT|ASSOCIATION|COL_HEADING|EDITOR-CALL|END-OF-PAGE|ENGINEERING|IMPLEMENTED|INTENSIFIED|RADIOBUTTON|SYSTEM-EXIT|TOP-OF-PAGE|TRANSACTION|APPLICATION|CONCATENATE|DESTINATION|ENHANCEMENT|IMMEDIATELY|NO-GROUPING|PRECOMPILED|REPLACEMENT|TITLE-LINES|ACTIVATION|BYTE-ORDER|CLASS-POOL|CONNECTION|CONVERSION|DEFINITION|DEPARTMENT|EXPIRATION|INHERITING|MESSAGE-ID|NO-HEADING|PERFORMING|QUEUE-ONLY|RIGHTSPACE|SCIENTIFIC|STATUSINFO|STRUCTURES|SYNCPOINTS|WITH-TITLE|ATTRIBUTES|BOUNDARIES|CLASS-DATA|COL_NORMAL|DD\/MM\/YYYY|DESCENDING|INTERFACES|LINE-COUNT|MM\/DD\/YYYY|NON-UNIQUE|PRESERVING|SELECTIONS|STATEMENTS|SUBROUTINE|TRUNCATION|TYPE-POOLS|ARITHMETIC|BACKGROUND|ENDPROVIDE|EXCEPTIONS|IDENTIFIER|INDEX-LINE|OBLIGATORY|PARAMETERS|PERCENTAGE|PUSHBUTTON|RESOLUTION|COMPONENTS|DEALLOCATE|DISCONNECT|DUPLICATES|FIRST-LINE|HEAD-LINES|NO-DISPLAY|OCCURRENCE|RESPECTING|RETURNCODE|SUBMATCHES|TRACE-FILE|ASCENDING|BYPASSING|ENDMODULE|EXCEPTION|EXCLUDING|EXPORTING|INCREMENT|MATCHCODE|PARAMETER|PARTIALLY|PREFERRED|REFERENCE|REPLACING|RETURNING|SELECTION|SEPARATED|SPECIFIED|STATEMENT|TIMESTAMP|TYPE-POOL|ACCEPTING|APPENDAGE|ASSIGNING|COL_GROUP|COMPARING|CONSTANTS|DANGEROUS|IMPORTING|INSTANCES|LEFTSPACE|LOG-POINT|QUICKINFO|READ-ONLY|SCROLLING|SQLSCRIPT|STEP-LOOP|TOP-LINES|TRANSLATE|APPENDING|AUTHORITY|CHARACTER|COMPONENT|CONDITION|DIRECTORY|DUPLICATE|MESSAGING|RECEIVING|SUBSCREEN|ACCORDING|COL_TOTAL|END-LINES|ENDMETHOD|ENDSELECT|EXPANDING|EXTENSION|INCLUDING|INFOTYPES|INTERFACE|INTERVALS|LINE-SIZE|PF-STATUS|PROCEDURE|PROTECTED|REQUESTED|RESUMABLE|RIGHTPLUS|SAP-SPOOL|SECONDARY|STRUCTURE|SUBSTRING|TABLEVIEW|NUMOFCHAR|ADJACENT|ANALYSIS|ASSIGNED|BACKWARD|CHANNELS|CHECKBOX|CONTINUE|CRITICAL|DATAINFO|DD\/MM\/YY|DURATION|ENCODING|ENDCLASS|FUNCTION|LEFTPLUS|LINEFEED|MM\/DD\/YY|OVERFLOW|RECEIVED|SKIPPING|SORTABLE|STANDARD|SUBTRACT|SUPPRESS|TABSTRIP|TITLEBAR|TRUNCATE|UNASSIGN|WHENEVER|ANALYZER|COALESCE|COMMENTS|CONDENSE|DECIMALS|DEFERRED|ENDWHILE|EXPLICIT|KEYWORDS|MESSAGES|POSITION|PRIORITY|RECEIVER|RENAMING|TIMEZONE|TRAILING|ALLOCATE|CENTERED|CIRCULAR|CONTROLS|CURRENCY|DELETING|DESCRIBE|DISTANCE|ENDCATCH|EXPONENT|EXTENDED|GENERATE|IGNORING|INCLUDES|INTERNAL|MAJOR-ID|MODIFIER|NEW-LINE|OPTIONAL|PROPERTY|ROLLBACK|STARTING|SUPPLIED|ABSTRACT|CHANGING|CONTEXTS|CREATING|CUSTOMER|DATABASE|DAYLIGHT|DEFINING|DISTINCT|DIVISION|ENABLING|ENDCHAIN|ESCAPING|HARMLESS|IMPLICIT|INACTIVE|LANGUAGE|MINOR-ID|MULTIPLY|NEW-PAGE|NO-TITLE|POS_HIGH|SEPARATE|TEXTPOOL|TRANSFER|SELECTOR|DBMAXLEN|ITERATOR|ARCHIVE|BIT-XOR|BYTE-CO|COLLECT|COMMENT|CURRENT|DEFAULT|DISPLAY|ENDFORM|EXTRACT|LEADING|LISTBOX|LOCATOR|MEMBERS|METHODS|NESTING|POS_LOW|PROCESS|PROVIDE|RAISING|RESERVE|SECONDS|SUMMARY|VISIBLE|BETWEEN|BIT-AND|BYTE-CS|CLEANUP|COMPUTE|CONTROL|CONVERT|DATASET|ENDCASE|FORWARD|HEADERS|HOTSPOT|INCLUDE|INVERSE|KEEPING|NO-ZERO|OBJECTS|OVERLAY|PADDING|PATTERN|PROGRAM|REFRESH|SECTION|SUMMING|TESTING|VERSION|WINDOWS|WITHOUT|BIT-NOT|BYTE-CA|BYTE-NA|CASTING|CONTEXT|COUNTRY|DYNAMIC|ENABLED|ENDLOOP|EXECUTE|FRIENDS|HANDLER|HEADING|INITIAL|\*-INPUT|LOGFILE|MAXIMUM|MINIMUM|NO-GAPS|NO-SIGN|PRAGMAS|PRIMARY|PRIVATE|REDUCED|REPLACE|REQUEST|RESULTS|UNICODE|WARNING|ALIASES|BYTE-CN|BYTE-NS|CALLING|COL_KEY|COLUMNS|CONNECT|ENDEXEC|ENTRIES|EXCLUDE|FILTERS|FURTHER|HELP-ID|LOGICAL|MAPPING|MESSAGE|NAMETAB|OPTIONS|PACKAGE|PERFORM|RECEIVE|STATICS|VARYING|BINDING|CHARLEN|GREATER|XSTRLEN|ACCEPT|APPEND|DETAIL|ELSEIF|ENDING|ENDTRY|FORMAT|FRAMES|GIVING|HASHED|HEADER|IMPORT|INSERT|MARGIN|MODULE|NATIVE|OBJECT|OFFSET|REMOTE|RESUME|SAVING|SIMPLE|SUBMIT|TABBED|TOKENS|UNIQUE|UNPACK|UPDATE|WINDOW|YELLOW|ACTUAL|ASPECT|CENTER|CURSOR|DELETE|DIALOG|DIVIDE|DURING|ERRORS|EVENTS|EXTEND|FILTER|HANDLE|HAVING|IGNORE|LITTLE|MEMORY|NO-GAP|OCCURS|OPTION|PERSON|PLACES|PUBLIC|REDUCE|REPORT|RESULT|SINGLE|SORTED|SWITCH|SYNTAX|TARGET|VALUES|WRITER|ASSERT|BLOCKS|BOUNDS|BUFFER|CHANGE|COLUMN|COMMIT|CONCAT|COPIES|CREATE|DDMMYY|DEFINE|ENDIAN|ESCAPE|EXPAND|KERNEL|LAYOUT|LEGACY|LEVELS|MMDDYY|NUMBER|OUTPUT|RANGES|READER|RETURN|SCREEN|SEARCH|SELECT|SHARED|SOURCE|STABLE|STATIC|SUBKEY|SUFFIX|TABLES|UNWIND|YYMMDD|ASSIGN|BACKUP|BEFORE|BINARY|BIT-OR|BLANKS|CLIENT|CODING|COMMON|DEMAND|DYNPRO|EXCEPT|EXISTS|EXPORT|FIELDS|GLOBAL|GROUPS|LENGTH|LOCALE|MEDIUM|METHOD|MODIFY|NESTED|OTHERS|REJECT|SCROLL|SUPPLY|SYMBOL|ENDFOR|STRLEN|ALIGN|BEGIN|BOUND|ENDAT|ENTRY|EVENT|FINAL|FLUSH|GRANT|INNER|SHORT|USING|WRITE|AFTER|BLACK|BLOCK|CLOCK|COLOR|COUNT|DUMMY|EMPTY|ENDDO|ENDON|GREEN|INDEX|INOUT|LEAVE|LEVEL|LINES|MODIF|ORDER|OUTER|RANGE|RESET|RETRY|RIGHT|SMART|SPLIT|STYLE|TABLE|THROW|UNDER|UNTIL|UPPER|UTF-8|WHERE|ALIAS|BLANK|CLEAR|CLOSE|EXACT|FETCH|FIRST|FOUND|GROUP|LLANG|LOCAL|OTHER|REGEX|SPOOL|TITLE|TYPES|VALID|WHILE|ALPHA|BOXED|CATCH|CHAIN|CHECK|CLASS|COVER|ENDIF|EQUIV|FIELD|FLOOR|FRAME|INPUT|LOWER|MATCH|NODES|PAGES|PRINT|RAISE|ROUND|SHIFT|SPACE|SPOTS|STAMP|STATE|TASKS|TIMES|TRMAC|ULINE|UNION|VALUE|WIDTH|EQUAL|LOG10|TRUNC|BLOB|CASE|CEIL|CLOB|COND|EXIT|FILE|GAPS|HOLD|INCL|INTO|KEEP|KEYS|LAST|LINE|LONG|LPAD|MAIL|MODE|OPEN|PINK|READ|ROWS|TEST|THEN|ZERO|AREA|BACK|BADI|BYTE|CAST|EDIT|EXEC|FAIL|FIND|FKEQ|FONT|FREE|GKEQ|HIDE|INIT|ITNO|LATE|LOOP|MAIN|MARK|MOVE|NEXT|NULL|RISK|ROLE|UNIT|WAIT|ZONE|BASE|CALL|CODE|DATA|DATE|FKGE|GKGE|HIGH|KIND|LEFT|LIST|MASK|MESH|NAME|NODE|PACK|PAGE|POOL|SEND|SIGN|SIZE|SOME|STOP|TASK|TEXT|TIME|USER|VARY|WITH|WORD|BLUE|CONV|COPY|DEEP|ELSE|FORM|FROM|HINT|ICON|JOIN|LIKE|LOAD|ONLY|PART|SCAN|SKIP|SORT|TYPE|UNIX|VIEW|WHEN|WORK|ACOS|ASIN|ATAN|COSH|EACH|FRAC|LESS|RTTI|SINH|SQRT|TANH|AVG|BIT|DIV|ISO|LET|OUT|PAD|SQL|ALL|CI_|CPI|END|LOB|LPI|MAX|MIN|NEW|OLE|RUN|SET|\?TO|YES|ABS|ADD|AND|BIG|FOR|HDB|JOB|LOW|NOT|SAP|TRY|VIA|XML|ANY|GET|IDS|KEY|MOD|OFF|PUT|RAW|RED|REF|SUM|TAB|XSD|CNT|COS|EXP|LOG|SIN|TAN|XOR|AT|CO|CP|DO|GT|ID|IF|NS|OR|BT|CA|CS|GE|NA|NB|EQ|IN|LT|NE|NO|OF|ON|PF|TO|AS|BY|CN|IS|LE|NP|UP|E|I|M|O|Z|C|X)\b/i,lookbehind:!0},number:/\b\d+\b/,operator:{pattern:/(\s)(?:\*\*?|<[=>]?|>=?|\?=|[-+\/=])(?=\s)/,lookbehind:!0},"string-operator":{pattern:/(\s)&&?(?=\s)/,lookbehind:!0,alias:"keyword"},"token-operator":[{pattern:/(\w)(?:->?|=>|[~|{}])(?=\w)/,lookbehind:!0,alias:"punctuation"},{pattern:/[|{}]/,alias:"punctuation"}],punctuation:/[,.:()]/}}return fy}var py,zD;function Jme(){if(zD)return py;zD=1,py=e,e.displayName="abnf",e.aliases=[];function e(t){(function(n){var r="(?:ALPHA|BIT|CHAR|CR|CRLF|CTL|DIGIT|DQUOTE|HEXDIG|HTAB|LF|LWSP|OCTET|SP|VCHAR|WSP)";n.languages.abnf={comment:/;.*/,string:{pattern:/(?:%[is])?"[^"\n\r]*"/,greedy:!0,inside:{punctuation:/^%[is]/}},range:{pattern:/%(?:b[01]+-[01]+|d\d+-\d+|x[A-F\d]+-[A-F\d]+)/i,alias:"number"},terminal:{pattern:/%(?:b[01]+(?:\.[01]+)*|d\d+(?:\.\d+)*|x[A-F\d]+(?:\.[A-F\d]+)*)/i,alias:"number"},repetition:{pattern:/(^|[^\w-])(?:\d*\*\d*|\d+)/,lookbehind:!0,alias:"operator"},definition:{pattern:/(^[ \t]*)(?:[a-z][\w-]*|<[^<>\r\n]*>)(?=\s*=)/m,lookbehind:!0,alias:"keyword",inside:{punctuation:/<|>/}},"core-rule":{pattern:RegExp("(?:(^|[^<\\w-])"+r+"|<"+r+">)(?![\\w-])","i"),lookbehind:!0,alias:["rule","constant"],inside:{punctuation:/<|>/}},rule:{pattern:/(^|[^<\w-])[a-z][\w-]*|<[^<>\r\n]*>/i,lookbehind:!0,inside:{punctuation:/<|>/}},operator:/=\/?|\//,punctuation:/[()\[\]]/}})(t)}return py}var gy,BD;function ebe(){if(BD)return gy;BD=1,gy=e,e.displayName="actionscript",e.aliases=[];function e(t){t.languages.actionscript=t.languages.extend("javascript",{keyword:/\b(?:as|break|case|catch|class|const|default|delete|do|dynamic|each|else|extends|final|finally|for|function|get|if|implements|import|in|include|instanceof|interface|internal|is|namespace|native|new|null|override|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|use|var|void|while|with)\b/,operator:/\+\+|--|(?:[+\-*\/%^]|&&?|\|\|?|<<?|>>?>?|[!=]=?)=?|[~?@]/}),t.languages.actionscript["class-name"].alias="function",delete t.languages.actionscript.parameter,delete t.languages.actionscript["literal-property"],t.languages.markup&&t.languages.insertBefore("actionscript","string",{xml:{pattern:/(^|[^.])<\/?\w+(?:\s+[^\s>\/=]+=("|')(?:\\[\s\S]|(?!\2)[^\\])*\2)*\s*\/?>/,lookbehind:!0,inside:t.languages.markup}})}return gy}var hy,jD;function tbe(){if(jD)return hy;jD=1,hy=e,e.displayName="ada",e.aliases=[];function e(t){t.languages.ada={comment:/--.*/,string:/"(?:""|[^"\r\f\n])*"/,number:[{pattern:/\b\d(?:_?\d)*#[\dA-F](?:_?[\dA-F])*(?:\.[\dA-F](?:_?[\dA-F])*)?#(?:E[+-]?\d(?:_?\d)*)?/i},{pattern:/\b\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:E[+-]?\d(?:_?\d)*)?\b/i}],"attr-name":/\b'\w+/,keyword:/\b(?:abort|abs|abstract|accept|access|aliased|all|and|array|at|begin|body|case|constant|declare|delay|delta|digits|do|else|elsif|end|entry|exception|exit|for|function|generic|goto|if|in|interface|is|limited|loop|mod|new|not|null|of|others|out|overriding|package|pragma|private|procedure|protected|raise|range|record|rem|renames|requeue|return|reverse|select|separate|some|subtype|synchronized|tagged|task|terminate|then|type|until|use|when|while|with|xor)\b/i,boolean:/\b(?:false|true)\b/i,operator:/<[=>]?|>=?|=>?|:=|\/=?|\*\*?|[&+-]/,punctuation:/\.\.?|[,;():]/,char:/'.'/,variable:/\b[a-z](?:\w)*\b/i}}return hy}var my,UD;function nbe(){if(UD)return my;UD=1,my=e,e.displayName="agda",e.aliases=[];function e(t){(function(n){n.languages.agda={comment:/\{-[\s\S]*?(?:-\}|$)|--.*/,string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^\\\r\n"])*"/,greedy:!0},punctuation:/[(){}⦃⦄.;@]/,"class-name":{pattern:/((?:data|record) +)\S+/,lookbehind:!0},function:{pattern:/(^[ \t]*)(?!\s)[^:\r\n]+(?=:)/m,lookbehind:!0},operator:{pattern:/(^\s*|\s)(?:[=|:∀→λ\\?_]|->)(?=\s)/,lookbehind:!0},keyword:/\b(?:Set|abstract|constructor|data|eta-equality|field|forall|hiding|import|in|inductive|infix|infixl|infixr|instance|let|macro|module|mutual|no-eta-equality|open|overlap|pattern|postulate|primitive|private|public|quote|quoteContext|quoteGoal|quoteTerm|record|renaming|rewrite|syntax|tactic|unquote|unquoteDecl|unquoteDef|using|variable|where|with)\b/}})(t)}return my}var by,GD;function rbe(){if(GD)return by;GD=1,by=e,e.displayName="al",e.aliases=[];function e(t){t.languages.al={comment:/\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/'(?:''|[^'\r\n])*'(?!')|"(?:""|[^"\r\n])*"(?!")/,greedy:!0},function:{pattern:/(\b(?:event|procedure|trigger)\s+|(?:^|[^.])\.\s*)[a-z_]\w*(?=\s*\()/i,lookbehind:!0},keyword:[/\b(?:array|asserterror|begin|break|case|do|downto|else|end|event|exit|for|foreach|function|if|implements|in|indataset|interface|internal|local|of|procedure|program|protected|repeat|runonclient|securityfiltering|suppressdispose|temporary|then|to|trigger|until|var|while|with|withevents)\b/i,/\b(?:action|actions|addafter|addbefore|addfirst|addlast|area|assembly|chartpart|codeunit|column|controladdin|cuegroup|customizes|dataitem|dataset|dotnet|elements|enum|enumextension|extends|field|fieldattribute|fieldelement|fieldgroup|fieldgroups|fields|filter|fixed|grid|group|key|keys|label|labels|layout|modify|moveafter|movebefore|movefirst|movelast|page|pagecustomization|pageextension|part|profile|query|repeater|report|requestpage|schema|separator|systempart|table|tableelement|tableextension|textattribute|textelement|type|usercontrol|value|xmlport)\b/i],number:/\b(?:0x[\da-f]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?)(?:F|LL?|U(?:LL?)?)?\b/i,boolean:/\b(?:false|true)\b/i,variable:/\b(?:Curr(?:FieldNo|Page|Report)|x?Rec|RequestOptionsPage)\b/,"class-name":/\b(?:automation|biginteger|bigtext|blob|boolean|byte|char|clienttype|code|completiontriggererrorlevel|connectiontype|database|dataclassification|datascope|date|dateformula|datetime|decimal|defaultlayout|dialog|dictionary|dotnetassembly|dotnettypedeclaration|duration|errorinfo|errortype|executioncontext|executionmode|fieldclass|fieldref|fieldtype|file|filterpagebuilder|guid|httpclient|httpcontent|httpheaders|httprequestmessage|httpresponsemessage|instream|integer|joker|jsonarray|jsonobject|jsontoken|jsonvalue|keyref|list|moduledependencyinfo|moduleinfo|none|notification|notificationscope|objecttype|option|outstream|pageresult|record|recordid|recordref|reportformat|securityfilter|sessionsettings|tableconnectiontype|tablefilter|testaction|testfield|testfilterfield|testpage|testpermissions|testrequestpage|text|textbuilder|textconst|textencoding|time|transactionmodel|transactiontype|variant|verbosity|version|view|views|webserviceactioncontext|webserviceactionresultcode|xmlattribute|xmlattributecollection|xmlcdata|xmlcomment|xmldeclaration|xmldocument|xmldocumenttype|xmlelement|xmlnamespacemanager|xmlnametable|xmlnode|xmlnodelist|xmlprocessinginstruction|xmlreadoptions|xmltext|xmlwriteoptions)\b/i,operator:/\.\.|:[=:]|[-+*/]=?|<>|[<>]=?|=|\b(?:and|div|mod|not|or|xor)\b/i,punctuation:/[()\[\]{}:.;,]/}}return by}var yy,HD;function abe(){if(HD)return yy;HD=1,yy=e,e.displayName="antlr4",e.aliases=["g4"];function e(t){t.languages.antlr4={comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,string:{pattern:/'(?:\\.|[^\\'\r\n])*'/,greedy:!0},"character-class":{pattern:/\[(?:\\.|[^\\\]\r\n])*\]/,greedy:!0,alias:"regex",inside:{range:{pattern:/([^[]|(?:^|[^\\])(?:\\\\)*\\\[)-(?!\])/,lookbehind:!0,alias:"punctuation"},escape:/\\(?:u(?:[a-fA-F\d]{4}|\{[a-fA-F\d]+\})|[pP]\{[=\w-]+\}|[^\r\nupP])/,punctuation:/[\[\]]/}},action:{pattern:/\{(?:[^{}]|\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*\}/,greedy:!0,inside:{content:{pattern:/(\{)[\s\S]+(?=\})/,lookbehind:!0},punctuation:/[{}]/}},command:{pattern:/(->\s*(?!\s))(?:\s*(?:,\s*)?\b[a-z]\w*(?:\s*\([^()\r\n]*\))?)+(?=\s*;)/i,lookbehind:!0,inside:{function:/\b\w+(?=\s*(?:[,(]|$))/,punctuation:/[,()]/}},annotation:{pattern:/@\w+(?:::\w+)*/,alias:"keyword"},label:{pattern:/#[ \t]*\w+/,alias:"punctuation"},keyword:/\b(?:catch|channels|finally|fragment|grammar|import|lexer|locals|mode|options|parser|returns|throws|tokens)\b/,definition:[{pattern:/\b[a-z]\w*(?=\s*:)/,alias:["rule","class-name"]},{pattern:/\b[A-Z]\w*(?=\s*:)/,alias:["token","constant"]}],constant:/\b[A-Z][A-Z_]*\b/,operator:/\.\.|->|[|~]|[*+?]\??/,punctuation:/[;:()=]/},t.languages.g4=t.languages.antlr4}return yy}var vy,$D;function obe(){if($D)return vy;$D=1,vy=e,e.displayName="apacheconf",e.aliases=[];function e(t){t.languages.apacheconf={comment:/#.*/,"directive-inline":{pattern:/(^[\t ]*)\b(?:AcceptFilter|AcceptPathInfo|AccessFileName|Action|Add(?:Alt|AltByEncoding|AltByType|Charset|DefaultCharset|Description|Encoding|Handler|Icon|IconByEncoding|IconByType|InputFilter|Language|ModuleInfo|OutputFilter|OutputFilterByType|Type)|Alias|AliasMatch|Allow(?:CONNECT|EncodedSlashes|Methods|Override|OverrideList)?|Anonymous(?:_LogEmail|_MustGiveEmail|_NoUserID|_VerifyEmail)?|AsyncRequestWorkerFactor|Auth(?:BasicAuthoritative|BasicFake|BasicProvider|BasicUseDigestAlgorithm|DBDUserPWQuery|DBDUserRealmQuery|DBMGroupFile|DBMType|DBMUserFile|Digest(?:Algorithm|Domain|NonceLifetime|Provider|Qop|ShmemSize)|Form(?:Authoritative|Body|DisableNoStore|FakeBasicAuth|Location|LoginRequiredLocation|LoginSuccessLocation|LogoutLocation|Method|Mimetype|Password|Provider|SitePassphrase|Size|Username)|GroupFile|LDAP(?:AuthorizePrefix|BindAuthoritative|BindDN|BindPassword|CharsetConfig|CompareAsUser|CompareDNOnServer|DereferenceAliases|GroupAttribute|GroupAttributeIsDN|InitialBindAsUser|InitialBindPattern|MaxSubGroupDepth|RemoteUserAttribute|RemoteUserIsDN|SearchAsUser|SubGroupAttribute|SubGroupClass|Url)|Merging|Name|nCache(?:Context|Enable|ProvideFor|SOCache|Timeout)|nzFcgiCheckAuthnProvider|nzFcgiDefineProvider|Type|UserFile|zDBDLoginToReferer|zDBDQuery|zDBDRedirectQuery|zDBMType|zSendForbiddenOnFailure)|BalancerGrowth|BalancerInherit|BalancerMember|BalancerPersist|BrowserMatch|BrowserMatchNoCase|BufferedLogs|BufferSize|Cache(?:DefaultExpire|DetailHeader|DirLength|DirLevels|Disable|Enable|File|Header|IgnoreCacheControl|IgnoreHeaders|IgnoreNoLastMod|IgnoreQueryString|IgnoreURLSessionIdentifiers|KeyBaseURL|LastModifiedFactor|Lock|LockMaxAge|LockPath|MaxExpire|MaxFileSize|MinExpire|MinFileSize|NegotiatedDocs|QuickHandler|ReadSize|ReadTime|Root|Socache(?:MaxSize|MaxTime|MinTime|ReadSize|ReadTime)?|StaleOnError|StoreExpired|StoreNoStore|StorePrivate)|CGIDScriptTimeout|CGIMapExtension|CharsetDefault|CharsetOptions|CharsetSourceEnc|CheckCaseOnly|CheckSpelling|ChrootDir|ContentDigest|CookieDomain|CookieExpires|CookieName|CookieStyle|CookieTracking|CoreDumpDirectory|CustomLog|Dav|DavDepthInfinity|DavGenericLockDB|DavLockDB|DavMinTimeout|DBDExptime|DBDInitSQL|DBDKeep|DBDMax|DBDMin|DBDParams|DBDPersist|DBDPrepareSQL|DBDriver|DefaultIcon|DefaultLanguage|DefaultRuntimeDir|DefaultType|Define|Deflate(?:BufferSize|CompressionLevel|FilterNote|InflateLimitRequestBody|InflateRatio(?:Burst|Limit)|MemLevel|WindowSize)|Deny|DirectoryCheckHandler|DirectoryIndex|DirectoryIndexRedirect|DirectorySlash|DocumentRoot|DTracePrivileges|DumpIOInput|DumpIOOutput|EnableExceptionHook|EnableMMAP|EnableSendfile|Error|ErrorDocument|ErrorLog|ErrorLogFormat|Example|ExpiresActive|ExpiresByType|ExpiresDefault|ExtendedStatus|ExtFilterDefine|ExtFilterOptions|FallbackResource|FileETag|FilterChain|FilterDeclare|FilterProtocol|FilterProvider|FilterTrace|ForceLanguagePriority|ForceType|ForensicLog|GprofDir|GracefulShutdownTimeout|Group|Header|HeaderName|Heartbeat(?:Address|Listen|MaxServers|Storage)|HostnameLookups|IdentityCheck|IdentityCheckTimeout|ImapBase|ImapDefault|ImapMenu|Include|IncludeOptional|Index(?:HeadInsert|Ignore|IgnoreReset|Options|OrderDefault|StyleSheet)|InputSed|ISAPI(?:AppendLogToErrors|AppendLogToQuery|CacheFile|FakeAsync|LogNotSupported|ReadAheadBuffer)|KeepAlive|KeepAliveTimeout|KeptBodySize|LanguagePriority|LDAP(?:CacheEntries|CacheTTL|ConnectionPoolTTL|ConnectionTimeout|LibraryDebug|OpCacheEntries|OpCacheTTL|ReferralHopLimit|Referrals|Retries|RetryDelay|SharedCacheFile|SharedCacheSize|Timeout|TrustedClientCert|TrustedGlobalCert|TrustedMode|VerifyServerCert)|Limit(?:InternalRecursion|Request(?:Body|Fields|FieldSize|Line)|XMLRequestBody)|Listen|ListenBackLog|LoadFile|LoadModule|LogFormat|LogLevel|LogMessage|LuaAuthzProvider|LuaCodeCache|Lua(?:Hook(?:AccessChecker|AuthChecker|CheckUserID|Fixups|InsertFilter|Log|MapToStorage|TranslateName|TypeChecker)|Inherit|InputFilter|MapHandler|OutputFilter|PackageCPath|PackagePath|QuickHandler|Root|Scope)|Max(?:ConnectionsPerChild|KeepAliveRequests|MemFree|RangeOverlaps|RangeReversals|Ranges|RequestWorkers|SpareServers|SpareThreads|Threads)|MergeTrailers|MetaDir|MetaFiles|MetaSuffix|MimeMagicFile|MinSpareServers|MinSpareThreads|MMapFile|ModemStandard|ModMimeUsePathInfo|MultiviewsMatch|Mutex|NameVirtualHost|NoProxy|NWSSLTrustedCerts|NWSSLUpgradeable|Options|Order|OutputSed|PassEnv|PidFile|PrivilegesMode|Protocol|ProtocolEcho|Proxy(?:AddHeaders|BadHeader|Block|Domain|ErrorOverride|ExpressDBMFile|ExpressDBMType|ExpressEnable|FtpDirCharset|FtpEscapeWildcards|FtpListOnWildcard|HTML(?:BufSize|CharsetOut|DocType|Enable|Events|Extended|Fixups|Interp|Links|Meta|StripComments|URLMap)|IOBufferSize|MaxForwards|Pass(?:Inherit|InterpolateEnv|Match|Reverse|ReverseCookieDomain|ReverseCookiePath)?|PreserveHost|ReceiveBufferSize|Remote|RemoteMatch|Requests|SCGIInternalRedirect|SCGISendfile|Set|SourceAddress|Status|Timeout|Via)|ReadmeName|ReceiveBufferSize|Redirect|RedirectMatch|RedirectPermanent|RedirectTemp|ReflectorHeader|RemoteIP(?:Header|InternalProxy|InternalProxyList|ProxiesHeader|TrustedProxy|TrustedProxyList)|RemoveCharset|RemoveEncoding|RemoveHandler|RemoveInputFilter|RemoveLanguage|RemoveOutputFilter|RemoveType|RequestHeader|RequestReadTimeout|Require|Rewrite(?:Base|Cond|Engine|Map|Options|Rule)|RLimitCPU|RLimitMEM|RLimitNPROC|Satisfy|ScoreBoardFile|Script(?:Alias|AliasMatch|InterpreterSource|Log|LogBuffer|LogLength|Sock)?|SecureListen|SeeRequestTail|SendBufferSize|Server(?:Admin|Alias|Limit|Name|Path|Root|Signature|Tokens)|Session(?:Cookie(?:Name|Name2|Remove)|Crypto(?:Cipher|Driver|Passphrase|PassphraseFile)|DBD(?:CookieName|CookieName2|CookieRemove|DeleteLabel|InsertLabel|PerUser|SelectLabel|UpdateLabel)|Env|Exclude|Header|Include|MaxAge)?|SetEnv|SetEnvIf|SetEnvIfExpr|SetEnvIfNoCase|SetHandler|SetInputFilter|SetOutputFilter|SSIEndTag|SSIErrorMsg|SSIETag|SSILastModified|SSILegacyExprParser|SSIStartTag|SSITimeFormat|SSIUndefinedEcho|SSL(?:CACertificateFile|CACertificatePath|CADNRequestFile|CADNRequestPath|CARevocationCheck|CARevocationFile|CARevocationPath|CertificateChainFile|CertificateFile|CertificateKeyFile|CipherSuite|Compression|CryptoDevice|Engine|FIPS|HonorCipherOrder|InsecureRenegotiation|OCSP(?:DefaultResponder|Enable|OverrideResponder|ResponderTimeout|ResponseMaxAge|ResponseTimeSkew|UseRequestNonce)|OpenSSLConfCmd|Options|PassPhraseDialog|Protocol|Proxy(?:CACertificateFile|CACertificatePath|CARevocation(?:Check|File|Path)|CheckPeer(?:CN|Expire|Name)|CipherSuite|Engine|MachineCertificate(?:ChainFile|File|Path)|Protocol|Verify|VerifyDepth)|RandomSeed|RenegBufferSize|Require|RequireSSL|Session(?:Cache|CacheTimeout|TicketKeyFile|Tickets)|SRPUnknownUserSeed|SRPVerifierFile|Stapling(?:Cache|ErrorCacheTimeout|FakeTryLater|ForceURL|ResponderTimeout|ResponseMaxAge|ResponseTimeSkew|ReturnResponderErrors|StandardCacheTimeout)|StrictSNIVHostCheck|UserName|UseStapling|VerifyClient|VerifyDepth)|StartServers|StartThreads|Substitute|Suexec|SuexecUserGroup|ThreadLimit|ThreadsPerChild|ThreadStackSize|TimeOut|TraceEnable|TransferLog|TypesConfig|UnDefine|UndefMacro|UnsetEnv|Use|UseCanonicalName|UseCanonicalPhysicalPort|User|UserDir|VHostCGIMode|VHostCGIPrivs|VHostGroup|VHostPrivs|VHostSecure|VHostUser|Virtual(?:DocumentRoot|ScriptAlias)(?:IP)?|WatchdogInterval|XBitHack|xml2EncAlias|xml2EncDefault|xml2StartParse)\b/im,lookbehind:!0,alias:"property"},"directive-block":{pattern:/<\/?\b(?:Auth[nz]ProviderAlias|Directory|DirectoryMatch|Else|ElseIf|Files|FilesMatch|If|IfDefine|IfModule|IfVersion|Limit|LimitExcept|Location|LocationMatch|Macro|Proxy|Require(?:All|Any|None)|VirtualHost)\b.*>/i,inside:{"directive-block":{pattern:/^<\/?\w+/,inside:{punctuation:/^<\/?/},alias:"tag"},"directive-block-parameter":{pattern:/.*[^>]/,inside:{punctuation:/:/,string:{pattern:/("|').*\1/,inside:{variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/}}},alias:"attr-value"},punctuation:/>/},alias:"tag"},"directive-flags":{pattern:/\[(?:[\w=],?)+\]/,alias:"keyword"},string:{pattern:/("|').*\1/,inside:{variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/}},variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/,regex:/\^?.*\$|\^.*\$?/}}return vy}var Sy,qD;function yA(){if(qD)return Sy;qD=1,Sy=e,e.displayName="sql",e.aliases=[];function e(t){t.languages.sql={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,lookbehind:!0},variable:[{pattern:/@(["'`])(?:\\[\s\S]|(?!\1)[^\\])+\1/,greedy:!0},/@[\w.$]+/],string:{pattern:/(^|[^@\\])("|')(?:\\[\s\S]|(?!\2)[^\\]|\2\2)*\2/,greedy:!0,lookbehind:!0},identifier:{pattern:/(^|[^@\\])`(?:\\[\s\S]|[^`\\]|``)*`/,greedy:!0,lookbehind:!0,inside:{punctuation:/^`|`$/}},function:/\b(?:AVG|COUNT|FIRST|FORMAT|LAST|LCASE|LEN|MAX|MID|MIN|MOD|NOW|ROUND|SUM|UCASE)(?=\s*\()/i,keyword:/\b(?:ACTION|ADD|AFTER|ALGORITHM|ALL|ALTER|ANALYZE|ANY|APPLY|AS|ASC|AUTHORIZATION|AUTO_INCREMENT|BACKUP|BDB|BEGIN|BERKELEYDB|BIGINT|BINARY|BIT|BLOB|BOOL|BOOLEAN|BREAK|BROWSE|BTREE|BULK|BY|CALL|CASCADED?|CASE|CHAIN|CHAR(?:ACTER|SET)?|CHECK(?:POINT)?|CLOSE|CLUSTERED|COALESCE|COLLATE|COLUMNS?|COMMENT|COMMIT(?:TED)?|COMPUTE|CONNECT|CONSISTENT|CONSTRAINT|CONTAINS(?:TABLE)?|CONTINUE|CONVERT|CREATE|CROSS|CURRENT(?:_DATE|_TIME|_TIMESTAMP|_USER)?|CURSOR|CYCLE|DATA(?:BASES?)?|DATE(?:TIME)?|DAY|DBCC|DEALLOCATE|DEC|DECIMAL|DECLARE|DEFAULT|DEFINER|DELAYED|DELETE|DELIMITERS?|DENY|DESC|DESCRIBE|DETERMINISTIC|DISABLE|DISCARD|DISK|DISTINCT|DISTINCTROW|DISTRIBUTED|DO|DOUBLE|DROP|DUMMY|DUMP(?:FILE)?|DUPLICATE|ELSE(?:IF)?|ENABLE|ENCLOSED|END|ENGINE|ENUM|ERRLVL|ERRORS|ESCAPED?|EXCEPT|EXEC(?:UTE)?|EXISTS|EXIT|EXPLAIN|EXTENDED|FETCH|FIELDS|FILE|FILLFACTOR|FIRST|FIXED|FLOAT|FOLLOWING|FOR(?: EACH ROW)?|FORCE|FOREIGN|FREETEXT(?:TABLE)?|FROM|FULL|FUNCTION|GEOMETRY(?:COLLECTION)?|GLOBAL|GOTO|GRANT|GROUP|HANDLER|HASH|HAVING|HOLDLOCK|HOUR|IDENTITY(?:COL|_INSERT)?|IF|IGNORE|IMPORT|INDEX|INFILE|INNER|INNODB|INOUT|INSERT|INT|INTEGER|INTERSECT|INTERVAL|INTO|INVOKER|ISOLATION|ITERATE|JOIN|KEYS?|KILL|LANGUAGE|LAST|LEAVE|LEFT|LEVEL|LIMIT|LINENO|LINES|LINESTRING|LOAD|LOCAL|LOCK|LONG(?:BLOB|TEXT)|LOOP|MATCH(?:ED)?|MEDIUM(?:BLOB|INT|TEXT)|MERGE|MIDDLEINT|MINUTE|MODE|MODIFIES|MODIFY|MONTH|MULTI(?:LINESTRING|POINT|POLYGON)|NATIONAL|NATURAL|NCHAR|NEXT|NO|NONCLUSTERED|NULLIF|NUMERIC|OFF?|OFFSETS?|ON|OPEN(?:DATASOURCE|QUERY|ROWSET)?|OPTIMIZE|OPTION(?:ALLY)?|ORDER|OUT(?:ER|FILE)?|OVER|PARTIAL|PARTITION|PERCENT|PIVOT|PLAN|POINT|POLYGON|PRECEDING|PRECISION|PREPARE|PREV|PRIMARY|PRINT|PRIVILEGES|PROC(?:EDURE)?|PUBLIC|PURGE|QUICK|RAISERROR|READS?|REAL|RECONFIGURE|REFERENCES|RELEASE|RENAME|REPEAT(?:ABLE)?|REPLACE|REPLICATION|REQUIRE|RESIGNAL|RESTORE|RESTRICT|RETURN(?:ING|S)?|REVOKE|RIGHT|ROLLBACK|ROUTINE|ROW(?:COUNT|GUIDCOL|S)?|RTREE|RULE|SAVE(?:POINT)?|SCHEMA|SECOND|SELECT|SERIAL(?:IZABLE)?|SESSION(?:_USER)?|SET(?:USER)?|SHARE|SHOW|SHUTDOWN|SIMPLE|SMALLINT|SNAPSHOT|SOME|SONAME|SQL|START(?:ING)?|STATISTICS|STATUS|STRIPED|SYSTEM_USER|TABLES?|TABLESPACE|TEMP(?:ORARY|TABLE)?|TERMINATED|TEXT(?:SIZE)?|THEN|TIME(?:STAMP)?|TINY(?:BLOB|INT|TEXT)|TOP?|TRAN(?:SACTIONS?)?|TRIGGER|TRUNCATE|TSEQUAL|TYPES?|UNBOUNDED|UNCOMMITTED|UNDEFINED|UNION|UNIQUE|UNLOCK|UNPIVOT|UNSIGNED|UPDATE(?:TEXT)?|USAGE|USE|USER|USING|VALUES?|VAR(?:BINARY|CHAR|CHARACTER|YING)|VIEW|WAITFOR|WARNINGS|WHEN|WHERE|WHILE|WITH(?: ROLLUP|IN)?|WORK|WRITE(?:TEXT)?|YEAR)\b/i,boolean:/\b(?:FALSE|NULL|TRUE)\b/i,number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,operator:/[-+*\/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?|\b(?:AND|BETWEEN|DIV|ILIKE|IN|IS|LIKE|NOT|OR|REGEXP|RLIKE|SOUNDS LIKE|XOR)\b/i,punctuation:/[;[\]()`,.]/}}return Sy}var Ey,VD;function ibe(){if(VD)return Ey;VD=1;var e=yA();Ey=t,t.displayName="apex",t.aliases=[];function t(n){n.register(e),function(r){var a=/\b(?:(?:after|before)(?=\s+[a-z])|abstract|activate|and|any|array|as|asc|autonomous|begin|bigdecimal|blob|boolean|break|bulk|by|byte|case|cast|catch|char|class|collect|commit|const|continue|currency|date|datetime|decimal|default|delete|desc|do|double|else|end|enum|exception|exit|export|extends|final|finally|float|for|from|get(?=\s*[{};])|global|goto|group|having|hint|if|implements|import|in|inner|insert|instanceof|int|integer|interface|into|join|like|limit|list|long|loop|map|merge|new|not|null|nulls|number|object|of|on|or|outer|override|package|parallel|pragma|private|protected|public|retrieve|return|rollback|select|set|short|sObject|sort|static|string|super|switch|synchronized|system|testmethod|then|this|throw|time|transaction|transient|trigger|try|undelete|update|upsert|using|virtual|void|webservice|when|where|while|(?:inherited|with|without)\s+sharing)\b/i,o=/\b(?:(?=[a-z_]\w*\s*[<\[])|(?!<keyword>))[A-Z_]\w*(?:\s*\.\s*[A-Z_]\w*)*\b(?:\s*(?:\[\s*\]|<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>))*/.source.replace(/<keyword>/g,function(){return a.source});function s(u){return RegExp(u.replace(/<CLASS-NAME>/g,function(){return o}),"i")}var l={keyword:a,punctuation:/[()\[\]{};,:.<>]/};r.languages.apex={comment:r.languages.clike.comment,string:r.languages.clike.string,sql:{pattern:/((?:[=,({:]|\breturn)\s*)\[[^\[\]]*\]/i,lookbehind:!0,greedy:!0,alias:"language-sql",inside:r.languages.sql},annotation:{pattern:/@\w+\b/,alias:"punctuation"},"class-name":[{pattern:s(/(\b(?:class|enum|extends|implements|instanceof|interface|new|trigger\s+\w+\s+on)\s+)<CLASS-NAME>/.source),lookbehind:!0,inside:l},{pattern:s(/(\(\s*)<CLASS-NAME>(?=\s*\)\s*[\w(])/.source),lookbehind:!0,inside:l},{pattern:s(/<CLASS-NAME>(?=\s*\w+\s*[;=,(){:])/.source),inside:l}],trigger:{pattern:/(\btrigger\s+)\w+\b/i,lookbehind:!0,alias:"class-name"},keyword:a,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/i,number:/(?:\B\.\d+|\b\d+(?:\.\d+|L)?)\b/i,operator:/[!=](?:==?)?|\?\.?|&&|\|\||--|\+\+|[-+*/^&|]=?|:|<<?=?|>{1,3}=?/,punctuation:/[()\[\]{};,.]/}}(n)}return Ey}var wy,WD;function sbe(){if(WD)return wy;WD=1,wy=e,e.displayName="apl",e.aliases=[];function e(t){t.languages.apl={comment:/(?:⍝|#[! ]).*$/m,string:{pattern:/'(?:[^'\r\n]|'')*'/,greedy:!0},number:/¯?(?:\d*\.?\b\d+(?:e[+¯]?\d+)?|¯|∞)(?:j¯?(?:(?:\d+(?:\.\d+)?|\.\d+)(?:e[+¯]?\d+)?|¯|∞))?/i,statement:/:[A-Z][a-z][A-Za-z]*\b/,"system-function":{pattern:/⎕[A-Z]+/i,alias:"function"},constant:/[⍬⌾#⎕⍞]/,function:/[-+×÷⌈⌊∣|⍳⍸?*⍟○!⌹<≤=>≥≠≡≢∊⍷∪∩~∨∧⍱⍲⍴,⍪⌽⊖⍉↑↓⊂⊃⊆⊇⌷⍋⍒⊤⊥⍕⍎⊣⊢⍁⍂≈⍯↗¤→]/,"monadic-operator":{pattern:/[\\\/⌿⍀¨⍨⌶&∥]/,alias:"operator"},"dyadic-operator":{pattern:/[.⍣⍠⍤∘⌸@⌺⍥]/,alias:"operator"},assignment:{pattern:/←/,alias:"keyword"},punctuation:/[\[;\]()◇⋄]/,dfn:{pattern:/[{}⍺⍵⍶⍹∇⍫:]/,alias:"builtin"}}}return wy}var xy,YD;function lbe(){if(YD)return xy;YD=1,xy=e,e.displayName="applescript",e.aliases=[];function e(t){t.languages.applescript={comment:[/\(\*(?:\(\*(?:[^*]|\*(?!\)))*\*\)|(?!\(\*)[\s\S])*?\*\)/,/--.+/,/#.+/],string:/"(?:\\.|[^"\\\r\n])*"/,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e-?\d+)?\b/i,operator:[/[&=≠≤≥*+\-\/÷^]|[<>]=?/,/\b(?:(?:begin|end|start)s? with|(?:contains?|(?:does not|doesn't) contain)|(?:is|isn't|is not) (?:contained by|in)|(?:(?:is|isn't|is not) )?(?:greater|less) than(?: or equal)?(?: to)?|(?:comes|(?:does not|doesn't) come) (?:after|before)|(?:is|isn't|is not) equal(?: to)?|(?:(?:does not|doesn't) equal|equal to|equals|is not|isn't)|(?:a )?(?:ref(?: to)?|reference to)|(?:and|as|div|mod|not|or))\b/],keyword:/\b(?:about|above|after|against|apart from|around|aside from|at|back|before|beginning|behind|below|beneath|beside|between|but|by|considering|continue|copy|does|eighth|else|end|equal|error|every|exit|false|fifth|first|for|fourth|from|front|get|given|global|if|ignoring|in|instead of|into|is|it|its|last|local|me|middle|my|ninth|of|on|onto|out of|over|prop|property|put|repeat|return|returning|second|set|seventh|since|sixth|some|tell|tenth|that|the|then|third|through|thru|timeout|times|to|transaction|true|try|until|where|while|whose|with|without)\b/,"class-name":/\b(?:POSIX file|RGB color|alias|application|boolean|centimeters|centimetres|class|constant|cubic centimeters|cubic centimetres|cubic feet|cubic inches|cubic meters|cubic metres|cubic yards|date|degrees Celsius|degrees Fahrenheit|degrees Kelvin|feet|file|gallons|grams|inches|integer|kilograms|kilometers|kilometres|list|liters|litres|meters|metres|miles|number|ounces|pounds|quarts|real|record|reference|script|square feet|square kilometers|square kilometres|square meters|square metres|square miles|square yards|text|yards)\b/,punctuation:/[{}():,¬«»《》]/}}return xy}var ky,KD;function cbe(){if(KD)return ky;KD=1,ky=e,e.displayName="aql",e.aliases=[];function e(t){t.languages.aql={comment:/\/\/.*|\/\*[\s\S]*?\*\//,property:{pattern:/([{,]\s*)(?:(?!\d)\w+|(["'´`])(?:(?!\2)[^\\\r\n]|\\.)*\2)(?=\s*:)/,lookbehind:!0,greedy:!0},string:{pattern:/(["'])(?:(?!\1)[^\\\r\n]|\\.)*\1/,greedy:!0},identifier:{pattern:/([´`])(?:(?!\1)[^\\\r\n]|\\.)*\1/,greedy:!0},variable:/@@?\w+/,keyword:[{pattern:/(\bWITH\s+)COUNT(?=\s+INTO\b)/i,lookbehind:!0},/\b(?:AGGREGATE|ALL|AND|ANY|ASC|COLLECT|DESC|DISTINCT|FILTER|FOR|GRAPH|IN|INBOUND|INSERT|INTO|K_PATHS|K_SHORTEST_PATHS|LET|LIKE|LIMIT|NONE|NOT|NULL|OR|OUTBOUND|REMOVE|REPLACE|RETURN|SHORTEST_PATH|SORT|UPDATE|UPSERT|WINDOW|WITH)\b/i,{pattern:/(^|[^\w.[])(?:KEEP|PRUNE|SEARCH|TO)\b/i,lookbehind:!0},{pattern:/(^|[^\w.[])(?:CURRENT|NEW|OLD)\b/,lookbehind:!0},{pattern:/\bOPTIONS(?=\s*\{)/i}],function:/\b(?!\d)\w+(?=\s*\()/,boolean:/\b(?:false|true)\b/i,range:{pattern:/\.\./,alias:"operator"},number:[/\b0b[01]+/i,/\b0x[0-9a-f]+/i,/(?:\B\.\d+|\b(?:0|[1-9]\d*)(?:\.\d+)?)(?:e[+-]?\d+)?/i],operator:/\*{2,}|[=!]~|[!=<>]=?|&&|\|\||[-+*/%]/,punctuation:/::|[?.:,;()[\]{}]/}}return ky}var Ty,XD;function Ci(){if(XD)return Ty;XD=1,Ty=e,e.displayName="c",e.aliases=[];function e(t){t.languages.c=t.languages.extend("clike",{comment:{pattern:/\/\/(?:[^\r\n\\]|\\(?:\r\n?|\n|(?![\r\n])))*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},"class-name":{pattern:/(\b(?:enum|struct)\s+(?:__attribute__\s*\(\([\s\S]*?\)\)\s*)?)\w+|\b[a-z]\w*_t\b/,lookbehind:!0},keyword:/\b(?:_Alignas|_Alignof|_Atomic|_Bool|_Complex|_Generic|_Imaginary|_Noreturn|_Static_assert|_Thread_local|__attribute__|asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|inline|int|long|register|return|short|signed|sizeof|static|struct|switch|typedef|typeof|union|unsigned|void|volatile|while)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ful]{0,4}/i,operator:/>>=?|<<=?|->|([-+&|:])\1|[?:~]|[-+*/%&|^!=<>]=?/}),t.languages.insertBefore("c","string",{char:{pattern:/'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n]){0,32}'/,greedy:!0}}),t.languages.insertBefore("c","string",{macro:{pattern:/(^[\t ]*)#\s*[a-z](?:[^\r\n\\/]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|\\(?:\r\n|[\s\S]))*/im,lookbehind:!0,greedy:!0,alias:"property",inside:{string:[{pattern:/^(#\s*include\s*)<[^>]+>/,lookbehind:!0},t.languages.c.string],char:t.languages.c.char,comment:t.languages.c.comment,"macro-name":[{pattern:/(^#\s*define\s+)\w+\b(?!\()/i,lookbehind:!0},{pattern:/(^#\s*define\s+)\w+\b(?=\()/i,lookbehind:!0,alias:"function"}],directive:{pattern:/^(#\s*)[a-z]+/,lookbehind:!0,alias:"keyword"},"directive-hash":/^#/,punctuation:/##|\\(?=[\r\n])/,expression:{pattern:/\S[\s\S]*/,inside:t.languages.c}}}}),t.languages.insertBefore("c","function",{constant:/\b(?:EOF|NULL|SEEK_CUR|SEEK_END|SEEK_SET|__DATE__|__FILE__|__LINE__|__TIMESTAMP__|__TIME__|__func__|stderr|stdin|stdout)\b/}),delete t.languages.c.boolean}return Ty}var Ay,ZD;function vA(){if(ZD)return Ay;ZD=1;var e=Ci();Ay=t,t.displayName="cpp",t.aliases=[];function t(n){n.register(e),function(r){var a=/\b(?:alignas|alignof|asm|auto|bool|break|case|catch|char|char16_t|char32_t|char8_t|class|co_await|co_return|co_yield|compl|concept|const|const_cast|consteval|constexpr|constinit|continue|decltype|default|delete|do|double|dynamic_cast|else|enum|explicit|export|extern|final|float|for|friend|goto|if|import|inline|int|int16_t|int32_t|int64_t|int8_t|long|module|mutable|namespace|new|noexcept|nullptr|operator|override|private|protected|public|register|reinterpret_cast|requires|return|short|signed|sizeof|static|static_assert|static_cast|struct|switch|template|this|thread_local|throw|try|typedef|typeid|typename|uint16_t|uint32_t|uint64_t|uint8_t|union|unsigned|using|virtual|void|volatile|wchar_t|while)\b/,o=/\b(?!<keyword>)\w+(?:\s*\.\s*\w+)*\b/.source.replace(/<keyword>/g,function(){return a.source});r.languages.cpp=r.languages.extend("c",{"class-name":[{pattern:RegExp(/(\b(?:class|concept|enum|struct|typename)\s+)(?!<keyword>)\w+/.source.replace(/<keyword>/g,function(){return a.source})),lookbehind:!0},/\b[A-Z]\w*(?=\s*::\s*\w+\s*\()/,/\b[A-Z_]\w*(?=\s*::\s*~\w+\s*\()/i,/\b\w+(?=\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>\s*::\s*\w+\s*\()/],keyword:a,number:{pattern:/(?:\b0b[01']+|\b0x(?:[\da-f']+(?:\.[\da-f']*)?|\.[\da-f']+)(?:p[+-]?[\d']+)?|(?:\b[\d']+(?:\.[\d']*)?|\B\.[\d']+)(?:e[+-]?[\d']+)?)[ful]{0,4}/i,greedy:!0},operator:/>>=?|<<=?|->|--|\+\+|&&|\|\||[?:~]|<=>|[-+*/%&|^!=<>]=?|\b(?:and|and_eq|bitand|bitor|not|not_eq|or|or_eq|xor|xor_eq)\b/,boolean:/\b(?:false|true)\b/}),r.languages.insertBefore("cpp","string",{module:{pattern:RegExp(/(\b(?:import|module)\s+)/.source+"(?:"+/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|<[^<>\r\n]*>/.source+"|"+/<mod-name>(?:\s*:\s*<mod-name>)?|:\s*<mod-name>/.source.replace(/<mod-name>/g,function(){return o})+")"),lookbehind:!0,greedy:!0,inside:{string:/^[<"][\s\S]+/,operator:/:/,punctuation:/\./}},"raw-string":{pattern:/R"([^()\\ ]{0,16})\([\s\S]*?\)\1"/,alias:"string",greedy:!0}}),r.languages.insertBefore("cpp","keyword",{"generic-function":{pattern:/\b(?!operator\b)[a-z_]\w*\s*<(?:[^<>]|<[^<>]*>)*>(?=\s*\()/i,inside:{function:/^\w+/,generic:{pattern:/<[\s\S]+/,alias:"class-name",inside:r.languages.cpp}}}}),r.languages.insertBefore("cpp","operator",{"double-colon":{pattern:/::/,alias:"punctuation"}}),r.languages.insertBefore("cpp","class-name",{"base-clause":{pattern:/(\b(?:class|struct)\s+\w+\s*:\s*)[^;{}"'\s]+(?:\s+[^;{}"'\s]+)*(?=\s*[;{])/,lookbehind:!0,greedy:!0,inside:r.languages.extend("cpp",{})}}),r.languages.insertBefore("inside","double-colon",{"class-name":/\b[a-z_]\w*\b(?!\s*::)/i},r.languages.cpp["base-clause"])}(n)}return Ay}var Ry,QD;function ube(){if(QD)return Ry;QD=1;var e=vA();Ry=t,t.displayName="arduino",t.aliases=["ino"];function t(n){n.register(e),n.languages.arduino=n.languages.extend("cpp",{keyword:/\b(?:String|array|bool|boolean|break|byte|case|catch|continue|default|do|double|else|finally|for|function|goto|if|in|instanceof|int|integer|long|loop|new|null|return|setup|string|switch|throw|try|void|while|word)\b/,constant:/\b(?:ANALOG_MESSAGE|DEFAULT|DIGITAL_MESSAGE|EXTERNAL|FIRMATA_STRING|HIGH|INPUT|INPUT_PULLUP|INTERNAL|INTERNAL1V1|INTERNAL2V56|LED_BUILTIN|LOW|OUTPUT|REPORT_ANALOG|REPORT_DIGITAL|SET_PIN_MODE|SYSEX_START|SYSTEM_RESET)\b/,builtin:/\b(?:Audio|BSSID|Bridge|Client|Console|EEPROM|Esplora|EsploraTFT|Ethernet|EthernetClient|EthernetServer|EthernetUDP|File|FileIO|FileSystem|Firmata|GPRS|GSM|GSMBand|GSMClient|GSMModem|GSMPIN|GSMScanner|GSMServer|GSMVoiceCall|GSM_SMS|HttpClient|IPAddress|IRread|Keyboard|KeyboardController|LiquidCrystal|LiquidCrystal_I2C|Mailbox|Mouse|MouseController|PImage|Process|RSSI|RobotControl|RobotMotor|SD|SPI|SSID|Scheduler|Serial|Server|Servo|SoftwareSerial|Stepper|Stream|TFT|Task|USBHost|WiFi|WiFiClient|WiFiServer|WiFiUDP|Wire|YunClient|YunServer|abs|addParameter|analogRead|analogReadResolution|analogReference|analogWrite|analogWriteResolution|answerCall|attach|attachGPRS|attachInterrupt|attached|autoscroll|available|background|beep|begin|beginPacket|beginSD|beginSMS|beginSpeaker|beginTFT|beginTransmission|beginWrite|bit|bitClear|bitRead|bitSet|bitWrite|blink|blinkVersion|buffer|changePIN|checkPIN|checkPUK|checkReg|circle|cityNameRead|cityNameWrite|clear|clearScreen|click|close|compassRead|config|connect|connected|constrain|cos|countryNameRead|countryNameWrite|createChar|cursor|debugPrint|delay|delayMicroseconds|detach|detachInterrupt|digitalRead|digitalWrite|disconnect|display|displayLogos|drawBMP|drawCompass|encryptionType|end|endPacket|endSMS|endTransmission|endWrite|exists|exitValue|fill|find|findUntil|flush|gatewayIP|get|getAsynchronously|getBand|getButton|getCurrentCarrier|getIMEI|getKey|getModifiers|getOemKey|getPINUsed|getResult|getSignalStrength|getSocket|getVoiceCallStatus|getXChange|getYChange|hangCall|height|highByte|home|image|interrupts|isActionDone|isDirectory|isListening|isPIN|isPressed|isValid|keyPressed|keyReleased|keyboardRead|knobRead|leftToRight|line|lineFollowConfig|listen|listenOnLocalhost|loadImage|localIP|lowByte|macAddress|maintain|map|max|messageAvailable|micros|millis|min|mkdir|motorsStop|motorsWrite|mouseDragged|mouseMoved|mousePressed|mouseReleased|move|noAutoscroll|noBlink|noBuffer|noCursor|noDisplay|noFill|noInterrupts|noListenOnLocalhost|noStroke|noTone|onReceive|onRequest|open|openNextFile|overflow|parseCommand|parseFloat|parseInt|parsePacket|pauseMode|peek|pinMode|playFile|playMelody|point|pointTo|position|pow|prepare|press|print|printFirmwareVersion|printVersion|println|process|processInput|pulseIn|put|random|randomSeed|read|readAccelerometer|readBlue|readButton|readBytes|readBytesUntil|readGreen|readJoystickButton|readJoystickSwitch|readJoystickX|readJoystickY|readLightSensor|readMessage|readMicrophone|readNetworks|readRed|readSlider|readString|readStringUntil|readTemperature|ready|rect|release|releaseAll|remoteIP|remoteNumber|remotePort|remove|requestFrom|retrieveCallingNumber|rewindDirectory|rightToLeft|rmdir|robotNameRead|robotNameWrite|run|runAsynchronously|runShellCommand|runShellCommandAsynchronously|running|scanNetworks|scrollDisplayLeft|scrollDisplayRight|seek|sendAnalog|sendDigitalPortPair|sendDigitalPorts|sendString|sendSysex|serialEvent|setBand|setBitOrder|setClockDivider|setCursor|setDNS|setDataMode|setFirmwareVersion|setMode|setPINUsed|setSpeed|setTextSize|setTimeout|shiftIn|shiftOut|shutdown|sin|size|sqrt|startLoop|step|stop|stroke|subnetMask|switchPIN|tan|tempoWrite|text|tone|transfer|tuneWrite|turn|updateIR|userNameRead|userNameWrite|voiceCall|waitContinue|width|write|writeBlue|writeGreen|writeJSON|writeMessage|writeMicroseconds|writeRGB|writeRed|yield)\b/}),n.languages.ino=n.languages.arduino}return Ry}var Cy,JD;function dbe(){if(JD)return Cy;JD=1,Cy=e,e.displayName="arff",e.aliases=[];function e(t){t.languages.arff={comment:/%.*/,string:{pattern:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/@(?:attribute|data|end|relation)\b/i,number:/\b\d+(?:\.\d+)?\b/,punctuation:/[{},]/}}return Cy}var _y,eL;function fbe(){if(eL)return _y;eL=1,_y=e,e.displayName="asciidoc",e.aliases=["adoc"];function e(t){(function(n){var r={pattern:/(^[ \t]*)\[(?!\[)(?:(["'$`])(?:(?!\2)[^\\]|\\.)*\2|\[(?:[^\[\]\\]|\\.)*\]|[^\[\]\\"'$`]|\\.)*\]/m,lookbehind:!0,inside:{quoted:{pattern:/([$`])(?:(?!\1)[^\\]|\\.)*\1/,inside:{punctuation:/^[$`]|[$`]$/}},interpreted:{pattern:/'(?:[^'\\]|\\.)*'/,inside:{punctuation:/^'|'$/}},string:/"(?:[^"\\]|\\.)*"/,variable:/\w+(?==)/,punctuation:/^\[|\]$|,/,operator:/=/,"attr-value":/(?!^\s+$).+/}},a=n.languages.asciidoc={"comment-block":{pattern:/^(\/{4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1/m,alias:"comment"},table:{pattern:/^\|={3,}(?:(?:\r?\n|\r(?!\n)).*)*?(?:\r?\n|\r)\|={3,}$/m,inside:{specifiers:{pattern:/(?:(?:(?:\d+(?:\.\d+)?|\.\d+)[+*](?:[<^>](?:\.[<^>])?|\.[<^>])?|[<^>](?:\.[<^>])?|\.[<^>])[a-z]*|[a-z]+)(?=\|)/,alias:"attr-value"},punctuation:{pattern:/(^|[^\\])[|!]=*/,lookbehind:!0}}},"passthrough-block":{pattern:/^(\+{4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1$/m,inside:{punctuation:/^\++|\++$/}},"literal-block":{pattern:/^(-{4,}|\.{4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1$/m,inside:{punctuation:/^(?:-+|\.+)|(?:-+|\.+)$/}},"other-block":{pattern:/^(--|\*{4,}|_{4,}|={4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1$/m,inside:{punctuation:/^(?:-+|\*+|_+|=+)|(?:-+|\*+|_+|=+)$/}},"list-punctuation":{pattern:/(^[ \t]*)(?:-|\*{1,5}|\.{1,5}|(?:[a-z]|\d+)\.|[xvi]+\))(?= )/im,lookbehind:!0,alias:"punctuation"},"list-label":{pattern:/(^[ \t]*)[a-z\d].+(?::{2,4}|;;)(?=\s)/im,lookbehind:!0,alias:"symbol"},"indented-block":{pattern:/((\r?\n|\r)\2)([ \t]+)\S.*(?:(?:\r?\n|\r)\3.+)*(?=\2{2}|$)/,lookbehind:!0},comment:/^\/\/.*/m,title:{pattern:/^.+(?:\r?\n|\r)(?:={3,}|-{3,}|~{3,}|\^{3,}|\+{3,})$|^={1,5} .+|^\.(?![\s.]).*/m,alias:"important",inside:{punctuation:/^(?:\.|=+)|(?:=+|-+|~+|\^+|\++)$/}},"attribute-entry":{pattern:/^:[^:\r\n]+:(?: .*?(?: \+(?:\r?\n|\r).*?)*)?$/m,alias:"tag"},attributes:r,hr:{pattern:/^'{3,}$/m,alias:"punctuation"},"page-break":{pattern:/^<{3,}$/m,alias:"punctuation"},admonition:{pattern:/^(?:CAUTION|IMPORTANT|NOTE|TIP|WARNING):/m,alias:"keyword"},callout:[{pattern:/(^[ \t]*)<?\d*>/m,lookbehind:!0,alias:"symbol"},{pattern:/<\d+>/,alias:"symbol"}],macro:{pattern:/\b[a-z\d][a-z\d-]*::?(?:[^\s\[\]]*\[(?:[^\]\\"']|(["'])(?:(?!\1)[^\\]|\\.)*\1|\\.)*\])/,inside:{function:/^[a-z\d-]+(?=:)/,punctuation:/^::?/,attributes:{pattern:/(?:\[(?:[^\]\\"']|(["'])(?:(?!\1)[^\\]|\\.)*\1|\\.)*\])/,inside:r.inside}}},inline:{pattern:/(^|[^\\])(?:(?:\B\[(?:[^\]\\"']|(["'])(?:(?!\2)[^\\]|\\.)*\2|\\.)*\])?(?:\b_(?!\s)(?: _|[^_\\\r\n]|\\.)+(?:(?:\r?\n|\r)(?: _|[^_\\\r\n]|\\.)+)*_\b|\B``(?!\s).+?(?:(?:\r?\n|\r).+?)*''\B|\B`(?!\s)(?:[^`'\s]|\s+\S)+['`]\B|\B(['*+#])(?!\s)(?: \3|(?!\3)[^\\\r\n]|\\.)+(?:(?:\r?\n|\r)(?: \3|(?!\3)[^\\\r\n]|\\.)+)*\3\B)|(?:\[(?:[^\]\\"']|(["'])(?:(?!\4)[^\\]|\\.)*\4|\\.)*\])?(?:(__|\*\*|\+\+\+?|##|\$\$|[~^]).+?(?:(?:\r?\n|\r).+?)*\5|\{[^}\r\n]+\}|\[\[\[?.+?(?:(?:\r?\n|\r).+?)*\]?\]\]|<<.+?(?:(?:\r?\n|\r).+?)*>>|\(\(\(?.+?(?:(?:\r?\n|\r).+?)*\)?\)\)))/m,lookbehind:!0,inside:{attributes:r,url:{pattern:/^(?:\[\[\[?.+?\]?\]\]|<<.+?>>)$/,inside:{punctuation:/^(?:\[\[\[?|<<)|(?:\]\]\]?|>>)$/}},"attribute-ref":{pattern:/^\{.+\}$/,inside:{variable:{pattern:/(^\{)[a-z\d,+_-]+/,lookbehind:!0},operator:/^[=?!#%@$]|!(?=[:}])/,punctuation:/^\{|\}$|::?/}},italic:{pattern:/^(['_])[\s\S]+\1$/,inside:{punctuation:/^(?:''?|__?)|(?:''?|__?)$/}},bold:{pattern:/^\*[\s\S]+\*$/,inside:{punctuation:/^\*\*?|\*\*?$/}},punctuation:/^(?:``?|\+{1,3}|##?|\$\$|[~^]|\(\(\(?)|(?:''?|\+{1,3}|##?|\$\$|[~^`]|\)?\)\))$/}},replacement:{pattern:/\((?:C|R|TM)\)/,alias:"builtin"},entity:/&#?[\da-z]{1,8};/i,"line-continuation":{pattern:/(^| )\+$/m,lookbehind:!0,alias:"punctuation"}};function o(s){s=s.split(" ");for(var l={},u=0,d=s.length;u<d;u++)l[s[u]]=a[s[u]];return l}r.inside.interpreted.inside.rest=o("macro inline replacement entity"),a["passthrough-block"].inside.rest=o("macro"),a["literal-block"].inside.rest=o("callout"),a.table.inside.rest=o("comment-block passthrough-block literal-block other-block list-punctuation indented-block comment title attribute-entry attributes hr page-break admonition list-label callout macro inline replacement entity line-continuation"),a["other-block"].inside.rest=o("table list-punctuation indented-block comment attribute-entry attributes hr page-break admonition list-label macro inline replacement entity line-continuation"),a.title.inside.rest=o("macro inline replacement entity"),n.hooks.add("wrap",function(s){s.type==="entity"&&(s.attributes.title=s.content.value.replace(/&amp;/,"&"))}),n.languages.adoc=n.languages.asciidoc})(t)}return _y}var Ny,tL;function pbe(){if(tL)return Ny;tL=1,Ny=e,e.displayName="asm6502",e.aliases=[];function e(t){t.languages.asm6502={comment:/;.*/,directive:{pattern:/\.\w+(?= )/,alias:"property"},string:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,"op-code":{pattern:/\b(?:ADC|AND|ASL|BCC|BCS|BEQ|BIT|BMI|BNE|BPL|BRK|BVC|BVS|CLC|CLD|CLI|CLV|CMP|CPX|CPY|DEC|DEX|DEY|EOR|INC|INX|INY|JMP|JSR|LDA|LDX|LDY|LSR|NOP|ORA|PHA|PHP|PLA|PLP|ROL|ROR|RTI|RTS|SBC|SEC|SED|SEI|STA|STX|STY|TAX|TAY|TSX|TXA|TXS|TYA|adc|and|asl|bcc|bcs|beq|bit|bmi|bne|bpl|brk|bvc|bvs|clc|cld|cli|clv|cmp|cpx|cpy|dec|dex|dey|eor|inc|inx|iny|jmp|jsr|lda|ldx|ldy|lsr|nop|ora|pha|php|pla|plp|rol|ror|rti|rts|sbc|sec|sed|sei|sta|stx|sty|tax|tay|tsx|txa|txs|tya)\b/,alias:"keyword"},"hex-number":{pattern:/#?\$[\da-f]{1,4}\b/i,alias:"number"},"binary-number":{pattern:/#?%[01]+\b/,alias:"number"},"decimal-number":{pattern:/#?\b\d+\b/,alias:"number"},register:{pattern:/\b[xya]\b/i,alias:"variable"},punctuation:/[(),:]/}}return Ny}var Oy,nL;function gbe(){if(nL)return Oy;nL=1,Oy=e,e.displayName="asmatmel",e.aliases=[];function e(t){t.languages.asmatmel={comment:{pattern:/;.*/,greedy:!0},string:{pattern:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},constant:/\b(?:PORT[A-Z]|DDR[A-Z]|(?:DD|P)[A-Z](?:\d|[0-2]\d|3[01]))\b/,directive:{pattern:/\.\w+(?= )/,alias:"property"},"r-register":{pattern:/\br(?:\d|[12]\d|3[01])\b/,alias:"variable"},"op-code":{pattern:/\b(?:ADC|ADD|ADIW|AND|ANDI|ASR|BCLR|BLD|BRBC|BRBS|BRCC|BRCS|BREAK|BREQ|BRGE|BRHC|BRHS|BRID|BRIE|BRLO|BRLT|BRMI|BRNE|BRPL|BRSH|BRTC|BRTS|BRVC|BRVS|BSET|BST|CALL|CBI|CBR|CLC|CLH|CLI|CLN|CLR|CLS|CLT|CLV|CLZ|COM|CP|CPC|CPI|CPSE|DEC|DES|EICALL|EIJMP|ELPM|EOR|FMUL|FMULS|FMULSU|ICALL|IJMP|IN|INC|JMP|LAC|LAS|LAT|LD|LD[A-Za-z0-9]|LPM|LSL|LSR|MOV|MOVW|MUL|MULS|MULSU|NEG|NOP|OR|ORI|OUT|POP|PUSH|RCALL|RET|RETI|RJMP|ROL|ROR|SBC|SBCI|SBI|SBIC|SBIS|SBIW|SBR|SBRC|SBRS|SEC|SEH|SEI|SEN|SER|SES|SET|SEV|SEZ|SLEEP|SPM|ST|ST[A-Z0-9]|SUB|SUBI|SWAP|TST|WDR|XCH|adc|add|adiw|and|andi|asr|bclr|bld|brbc|brbs|brcc|brcs|break|breq|brge|brhc|brhs|brid|brie|brlo|brlt|brmi|brne|brpl|brsh|brtc|brts|brvc|brvs|bset|bst|call|cbi|cbr|clc|clh|cli|cln|clr|cls|clt|clv|clz|com|cp|cpc|cpi|cpse|dec|des|eicall|eijmp|elpm|eor|fmul|fmuls|fmulsu|icall|ijmp|in|inc|jmp|lac|las|lat|ld|ld[a-z0-9]|lpm|lsl|lsr|mov|movw|mul|muls|mulsu|neg|nop|or|ori|out|pop|push|rcall|ret|reti|rjmp|rol|ror|sbc|sbci|sbi|sbic|sbis|sbiw|sbr|sbrc|sbrs|sec|seh|sei|sen|ser|ses|set|sev|sez|sleep|spm|st|st[a-zA-Z0-9]|sub|subi|swap|tst|wdr|xch)\b/,alias:"keyword"},"hex-number":{pattern:/#?\$[\da-f]{2,4}\b/i,alias:"number"},"binary-number":{pattern:/#?%[01]+\b/,alias:"number"},"decimal-number":{pattern:/#?\b\d+\b/,alias:"number"},register:{pattern:/\b[acznvshtixy]\b/i,alias:"variable"},operator:/>>=?|<<=?|&&?|\|\|?|[-+*/%&|^!=<>?]=?/,punctuation:/[(),:]/}}return Oy}var Iy,rL;function zp(){if(rL)return Iy;rL=1,Iy=e,e.displayName="csharp",e.aliases=["dotnet","cs"];function e(t){(function(n){function r(V,j){return V.replace(/<<(\d+)>>/g,function(P,Z){return"(?:"+j[+Z]+")"})}function a(V,j,P){return RegExp(r(V,j),"")}function o(V,j){for(var P=0;P<j;P++)V=V.replace(/<<self>>/g,function(){return"(?:"+V+")"});return V.replace(/<<self>>/g,"[^\\s\\S]")}var s={type:"bool byte char decimal double dynamic float int long object sbyte short string uint ulong ushort var void",typeDeclaration:"class enum interface record struct",contextual:"add alias and ascending async await by descending from(?=\\s*(?:\\w|$)) get global group into init(?=\\s*;) join let nameof not notnull on or orderby partial remove select set unmanaged value when where with(?=\\s*{)",other:"abstract as base break case catch checked const continue default delegate do else event explicit extern finally fixed for foreach goto if implicit in internal is lock namespace new null operator out override params private protected public readonly ref return sealed sizeof stackalloc static switch this throw try typeof unchecked unsafe using virtual volatile while yield"};function l(V){return"\\b(?:"+V.trim().replace(/ /g,"|")+")\\b"}var u=l(s.typeDeclaration),d=RegExp(l(s.type+" "+s.typeDeclaration+" "+s.contextual+" "+s.other)),p=l(s.typeDeclaration+" "+s.contextual+" "+s.other),g=l(s.type+" "+s.typeDeclaration+" "+s.other),m=o(/<(?:[^<>;=+\-*/%&|^]|<<self>>)*>/.source,2),b=o(/\((?:[^()]|<<self>>)*\)/.source,2),v=/@?\b[A-Za-z_]\w*\b/.source,y=r(/<<0>>(?:\s*<<1>>)?/.source,[v,m]),k=r(/(?!<<0>>)<<1>>(?:\s*\.\s*<<1>>)*/.source,[p,y]),A=/\[\s*(?:,\s*)*\]/.source,x=r(/<<0>>(?:\s*(?:\?\s*)?<<1>>)*(?:\s*\?)?/.source,[k,A]),R=r(/[^,()<>[\];=+\-*/%&|^]|<<0>>|<<1>>|<<2>>/.source,[m,b,A]),O=r(/\(<<0>>+(?:,<<0>>+)+\)/.source,[R]),N=r(/(?:<<0>>|<<1>>)(?:\s*(?:\?\s*)?<<2>>)*(?:\s*\?)?/.source,[O,k,A]),C={keyword:d,punctuation:/[<>()?,.:[\]]/},_=/'(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'/.source,M=/"(?:\\.|[^\\"\r\n])*"/.source,I=/@"(?:""|\\[\s\S]|[^\\"])*"(?!")/.source;n.languages.csharp=n.languages.extend("clike",{string:[{pattern:a(/(^|[^$\\])<<0>>/.source,[I]),lookbehind:!0,greedy:!0},{pattern:a(/(^|[^@$\\])<<0>>/.source,[M]),lookbehind:!0,greedy:!0}],"class-name":[{pattern:a(/(\busing\s+static\s+)<<0>>(?=\s*;)/.source,[k]),lookbehind:!0,inside:C},{pattern:a(/(\busing\s+<<0>>\s*=\s*)<<1>>(?=\s*;)/.source,[v,N]),lookbehind:!0,inside:C},{pattern:a(/(\busing\s+)<<0>>(?=\s*=)/.source,[v]),lookbehind:!0},{pattern:a(/(\b<<0>>\s+)<<1>>/.source,[u,y]),lookbehind:!0,inside:C},{pattern:a(/(\bcatch\s*\(\s*)<<0>>/.source,[k]),lookbehind:!0,inside:C},{pattern:a(/(\bwhere\s+)<<0>>/.source,[v]),lookbehind:!0},{pattern:a(/(\b(?:is(?:\s+not)?|as)\s+)<<0>>/.source,[x]),lookbehind:!0,inside:C},{pattern:a(/\b<<0>>(?=\s+(?!<<1>>|with\s*\{)<<2>>(?:\s*[=,;:{)\]]|\s+(?:in|when)\b))/.source,[N,g,v]),inside:C}],keyword:d,number:/(?:\b0(?:x[\da-f_]*[\da-f]|b[01_]*[01])|(?:\B\.\d+(?:_+\d+)*|\b\d+(?:_+\d+)*(?:\.\d+(?:_+\d+)*)?)(?:e[-+]?\d+(?:_+\d+)*)?)(?:[dflmu]|lu|ul)?\b/i,operator:/>>=?|<<=?|[-=]>|([-+&|])\1|~|\?\?=?|[-+*/%&|^!=<>]=?/,punctuation:/\?\.?|::|[{}[\];(),.:]/}),n.languages.insertBefore("csharp","number",{range:{pattern:/\.\./,alias:"operator"}}),n.languages.insertBefore("csharp","punctuation",{"named-parameter":{pattern:a(/([(,]\s*)<<0>>(?=\s*:)/.source,[v]),lookbehind:!0,alias:"punctuation"}}),n.languages.insertBefore("csharp","class-name",{namespace:{pattern:a(/(\b(?:namespace|using)\s+)<<0>>(?:\s*\.\s*<<0>>)*(?=\s*[;{])/.source,[v]),lookbehind:!0,inside:{punctuation:/\./}},"type-expression":{pattern:a(/(\b(?:default|sizeof|typeof)\s*\(\s*(?!\s))(?:[^()\s]|\s(?!\s)|<<0>>)*(?=\s*\))/.source,[b]),lookbehind:!0,alias:"class-name",inside:C},"return-type":{pattern:a(/<<0>>(?=\s+(?:<<1>>\s*(?:=>|[({]|\.\s*this\s*\[)|this\s*\[))/.source,[N,k]),inside:C,alias:"class-name"},"constructor-invocation":{pattern:a(/(\bnew\s+)<<0>>(?=\s*[[({])/.source,[N]),lookbehind:!0,inside:C,alias:"class-name"},"generic-method":{pattern:a(/<<0>>\s*<<1>>(?=\s*\()/.source,[v,m]),inside:{function:a(/^<<0>>/.source,[v]),generic:{pattern:RegExp(m),alias:"class-name",inside:C}}},"type-list":{pattern:a(/\b((?:<<0>>\s+<<1>>|record\s+<<1>>\s*<<5>>|where\s+<<2>>)\s*:\s*)(?:<<3>>|<<4>>|<<1>>\s*<<5>>|<<6>>)(?:\s*,\s*(?:<<3>>|<<4>>|<<6>>))*(?=\s*(?:where|[{;]|=>|$))/.source,[u,y,v,N,d.source,b,/\bnew\s*\(\s*\)/.source]),lookbehind:!0,inside:{"record-arguments":{pattern:a(/(^(?!new\s*\()<<0>>\s*)<<1>>/.source,[y,b]),lookbehind:!0,greedy:!0,inside:n.languages.csharp},keyword:d,"class-name":{pattern:RegExp(N),greedy:!0,inside:C},punctuation:/[,()]/}},preprocessor:{pattern:/(^[\t ]*)#.*/m,lookbehind:!0,alias:"property",inside:{directive:{pattern:/(#)\b(?:define|elif|else|endif|endregion|error|if|line|nullable|pragma|region|undef|warning)\b/,lookbehind:!0,alias:"keyword"}}}});var D=M+"|"+_,U=r(/\/(?![*/])|\/\/[^\r\n]*[\r\n]|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>/.source,[D]),$=o(r(/[^"'/()]|<<0>>|\(<<self>>*\)/.source,[U]),2),B=/\b(?:assembly|event|field|method|module|param|property|return|type)\b/.source,W=r(/<<0>>(?:\s*\(<<1>>*\))?/.source,[k,$]);n.languages.insertBefore("csharp","class-name",{attribute:{pattern:a(/((?:^|[^\s\w>)?])\s*\[\s*)(?:<<0>>\s*:\s*)?<<1>>(?:\s*,\s*<<1>>)*(?=\s*\])/.source,[B,W]),lookbehind:!0,greedy:!0,inside:{target:{pattern:a(/^<<0>>(?=\s*:)/.source,[B]),alias:"keyword"},"attribute-arguments":{pattern:a(/\(<<0>>*\)/.source,[$]),inside:n.languages.csharp},"class-name":{pattern:RegExp(k),inside:{punctuation:/\./}},punctuation:/[:,]/}}});var K=/:[^}\r\n]+/.source,H=o(r(/[^"'/()]|<<0>>|\(<<self>>*\)/.source,[U]),2),G=r(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source,[H,K]),z=o(r(/[^"'/()]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>|\(<<self>>*\)/.source,[D]),2),Y=r(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source,[z,K]);function L(V,j){return{interpolation:{pattern:a(/((?:^|[^{])(?:\{\{)*)<<0>>/.source,[V]),lookbehind:!0,inside:{"format-string":{pattern:a(/(^\{(?:(?![}:])<<0>>)*)<<1>>(?=\}$)/.source,[j,K]),lookbehind:!0,inside:{punctuation:/^:/}},punctuation:/^\{|\}$/,expression:{pattern:/[\s\S]+/,alias:"language-csharp",inside:n.languages.csharp}}},string:/[\s\S]+/}}n.languages.insertBefore("csharp","string",{"interpolation-string":[{pattern:a(/(^|[^\\])(?:\$@|@\$)"(?:""|\\[\s\S]|\{\{|<<0>>|[^\\{"])*"/.source,[G]),lookbehind:!0,greedy:!0,inside:L(G,H)},{pattern:a(/(^|[^@\\])\$"(?:\\.|\{\{|<<0>>|[^\\"{])*"/.source,[Y]),lookbehind:!0,greedy:!0,inside:L(Y,z)}],char:{pattern:RegExp(_),greedy:!0}}),n.languages.dotnet=n.languages.cs=n.languages.csharp})(t)}return Iy}var Dy,aL;function hbe(){if(aL)return Dy;aL=1;var e=zp();Dy=t,t.displayName="aspnet",t.aliases=[];function t(n){n.register(e),n.languages.aspnet=n.languages.extend("markup",{"page-directive":{pattern:/<%\s*@.*%>/,alias:"tag",inside:{"page-directive":{pattern:/<%\s*@\s*(?:Assembly|Control|Implements|Import|Master(?:Type)?|OutputCache|Page|PreviousPageType|Reference|Register)?|%>/i,alias:"tag"},rest:n.languages.markup.tag.inside}},directive:{pattern:/<%.*%>/,alias:"tag",inside:{directive:{pattern:/<%\s*?[$=%#:]{0,2}|%>/,alias:"tag"},rest:n.languages.csharp}}}),n.languages.aspnet.tag.pattern=/<(?!%)\/?[^\s>\/]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/,n.languages.insertBefore("inside","punctuation",{directive:n.languages.aspnet.directive},n.languages.aspnet.tag.inside["attr-value"]),n.languages.insertBefore("aspnet","comment",{"asp-comment":{pattern:/<%--[\s\S]*?--%>/,alias:["asp","comment"]}}),n.languages.insertBefore("aspnet",n.languages.javascript?"script":"tag",{"asp-script":{pattern:/(<script(?=.*runat=['"]?server\b)[^>]*>)[\s\S]*?(?=<\/script>)/i,lookbehind:!0,alias:["asp","script"],inside:n.languages.csharp||{}}})}return Dy}var Ly,oL;function mbe(){if(oL)return Ly;oL=1,Ly=e,e.displayName="autohotkey",e.aliases=[];function e(t){t.languages.autohotkey={comment:[{pattern:/(^|\s);.*/,lookbehind:!0},{pattern:/(^[\t ]*)\/\*(?:[\r\n](?![ \t]*\*\/)|[^\r\n])*(?:[\r\n][ \t]*\*\/)?/m,lookbehind:!0,greedy:!0}],tag:{pattern:/^([ \t]*)[^\s,`":]+(?=:[ \t]*$)/m,lookbehind:!0},string:/"(?:[^"\n\r]|"")*"/,variable:/%\w+%/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/\?|\/\/?=?|:=|\|[=|]?|&[=&]?|\+[=+]?|-[=-]?|\*[=*]?|<(?:<=?|>|=)?|>>?=?|[.^!=~]=?|\b(?:AND|NOT|OR)\b/,boolean:/\b(?:false|true)\b/,selector:/\b(?:AutoTrim|BlockInput|Break|Click|ClipWait|Continue|Control|ControlClick|ControlFocus|ControlGet|ControlGetFocus|ControlGetPos|ControlGetText|ControlMove|ControlSend|ControlSendRaw|ControlSetText|CoordMode|Critical|DetectHiddenText|DetectHiddenWindows|Drive|DriveGet|DriveSpaceFree|EnvAdd|EnvDiv|EnvGet|EnvMult|EnvSet|EnvSub|EnvUpdate|Exit|ExitApp|FileAppend|FileCopy|FileCopyDir|FileCreateDir|FileCreateShortcut|FileDelete|FileEncoding|FileGetAttrib|FileGetShortcut|FileGetSize|FileGetTime|FileGetVersion|FileInstall|FileMove|FileMoveDir|FileRead|FileReadLine|FileRecycle|FileRecycleEmpty|FileRemoveDir|FileSelectFile|FileSelectFolder|FileSetAttrib|FileSetTime|FormatTime|GetKeyState|Gosub|Goto|GroupActivate|GroupAdd|GroupClose|GroupDeactivate|Gui|GuiControl|GuiControlGet|Hotkey|ImageSearch|IniDelete|IniRead|IniWrite|Input|InputBox|KeyWait|ListHotkeys|ListLines|ListVars|Loop|Menu|MouseClick|MouseClickDrag|MouseGetPos|MouseMove|MsgBox|OnExit|OutputDebug|Pause|PixelGetColor|PixelSearch|PostMessage|Process|Progress|Random|RegDelete|RegRead|RegWrite|Reload|Repeat|Return|Run|RunAs|RunWait|Send|SendEvent|SendInput|SendMessage|SendMode|SendPlay|SendRaw|SetBatchLines|SetCapslockState|SetControlDelay|SetDefaultMouseSpeed|SetEnv|SetFormat|SetKeyDelay|SetMouseDelay|SetNumlockState|SetRegView|SetScrollLockState|SetStoreCapslockMode|SetTimer|SetTitleMatchMode|SetWinDelay|SetWorkingDir|Shutdown|Sleep|Sort|SoundBeep|SoundGet|SoundGetWaveVolume|SoundPlay|SoundSet|SoundSetWaveVolume|SplashImage|SplashTextOff|SplashTextOn|SplitPath|StatusBarGetText|StatusBarWait|StringCaseSense|StringGetPos|StringLeft|StringLen|StringLower|StringMid|StringReplace|StringRight|StringSplit|StringTrimLeft|StringTrimRight|StringUpper|Suspend|SysGet|Thread|ToolTip|Transform|TrayTip|URLDownloadToFile|WinActivate|WinActivateBottom|WinClose|WinGet|WinGetActiveStats|WinGetActiveTitle|WinGetClass|WinGetPos|WinGetText|WinGetTitle|WinHide|WinKill|WinMaximize|WinMenuSelectItem|WinMinimize|WinMinimizeAll|WinMinimizeAllUndo|WinMove|WinRestore|WinSet|WinSetTitle|WinShow|WinWait|WinWaitActive|WinWaitClose|WinWaitNotActive)\b/i,constant:/\b(?:a_ahkpath|a_ahkversion|a_appdata|a_appdatacommon|a_autotrim|a_batchlines|a_caretx|a_carety|a_computername|a_controldelay|a_cursor|a_dd|a_ddd|a_dddd|a_defaultmousespeed|a_desktop|a_desktopcommon|a_detecthiddentext|a_detecthiddenwindows|a_endchar|a_eventinfo|a_exitreason|a_fileencoding|a_formatfloat|a_formatinteger|a_gui|a_guicontrol|a_guicontrolevent|a_guievent|a_guiheight|a_guiwidth|a_guix|a_guiy|a_hour|a_iconfile|a_iconhidden|a_iconnumber|a_icontip|a_index|a_ipaddress1|a_ipaddress2|a_ipaddress3|a_ipaddress4|a_is64bitos|a_isadmin|a_iscompiled|a_iscritical|a_ispaused|a_issuspended|a_isunicode|a_keydelay|a_language|a_lasterror|a_linefile|a_linenumber|a_loopfield|a_loopfileattrib|a_loopfiledir|a_loopfileext|a_loopfilefullpath|a_loopfilelongpath|a_loopfilename|a_loopfileshortname|a_loopfileshortpath|a_loopfilesize|a_loopfilesizekb|a_loopfilesizemb|a_loopfiletimeaccessed|a_loopfiletimecreated|a_loopfiletimemodified|a_loopreadline|a_loopregkey|a_loopregname|a_loopregsubkey|a_loopregtimemodified|a_loopregtype|a_mday|a_min|a_mm|a_mmm|a_mmmm|a_mon|a_mousedelay|a_msec|a_mydocuments|a_now|a_nowutc|a_numbatchlines|a_ostype|a_osversion|a_priorhotkey|a_priorkey|a_programfiles|a_programs|a_programscommon|a_ptrsize|a_regview|a_screendpi|a_screenheight|a_screenwidth|a_scriptdir|a_scriptfullpath|a_scripthwnd|a_scriptname|a_sec|a_space|a_startmenu|a_startmenucommon|a_startup|a_startupcommon|a_stringcasesense|a_tab|a_temp|a_thisfunc|a_thishotkey|a_thislabel|a_thismenu|a_thismenuitem|a_thismenuitempos|a_tickcount|a_timeidle|a_timeidlephysical|a_timesincepriorhotkey|a_timesincethishotkey|a_titlematchmode|a_titlematchmodespeed|a_username|a_wday|a_windelay|a_windir|a_workingdir|a_yday|a_year|a_yweek|a_yyyy|clipboard|clipboardall|comspec|errorlevel|programfiles)\b/i,builtin:/\b(?:abs|acos|asc|asin|atan|ceil|chr|class|comobjactive|comobjarray|comobjconnect|comobjcreate|comobjerror|comobjflags|comobjget|comobjquery|comobjtype|comobjvalue|cos|dllcall|exp|fileexist|Fileopen|floor|format|il_add|il_create|il_destroy|instr|isfunc|islabel|IsObject|ln|log|ltrim|lv_add|lv_delete|lv_deletecol|lv_getcount|lv_getnext|lv_gettext|lv_insert|lv_insertcol|lv_modify|lv_modifycol|lv_setimagelist|mod|numget|numput|onmessage|regexmatch|regexreplace|registercallback|round|rtrim|sb_seticon|sb_setparts|sb_settext|sin|sqrt|strlen|strreplace|strsplit|substr|tan|tv_add|tv_delete|tv_get|tv_getchild|tv_getcount|tv_getnext|tv_getparent|tv_getprev|tv_getselection|tv_gettext|tv_modify|varsetcapacity|winactive|winexist|__Call|__Get|__New|__Set)\b/i,symbol:/\b(?:alt|altdown|altup|appskey|backspace|browser_back|browser_favorites|browser_forward|browser_home|browser_refresh|browser_search|browser_stop|bs|capslock|ctrl|ctrlbreak|ctrldown|ctrlup|del|delete|down|end|enter|esc|escape|f1|f10|f11|f12|f13|f14|f15|f16|f17|f18|f19|f2|f20|f21|f22|f23|f24|f3|f4|f5|f6|f7|f8|f9|home|ins|insert|joy1|joy10|joy11|joy12|joy13|joy14|joy15|joy16|joy17|joy18|joy19|joy2|joy20|joy21|joy22|joy23|joy24|joy25|joy26|joy27|joy28|joy29|joy3|joy30|joy31|joy32|joy4|joy5|joy6|joy7|joy8|joy9|joyaxes|joybuttons|joyinfo|joyname|joypov|joyr|joyu|joyv|joyx|joyy|joyz|lalt|launch_app1|launch_app2|launch_mail|launch_media|lbutton|lcontrol|lctrl|left|lshift|lwin|lwindown|lwinup|mbutton|media_next|media_play_pause|media_prev|media_stop|numlock|numpad0|numpad1|numpad2|numpad3|numpad4|numpad5|numpad6|numpad7|numpad8|numpad9|numpadadd|numpadclear|numpaddel|numpaddiv|numpaddot|numpaddown|numpadend|numpadenter|numpadhome|numpadins|numpadleft|numpadmult|numpadpgdn|numpadpgup|numpadright|numpadsub|numpadup|pgdn|pgup|printscreen|ralt|rbutton|rcontrol|rctrl|right|rshift|rwin|rwindown|rwinup|scrolllock|shift|shiftdown|shiftup|space|tab|up|volume_down|volume_mute|volume_up|wheeldown|wheelleft|wheelright|wheelup|xbutton1|xbutton2)\b/i,important:/#\b(?:AllowSameLineComments|ClipboardTimeout|CommentFlag|DerefChar|ErrorStdOut|EscapeChar|HotkeyInterval|HotkeyModifierTimeout|Hotstring|If|IfTimeout|IfWinActive|IfWinExist|IfWinNotActive|IfWinNotExist|Include|IncludeAgain|InputLevel|InstallKeybdHook|InstallMouseHook|KeyHistory|MaxHotkeysPerInterval|MaxMem|MaxThreads|MaxThreadsBuffer|MaxThreadsPerHotkey|MenuMaskKey|NoEnv|NoTrayIcon|Persistent|SingleInstance|UseHook|Warn|WinActivateForce)\b/i,keyword:/\b(?:Abort|AboveNormal|Add|ahk_class|ahk_exe|ahk_group|ahk_id|ahk_pid|All|Alnum|Alpha|AltSubmit|AltTab|AltTabAndMenu|AltTabMenu|AltTabMenuDismiss|AlwaysOnTop|AutoSize|Background|BackgroundTrans|BelowNormal|between|BitAnd|BitNot|BitOr|BitShiftLeft|BitShiftRight|BitXOr|Bold|Border|Button|ByRef|Catch|Checkbox|Checked|CheckedGray|Choose|ChooseString|Close|Color|ComboBox|Contains|ControlList|Count|Date|DateTime|Days|DDL|Default|DeleteAll|Delimiter|Deref|Destroy|Digit|Disable|Disabled|DropDownList|Edit|Eject|Else|Enable|Enabled|Error|Exist|Expand|ExStyle|FileSystem|Finally|First|Flash|Float|FloatFast|Focus|Font|for|global|Grid|Group|GroupBox|GuiClose|GuiContextMenu|GuiDropFiles|GuiEscape|GuiSize|Hdr|Hidden|Hide|High|HKCC|HKCR|HKCU|HKEY_CLASSES_ROOT|HKEY_CURRENT_CONFIG|HKEY_CURRENT_USER|HKEY_LOCAL_MACHINE|HKEY_USERS|HKLM|HKU|Hours|HScroll|Icon|IconSmall|ID|IDLast|If|IfEqual|IfExist|IfGreater|IfGreaterOrEqual|IfInString|IfLess|IfLessOrEqual|IfMsgBox|IfNotEqual|IfNotExist|IfNotInString|IfWinActive|IfWinExist|IfWinNotActive|IfWinNotExist|Ignore|ImageList|in|Integer|IntegerFast|Interrupt|is|italic|Join|Label|LastFound|LastFoundExist|Limit|Lines|List|ListBox|ListView|local|Lock|Logoff|Low|Lower|Lowercase|MainWindow|Margin|Maximize|MaximizeBox|MaxSize|Minimize|MinimizeBox|MinMax|MinSize|Minutes|MonthCal|Mouse|Move|Multi|NA|No|NoActivate|NoDefault|NoHide|NoIcon|NoMainWindow|norm|Normal|NoSort|NoSortHdr|NoStandard|Not|NoTab|NoTimers|Number|Off|Ok|On|OwnDialogs|Owner|Parse|Password|Picture|Pixel|Pos|Pow|Priority|ProcessName|Radio|Range|Read|ReadOnly|Realtime|Redraw|Region|REG_BINARY|REG_DWORD|REG_EXPAND_SZ|REG_MULTI_SZ|REG_SZ|Relative|Rename|Report|Resize|Restore|Retry|RGB|Screen|Seconds|Section|Serial|SetLabel|ShiftAltTab|Show|Single|Slider|SortDesc|Standard|static|Status|StatusBar|StatusCD|strike|Style|Submit|SysMenu|Tab2|TabStop|Text|Theme|Throw|Tile|ToggleCheck|ToggleEnable|ToolWindow|Top|Topmost|TransColor|Transparent|Tray|TreeView|Try|TryAgain|Type|UnCheck|underline|Unicode|Unlock|Until|UpDown|Upper|Uppercase|UseErrorLevel|Vis|VisFirst|Visible|VScroll|Wait|WaitClose|WantCtrlA|WantF2|WantReturn|While|Wrap|Xdigit|xm|xp|xs|Yes|ym|yp|ys)\b/i,function:/[^(); \t,\n+*\-=?>:\\\/<&%\[\]]+(?=\()/,punctuation:/[{}[\]():,]/}}return Ly}var My,iL;function bbe(){if(iL)return My;iL=1,My=e,e.displayName="autoit",e.aliases=[];function e(t){t.languages.autoit={comment:[/;.*/,{pattern:/(^[\t ]*)#(?:comments-start|cs)[\s\S]*?^[ \t]*#(?:ce|comments-end)/m,lookbehind:!0}],url:{pattern:/(^[\t ]*#include\s+)(?:<[^\r\n>]+>|"[^\r\n"]+")/m,lookbehind:!0},string:{pattern:/(["'])(?:\1\1|(?!\1)[^\r\n])*\1/,greedy:!0,inside:{variable:/([%$@])\w+\1/}},directive:{pattern:/(^[\t ]*)#[\w-]+/m,lookbehind:!0,alias:"keyword"},function:/\b\w+(?=\()/,variable:/[$@]\w+/,keyword:/\b(?:Case|Const|Continue(?:Case|Loop)|Default|Dim|Do|Else(?:If)?|End(?:Func|If|Select|Switch|With)|Enum|Exit(?:Loop)?|For|Func|Global|If|In|Local|Next|Null|ReDim|Select|Static|Step|Switch|Then|To|Until|Volatile|WEnd|While|With)\b/i,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,boolean:/\b(?:False|True)\b/i,operator:/<[=>]?|[-+*\/=&>]=?|[?^]|\b(?:And|Not|Or)\b/i,punctuation:/[\[\]().,:]/}}return My}var Py,sL;function ybe(){if(sL)return Py;sL=1,Py=e,e.displayName="avisynth",e.aliases=["avs"];function e(t){(function(n){function r(p,g){return p.replace(/<<(\d+)>>/g,function(m,b){return g[+b]})}function a(p,g,m){return RegExp(r(p,g),m)}var o=/bool|clip|float|int|string|val/.source,s=[/is(?:bool|clip|float|int|string)|defined|(?:(?:internal)?function|var)?exists?/.source,/apply|assert|default|eval|import|nop|select|undefined/.source,/opt_(?:allowfloataudio|avipadscanlines|dwchannelmask|enable_(?:b64a|planartopackedrgb|v210|y3_10_10|y3_10_16)|usewaveextensible|vdubplanarhack)|set(?:cachemode|maxcpu|memorymax|planarlegacyalignment|workingdir)/.source,/hex(?:value)?|value/.source,/abs|ceil|continued(?:denominator|numerator)?|exp|floor|fmod|frac|log(?:10)?|max|min|muldiv|pi|pow|rand|round|sign|spline|sqrt/.source,/a?sinh?|a?cosh?|a?tan[2h]?/.source,/(?:bit(?:and|not|x?or|[lr]?shift[aslu]?|sh[lr]|sa[lr]|[lr]rotatel?|ro[rl]|te?st|set(?:count)?|cl(?:ea)?r|ch(?:an)?ge?))/.source,/average(?:[bgr]|chroma[uv]|luma)|(?:[rgb]|chroma[uv]|luma|rgb|[yuv](?=difference(?:fromprevious|tonext)))difference(?:fromprevious|tonext)?|[yuvrgb]plane(?:median|min|max|minmaxdifference)/.source,/getprocessinfo|logmsg|script(?:dir(?:utf8)?|file(?:utf8)?|name(?:utf8)?)|setlogparams/.source,/chr|(?:fill|find|left|mid|replace|rev|right)str|format|[lu]case|ord|str(?:cmpi?|fromutf8|len|toutf8)|time|trim(?:all|left|right)/.source,/isversionorgreater|version(?:number|string)/.source,/buildpixeltype|colorspacenametopixeltype/.source,/addautoloaddir|on(?:cpu|cuda)|prefetch|setfiltermtmode/.source].join("|"),l=[/has(?:audio|video)/.source,/height|width/.source,/frame(?:count|rate)|framerate(?:denominator|numerator)/.source,/getparity|is(?:field|frame)based/.source,/bitspercomponent|componentsize|hasalpha|is(?:planar(?:rgba?)?|interleaved|rgb(?:24|32|48|64)?|y(?:8|u(?:va?|y2))?|yv(?:12|16|24|411)|420|422|444|packedrgb)|numcomponents|pixeltype/.source,/audio(?:bits|channels|duration|length(?:[fs]|hi|lo)?|rate)|isaudio(?:float|int)/.source].join("|"),u=[/avi(?:file)?source|directshowsource|image(?:reader|source|sourceanim)|opendmlsource|segmented(?:avisource|directshowsource)|wavsource/.source,/coloryuv|convertbacktoyuy2|convertto(?:RGB(?:24|32|48|64)|(?:planar)?RGBA?|Y8?|YV(?:12|16|24|411)|YUVA?(?:411|420|422|444)|YUY2)|fixluminance|gr[ae]yscale|invert|levels|limiter|mergea?rgb|merge(?:chroma|luma)|rgbadjust|show(?:alpha|blue|green|red)|swapuv|tweak|[uv]toy8?|ytouv/.source,/(?:colorkey|reset)mask|layer|mask(?:hs)?|merge|overlay|subtract/.source,/addborders|(?:bicubic|bilinear|blackman|gauss|lanczos4|lanczos|point|sinc|spline(?:16|36|64))resize|crop(?:bottom)?|flip(?:horizontal|vertical)|(?:horizontal|vertical)?reduceby2|letterbox|skewrows|turn(?:180|left|right)/.source,/blur|fixbrokenchromaupsampling|generalconvolution|(?:spatial|temporal)soften|sharpen/.source,/trim|(?:un)?alignedsplice|(?:assume|assumescaled|change|convert)FPS|(?:delete|duplicate)frame|dissolve|fade(?:in|io|out)[02]?|freezeframe|interleave|loop|reverse|select(?:even|odd|(?:range)?every)/.source,/assume[bt]ff|assume(?:field|frame)based|bob|complementparity|doubleweave|peculiarblend|pulldown|separate(?:columns|fields|rows)|swapfields|weave(?:columns|rows)?/.source,/amplify(?:db)?|assumesamplerate|audiodub(?:ex)?|audiotrim|convertaudioto(?:(?:8|16|24|32)bit|float)|converttomono|delayaudio|ensurevbrmp3sync|get(?:left|right)?channel|kill(?:audio|video)|mergechannels|mixaudio|monotostereo|normalize|resampleaudio|ssrc|supereq|timestretch/.source,/animate|applyrange|conditional(?:filter|reader|select)|frameevaluate|scriptclip|tcp(?:server|source)|writefile(?:end|if|start)?/.source,/imagewriter/.source,/blackness|blankclip|colorbars(?:hd)?|compare|dumpfiltergraph|echo|histogram|info|messageclip|preroll|setgraphanalysis|show(?:framenumber|smpte|time)|showfiveversions|stack(?:horizontal|vertical)|subtitle|tone|version/.source].join("|"),d=[s,l,u].join("|");n.languages.avisynth={comment:[{pattern:/(^|[^\\])\[\*(?:[^\[*]|\[(?!\*)|\*(?!\])|\[\*(?:[^\[*]|\[(?!\*)|\*(?!\]))*\*\])*\*\]/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\$])#.*/,lookbehind:!0,greedy:!0}],argument:{pattern:a(/\b(?:<<0>>)\s+("?)\w+\1/.source,[o],"i"),inside:{keyword:/^\w+/}},"argument-label":{pattern:/([,(][\s\\]*)\w+\s*=(?!=)/,lookbehind:!0,inside:{"argument-name":{pattern:/^\w+/,alias:"punctuation"},punctuation:/=$/}},string:[{pattern:/"""[\s\S]*?"""/,greedy:!0},{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0,inside:{constant:{pattern:/\b(?:DEFAULT_MT_MODE|(?:MAINSCRIPT|PROGRAM|SCRIPT)DIR|(?:MACHINE|USER)_(?:CLASSIC|PLUS)_PLUGINS)\b/}}}],variable:/\b(?:last)\b/i,boolean:/\b(?:false|no|true|yes)\b/i,keyword:/\b(?:catch|else|for|function|global|if|return|try|while|__END__)\b/i,constant:/\bMT_(?:MULTI_INSTANCE|NICE_FILTER|SERIALIZED|SPECIAL_MT)\b/,"builtin-function":{pattern:a(/\b(?:<<0>>)\b/.source,[d],"i"),alias:"function"},"type-cast":{pattern:a(/\b(?:<<0>>)(?=\s*\()/.source,[o],"i"),alias:"keyword"},function:{pattern:/\b[a-z_]\w*(?=\s*\()|(\.)[a-z_]\w*\b/i,lookbehind:!0},"line-continuation":{pattern:/(^[ \t]*)\\|\\(?=[ \t]*$)/m,lookbehind:!0,alias:"punctuation"},number:/\B\$(?:[\da-f]{6}|[\da-f]{8})\b|(?:(?:\b|\B-)\d+(?:\.\d*)?\b|\B\.\d+\b)/i,operator:/\+\+?|[!=<>]=?|&&|\|\||[?:*/%-]/,punctuation:/[{}\[\]();,.]/},n.languages.avs=n.languages.avisynth})(t)}return Py}var Fy,lL;function vbe(){if(lL)return Fy;lL=1,Fy=e,e.displayName="avroIdl",e.aliases=[];function e(t){t.languages["avro-idl"]={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/(^|[^\\])"(?:[^\r\n"\\]|\\.)*"/,lookbehind:!0,greedy:!0},annotation:{pattern:/@(?:[$\w.-]|`[^\r\n`]+`)+/,greedy:!0,alias:"function"},"function-identifier":{pattern:/`[^\r\n`]+`(?=\s*\()/,greedy:!0,alias:"function"},identifier:{pattern:/`[^\r\n`]+`/,greedy:!0},"class-name":{pattern:/(\b(?:enum|error|protocol|record|throws)\b\s+)[$\w]+/,lookbehind:!0,greedy:!0},keyword:/\b(?:array|boolean|bytes|date|decimal|double|enum|error|false|fixed|float|idl|import|int|local_timestamp_ms|long|map|null|oneway|protocol|record|schema|string|throws|time_ms|timestamp_ms|true|union|uuid|void)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:[{pattern:/(^|[^\w.])-?(?:(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|0x(?:[a-f0-9]+(?:\.[a-f0-9]*)?|\.[a-f0-9]+)(?:p[+-]?\d+)?)[dfl]?(?![\w.])/i,lookbehind:!0},/-?\b(?:Infinity|NaN)\b/],operator:/=/,punctuation:/[()\[\]{}<>.:,;-]/},t.languages.avdl=t.languages["avro-idl"]}return Fy}var zy,cL;function jH(){if(cL)return zy;cL=1,zy=e,e.displayName="bash",e.aliases=["shell"];function e(t){(function(n){var r="\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b",a={pattern:/(^(["']?)\w+\2)[ \t]+\S.*/,lookbehind:!0,alias:"punctuation",inside:null},o={bash:a,environment:{pattern:RegExp("\\$"+r),alias:"constant"},variable:[{pattern:/\$?\(\([\s\S]+?\)\)/,greedy:!0,inside:{variable:[{pattern:/(^\$\(\([\s\S]+)\)\)/,lookbehind:!0},/^\$\(\(/],number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,punctuation:/\(\(?|\)\)?|,|;/}},{pattern:/\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,greedy:!0,inside:{variable:/^\$\(|^`|\)$|`$/}},{pattern:/\$\{[^}]+\}/,greedy:!0,inside:{operator:/:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/,punctuation:/[\[\]]/,environment:{pattern:RegExp("(\\{)"+r),lookbehind:!0,alias:"constant"}}},/\$(?:\w+|[#?*!@$])/],entity:/\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/};n.languages.bash={shebang:{pattern:/^#!\s*\/.*/,alias:"important"},comment:{pattern:/(^|[^"{\\$])#.*/,lookbehind:!0},"function-name":[{pattern:/(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,lookbehind:!0,alias:"function"},{pattern:/\b[\w-]+(?=\s*\(\s*\)\s*\{)/,alias:"function"}],"for-or-select":{pattern:/(\b(?:for|select)\s+)\w+(?=\s+in\s)/,alias:"variable",lookbehind:!0},"assign-left":{pattern:/(^|[\s;|&]|[<>]\()\w+(?=\+?=)/,inside:{environment:{pattern:RegExp("(^|[\\s;|&]|[<>]\\()"+r),lookbehind:!0,alias:"constant"}},alias:"variable",lookbehind:!0},string:[{pattern:/((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,lookbehind:!0,greedy:!0,inside:o},{pattern:/((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,lookbehind:!0,greedy:!0,inside:{bash:a}},{pattern:/(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,lookbehind:!0,greedy:!0,inside:o},{pattern:/(^|[^$\\])'[^']*'/,lookbehind:!0,greedy:!0},{pattern:/\$'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,inside:{entity:o.entity}}],environment:{pattern:RegExp("\\$?"+r),alias:"constant"},variable:o.variable,function:{pattern:/(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,lookbehind:!0},keyword:{pattern:/(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,lookbehind:!0},builtin:{pattern:/(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,lookbehind:!0,alias:"class-name"},boolean:{pattern:/(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,lookbehind:!0},"file-descriptor":{pattern:/\B&\d\b/,alias:"important"},operator:{pattern:/\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,inside:{"file-descriptor":{pattern:/^\d/,alias:"important"}}},punctuation:/\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,number:{pattern:/(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,lookbehind:!0}},a.inside=n.languages.bash;for(var s=["comment","function-name","for-or-select","assign-left","string","environment","function","keyword","builtin","boolean","file-descriptor","operator","punctuation","number"],l=o.variable[1].inside,u=0;u<s.length;u++)l[s[u]]=n.languages.bash[s[u]];n.languages.shell=n.languages.bash})(t)}return zy}var By,uL;function UH(){if(uL)return By;uL=1,By=e,e.displayName="basic",e.aliases=[];function e(t){t.languages.basic={comment:{pattern:/(?:!|REM\b).+/i,inside:{keyword:/^REM/i}},string:{pattern:/"(?:""|[!#$%&'()*,\/:;<=>?^\w +\-.])*"/,greedy:!0},number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,keyword:/\b(?:AS|BEEP|BLOAD|BSAVE|CALL(?: ABSOLUTE)?|CASE|CHAIN|CHDIR|CLEAR|CLOSE|CLS|COM|COMMON|CONST|DATA|DECLARE|DEF(?: FN| SEG|DBL|INT|LNG|SNG|STR)|DIM|DO|DOUBLE|ELSE|ELSEIF|END|ENVIRON|ERASE|ERROR|EXIT|FIELD|FILES|FOR|FUNCTION|GET|GOSUB|GOTO|IF|INPUT|INTEGER|IOCTL|KEY|KILL|LINE INPUT|LOCATE|LOCK|LONG|LOOP|LSET|MKDIR|NAME|NEXT|OFF|ON(?: COM| ERROR| KEY| TIMER)?|OPEN|OPTION BASE|OUT|POKE|PUT|READ|REDIM|REM|RESTORE|RESUME|RETURN|RMDIR|RSET|RUN|SELECT CASE|SHARED|SHELL|SINGLE|SLEEP|STATIC|STEP|STOP|STRING|SUB|SWAP|SYSTEM|THEN|TIMER|TO|TROFF|TRON|TYPE|UNLOCK|UNTIL|USING|VIEW PRINT|WAIT|WEND|WHILE|WRITE)(?:\$|\b)/i,function:/\b(?:ABS|ACCESS|ACOS|ANGLE|AREA|ARITHMETIC|ARRAY|ASIN|ASK|AT|ATN|BASE|BEGIN|BREAK|CAUSE|CEIL|CHR|CLIP|COLLATE|COLOR|CON|COS|COSH|COT|CSC|DATE|DATUM|DEBUG|DECIMAL|DEF|DEG|DEGREES|DELETE|DET|DEVICE|DISPLAY|DOT|ELAPSED|EPS|ERASABLE|EXLINE|EXP|EXTERNAL|EXTYPE|FILETYPE|FIXED|FP|GO|GRAPH|HANDLER|IDN|IMAGE|IN|INT|INTERNAL|IP|IS|KEYED|LBOUND|LCASE|LEFT|LEN|LENGTH|LET|LINE|LINES|LOG|LOG10|LOG2|LTRIM|MARGIN|MAT|MAX|MAXNUM|MID|MIN|MISSING|MOD|NATIVE|NUL|NUMERIC|OF|OPTION|ORD|ORGANIZATION|OUTIN|OUTPUT|PI|POINT|POINTER|POINTS|POS|PRINT|PROGRAM|PROMPT|RAD|RADIANS|RANDOMIZE|RECORD|RECSIZE|RECTYPE|RELATIVE|REMAINDER|REPEAT|REST|RETRY|REWRITE|RIGHT|RND|ROUND|RTRIM|SAME|SEC|SELECT|SEQUENTIAL|SET|SETTER|SGN|SIN|SINH|SIZE|SKIP|SQR|STANDARD|STATUS|STR|STREAM|STYLE|TAB|TAN|TANH|TEMPLATE|TEXT|THERE|TIME|TIMEOUT|TRACE|TRANSFORM|TRUNCATE|UBOUND|UCASE|USE|VAL|VARIABLE|VIEWPORT|WHEN|WINDOW|WITH|ZER|ZONEWIDTH)(?:\$|\b)/i,operator:/<[=>]?|>=?|[+\-*\/^=&]|\b(?:AND|EQV|IMP|NOT|OR|XOR)\b/i,punctuation:/[,;:()]/}}return By}var jy,dL;function Sbe(){if(dL)return jy;dL=1,jy=e,e.displayName="batch",e.aliases=[];function e(t){(function(n){var r=/%%?[~:\w]+%?|!\S+!/,a={pattern:/\/[a-z?]+(?=[ :]|$):?|-[a-z]\b|--[a-z-]+\b/im,alias:"attr-name",inside:{punctuation:/:/}},o=/"(?:[\\"]"|[^"])*"(?!")/,s=/(?:\b|-)\d+\b/;n.languages.batch={comment:[/^::.*/m,{pattern:/((?:^|[&(])[ \t]*)rem\b(?:[^^&)\r\n]|\^(?:\r\n|[\s\S]))*/im,lookbehind:!0}],label:{pattern:/^:.*/m,alias:"property"},command:[{pattern:/((?:^|[&(])[ \t]*)for(?: \/[a-z?](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* \S+ in \([^)]+\) do/im,lookbehind:!0,inside:{keyword:/\b(?:do|in)\b|^for\b/i,string:o,parameter:a,variable:r,number:s,punctuation:/[()',]/}},{pattern:/((?:^|[&(])[ \t]*)if(?: \/[a-z?](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* (?:not )?(?:cmdextversion \d+|defined \w+|errorlevel \d+|exist \S+|(?:"[^"]*"|(?!")(?:(?!==)\S)+)?(?:==| (?:equ|geq|gtr|leq|lss|neq) )(?:"[^"]*"|[^\s"]\S*))/im,lookbehind:!0,inside:{keyword:/\b(?:cmdextversion|defined|errorlevel|exist|not)\b|^if\b/i,string:o,parameter:a,variable:r,number:s,operator:/\^|==|\b(?:equ|geq|gtr|leq|lss|neq)\b/i}},{pattern:/((?:^|[&()])[ \t]*)else\b/im,lookbehind:!0,inside:{keyword:/^else\b/i}},{pattern:/((?:^|[&(])[ \t]*)set(?: \/[a-z](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* (?:[^^&)\r\n]|\^(?:\r\n|[\s\S]))*/im,lookbehind:!0,inside:{keyword:/^set\b/i,string:o,parameter:a,variable:[r,/\w+(?=(?:[*\/%+\-&^|]|<<|>>)?=)/],number:s,operator:/[*\/%+\-&^|]=?|<<=?|>>=?|[!~_=]/,punctuation:/[()',]/}},{pattern:/((?:^|[&(])[ \t]*@?)\w+\b(?:"(?:[\\"]"|[^"])*"(?!")|[^"^&)\r\n]|\^(?:\r\n|[\s\S]))*/m,lookbehind:!0,inside:{keyword:/^\w+\b/,string:o,parameter:a,label:{pattern:/(^\s*):\S+/m,lookbehind:!0,alias:"property"},variable:r,number:s,operator:/\^/}}],operator:/[&@]/,punctuation:/[()']/}})(t)}return jy}var Uy,fL;function Ebe(){if(fL)return Uy;fL=1,Uy=e,e.displayName="bbcode",e.aliases=["shortcode"];function e(t){t.languages.bbcode={tag:{pattern:/\[\/?[^\s=\]]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))?(?:\s+[^\s=\]]+\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))*\s*\]/,inside:{tag:{pattern:/^\[\/?[^\s=\]]+/,inside:{punctuation:/^\[\/?/}},"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+)/,inside:{punctuation:[/^=/,{pattern:/^(\s*)["']|["']$/,lookbehind:!0}]}},punctuation:/\]/,"attr-name":/[^\s=\]]+/}}},t.languages.shortcode=t.languages.bbcode}return Uy}var Gy,pL;function wbe(){if(pL)return Gy;pL=1,Gy=e,e.displayName="bicep",e.aliases=[];function e(t){t.languages.bicep={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],property:[{pattern:/([\r\n][ \t]*)[a-z_]\w*(?=[ \t]*:)/i,lookbehind:!0},{pattern:/([\r\n][ \t]*)'(?:\\.|\$(?!\{)|[^'\\\r\n$])*'(?=[ \t]*:)/,lookbehind:!0,greedy:!0}],string:[{pattern:/'''[^'][\s\S]*?'''/,greedy:!0},{pattern:/(^|[^\\'])'(?:\\.|\$(?!\{)|[^'\\\r\n$])*'/,lookbehind:!0,greedy:!0}],"interpolated-string":{pattern:/(^|[^\\'])'(?:\\.|\$(?:(?!\{)|\{[^{}\r\n]*\})|[^'\\\r\n$])*'/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/\$\{[^{}\r\n]*\}/,inside:{expression:{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0},punctuation:/^\$\{|\}$/}},string:/[\s\S]+/}},datatype:{pattern:/(\b(?:output|param)\b[ \t]+\w+[ \t]+)\w+\b/,lookbehind:!0,alias:"class-name"},boolean:/\b(?:false|true)\b/,keyword:/\b(?:existing|for|if|in|module|null|output|param|resource|targetScope|var)\b/,decorator:/@\w+\b/,function:/\b[a-z_]\w*(?=[ \t]*\()/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/,punctuation:/[{}[\];(),.:]/},t.languages.bicep["interpolated-string"].inside.interpolation.inside.expression.inside=t.languages.bicep}return Gy}var Hy,gL;function xbe(){if(gL)return Hy;gL=1,Hy=e,e.displayName="birb",e.aliases=[];function e(t){t.languages.birb=t.languages.extend("clike",{string:{pattern:/r?("|')(?:\\.|(?!\1)[^\\])*\1/,greedy:!0},"class-name":[/\b[A-Z](?:[\d_]*[a-zA-Z]\w*)?\b/,/\b(?:[A-Z]\w*|(?!(?:var|void)\b)[a-z]\w*)(?=\s+\w+\s*[;,=()])/],keyword:/\b(?:assert|break|case|class|const|default|else|enum|final|follows|for|grab|if|nest|new|next|noSeeb|return|static|switch|throw|var|void|while)\b/,operator:/\+\+|--|&&|\|\||<<=?|>>=?|~(?:\/=?)?|[+\-*\/%&^|=!<>]=?|\?|:/,variable:/\b[a-z_]\w*\b/}),t.languages.insertBefore("birb","function",{metadata:{pattern:/<\w+>/,greedy:!0,alias:"symbol"}})}return Hy}var $y,hL;function kbe(){if(hL)return $y;hL=1;var e=Ci();$y=t,t.displayName="bison",t.aliases=[];function t(n){n.register(e),n.languages.bison=n.languages.extend("c",{}),n.languages.insertBefore("bison","comment",{bison:{pattern:/^(?:[^%]|%(?!%))*%%[\s\S]*?%%/,inside:{c:{pattern:/%\{[\s\S]*?%\}|\{(?:\{[^}]*\}|[^{}])*\}/,inside:{delimiter:{pattern:/^%?\{|%?\}$/,alias:"punctuation"},"bison-variable":{pattern:/[$@](?:<[^\s>]+>)?[\w$]+/,alias:"variable",inside:{punctuation:/<|>/}},rest:n.languages.c}},comment:n.languages.c.comment,string:n.languages.c.string,property:/\S+(?=:)/,keyword:/%\w+/,number:{pattern:/(^|[^@])\b(?:0x[\da-f]+|\d+)/i,lookbehind:!0},punctuation:/%[%?]|[|:;\[\]<>]/}}})}return $y}var qy,mL;function Tbe(){if(mL)return qy;mL=1,qy=e,e.displayName="bnf",e.aliases=["rbnf"];function e(t){t.languages.bnf={string:{pattern:/"[^\r\n"]*"|'[^\r\n']*'/},definition:{pattern:/<[^<>\r\n\t]+>(?=\s*::=)/,alias:["rule","keyword"],inside:{punctuation:/^<|>$/}},rule:{pattern:/<[^<>\r\n\t]+>/,inside:{punctuation:/^<|>$/}},operator:/::=|[|()[\]{}*+?]|\.{3}/},t.languages.rbnf=t.languages.bnf}return qy}var Vy,bL;function Abe(){if(bL)return Vy;bL=1,Vy=e,e.displayName="brainfuck",e.aliases=[];function e(t){t.languages.brainfuck={pointer:{pattern:/<|>/,alias:"keyword"},increment:{pattern:/\+/,alias:"inserted"},decrement:{pattern:/-/,alias:"deleted"},branching:{pattern:/\[|\]/,alias:"important"},operator:/[.,]/,comment:/\S+/}}return Vy}var Wy,yL;function Rbe(){if(yL)return Wy;yL=1,Wy=e,e.displayName="brightscript",e.aliases=[];function e(t){t.languages.brightscript={comment:/(?:\brem|').*/i,"directive-statement":{pattern:/(^[\t ]*)#(?:const|else(?:[\t ]+if)?|end[\t ]+if|error|if).*/im,lookbehind:!0,alias:"property",inside:{"error-message":{pattern:/(^#error).+/,lookbehind:!0},directive:{pattern:/^#(?:const|else(?:[\t ]+if)?|end[\t ]+if|error|if)/,alias:"keyword"},expression:{pattern:/[\s\S]+/,inside:null}}},property:{pattern:/([\r\n{,][\t ]*)(?:(?!\d)\w+|"(?:[^"\r\n]|"")*"(?!"))(?=[ \t]*:)/,lookbehind:!0,greedy:!0},string:{pattern:/"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},"class-name":{pattern:/(\bAs[\t ]+)\w+/i,lookbehind:!0},keyword:/\b(?:As|Dim|Each|Else|Elseif|End|Exit|For|Function|Goto|If|In|Print|Return|Step|Stop|Sub|Then|To|While)\b/i,boolean:/\b(?:false|true)\b/i,function:/\b(?!\d)\w+(?=[\t ]*\()/,number:/(?:\b\d+(?:\.\d+)?(?:[ed][+-]\d+)?|&h[a-f\d]+)\b[%&!#]?/i,operator:/--|\+\+|>>=?|<<=?|<>|[-+*/\\<>]=?|[:^=?]|\b(?:and|mod|not|or)\b/i,punctuation:/[.,;()[\]{}]/,constant:/\b(?:LINE_NUM)\b/i},t.languages.brightscript["directive-statement"].inside.expression.inside=t.languages.brightscript}return Wy}var Yy,vL;function Cbe(){if(vL)return Yy;vL=1,Yy=e,e.displayName="bro",e.aliases=[];function e(t){t.languages.bro={comment:{pattern:/(^|[^\\$])#.*/,lookbehind:!0,inside:{italic:/\b(?:FIXME|TODO|XXX)\b/}},string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},boolean:/\b[TF]\b/,function:{pattern:/(\b(?:event|function|hook)[ \t]+)\w+(?:::\w+)?/,lookbehind:!0},builtin:/(?:@(?:load(?:-(?:plugin|sigs))?|unload|prefixes|ifn?def|else|(?:end)?if|DIR|FILENAME))|(?:&?(?:add_func|create_expire|default|delete_func|encrypt|error_handler|expire_func|group|log|mergeable|optional|persistent|priority|raw_output|read_expire|redef|rotate_interval|rotate_size|synchronized|type_column|write_expire))/,constant:{pattern:/(\bconst[ \t]+)\w+/i,lookbehind:!0},keyword:/\b(?:add|addr|alarm|any|bool|break|const|continue|count|delete|double|else|enum|event|export|file|for|function|global|hook|if|in|int|interval|local|module|next|of|opaque|pattern|port|print|record|return|schedule|set|string|subnet|table|time|timeout|using|vector|when)\b/,operator:/--?|\+\+?|!=?=?|<=?|>=?|==?=?|&&|\|\|?|\?|\*|\/|~|\^|%/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,punctuation:/[{}[\];(),.:]/}}return Yy}var Ky,SL;function _be(){if(SL)return Ky;SL=1,Ky=e,e.displayName="bsl",e.aliases=[];function e(t){t.languages.bsl={comment:/\/\/.*/,string:[{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},{pattern:/'(?:[^'\r\n\\]|\\.)*'/}],keyword:[{pattern:/(^|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:пока|для|новый|прервать|попытка|исключение|вызватьисключение|иначе|конецпопытки|неопределено|функция|перем|возврат|конецфункции|если|иначеесли|процедура|конецпроцедуры|тогда|знач|экспорт|конецесли|из|каждого|истина|ложь|по|цикл|конеццикла|выполнить)(?![\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])/i,lookbehind:!0},{pattern:/\b(?:break|do|each|else|elseif|enddo|endfunction|endif|endprocedure|endtry|except|execute|export|false|for|function|if|in|new|null|procedure|raise|return|then|to|true|try|undefined|val|var|while)\b/i}],number:{pattern:/(^(?=\d)|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:\d+(?:\.\d*)?|\.\d+)(?:E[+-]?\d+)?/i,lookbehind:!0},operator:[/[<>+\-*/]=?|[%=]/,{pattern:/(^|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:и|или|не)(?![\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])/i,lookbehind:!0},{pattern:/\b(?:and|not|or)\b/i}],punctuation:/\(\.|\.\)|[()\[\]:;,.]/,directive:[{pattern:/^([ \t]*)&.*/m,lookbehind:!0,greedy:!0,alias:"important"},{pattern:/^([ \t]*)#.*/gm,lookbehind:!0,greedy:!0,alias:"important"}]},t.languages.oscript=t.languages.bsl}return Ky}var Xy,EL;function Nbe(){if(EL)return Xy;EL=1,Xy=e,e.displayName="cfscript",e.aliases=[];function e(t){t.languages.cfscript=t.languages.extend("clike",{comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,inside:{annotation:{pattern:/(?:^|[^.])@[\w\.]+/,alias:"punctuation"}}},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],keyword:/\b(?:abstract|break|catch|component|continue|default|do|else|extends|final|finally|for|function|if|in|include|package|private|property|public|remote|required|rethrow|return|static|switch|throw|try|var|while|xml)\b(?!\s*=)/,operator:[/\+\+|--|&&|\|\||::|=>|[!=]==|<=?|>=?|[-+*/%&|^!=<>]=?|\?(?:\.|:)?|[?:]/,/\b(?:and|contains|eq|equal|eqv|gt|gte|imp|is|lt|lte|mod|not|or|xor)\b/],scope:{pattern:/\b(?:application|arguments|cgi|client|cookie|local|session|super|this|variables)\b/,alias:"global"},type:{pattern:/\b(?:any|array|binary|boolean|date|guid|numeric|query|string|struct|uuid|void|xml)\b/,alias:"builtin"}}),t.languages.insertBefore("cfscript","keyword",{"function-variable":{pattern:/[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"}}),delete t.languages.cfscript["class-name"],t.languages.cfc=t.languages.cfscript}return Xy}var Zy,wL;function Obe(){if(wL)return Zy;wL=1;var e=vA();Zy=t,t.displayName="chaiscript",t.aliases=[];function t(n){n.register(e),n.languages.chaiscript=n.languages.extend("clike",{string:{pattern:/(^|[^\\])'(?:[^'\\]|\\[\s\S])*'/,lookbehind:!0,greedy:!0},"class-name":[{pattern:/(\bclass\s+)\w+/,lookbehind:!0},{pattern:/(\b(?:attr|def)\s+)\w+(?=\s*::)/,lookbehind:!0}],keyword:/\b(?:attr|auto|break|case|catch|class|continue|def|default|else|finally|for|fun|global|if|return|switch|this|try|var|while)\b/,number:[n.languages.cpp.number,/\b(?:Infinity|NaN)\b/],operator:/>>=?|<<=?|\|\||&&|:[:=]?|--|\+\+|[=!<>+\-*/%|&^]=?|[?~]|`[^`\r\n]{1,4}`/}),n.languages.insertBefore("chaiscript","operator",{"parameter-type":{pattern:/([,(]\s*)\w+(?=\s+\w)/,lookbehind:!0,alias:"class-name"}}),n.languages.insertBefore("chaiscript","string",{"string-interpolation":{pattern:/(^|[^\\])"(?:[^"$\\]|\\[\s\S]|\$(?!\{)|\$\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\}/,lookbehind:!0,inside:{"interpolation-expression":{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:n.languages.chaiscript},"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"}}},string:/[\s\S]+/}}})}return Zy}var Qy,xL;function Ibe(){if(xL)return Qy;xL=1,Qy=e,e.displayName="cil",e.aliases=[];function e(t){t.languages.cil={comment:/\/\/.*/,string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},directive:{pattern:/(^|\W)\.[a-z]+(?=\s)/,lookbehind:!0,alias:"class-name"},variable:/\[[\w\.]+\]/,keyword:/\b(?:abstract|ansi|assembly|auto|autochar|beforefieldinit|bool|bstr|byvalstr|catch|char|cil|class|currency|date|decimal|default|enum|error|explicit|extends|extern|famandassem|family|famorassem|final(?:ly)?|float32|float64|hidebysig|u?int(?:8|16|32|64)?|iant|idispatch|implements|import|initonly|instance|interface|iunknown|literal|lpstr|lpstruct|lptstr|lpwstr|managed|method|native(?:Type)?|nested|newslot|object(?:ref)?|pinvokeimpl|private|privatescope|public|reqsecobj|rtspecialname|runtime|sealed|sequential|serializable|specialname|static|string|struct|syschar|tbstr|unicode|unmanagedexp|unsigned|value(?:type)?|variant|virtual|void)\b/,function:/\b(?:(?:constrained|no|readonly|tail|unaligned|volatile)\.)?(?:conv\.(?:[iu][1248]?|ovf\.[iu][1248]?(?:\.un)?|r\.un|r4|r8)|ldc\.(?:i4(?:\.\d+|\.[mM]1|\.s)?|i8|r4|r8)|ldelem(?:\.[iu][1248]?|\.r[48]|\.ref|a)?|ldind\.(?:[iu][1248]?|r[48]|ref)|stelem\.?(?:i[1248]?|r[48]|ref)?|stind\.(?:i[1248]?|r[48]|ref)?|end(?:fault|filter|finally)|ldarg(?:\.[0-3s]|a(?:\.s)?)?|ldloc(?:\.\d+|\.s)?|sub(?:\.ovf(?:\.un)?)?|mul(?:\.ovf(?:\.un)?)?|add(?:\.ovf(?:\.un)?)?|stloc(?:\.[0-3s])?|refany(?:type|val)|blt(?:\.un)?(?:\.s)?|ble(?:\.un)?(?:\.s)?|bgt(?:\.un)?(?:\.s)?|bge(?:\.un)?(?:\.s)?|unbox(?:\.any)?|init(?:blk|obj)|call(?:i|virt)?|brfalse(?:\.s)?|bne\.un(?:\.s)?|ldloca(?:\.s)?|brzero(?:\.s)?|brtrue(?:\.s)?|brnull(?:\.s)?|brinst(?:\.s)?|starg(?:\.s)?|leave(?:\.s)?|shr(?:\.un)?|rem(?:\.un)?|div(?:\.un)?|clt(?:\.un)?|alignment|castclass|ldvirtftn|beq(?:\.s)?|ckfinite|ldsflda|ldtoken|localloc|mkrefany|rethrow|cgt\.un|arglist|switch|stsfld|sizeof|newobj|newarr|ldsfld|ldnull|ldflda|isinst|throw|stobj|stfld|ldstr|ldobj|ldlen|ldftn|ldfld|cpobj|cpblk|break|br\.s|xor|shl|ret|pop|not|nop|neg|jmp|dup|cgt|ceq|box|and|or|br)\b/,boolean:/\b(?:false|true)\b/,number:/\b-?(?:0x[0-9a-f]+|\d+)(?:\.[0-9a-f]+)?\b/i,punctuation:/[{}[\];(),:=]|IL_[0-9A-Za-z]+/}}return Qy}var Jy,kL;function Dbe(){if(kL)return Jy;kL=1,Jy=e,e.displayName="clojure",e.aliases=[];function e(t){t.languages.clojure={comment:{pattern:/;.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},char:/\\\w+/,symbol:{pattern:/(^|[\s()\[\]{},])::?[\w*+!?'<>=/.-]+/,lookbehind:!0},keyword:{pattern:/(\()(?:-|->|->>|\.|\.\.|\*|\/|\+|<|<=|=|==|>|>=|accessor|agent|agent-errors|aget|alength|all-ns|alter|and|append-child|apply|array-map|aset|aset-boolean|aset-byte|aset-char|aset-double|aset-float|aset-int|aset-long|aset-short|assert|assoc|await|await-for|bean|binding|bit-and|bit-not|bit-or|bit-shift-left|bit-shift-right|bit-xor|boolean|branch\?|butlast|byte|cast|char|children|class|clear-agent-errors|comment|commute|comp|comparator|complement|concat|cond|conj|cons|constantly|construct-proxy|contains\?|count|create-ns|create-struct|cycle|dec|declare|def|def-|definline|definterface|defmacro|defmethod|defmulti|defn|defn-|defonce|defproject|defprotocol|defrecord|defstruct|deftype|deref|difference|disj|dissoc|distinct|do|doall|doc|dorun|doseq|dosync|dotimes|doto|double|down|drop|drop-while|edit|end\?|ensure|eval|every\?|false\?|ffirst|file-seq|filter|find|find-doc|find-ns|find-var|first|float|flush|fn|fnseq|for|frest|gensym|get|get-proxy-class|hash-map|hash-set|identical\?|identity|if|if-let|if-not|import|in-ns|inc|index|insert-child|insert-left|insert-right|inspect-table|inspect-tree|instance\?|int|interleave|intersection|into|into-array|iterate|join|key|keys|keyword|keyword\?|last|lazy-cat|lazy-cons|left|lefts|let|line-seq|list|list\*|load|load-file|locking|long|loop|macroexpand|macroexpand-1|make-array|make-node|map|map-invert|map\?|mapcat|max|max-key|memfn|merge|merge-with|meta|min|min-key|monitor-enter|name|namespace|neg\?|new|newline|next|nil\?|node|not|not-any\?|not-every\?|not=|ns|ns-imports|ns-interns|ns-map|ns-name|ns-publics|ns-refers|ns-resolve|ns-unmap|nth|nthrest|or|parse|partial|path|peek|pop|pos\?|pr|pr-str|print|print-str|println|println-str|prn|prn-str|project|proxy|proxy-mappings|quot|quote|rand|rand-int|range|re-find|re-groups|re-matcher|re-matches|re-pattern|re-seq|read|read-line|recur|reduce|ref|ref-set|refer|rem|remove|remove-method|remove-ns|rename|rename-keys|repeat|replace|replicate|resolve|rest|resultset-seq|reverse|rfirst|right|rights|root|rrest|rseq|second|select|select-keys|send|send-off|seq|seq-zip|seq\?|set|set!|short|slurp|some|sort|sort-by|sorted-map|sorted-map-by|sorted-set|special-symbol\?|split-at|split-with|str|string\?|struct|struct-map|subs|subvec|symbol|symbol\?|sync|take|take-nth|take-while|test|throw|time|to-array|to-array-2d|tree-seq|true\?|try|union|up|update-proxy|val|vals|var|var-get|var-set|var\?|vector|vector-zip|vector\?|when|when-first|when-let|when-not|with-local-vars|with-meta|with-open|with-out-str|xml-seq|xml-zip|zero\?|zipmap|zipper)(?=[\s)]|$)/,lookbehind:!0},boolean:/\b(?:false|nil|true)\b/,number:{pattern:/(^|[^\w$@])(?:\d+(?:[/.]\d+)?(?:e[+-]?\d+)?|0x[a-f0-9]+|[1-9]\d?r[a-z0-9]+)[lmn]?(?![\w$@])/i,lookbehind:!0},function:{pattern:/((?:^|[^'])\()[\w*+!?'<>=/.-]+(?=[\s)]|$)/,lookbehind:!0},operator:/[#@^`~]/,punctuation:/[{}\[\](),]/}}return Jy}var ev,TL;function Lbe(){if(TL)return ev;TL=1,ev=e,e.displayName="cmake",e.aliases=[];function e(t){t.languages.cmake={comment:/#.*/,string:{pattern:/"(?:[^\\"]|\\.)*"/,greedy:!0,inside:{interpolation:{pattern:/\$\{(?:[^{}$]|\$\{[^{}$]*\})*\}/,inside:{punctuation:/\$\{|\}/,variable:/\w+/}}}},variable:/\b(?:CMAKE_\w+|\w+_(?:(?:BINARY|SOURCE)_DIR|DESCRIPTION|HOMEPAGE_URL|ROOT|VERSION(?:_MAJOR|_MINOR|_PATCH|_TWEAK)?)|(?:ANDROID|APPLE|BORLAND|BUILD_SHARED_LIBS|CACHE|CPACK_(?:ABSOLUTE_DESTINATION_FILES|COMPONENT_INCLUDE_TOPLEVEL_DIRECTORY|ERROR_ON_ABSOLUTE_INSTALL_DESTINATION|INCLUDE_TOPLEVEL_DIRECTORY|INSTALL_DEFAULT_DIRECTORY_PERMISSIONS|INSTALL_SCRIPT|PACKAGING_INSTALL_PREFIX|SET_DESTDIR|WARN_ON_ABSOLUTE_INSTALL_DESTINATION)|CTEST_(?:BINARY_DIRECTORY|BUILD_COMMAND|BUILD_NAME|BZR_COMMAND|BZR_UPDATE_OPTIONS|CHANGE_ID|CHECKOUT_COMMAND|CONFIGURATION_TYPE|CONFIGURE_COMMAND|COVERAGE_COMMAND|COVERAGE_EXTRA_FLAGS|CURL_OPTIONS|CUSTOM_(?:COVERAGE_EXCLUDE|ERROR_EXCEPTION|ERROR_MATCH|ERROR_POST_CONTEXT|ERROR_PRE_CONTEXT|MAXIMUM_FAILED_TEST_OUTPUT_SIZE|MAXIMUM_NUMBER_OF_(?:ERRORS|WARNINGS)|MAXIMUM_PASSED_TEST_OUTPUT_SIZE|MEMCHECK_IGNORE|POST_MEMCHECK|POST_TEST|PRE_MEMCHECK|PRE_TEST|TESTS_IGNORE|WARNING_EXCEPTION|WARNING_MATCH)|CVS_CHECKOUT|CVS_COMMAND|CVS_UPDATE_OPTIONS|DROP_LOCATION|DROP_METHOD|DROP_SITE|DROP_SITE_CDASH|DROP_SITE_PASSWORD|DROP_SITE_USER|EXTRA_COVERAGE_GLOB|GIT_COMMAND|GIT_INIT_SUBMODULES|GIT_UPDATE_CUSTOM|GIT_UPDATE_OPTIONS|HG_COMMAND|HG_UPDATE_OPTIONS|LABELS_FOR_SUBPROJECTS|MEMORYCHECK_(?:COMMAND|COMMAND_OPTIONS|SANITIZER_OPTIONS|SUPPRESSIONS_FILE|TYPE)|NIGHTLY_START_TIME|P4_CLIENT|P4_COMMAND|P4_OPTIONS|P4_UPDATE_OPTIONS|RUN_CURRENT_SCRIPT|SCP_COMMAND|SITE|SOURCE_DIRECTORY|SUBMIT_URL|SVN_COMMAND|SVN_OPTIONS|SVN_UPDATE_OPTIONS|TEST_LOAD|TEST_TIMEOUT|TRIGGER_SITE|UPDATE_COMMAND|UPDATE_OPTIONS|UPDATE_VERSION_ONLY|USE_LAUNCHERS)|CYGWIN|ENV|EXECUTABLE_OUTPUT_PATH|GHS-MULTI|IOS|LIBRARY_OUTPUT_PATH|MINGW|MSVC(?:10|11|12|14|60|70|71|80|90|_IDE|_TOOLSET_VERSION|_VERSION)?|MSYS|PROJECT_(?:BINARY_DIR|DESCRIPTION|HOMEPAGE_URL|NAME|SOURCE_DIR|VERSION|VERSION_(?:MAJOR|MINOR|PATCH|TWEAK))|UNIX|WIN32|WINCE|WINDOWS_PHONE|WINDOWS_STORE|XCODE|XCODE_VERSION))\b/,property:/\b(?:cxx_\w+|(?:ARCHIVE_OUTPUT_(?:DIRECTORY|NAME)|COMPILE_DEFINITIONS|COMPILE_PDB_NAME|COMPILE_PDB_OUTPUT_DIRECTORY|EXCLUDE_FROM_DEFAULT_BUILD|IMPORTED_(?:IMPLIB|LIBNAME|LINK_DEPENDENT_LIBRARIES|LINK_INTERFACE_LANGUAGES|LINK_INTERFACE_LIBRARIES|LINK_INTERFACE_MULTIPLICITY|LOCATION|NO_SONAME|OBJECTS|SONAME)|INTERPROCEDURAL_OPTIMIZATION|LIBRARY_OUTPUT_DIRECTORY|LIBRARY_OUTPUT_NAME|LINK_FLAGS|LINK_INTERFACE_LIBRARIES|LINK_INTERFACE_MULTIPLICITY|LOCATION|MAP_IMPORTED_CONFIG|OSX_ARCHITECTURES|OUTPUT_NAME|PDB_NAME|PDB_OUTPUT_DIRECTORY|RUNTIME_OUTPUT_DIRECTORY|RUNTIME_OUTPUT_NAME|STATIC_LIBRARY_FLAGS|VS_CSHARP|VS_DOTNET_REFERENCEPROP|VS_DOTNET_REFERENCE|VS_GLOBAL_SECTION_POST|VS_GLOBAL_SECTION_PRE|VS_GLOBAL|XCODE_ATTRIBUTE)_\w+|\w+_(?:CLANG_TIDY|COMPILER_LAUNCHER|CPPCHECK|CPPLINT|INCLUDE_WHAT_YOU_USE|OUTPUT_NAME|POSTFIX|VISIBILITY_PRESET)|ABSTRACT|ADDITIONAL_MAKE_CLEAN_FILES|ADVANCED|ALIASED_TARGET|ALLOW_DUPLICATE_CUSTOM_TARGETS|ANDROID_(?:ANT_ADDITIONAL_OPTIONS|API|API_MIN|ARCH|ASSETS_DIRECTORIES|GUI|JAR_DEPENDENCIES|NATIVE_LIB_DEPENDENCIES|NATIVE_LIB_DIRECTORIES|PROCESS_MAX|PROGUARD|PROGUARD_CONFIG_PATH|SECURE_PROPS_PATH|SKIP_ANT_STEP|STL_TYPE)|ARCHIVE_OUTPUT_DIRECTORY|ATTACHED_FILES|ATTACHED_FILES_ON_FAIL|AUTOGEN_(?:BUILD_DIR|ORIGIN_DEPENDS|PARALLEL|SOURCE_GROUP|TARGETS_FOLDER|TARGET_DEPENDS)|AUTOMOC|AUTOMOC_(?:COMPILER_PREDEFINES|DEPEND_FILTERS|EXECUTABLE|MACRO_NAMES|MOC_OPTIONS|SOURCE_GROUP|TARGETS_FOLDER)|AUTORCC|AUTORCC_EXECUTABLE|AUTORCC_OPTIONS|AUTORCC_SOURCE_GROUP|AUTOUIC|AUTOUIC_EXECUTABLE|AUTOUIC_OPTIONS|AUTOUIC_SEARCH_PATHS|BINARY_DIR|BUILDSYSTEM_TARGETS|BUILD_RPATH|BUILD_RPATH_USE_ORIGIN|BUILD_WITH_INSTALL_NAME_DIR|BUILD_WITH_INSTALL_RPATH|BUNDLE|BUNDLE_EXTENSION|CACHE_VARIABLES|CLEAN_NO_CUSTOM|COMMON_LANGUAGE_RUNTIME|COMPATIBLE_INTERFACE_(?:BOOL|NUMBER_MAX|NUMBER_MIN|STRING)|COMPILE_(?:DEFINITIONS|FEATURES|FLAGS|OPTIONS|PDB_NAME|PDB_OUTPUT_DIRECTORY)|COST|CPACK_DESKTOP_SHORTCUTS|CPACK_NEVER_OVERWRITE|CPACK_PERMANENT|CPACK_STARTUP_SHORTCUTS|CPACK_START_MENU_SHORTCUTS|CPACK_WIX_ACL|CROSSCOMPILING_EMULATOR|CUDA_EXTENSIONS|CUDA_PTX_COMPILATION|CUDA_RESOLVE_DEVICE_SYMBOLS|CUDA_SEPARABLE_COMPILATION|CUDA_STANDARD|CUDA_STANDARD_REQUIRED|CXX_EXTENSIONS|CXX_STANDARD|CXX_STANDARD_REQUIRED|C_EXTENSIONS|C_STANDARD|C_STANDARD_REQUIRED|DEBUG_CONFIGURATIONS|DEFINE_SYMBOL|DEFINITIONS|DEPENDS|DEPLOYMENT_ADDITIONAL_FILES|DEPLOYMENT_REMOTE_DIRECTORY|DISABLED|DISABLED_FEATURES|ECLIPSE_EXTRA_CPROJECT_CONTENTS|ECLIPSE_EXTRA_NATURES|ENABLED_FEATURES|ENABLED_LANGUAGES|ENABLE_EXPORTS|ENVIRONMENT|EXCLUDE_FROM_ALL|EXCLUDE_FROM_DEFAULT_BUILD|EXPORT_NAME|EXPORT_PROPERTIES|EXTERNAL_OBJECT|EchoString|FAIL_REGULAR_EXPRESSION|FIND_LIBRARY_USE_LIB32_PATHS|FIND_LIBRARY_USE_LIB64_PATHS|FIND_LIBRARY_USE_LIBX32_PATHS|FIND_LIBRARY_USE_OPENBSD_VERSIONING|FIXTURES_CLEANUP|FIXTURES_REQUIRED|FIXTURES_SETUP|FOLDER|FRAMEWORK|Fortran_FORMAT|Fortran_MODULE_DIRECTORY|GENERATED|GENERATOR_FILE_NAME|GENERATOR_IS_MULTI_CONFIG|GHS_INTEGRITY_APP|GHS_NO_SOURCE_GROUP_FILE|GLOBAL_DEPENDS_DEBUG_MODE|GLOBAL_DEPENDS_NO_CYCLES|GNUtoMS|HAS_CXX|HEADER_FILE_ONLY|HELPSTRING|IMPLICIT_DEPENDS_INCLUDE_TRANSFORM|IMPORTED|IMPORTED_(?:COMMON_LANGUAGE_RUNTIME|CONFIGURATIONS|GLOBAL|IMPLIB|LIBNAME|LINK_DEPENDENT_LIBRARIES|LINK_INTERFACE_(?:LANGUAGES|LIBRARIES|MULTIPLICITY)|LOCATION|NO_SONAME|OBJECTS|SONAME)|IMPORT_PREFIX|IMPORT_SUFFIX|INCLUDE_DIRECTORIES|INCLUDE_REGULAR_EXPRESSION|INSTALL_NAME_DIR|INSTALL_RPATH|INSTALL_RPATH_USE_LINK_PATH|INTERFACE_(?:AUTOUIC_OPTIONS|COMPILE_DEFINITIONS|COMPILE_FEATURES|COMPILE_OPTIONS|INCLUDE_DIRECTORIES|LINK_DEPENDS|LINK_DIRECTORIES|LINK_LIBRARIES|LINK_OPTIONS|POSITION_INDEPENDENT_CODE|SOURCES|SYSTEM_INCLUDE_DIRECTORIES)|INTERPROCEDURAL_OPTIMIZATION|IN_TRY_COMPILE|IOS_INSTALL_COMBINED|JOB_POOLS|JOB_POOL_COMPILE|JOB_POOL_LINK|KEEP_EXTENSION|LABELS|LANGUAGE|LIBRARY_OUTPUT_DIRECTORY|LINKER_LANGUAGE|LINK_(?:DEPENDS|DEPENDS_NO_SHARED|DIRECTORIES|FLAGS|INTERFACE_LIBRARIES|INTERFACE_MULTIPLICITY|LIBRARIES|OPTIONS|SEARCH_END_STATIC|SEARCH_START_STATIC|WHAT_YOU_USE)|LISTFILE_STACK|LOCATION|MACOSX_BUNDLE|MACOSX_BUNDLE_INFO_PLIST|MACOSX_FRAMEWORK_INFO_PLIST|MACOSX_PACKAGE_LOCATION|MACOSX_RPATH|MACROS|MANUALLY_ADDED_DEPENDENCIES|MEASUREMENT|MODIFIED|NAME|NO_SONAME|NO_SYSTEM_FROM_IMPORTED|OBJECT_DEPENDS|OBJECT_OUTPUTS|OSX_ARCHITECTURES|OUTPUT_NAME|PACKAGES_FOUND|PACKAGES_NOT_FOUND|PARENT_DIRECTORY|PASS_REGULAR_EXPRESSION|PDB_NAME|PDB_OUTPUT_DIRECTORY|POSITION_INDEPENDENT_CODE|POST_INSTALL_SCRIPT|PREDEFINED_TARGETS_FOLDER|PREFIX|PRE_INSTALL_SCRIPT|PRIVATE_HEADER|PROCESSORS|PROCESSOR_AFFINITY|PROJECT_LABEL|PUBLIC_HEADER|REPORT_UNDEFINED_PROPERTIES|REQUIRED_FILES|RESOURCE|RESOURCE_LOCK|RULE_LAUNCH_COMPILE|RULE_LAUNCH_CUSTOM|RULE_LAUNCH_LINK|RULE_MESSAGES|RUNTIME_OUTPUT_DIRECTORY|RUN_SERIAL|SKIP_AUTOGEN|SKIP_AUTOMOC|SKIP_AUTORCC|SKIP_AUTOUIC|SKIP_BUILD_RPATH|SKIP_RETURN_CODE|SOURCES|SOURCE_DIR|SOVERSION|STATIC_LIBRARY_FLAGS|STATIC_LIBRARY_OPTIONS|STRINGS|SUBDIRECTORIES|SUFFIX|SYMBOLIC|TARGET_ARCHIVES_MAY_BE_SHARED_LIBS|TARGET_MESSAGES|TARGET_SUPPORTS_SHARED_LIBS|TESTS|TEST_INCLUDE_FILE|TEST_INCLUDE_FILES|TIMEOUT|TIMEOUT_AFTER_MATCH|TYPE|USE_FOLDERS|VALUE|VARIABLES|VERSION|VISIBILITY_INLINES_HIDDEN|VS_(?:CONFIGURATION_TYPE|COPY_TO_OUT_DIR|DEBUGGER_(?:COMMAND|COMMAND_ARGUMENTS|ENVIRONMENT|WORKING_DIRECTORY)|DEPLOYMENT_CONTENT|DEPLOYMENT_LOCATION|DOTNET_REFERENCES|DOTNET_REFERENCES_COPY_LOCAL|GLOBAL_KEYWORD|GLOBAL_PROJECT_TYPES|GLOBAL_ROOTNAMESPACE|INCLUDE_IN_VSIX|IOT_STARTUP_TASK|KEYWORD|RESOURCE_GENERATOR|SCC_AUXPATH|SCC_LOCALPATH|SCC_PROJECTNAME|SCC_PROVIDER|SDK_REFERENCES|SHADER_(?:DISABLE_OPTIMIZATIONS|ENABLE_DEBUG|ENTRYPOINT|FLAGS|MODEL|OBJECT_FILE_NAME|OUTPUT_HEADER_FILE|TYPE|VARIABLE_NAME)|STARTUP_PROJECT|TOOL_OVERRIDE|USER_PROPS|WINRT_COMPONENT|WINRT_EXTENSIONS|WINRT_REFERENCES|XAML_TYPE)|WILL_FAIL|WIN32_EXECUTABLE|WINDOWS_EXPORT_ALL_SYMBOLS|WORKING_DIRECTORY|WRAP_EXCLUDE|XCODE_(?:EMIT_EFFECTIVE_PLATFORM_NAME|EXPLICIT_FILE_TYPE|FILE_ATTRIBUTES|LAST_KNOWN_FILE_TYPE|PRODUCT_TYPE|SCHEME_(?:ADDRESS_SANITIZER|ADDRESS_SANITIZER_USE_AFTER_RETURN|ARGUMENTS|DISABLE_MAIN_THREAD_CHECKER|DYNAMIC_LIBRARY_LOADS|DYNAMIC_LINKER_API_USAGE|ENVIRONMENT|EXECUTABLE|GUARD_MALLOC|MAIN_THREAD_CHECKER_STOP|MALLOC_GUARD_EDGES|MALLOC_SCRIBBLE|MALLOC_STACK|THREAD_SANITIZER(?:_STOP)?|UNDEFINED_BEHAVIOUR_SANITIZER(?:_STOP)?|ZOMBIE_OBJECTS))|XCTEST)\b/,keyword:/\b(?:add_compile_definitions|add_compile_options|add_custom_command|add_custom_target|add_definitions|add_dependencies|add_executable|add_library|add_link_options|add_subdirectory|add_test|aux_source_directory|break|build_command|build_name|cmake_host_system_information|cmake_minimum_required|cmake_parse_arguments|cmake_policy|configure_file|continue|create_test_sourcelist|ctest_build|ctest_configure|ctest_coverage|ctest_empty_binary_directory|ctest_memcheck|ctest_read_custom_files|ctest_run_script|ctest_sleep|ctest_start|ctest_submit|ctest_test|ctest_update|ctest_upload|define_property|else|elseif|enable_language|enable_testing|endforeach|endfunction|endif|endmacro|endwhile|exec_program|execute_process|export|export_library_dependencies|file|find_file|find_library|find_package|find_path|find_program|fltk_wrap_ui|foreach|function|get_cmake_property|get_directory_property|get_filename_component|get_property|get_source_file_property|get_target_property|get_test_property|if|include|include_directories|include_external_msproject|include_guard|include_regular_expression|install|install_files|install_programs|install_targets|link_directories|link_libraries|list|load_cache|load_command|macro|make_directory|mark_as_advanced|math|message|option|output_required_files|project|qt_wrap_cpp|qt_wrap_ui|remove|remove_definitions|return|separate_arguments|set|set_directory_properties|set_property|set_source_files_properties|set_target_properties|set_tests_properties|site_name|source_group|string|subdir_depends|subdirs|target_compile_definitions|target_compile_features|target_compile_options|target_include_directories|target_link_directories|target_link_libraries|target_link_options|target_sources|try_compile|try_run|unset|use_mangled_mesa|utility_source|variable_requires|variable_watch|while|write_file)(?=\s*\()\b/,boolean:/\b(?:FALSE|OFF|ON|TRUE)\b/,namespace:/\b(?:INTERFACE|PRIVATE|PROPERTIES|PUBLIC|SHARED|STATIC|TARGET_OBJECTS)\b/,operator:/\b(?:AND|DEFINED|EQUAL|GREATER|LESS|MATCHES|NOT|OR|STREQUAL|STRGREATER|STRLESS|VERSION_EQUAL|VERSION_GREATER|VERSION_LESS)\b/,inserted:{pattern:/\b\w+::\w+\b/,alias:"class-name"},number:/\b\d+(?:\.\d+)*\b/,function:/\b[a-z_]\w*(?=\s*\()\b/i,punctuation:/[()>}]|\$[<{]/}}return ev}var tv,AL;function Mbe(){if(AL)return tv;AL=1,tv=e,e.displayName="cobol",e.aliases=[];function e(t){t.languages.cobol={comment:{pattern:/\*>.*|(^[ \t]*)\*.*/m,lookbehind:!0,greedy:!0},string:{pattern:/[xzgn]?(?:"(?:[^\r\n"]|"")*"(?!")|'(?:[^\r\n']|'')*'(?!'))/i,greedy:!0},level:{pattern:/(^[ \t]*)\d+\b/m,lookbehind:!0,greedy:!0,alias:"number"},"class-name":{pattern:/(\bpic(?:ture)?\s+)(?:(?:[-\w$/,:*+<>]|\.(?!\s|$))(?:\(\d+\))?)+/i,lookbehind:!0,inside:{number:{pattern:/(\()\d+/,lookbehind:!0},punctuation:/[()]/}},keyword:{pattern:/(^|[^\w-])(?:ABORT|ACCEPT|ACCESS|ADD|ADDRESS|ADVANCING|AFTER|ALIGNED|ALL|ALPHABET|ALPHABETIC|ALPHABETIC-LOWER|ALPHABETIC-UPPER|ALPHANUMERIC|ALPHANUMERIC-EDITED|ALSO|ALTER|ALTERNATE|ANY|ARE|AREA|AREAS|AS|ASCENDING|ASCII|ASSIGN|ASSOCIATED-DATA|ASSOCIATED-DATA-LENGTH|AT|ATTRIBUTE|AUTHOR|AUTO|AUTO-SKIP|BACKGROUND-COLOR|BACKGROUND-COLOUR|BASIS|BEEP|BEFORE|BEGINNING|BELL|BINARY|BIT|BLANK|BLINK|BLOCK|BOTTOM|BOUNDS|BY|BYFUNCTION|BYTITLE|CALL|CANCEL|CAPABLE|CCSVERSION|CD|CF|CH|CHAINING|CHANGED|CHANNEL|CHARACTER|CHARACTERS|CLASS|CLASS-ID|CLOCK-UNITS|CLOSE|CLOSE-DISPOSITION|COBOL|CODE|CODE-SET|COL|COLLATING|COLUMN|COM-REG|COMMA|COMMITMENT|COMMON|COMMUNICATION|COMP|COMP-1|COMP-2|COMP-3|COMP-4|COMP-5|COMPUTATIONAL|COMPUTATIONAL-1|COMPUTATIONAL-2|COMPUTATIONAL-3|COMPUTATIONAL-4|COMPUTATIONAL-5|COMPUTE|CONFIGURATION|CONTAINS|CONTENT|CONTINUE|CONTROL|CONTROL-POINT|CONTROLS|CONVENTION|CONVERTING|COPY|CORR|CORRESPONDING|COUNT|CRUNCH|CURRENCY|CURSOR|DATA|DATA-BASE|DATE|DATE-COMPILED|DATE-WRITTEN|DAY|DAY-OF-WEEK|DBCS|DE|DEBUG-CONTENTS|DEBUG-ITEM|DEBUG-LINE|DEBUG-NAME|DEBUG-SUB-1|DEBUG-SUB-2|DEBUG-SUB-3|DEBUGGING|DECIMAL-POINT|DECLARATIVES|DEFAULT|DEFAULT-DISPLAY|DEFINITION|DELETE|DELIMITED|DELIMITER|DEPENDING|DESCENDING|DESTINATION|DETAIL|DFHRESP|DFHVALUE|DISABLE|DISK|DISPLAY|DISPLAY-1|DIVIDE|DIVISION|DONTCARE|DOUBLE|DOWN|DUPLICATES|DYNAMIC|EBCDIC|EGCS|EGI|ELSE|EMI|EMPTY-CHECK|ENABLE|END|END-ACCEPT|END-ADD|END-CALL|END-COMPUTE|END-DELETE|END-DIVIDE|END-EVALUATE|END-IF|END-MULTIPLY|END-OF-PAGE|END-PERFORM|END-READ|END-RECEIVE|END-RETURN|END-REWRITE|END-SEARCH|END-START|END-STRING|END-SUBTRACT|END-UNSTRING|END-WRITE|ENDING|ENTER|ENTRY|ENTRY-PROCEDURE|ENVIRONMENT|EOL|EOP|EOS|ERASE|ERROR|ESCAPE|ESI|EVALUATE|EVENT|EVERY|EXCEPTION|EXCLUSIVE|EXHIBIT|EXIT|EXPORT|EXTEND|EXTENDED|EXTERNAL|FD|FILE|FILE-CONTROL|FILLER|FINAL|FIRST|FOOTING|FOR|FOREGROUND-COLOR|FOREGROUND-COLOUR|FROM|FULL|FUNCTION|FUNCTION-POINTER|FUNCTIONNAME|GENERATE|GIVING|GLOBAL|GO|GOBACK|GRID|GROUP|HEADING|HIGH-VALUE|HIGH-VALUES|HIGHLIGHT|I-O|I-O-CONTROL|ID|IDENTIFICATION|IF|IMPLICIT|IMPORT|IN|INDEX|INDEXED|INDICATE|INITIAL|INITIALIZE|INITIATE|INPUT|INPUT-OUTPUT|INSPECT|INSTALLATION|INTEGER|INTO|INVALID|INVOKE|IS|JUST|JUSTIFIED|KANJI|KEPT|KEY|KEYBOARD|LABEL|LANGUAGE|LAST|LB|LD|LEADING|LEFT|LEFTLINE|LENGTH|LENGTH-CHECK|LIBACCESS|LIBPARAMETER|LIBRARY|LIMIT|LIMITS|LINAGE|LINAGE-COUNTER|LINE|LINE-COUNTER|LINES|LINKAGE|LIST|LOCAL|LOCAL-STORAGE|LOCK|LONG-DATE|LONG-TIME|LOW-VALUE|LOW-VALUES|LOWER|LOWLIGHT|MEMORY|MERGE|MESSAGE|MMDDYYYY|MODE|MODULES|MORE-LABELS|MOVE|MULTIPLE|MULTIPLY|NAMED|NATIONAL|NATIONAL-EDITED|NATIVE|NEGATIVE|NETWORK|NEXT|NO|NO-ECHO|NULL|NULLS|NUMBER|NUMERIC|NUMERIC-DATE|NUMERIC-EDITED|NUMERIC-TIME|OBJECT-COMPUTER|OCCURS|ODT|OF|OFF|OMITTED|ON|OPEN|OPTIONAL|ORDER|ORDERLY|ORGANIZATION|OTHER|OUTPUT|OVERFLOW|OVERLINE|OWN|PACKED-DECIMAL|PADDING|PAGE|PAGE-COUNTER|PASSWORD|PERFORM|PF|PH|PIC|PICTURE|PLUS|POINTER|PORT|POSITION|POSITIVE|PRINTER|PRINTING|PRIVATE|PROCEDURE|PROCEDURE-POINTER|PROCEDURES|PROCEED|PROCESS|PROGRAM|PROGRAM-ID|PROGRAM-LIBRARY|PROMPT|PURGE|QUEUE|QUOTE|QUOTES|RANDOM|RD|READ|READER|REAL|RECEIVE|RECEIVED|RECORD|RECORDING|RECORDS|RECURSIVE|REDEFINES|REEL|REF|REFERENCE|REFERENCES|RELATIVE|RELEASE|REMAINDER|REMARKS|REMOTE|REMOVAL|REMOVE|RENAMES|REPLACE|REPLACING|REPORT|REPORTING|REPORTS|REQUIRED|RERUN|RESERVE|RESET|RETURN|RETURN-CODE|RETURNING|REVERSE-VIDEO|REVERSED|REWIND|REWRITE|RF|RH|RIGHT|ROUNDED|RUN|SAME|SAVE|SCREEN|SD|SEARCH|SECTION|SECURE|SECURITY|SEGMENT|SEGMENT-LIMIT|SELECT|SEND|SENTENCE|SEPARATE|SEQUENCE|SEQUENTIAL|SET|SHARED|SHAREDBYALL|SHAREDBYRUNUNIT|SHARING|SHIFT-IN|SHIFT-OUT|SHORT-DATE|SIGN|SIZE|SORT|SORT-CONTROL|SORT-CORE-SIZE|SORT-FILE-SIZE|SORT-MERGE|SORT-MESSAGE|SORT-MODE-SIZE|SORT-RETURN|SOURCE|SOURCE-COMPUTER|SPACE|SPACES|SPECIAL-NAMES|STANDARD|STANDARD-1|STANDARD-2|START|STATUS|STOP|STRING|SUB-QUEUE-1|SUB-QUEUE-2|SUB-QUEUE-3|SUBTRACT|SUM|SUPPRESS|SYMBOL|SYMBOLIC|SYNC|SYNCHRONIZED|TABLE|TALLY|TALLYING|TAPE|TASK|TERMINAL|TERMINATE|TEST|TEXT|THEN|THREAD|THREAD-LOCAL|THROUGH|THRU|TIME|TIMER|TIMES|TITLE|TO|TODAYS-DATE|TODAYS-NAME|TOP|TRAILING|TRUNCATED|TYPE|TYPEDEF|UNDERLINE|UNIT|UNSTRING|UNTIL|UP|UPON|USAGE|USE|USING|VALUE|VALUES|VARYING|VIRTUAL|WAIT|WHEN|WHEN-COMPILED|WITH|WORDS|WORKING-STORAGE|WRITE|YEAR|YYYYDDD|YYYYMMDD|ZERO-FILL|ZEROES|ZEROS)(?![\w-])/i,lookbehind:!0},boolean:{pattern:/(^|[^\w-])(?:false|true)(?![\w-])/i,lookbehind:!0},number:{pattern:/(^|[^\w-])(?:[+-]?(?:(?:\d+(?:[.,]\d+)?|[.,]\d+)(?:e[+-]?\d+)?|zero))(?![\w-])/i,lookbehind:!0},operator:[/<>|[<>]=?|[=+*/&]/,{pattern:/(^|[^\w-])(?:-|and|equal|greater|less|not|or|than)(?![\w-])/i,lookbehind:!0}],punctuation:/[.:,()]/}}return tv}var nv,RL;function Pbe(){if(RL)return nv;RL=1,nv=e,e.displayName="coffeescript",e.aliases=["coffee"];function e(t){(function(n){var r=/#(?!\{).+/,a={pattern:/#\{[^}]+\}/,alias:"variable"};n.languages.coffeescript=n.languages.extend("javascript",{comment:r,string:[{pattern:/'(?:\\[\s\S]|[^\\'])*'/,greedy:!0},{pattern:/"(?:\\[\s\S]|[^\\"])*"/,greedy:!0,inside:{interpolation:a}}],keyword:/\b(?:and|break|by|catch|class|continue|debugger|delete|do|each|else|extend|extends|false|finally|for|if|in|instanceof|is|isnt|let|loop|namespace|new|no|not|null|of|off|on|or|own|return|super|switch|then|this|throw|true|try|typeof|undefined|unless|until|when|while|window|with|yes|yield)\b/,"class-member":{pattern:/@(?!\d)\w+/,alias:"variable"}}),n.languages.insertBefore("coffeescript","comment",{"multiline-comment":{pattern:/###[\s\S]+?###/,alias:"comment"},"block-regex":{pattern:/\/{3}[\s\S]*?\/{3}/,alias:"regex",inside:{comment:r,interpolation:a}}}),n.languages.insertBefore("coffeescript","string",{"inline-javascript":{pattern:/`(?:\\[\s\S]|[^\\`])*`/,inside:{delimiter:{pattern:/^`|`$/,alias:"punctuation"},script:{pattern:/[\s\S]+/,alias:"language-javascript",inside:n.languages.javascript}}},"multiline-string":[{pattern:/'''[\s\S]*?'''/,greedy:!0,alias:"string"},{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string",inside:{interpolation:a}}]}),n.languages.insertBefore("coffeescript","keyword",{property:/(?!\d)\w+(?=\s*:(?!:))/}),delete n.languages.coffeescript["template-string"],n.languages.coffee=n.languages.coffeescript})(t)}return nv}var rv,CL;function Fbe(){if(CL)return rv;CL=1,rv=e,e.displayName="concurnas",e.aliases=["conc"];function e(t){t.languages.concurnas={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\/\/.*)/,lookbehind:!0,greedy:!0},langext:{pattern:/\b\w+\s*\|\|[\s\S]+?\|\|/,greedy:!0,inside:{"class-name":/^\w+/,string:{pattern:/(^\s*\|\|)[\s\S]+(?=\|\|$)/,lookbehind:!0},punctuation:/\|\|/}},function:{pattern:/((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/,lookbehind:!0},keyword:/\b(?:abstract|actor|also|annotation|assert|async|await|bool|boolean|break|byte|case|catch|changed|char|class|closed|constant|continue|def|default|del|double|elif|else|enum|every|extends|false|finally|float|for|from|global|gpudef|gpukernel|if|import|in|init|inject|int|lambda|local|long|loop|match|new|nodefault|null|of|onchange|open|out|override|package|parfor|parforsync|post|pre|private|protected|provide|provider|public|return|shared|short|single|size_t|sizeof|super|sync|this|throw|trait|trans|transient|true|try|typedef|unchecked|using|val|var|void|while|with)\b/,boolean:/\b(?:false|true)\b/,number:/\b0b[01][01_]*L?\b|\b0x(?:[\da-f_]*\.)?[\da-f_p+-]+\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfls]?/i,punctuation:/[{}[\];(),.:]/,operator:/<==|>==|=>|->|<-|<>|&==|&<>|\?:?|\.\?|\+\+|--|[-+*/=<>]=?|[!^~]|\b(?:and|as|band|bor|bxor|comp|is|isnot|mod|or)\b=?/,annotation:{pattern:/@(?:\w+:)?(?:\w+|\[[^\]]+\])?/,alias:"builtin"}},t.languages.insertBefore("concurnas","langext",{"regex-literal":{pattern:/\br("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:t.languages.concurnas},regex:/[\s\S]+/}},"string-literal":{pattern:/(?:\B|\bs)("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:t.languages.concurnas},string:/[\s\S]+/}}}),t.languages.conc=t.languages.concurnas}return rv}var av,_L;function zbe(){if(_L)return av;_L=1,av=e,e.displayName="coq",e.aliases=[];function e(t){(function(n){for(var r=/\(\*(?:[^(*]|\((?!\*)|\*(?!\))|<self>)*\*\)/.source,a=0;a<2;a++)r=r.replace(/<self>/g,function(){return r});r=r.replace(/<self>/g,"[]"),n.languages.coq={comment:RegExp(r),string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},attribute:[{pattern:RegExp(/#\[(?:[^\[\]("]|"(?:[^"]|"")*"(?!")|\((?!\*)|<comment>)*\]/.source.replace(/<comment>/g,function(){return r})),greedy:!0,alias:"attr-name",inside:{comment:RegExp(r),string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},operator:/=/,punctuation:/^#\[|\]$|[,()]/}},{pattern:/\b(?:Cumulative|Global|Local|Monomorphic|NonCumulative|Polymorphic|Private|Program)\b/,alias:"attr-name"}],keyword:/\b(?:Abort|About|Add|Admit|Admitted|All|Arguments|As|Assumptions|Axiom|Axioms|Back|BackTo|Backtrace|BinOp|BinOpSpec|BinRel|Bind|Blacklist|Canonical|Case|Cd|Check|Class|Classes|Close|CoFixpoint|CoInductive|Coercion|Coercions|Collection|Combined|Compute|Conjecture|Conjectures|Constant|Constants|Constraint|Constructors|Context|Corollary|Create|CstOp|Custom|Cut|Debug|Declare|Defined|Definition|Delimit|Dependencies|Dependent|Derive|Diffs|Drop|Elimination|End|Entry|Equality|Eval|Example|Existential|Existentials|Existing|Export|Extern|Extraction|Fact|Fail|Field|File|Firstorder|Fixpoint|Flags|Focus|From|Funclass|Function|Functional|GC|Generalizable|Goal|Grab|Grammar|Graph|Guarded|Haskell|Heap|Hide|Hint|HintDb|Hints|Hypotheses|Hypothesis|IF|Identity|Immediate|Implicit|Implicits|Import|Include|Induction|Inductive|Infix|Info|Initial|InjTyp|Inline|Inspect|Instance|Instances|Intro|Intros|Inversion|Inversion_clear|JSON|Language|Left|Lemma|Let|Lia|Libraries|Library|Load|LoadPath|Locate|Ltac|Ltac2|ML|Match|Method|Minimality|Module|Modules|Morphism|Next|NoInline|Notation|Number|OCaml|Obligation|Obligations|Opaque|Open|Optimize|Parameter|Parameters|Parametric|Path|Paths|Prenex|Preterm|Primitive|Print|Profile|Projections|Proof|Prop|PropBinOp|PropOp|PropUOp|Property|Proposition|Pwd|Qed|Quit|Rec|Record|Recursive|Redirect|Reduction|Register|Relation|Remark|Remove|Require|Reserved|Reset|Resolve|Restart|Rewrite|Right|Ring|Rings|SProp|Saturate|Save|Scheme|Scope|Scopes|Search|SearchHead|SearchPattern|SearchRewrite|Section|Separate|Set|Setoid|Show|Signatures|Solve|Solver|Sort|Sortclass|Sorted|Spec|Step|Strategies|Strategy|String|Structure|SubClass|Subgraph|SuchThat|Tactic|Term|TestCompile|Theorem|Time|Timeout|To|Transparent|Type|Typeclasses|Types|Typing|UnOp|UnOpSpec|Undelimit|Undo|Unfocus|Unfocused|Unfold|Universe|Universes|Unshelve|Variable|Variables|Variant|Verbose|View|Visibility|Zify|_|apply|as|at|by|cofix|else|end|exists|exists2|fix|for|forall|fun|if|in|let|match|measure|move|removed|return|struct|then|using|wf|where|with)\b/,number:/\b(?:0x[a-f0-9][a-f0-9_]*(?:\.[a-f0-9_]+)?(?:p[+-]?\d[\d_]*)?|\d[\d_]*(?:\.[\d_]+)?(?:e[+-]?\d[\d_]*)?)\b/i,punct:{pattern:/@\{|\{\||\[=|:>/,alias:"punctuation"},operator:/\/\\|\\\/|\.{2,3}|:{1,2}=|\*\*|[-=]>|<(?:->?|[+:=>]|<:)|>(?:=|->)|\|[-|]?|[-!%&*+/<=>?@^~']/,punctuation:/\.\(|`\(|@\{|`\{|\{\||\[=|:>|[:.,;(){}\[\]]/}})(t)}return av}var ov,NL;function Bp(){if(NL)return ov;NL=1,ov=e,e.displayName="ruby",e.aliases=["rb"];function e(t){(function(n){n.languages.ruby=n.languages.extend("clike",{comment:{pattern:/#.*|^=begin\s[\s\S]*?^=end/m,greedy:!0},"class-name":{pattern:/(\b(?:class|module)\s+|\bcatch\s+\()[\w.\\]+|\b[A-Z_]\w*(?=\s*\.\s*new\b)/,lookbehind:!0,inside:{punctuation:/[.\\]/}},keyword:/\b(?:BEGIN|END|alias|and|begin|break|case|class|def|define_method|defined|do|each|else|elsif|end|ensure|extend|for|if|in|include|module|new|next|nil|not|or|prepend|private|protected|public|raise|redo|require|rescue|retry|return|self|super|then|throw|undef|unless|until|when|while|yield)\b/,operator:/\.{2,3}|&\.|===|<?=>|[!=]?~|(?:&&|\|\||<<|>>|\*\*|[+\-*/%<>!^&|=])=?|[?:]/,punctuation:/[(){}[\].,;]/}),n.languages.insertBefore("ruby","operator",{"double-colon":{pattern:/::/,alias:"punctuation"}});var r={pattern:/((?:^|[^\\])(?:\\{2})*)#\{(?:[^{}]|\{[^{}]*\})*\}/,lookbehind:!0,inside:{content:{pattern:/^(#\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:n.languages.ruby},delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"}}};delete n.languages.ruby.function;var a="(?:"+[/([^a-zA-Z0-9\s{(\[<=])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/\((?:[^()\\]|\\[\s\S]|\((?:[^()\\]|\\[\s\S])*\))*\)/.source,/\{(?:[^{}\\]|\\[\s\S]|\{(?:[^{}\\]|\\[\s\S])*\})*\}/.source,/\[(?:[^\[\]\\]|\\[\s\S]|\[(?:[^\[\]\\]|\\[\s\S])*\])*\]/.source,/<(?:[^<>\\]|\\[\s\S]|<(?:[^<>\\]|\\[\s\S])*>)*>/.source].join("|")+")",o=/(?:"(?:\\.|[^"\\\r\n])*"|(?:\b[a-zA-Z_]\w*|[^\s\0-\x7F]+)[?!]?|\$.)/.source;n.languages.insertBefore("ruby","keyword",{"regex-literal":[{pattern:RegExp(/%r/.source+a+/[egimnosux]{0,6}/.source),greedy:!0,inside:{interpolation:r,regex:/[\s\S]+/}},{pattern:/(^|[^/])\/(?!\/)(?:\[[^\r\n\]]+\]|\\.|[^[/\\\r\n])+\/[egimnosux]{0,6}(?=\s*(?:$|[\r\n,.;})#]))/,lookbehind:!0,greedy:!0,inside:{interpolation:r,regex:/[\s\S]+/}}],variable:/[@$]+[a-zA-Z_]\w*(?:[?!]|\b)/,symbol:[{pattern:RegExp(/(^|[^:]):/.source+o),lookbehind:!0,greedy:!0},{pattern:RegExp(/([\r\n{(,][ \t]*)/.source+o+/(?=:(?!:))/.source),lookbehind:!0,greedy:!0}],"method-definition":{pattern:/(\bdef\s+)\w+(?:\s*\.\s*\w+)?/,lookbehind:!0,inside:{function:/\b\w+$/,keyword:/^self\b/,"class-name":/^\w+/,punctuation:/\./}}}),n.languages.insertBefore("ruby","string",{"string-literal":[{pattern:RegExp(/%[qQiIwWs]?/.source+a),greedy:!0,inside:{interpolation:r,string:/[\s\S]+/}},{pattern:/("|')(?:#\{[^}]+\}|#(?!\{)|\\(?:\r\n|[\s\S])|(?!\1)[^\\#\r\n])*\1/,greedy:!0,inside:{interpolation:r,string:/[\s\S]+/}},{pattern:/<<[-~]?([a-z_]\w*)[\r\n](?:.*[\r\n])*?[\t ]*\1/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<[-~]?[a-z_]\w*|\b[a-z_]\w*$/i,inside:{symbol:/\b\w+/,punctuation:/^<<[-~]?/}},interpolation:r,string:/[\s\S]+/}},{pattern:/<<[-~]?'([a-z_]\w*)'[\r\n](?:.*[\r\n])*?[\t ]*\1/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<[-~]?'[a-z_]\w*'|\b[a-z_]\w*$/i,inside:{symbol:/\b\w+/,punctuation:/^<<[-~]?'|'$/}},string:/[\s\S]+/}}],"command-literal":[{pattern:RegExp(/%x/.source+a),greedy:!0,inside:{interpolation:r,command:{pattern:/[\s\S]+/,alias:"string"}}},{pattern:/`(?:#\{[^}]+\}|#(?!\{)|\\(?:\r\n|[\s\S])|[^\\`#\r\n])*`/,greedy:!0,inside:{interpolation:r,command:{pattern:/[\s\S]+/,alias:"string"}}}]}),delete n.languages.ruby.string,n.languages.insertBefore("ruby","number",{builtin:/\b(?:Array|Bignum|Binding|Class|Continuation|Dir|Exception|FalseClass|File|Fixnum|Float|Hash|IO|Integer|MatchData|Method|Module|NilClass|Numeric|Object|Proc|Range|Regexp|Stat|String|Struct|Symbol|TMS|Thread|ThreadGroup|Time|TrueClass)\b/,constant:/\b[A-Z][A-Z0-9_]*(?:[?!]|\b)/}),n.languages.rb=n.languages.ruby})(t)}return ov}var iv,OL;function Bbe(){if(OL)return iv;OL=1;var e=Bp();iv=t,t.displayName="crystal",t.aliases=[];function t(n){n.register(e),function(r){r.languages.crystal=r.languages.extend("ruby",{keyword:[/\b(?:__DIR__|__END_LINE__|__FILE__|__LINE__|abstract|alias|annotation|as|asm|begin|break|case|class|def|do|else|elsif|end|ensure|enum|extend|for|fun|if|ifdef|include|instance_sizeof|lib|macro|module|next|of|out|pointerof|private|protected|ptr|require|rescue|return|select|self|sizeof|struct|super|then|type|typeof|undef|uninitialized|union|unless|until|when|while|with|yield)\b/,{pattern:/(\.\s*)(?:is_a|responds_to)\?/,lookbehind:!0}],number:/\b(?:0b[01_]*[01]|0o[0-7_]*[0-7]|0x[\da-fA-F_]*[\da-fA-F]|(?:\d(?:[\d_]*\d)?)(?:\.[\d_]*\d)?(?:[eE][+-]?[\d_]*\d)?)(?:_(?:[uif](?:8|16|32|64))?)?\b/,operator:[/->/,r.languages.ruby.operator],punctuation:/[(){}[\].,;\\]/}),r.languages.insertBefore("crystal","string-literal",{attribute:{pattern:/@\[.*?\]/,inside:{delimiter:{pattern:/^@\[|\]$/,alias:"punctuation"},attribute:{pattern:/^(\s*)\w+/,lookbehind:!0,alias:"class-name"},args:{pattern:/\S(?:[\s\S]*\S)?/,inside:r.languages.crystal}}},expansion:{pattern:/\{(?:\{.*?\}|%.*?%)\}/,inside:{content:{pattern:/^(\{.)[\s\S]+(?=.\}$)/,lookbehind:!0,inside:r.languages.crystal},delimiter:{pattern:/^\{[\{%]|[\}%]\}$/,alias:"operator"}}},char:{pattern:/'(?:[^\\\r\n]{1,2}|\\(?:.|u(?:[A-Fa-f0-9]{1,4}|\{[A-Fa-f0-9]{1,6}\})))'/,greedy:!0}})}(n)}return iv}var sv,IL;function jbe(){if(IL)return sv;IL=1;var e=zp();sv=t,t.displayName="cshtml",t.aliases=["razor"];function t(n){n.register(e),function(r){var a=/\/(?![/*])|\/\/.*[\r\n]|\/\*[^*]*(?:\*(?!\/)[^*]*)*\*\//.source,o=/@(?!")|"(?:[^\r\n\\"]|\\.)*"|@"(?:[^\\"]|""|\\[\s\S])*"(?!")/.source+"|"+/'(?:(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'|(?=[^\\](?!')))/.source;function s(k,A){for(var x=0;x<A;x++)k=k.replace(/<self>/g,function(){return"(?:"+k+")"});return k.replace(/<self>/g,"[^\\s\\S]").replace(/<str>/g,"(?:"+o+")").replace(/<comment>/g,"(?:"+a+")")}var l=s(/\((?:[^()'"@/]|<str>|<comment>|<self>)*\)/.source,2),u=s(/\[(?:[^\[\]'"@/]|<str>|<comment>|<self>)*\]/.source,2),d=s(/\{(?:[^{}'"@/]|<str>|<comment>|<self>)*\}/.source,2),p=s(/<(?:[^<>'"@/]|<str>|<comment>|<self>)*>/.source,2),g=/(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?/.source,m=/(?!\d)[^\s>\/=$<%]+/.source+g+/\s*\/?>/.source,b=/\B@?/.source+"(?:"+/<([a-zA-Z][\w:]*)/.source+g+/\s*>/.source+"(?:"+(/[^<]/.source+"|"+/<\/?(?!\1\b)/.source+m+"|"+s(/<\1/.source+g+/\s*>/.source+"(?:"+(/[^<]/.source+"|"+/<\/?(?!\1\b)/.source+m+"|<self>")+")*"+/<\/\1\s*>/.source,2))+")*"+/<\/\1\s*>/.source+"|"+/</.source+m+")";r.languages.cshtml=r.languages.extend("markup",{});var v=r.languages.insertBefore("csharp","string",{html:{pattern:RegExp(b),greedy:!0,inside:r.languages.cshtml}},{csharp:r.languages.extend("csharp",{})}),y={pattern:/\S[\s\S]*/,alias:"language-csharp",inside:v};r.languages.insertBefore("cshtml","prolog",{"razor-comment":{pattern:/@\*[\s\S]*?\*@/,greedy:!0,alias:"comment"},block:{pattern:RegExp(/(^|[^@])@/.source+"(?:"+[d,/(?:code|functions)\s*/.source+d,/(?:for|foreach|lock|switch|using|while)\s*/.source+l+/\s*/.source+d,/do\s*/.source+d+/\s*while\s*/.source+l+/(?:\s*;)?/.source,/try\s*/.source+d+/\s*catch\s*/.source+l+/\s*/.source+d+/\s*finally\s*/.source+d,/if\s*/.source+l+/\s*/.source+d+"(?:"+/\s*else/.source+"(?:"+/\s+if\s*/.source+l+")?"+/\s*/.source+d+")*"].join("|")+")"),lookbehind:!0,greedy:!0,inside:{keyword:/^@\w*/,csharp:y}},directive:{pattern:/^([ \t]*)@(?:addTagHelper|attribute|implements|inherits|inject|layout|model|namespace|page|preservewhitespace|removeTagHelper|section|tagHelperPrefix|using)(?=\s).*/m,lookbehind:!0,greedy:!0,inside:{keyword:/^@\w+/,csharp:y}},value:{pattern:RegExp(/(^|[^@])@/.source+/(?:await\b\s*)?/.source+"(?:"+/\w+\b/.source+"|"+l+")(?:"+/[?!]?\.\w+\b/.source+"|"+l+"|"+u+"|"+p+l+")*"),lookbehind:!0,greedy:!0,alias:"variable",inside:{keyword:/^@/,csharp:y}},"delegate-operator":{pattern:/(^|[^@])@(?=<)/,lookbehind:!0,alias:"operator"}}),r.languages.razor=r.languages.cshtml}(n)}return sv}var lv,DL;function Ube(){if(DL)return lv;DL=1,lv=e,e.displayName="csp",e.aliases=[];function e(t){(function(n){function r(a){return RegExp(/([ \t])/.source+"(?:"+a+")"+/(?=[\s;]|$)/.source,"i")}n.languages.csp={directive:{pattern:/(^|[\s;])(?:base-uri|block-all-mixed-content|(?:child|connect|default|font|frame|img|manifest|media|object|prefetch|script|style|worker)-src|disown-opener|form-action|frame-(?:ancestors|options)|input-protection(?:-(?:clip|selectors))?|navigate-to|plugin-types|policy-uri|referrer|reflected-xss|report-(?:to|uri)|require-sri-for|sandbox|(?:script|style)-src-(?:attr|elem)|upgrade-insecure-requests)(?=[\s;]|$)/i,lookbehind:!0,alias:"property"},scheme:{pattern:r(/[a-z][a-z0-9.+-]*:/.source),lookbehind:!0},none:{pattern:r(/'none'/.source),lookbehind:!0,alias:"keyword"},nonce:{pattern:r(/'nonce-[-+/\w=]+'/.source),lookbehind:!0,alias:"number"},hash:{pattern:r(/'sha(?:256|384|512)-[-+/\w=]+'/.source),lookbehind:!0,alias:"number"},host:{pattern:r(/[a-z][a-z0-9.+-]*:\/\/[^\s;,']*/.source+"|"+/\*[^\s;,']*/.source+"|"+/[a-z0-9-]+(?:\.[a-z0-9-]+)+(?::[\d*]+)?(?:\/[^\s;,']*)?/.source),lookbehind:!0,alias:"url",inside:{important:/\*/}},keyword:[{pattern:r(/'unsafe-[a-z-]+'/.source),lookbehind:!0,alias:"unsafe"},{pattern:r(/'[a-z-]+'/.source),lookbehind:!0,alias:"safe"}],punctuation:/;/}})(t)}return lv}var cv,LL;function Gbe(){if(LL)return cv;LL=1,cv=e,e.displayName="cssExtras",e.aliases=[];function e(t){(function(n){var r=/("|')(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,a;n.languages.css.selector={pattern:n.languages.css.selector.pattern,lookbehind:!0,inside:a={"pseudo-element":/:(?:after|before|first-letter|first-line|selection)|::[-\w]+/,"pseudo-class":/:[-\w]+/,class:/\.[-\w]+/,id:/#[-\w]+/,attribute:{pattern:RegExp(`\\[(?:[^[\\]"']|`+r.source+")*\\]"),greedy:!0,inside:{punctuation:/^\[|\]$/,"case-sensitivity":{pattern:/(\s)[si]$/i,lookbehind:!0,alias:"keyword"},namespace:{pattern:/^(\s*)(?:(?!\s)[-*\w\xA0-\uFFFF])*\|(?!=)/,lookbehind:!0,inside:{punctuation:/\|$/}},"attr-name":{pattern:/^(\s*)(?:(?!\s)[-\w\xA0-\uFFFF])+/,lookbehind:!0},"attr-value":[r,{pattern:/(=\s*)(?:(?!\s)[-\w\xA0-\uFFFF])+(?=\s*$)/,lookbehind:!0}],operator:/[|~*^$]?=/}},"n-th":[{pattern:/(\(\s*)[+-]?\d*[\dn](?:\s*[+-]\s*\d+)?(?=\s*\))/,lookbehind:!0,inside:{number:/[\dn]+/,operator:/[+-]/}},{pattern:/(\(\s*)(?:even|odd)(?=\s*\))/i,lookbehind:!0}],combinator:/>|\+|~|\|\|/,punctuation:/[(),]/}},n.languages.css.atrule.inside["selector-function-argument"].inside=a,n.languages.insertBefore("css","property",{variable:{pattern:/(^|[^-\w\xA0-\uFFFF])--(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*/i,lookbehind:!0}});var o={pattern:/(\b\d+)(?:%|[a-z]+(?![\w-]))/,lookbehind:!0},s={pattern:/(^|[^\w.-])-?(?:\d+(?:\.\d+)?|\.\d+)/,lookbehind:!0};n.languages.insertBefore("css","function",{operator:{pattern:/(\s)[+\-*\/](?=\s)/,lookbehind:!0},hexcode:{pattern:/\B#[\da-f]{3,8}\b/i,alias:"color"},color:[{pattern:/(^|[^\w-])(?:AliceBlue|AntiqueWhite|Aqua|Aquamarine|Azure|Beige|Bisque|Black|BlanchedAlmond|Blue|BlueViolet|Brown|BurlyWood|CadetBlue|Chartreuse|Chocolate|Coral|CornflowerBlue|Cornsilk|Crimson|Cyan|DarkBlue|DarkCyan|DarkGoldenRod|DarkGr[ae]y|DarkGreen|DarkKhaki|DarkMagenta|DarkOliveGreen|DarkOrange|DarkOrchid|DarkRed|DarkSalmon|DarkSeaGreen|DarkSlateBlue|DarkSlateGr[ae]y|DarkTurquoise|DarkViolet|DeepPink|DeepSkyBlue|DimGr[ae]y|DodgerBlue|FireBrick|FloralWhite|ForestGreen|Fuchsia|Gainsboro|GhostWhite|Gold|GoldenRod|Gr[ae]y|Green|GreenYellow|HoneyDew|HotPink|IndianRed|Indigo|Ivory|Khaki|Lavender|LavenderBlush|LawnGreen|LemonChiffon|LightBlue|LightCoral|LightCyan|LightGoldenRodYellow|LightGr[ae]y|LightGreen|LightPink|LightSalmon|LightSeaGreen|LightSkyBlue|LightSlateGr[ae]y|LightSteelBlue|LightYellow|Lime|LimeGreen|Linen|Magenta|Maroon|MediumAquaMarine|MediumBlue|MediumOrchid|MediumPurple|MediumSeaGreen|MediumSlateBlue|MediumSpringGreen|MediumTurquoise|MediumVioletRed|MidnightBlue|MintCream|MistyRose|Moccasin|NavajoWhite|Navy|OldLace|Olive|OliveDrab|Orange|OrangeRed|Orchid|PaleGoldenRod|PaleGreen|PaleTurquoise|PaleVioletRed|PapayaWhip|PeachPuff|Peru|Pink|Plum|PowderBlue|Purple|Red|RosyBrown|RoyalBlue|SaddleBrown|Salmon|SandyBrown|SeaGreen|SeaShell|Sienna|Silver|SkyBlue|SlateBlue|SlateGr[ae]y|Snow|SpringGreen|SteelBlue|Tan|Teal|Thistle|Tomato|Transparent|Turquoise|Violet|Wheat|White|WhiteSmoke|Yellow|YellowGreen)(?![\w-])/i,lookbehind:!0},{pattern:/\b(?:hsl|rgb)\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*\)\B|\b(?:hsl|rgb)a\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*,\s*(?:0|0?\.\d+|1)\s*\)\B/i,inside:{unit:o,number:s,function:/[\w-]+(?=\()/,punctuation:/[(),]/}}],entity:/\\[\da-f]{1,8}/i,unit:o,number:s})})(t)}return cv}var uv,ML;function Hbe(){if(ML)return uv;ML=1,uv=e,e.displayName="csv",e.aliases=[];function e(t){t.languages.csv={value:/[^\r\n,"]+|"(?:[^"]|"")*"(?!")/,punctuation:/,/}}return uv}var dv,PL;function $be(){if(PL)return dv;PL=1,dv=e,e.displayName="cypher",e.aliases=[];function e(t){t.languages.cypher={comment:/\/\/.*/,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/,greedy:!0},"class-name":{pattern:/(:\s*)(?:\w+|`(?:[^`\\\r\n])*`)(?=\s*[{):])/,lookbehind:!0,greedy:!0},relationship:{pattern:/(-\[\s*(?:\w+\s*|`(?:[^`\\\r\n])*`\s*)?:\s*|\|\s*:\s*)(?:\w+|`(?:[^`\\\r\n])*`)/,lookbehind:!0,greedy:!0,alias:"property"},identifier:{pattern:/`(?:[^`\\\r\n])*`/,greedy:!0},variable:/\$\w+/,keyword:/\b(?:ADD|ALL|AND|AS|ASC|ASCENDING|ASSERT|BY|CALL|CASE|COMMIT|CONSTRAINT|CONTAINS|CREATE|CSV|DELETE|DESC|DESCENDING|DETACH|DISTINCT|DO|DROP|ELSE|END|ENDS|EXISTS|FOR|FOREACH|IN|INDEX|IS|JOIN|KEY|LIMIT|LOAD|MANDATORY|MATCH|MERGE|NODE|NOT|OF|ON|OPTIONAL|OR|ORDER(?=\s+BY)|PERIODIC|REMOVE|REQUIRE|RETURN|SCALAR|SCAN|SET|SKIP|START|STARTS|THEN|UNION|UNIQUE|UNWIND|USING|WHEN|WHERE|WITH|XOR|YIELD)\b/i,function:/\b\w+\b(?=\s*\()/,boolean:/\b(?:false|null|true)\b/i,number:/\b(?:0x[\da-fA-F]+|\d+(?:\.\d+)?(?:[eE][+-]?\d+)?)\b/,operator:/:|<--?|--?>?|<>|=~?|[<>]=?|[+*/%^|]|\.\.\.?/,punctuation:/[()[\]{},;.]/}}return dv}var fv,FL;function qbe(){if(FL)return fv;FL=1,fv=e,e.displayName="d",e.aliases=[];function e(t){t.languages.d=t.languages.extend("clike",{comment:[{pattern:/^\s*#!.+/,greedy:!0},{pattern:RegExp(/(^|[^\\])/.source+"(?:"+[/\/\+(?:\/\+(?:[^+]|\+(?!\/))*\+\/|(?!\/\+)[\s\S])*?\+\//.source,/\/\/.*/.source,/\/\*[\s\S]*?\*\//.source].join("|")+")"),lookbehind:!0,greedy:!0}],string:[{pattern:RegExp([/\b[rx]"(?:\\[\s\S]|[^\\"])*"[cwd]?/.source,/\bq"(?:\[[\s\S]*?\]|\([\s\S]*?\)|<[\s\S]*?>|\{[\s\S]*?\})"/.source,/\bq"((?!\d)\w+)$[\s\S]*?^\1"/.source,/\bq"(.)[\s\S]*?\2"/.source,/(["`])(?:\\[\s\S]|(?!\3)[^\\])*\3[cwd]?/.source].join("|"),"m"),greedy:!0},{pattern:/\bq\{(?:\{[^{}]*\}|[^{}])*\}/,greedy:!0,alias:"token-string"}],keyword:/\$|\b(?:__(?:(?:DATE|EOF|FILE|FUNCTION|LINE|MODULE|PRETTY_FUNCTION|TIMESTAMP|TIME|VENDOR|VERSION)__|gshared|parameters|traits|vector)|abstract|alias|align|asm|assert|auto|body|bool|break|byte|case|cast|catch|cdouble|cent|cfloat|char|class|const|continue|creal|dchar|debug|default|delegate|delete|deprecated|do|double|dstring|else|enum|export|extern|false|final|finally|float|for|foreach|foreach_reverse|function|goto|idouble|if|ifloat|immutable|import|inout|int|interface|invariant|ireal|lazy|long|macro|mixin|module|new|nothrow|null|out|override|package|pragma|private|protected|ptrdiff_t|public|pure|real|ref|return|scope|shared|short|size_t|static|string|struct|super|switch|synchronized|template|this|throw|true|try|typedef|typeid|typeof|ubyte|ucent|uint|ulong|union|unittest|ushort|version|void|volatile|wchar|while|with|wstring)\b/,number:[/\b0x\.?[a-f\d_]+(?:(?!\.\.)\.[a-f\d_]*)?(?:p[+-]?[a-f\d_]+)?[ulfi]{0,4}/i,{pattern:/((?:\.\.)?)(?:\b0b\.?|\b|\.)\d[\d_]*(?:(?!\.\.)\.[\d_]*)?(?:e[+-]?\d[\d_]*)?[ulfi]{0,4}/i,lookbehind:!0}],operator:/\|[|=]?|&[&=]?|\+[+=]?|-[-=]?|\.?\.\.|=[>=]?|!(?:i[ns]\b|<>?=?|>=?|=)?|\bi[ns]\b|(?:<[<>]?|>>?>?|\^\^|[*\/%^~])=?/}),t.languages.insertBefore("d","string",{char:/'(?:\\(?:\W|\w+)|[^\\])'/}),t.languages.insertBefore("d","keyword",{property:/\B@\w*/}),t.languages.insertBefore("d","function",{register:{pattern:/\b(?:[ABCD][LHX]|E?(?:BP|DI|SI|SP)|[BS]PL|[ECSDGF]S|CR[0234]|[DS]IL|DR[012367]|E[ABCD]X|X?MM[0-7]|R(?:1[0-5]|[89])[BWD]?|R[ABCD]X|R[BS]P|R[DS]I|TR[3-7]|XMM(?:1[0-5]|[89])|YMM(?:1[0-5]|\d))\b|\bST(?:\([0-7]\)|\b)/,alias:"variable"}})}return fv}var pv,zL;function Vbe(){if(zL)return pv;zL=1,pv=e,e.displayName="dart",e.aliases=[];function e(t){(function(n){var r=[/\b(?:async|sync|yield)\*/,/\b(?:abstract|assert|async|await|break|case|catch|class|const|continue|covariant|default|deferred|do|dynamic|else|enum|export|extends|extension|external|factory|final|finally|for|get|hide|if|implements|import|in|interface|library|mixin|new|null|on|operator|part|rethrow|return|set|show|static|super|switch|sync|this|throw|try|typedef|var|void|while|with|yield)\b/],a=/(^|[^\w.])(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source,o={pattern:RegExp(a+/[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}}}};n.languages.dart=n.languages.extend("clike",{"class-name":[o,{pattern:RegExp(a+/[A-Z]\w*(?=\s+\w+\s*[;,=()])/.source),lookbehind:!0,inside:o.inside}],keyword:r,operator:/\bis!|\b(?:as|is)\b|\+\+|--|&&|\|\||<<=?|>>=?|~(?:\/=?)?|[+\-*\/%&^|=!<>]=?|\?/}),n.languages.insertBefore("dart","string",{"string-literal":{pattern:/r?(?:("""|''')[\s\S]*?\1|(["'])(?:\\.|(?!\2)[^\\\r\n])*\2(?!\2))/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\w+|\{(?:[^{}]|\{[^{}]*\})*\})/,lookbehind:!0,inside:{punctuation:/^\$\{?|\}$/,expression:{pattern:/[\s\S]+/,inside:n.languages.dart}}},string:/[\s\S]+/}},string:void 0}),n.languages.insertBefore("dart","class-name",{metadata:{pattern:/@\w+/,alias:"function"}}),n.languages.insertBefore("dart","class-name",{generics:{pattern:/<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<[\w\s,.&?]*>)*>)*>)*>/,inside:{"class-name":o,keyword:r,punctuation:/[<>(),.:]/,operator:/[?&|]/}}})})(t)}return pv}var gv,BL;function Wbe(){if(BL)return gv;BL=1,gv=e,e.displayName="dataweave",e.aliases=[];function e(t){(function(n){n.languages.dataweave={url:/\b[A-Za-z]+:\/\/[\w/:.?=&-]+|\burn:[\w:.?=&-]+/,property:{pattern:/(?:\b\w+#)?(?:"(?:\\.|[^\\"\r\n])*"|\b\w+)(?=\s*[:@])/,greedy:!0},string:{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},"mime-type":/\b(?:application|audio|image|multipart|text|video)\/[\w+-]+/,date:{pattern:/\|[\w:+-]+\|/,greedy:!0},comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],regex:{pattern:/\/(?:[^\\\/\r\n]|\\[^\r\n])+\//,greedy:!0},keyword:/\b(?:and|as|at|case|do|else|fun|if|input|is|match|not|ns|null|or|output|type|unless|update|using|var)\b/,function:/\b[A-Z_]\w*(?=\s*\()/i,number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,punctuation:/[{}[\];(),.:@]/,operator:/<<|>>|->|[<>~=]=?|!=|--?-?|\+\+?|!|\?/,boolean:/\b(?:false|true)\b/}})(t)}return gv}var hv,jL;function Ybe(){if(jL)return hv;jL=1,hv=e,e.displayName="dax",e.aliases=[];function e(t){t.languages.dax={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/).*)/,lookbehind:!0},"data-field":{pattern:/'(?:[^']|'')*'(?!')(?:\[[ \w\xA0-\uFFFF]+\])?|\w+\[[ \w\xA0-\uFFFF]+\]/,alias:"symbol"},measure:{pattern:/\[[ \w\xA0-\uFFFF]+\]/,alias:"constant"},string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},function:/\b(?:ABS|ACOS|ACOSH|ACOT|ACOTH|ADDCOLUMNS|ADDMISSINGITEMS|ALL|ALLCROSSFILTERED|ALLEXCEPT|ALLNOBLANKROW|ALLSELECTED|AND|APPROXIMATEDISTINCTCOUNT|ASIN|ASINH|ATAN|ATANH|AVERAGE|AVERAGEA|AVERAGEX|BETA\.DIST|BETA\.INV|BLANK|CALCULATE|CALCULATETABLE|CALENDAR|CALENDARAUTO|CEILING|CHISQ\.DIST|CHISQ\.DIST\.RT|CHISQ\.INV|CHISQ\.INV\.RT|CLOSINGBALANCEMONTH|CLOSINGBALANCEQUARTER|CLOSINGBALANCEYEAR|COALESCE|COMBIN|COMBINA|COMBINEVALUES|CONCATENATE|CONCATENATEX|CONFIDENCE\.NORM|CONFIDENCE\.T|CONTAINS|CONTAINSROW|CONTAINSSTRING|CONTAINSSTRINGEXACT|CONVERT|COS|COSH|COT|COTH|COUNT|COUNTA|COUNTAX|COUNTBLANK|COUNTROWS|COUNTX|CROSSFILTER|CROSSJOIN|CURRENCY|CURRENTGROUP|CUSTOMDATA|DATATABLE|DATE|DATEADD|DATEDIFF|DATESBETWEEN|DATESINPERIOD|DATESMTD|DATESQTD|DATESYTD|DATEVALUE|DAY|DEGREES|DETAILROWS|DISTINCT|DISTINCTCOUNT|DISTINCTCOUNTNOBLANK|DIVIDE|EARLIER|EARLIEST|EDATE|ENDOFMONTH|ENDOFQUARTER|ENDOFYEAR|EOMONTH|ERROR|EVEN|EXACT|EXCEPT|EXP|EXPON\.DIST|FACT|FALSE|FILTER|FILTERS|FIND|FIRSTDATE|FIRSTNONBLANK|FIRSTNONBLANKVALUE|FIXED|FLOOR|FORMAT|GCD|GENERATE|GENERATEALL|GENERATESERIES|GEOMEAN|GEOMEANX|GROUPBY|HASONEFILTER|HASONEVALUE|HOUR|IF|IF\.EAGER|IFERROR|IGNORE|INT|INTERSECT|ISBLANK|ISCROSSFILTERED|ISEMPTY|ISERROR|ISEVEN|ISFILTERED|ISINSCOPE|ISLOGICAL|ISNONTEXT|ISNUMBER|ISO\.CEILING|ISODD|ISONORAFTER|ISSELECTEDMEASURE|ISSUBTOTAL|ISTEXT|KEEPFILTERS|KEYWORDMATCH|LASTDATE|LASTNONBLANK|LASTNONBLANKVALUE|LCM|LEFT|LEN|LN|LOG|LOG10|LOOKUPVALUE|LOWER|MAX|MAXA|MAXX|MEDIAN|MEDIANX|MID|MIN|MINA|MINUTE|MINX|MOD|MONTH|MROUND|NATURALINNERJOIN|NATURALLEFTOUTERJOIN|NEXTDAY|NEXTMONTH|NEXTQUARTER|NEXTYEAR|NONVISUAL|NORM\.DIST|NORM\.INV|NORM\.S\.DIST|NORM\.S\.INV|NOT|NOW|ODD|OPENINGBALANCEMONTH|OPENINGBALANCEQUARTER|OPENINGBALANCEYEAR|OR|PARALLELPERIOD|PATH|PATHCONTAINS|PATHITEM|PATHITEMREVERSE|PATHLENGTH|PERCENTILE\.EXC|PERCENTILE\.INC|PERCENTILEX\.EXC|PERCENTILEX\.INC|PERMUT|PI|POISSON\.DIST|POWER|PREVIOUSDAY|PREVIOUSMONTH|PREVIOUSQUARTER|PREVIOUSYEAR|PRODUCT|PRODUCTX|QUARTER|QUOTIENT|RADIANS|RAND|RANDBETWEEN|RANK\.EQ|RANKX|RELATED|RELATEDTABLE|REMOVEFILTERS|REPLACE|REPT|RIGHT|ROLLUP|ROLLUPADDISSUBTOTAL|ROLLUPGROUP|ROLLUPISSUBTOTAL|ROUND|ROUNDDOWN|ROUNDUP|ROW|SAMEPERIODLASTYEAR|SAMPLE|SEARCH|SECOND|SELECTCOLUMNS|SELECTEDMEASURE|SELECTEDMEASUREFORMATSTRING|SELECTEDMEASURENAME|SELECTEDVALUE|SIGN|SIN|SINH|SQRT|SQRTPI|STARTOFMONTH|STARTOFQUARTER|STARTOFYEAR|STDEV\.P|STDEV\.S|STDEVX\.P|STDEVX\.S|SUBSTITUTE|SUBSTITUTEWITHINDEX|SUM|SUMMARIZE|SUMMARIZECOLUMNS|SUMX|SWITCH|T\.DIST|T\.DIST\.2T|T\.DIST\.RT|T\.INV|T\.INV\.2T|TAN|TANH|TIME|TIMEVALUE|TODAY|TOPN|TOPNPERLEVEL|TOPNSKIP|TOTALMTD|TOTALQTD|TOTALYTD|TREATAS|TRIM|TRUE|TRUNC|UNICHAR|UNICODE|UNION|UPPER|USERELATIONSHIP|USERNAME|USEROBJECTID|USERPRINCIPALNAME|UTCNOW|UTCTODAY|VALUE|VALUES|VAR\.P|VAR\.S|VARX\.P|VARX\.S|WEEKDAY|WEEKNUM|XIRR|XNPV|YEAR|YEARFRAC)(?=\s*\()/i,keyword:/\b(?:DEFINE|EVALUATE|MEASURE|ORDER\s+BY|RETURN|VAR|START\s+AT|ASC|DESC)\b/i,boolean:{pattern:/\b(?:FALSE|NULL|TRUE)\b/i,alias:"constant"},number:/\b\d+(?:\.\d*)?|\B\.\d+\b/,operator:/:=|[-+*\/=^]|&&?|\|\||<(?:=>?|<|>)?|>[>=]?|\b(?:IN|NOT)\b/i,punctuation:/[;\[\](){}`,.]/}}return hv}var mv,UL;function Kbe(){if(UL)return mv;UL=1,mv=e,e.displayName="dhall",e.aliases=[];function e(t){t.languages.dhall={comment:/--.*|\{-(?:[^-{]|-(?!\})|\{(?!-)|\{-(?:[^-{]|-(?!\})|\{(?!-))*-\})*-\}/,string:{pattern:/"(?:[^"\\]|\\.)*"|''(?:[^']|'(?!')|'''|''\$\{)*''(?!'|\$)/,greedy:!0,inside:{interpolation:{pattern:/\$\{[^{}]*\}/,inside:{expression:{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0,alias:"language-dhall",inside:null},punctuation:/\$\{|\}/}}}},label:{pattern:/`[^`]*`/,greedy:!0},url:{pattern:/\bhttps?:\/\/[\w.:%!$&'*+;=@~-]+(?:\/[\w.:%!$&'*+;=@~-]*)*(?:\?[/?\w.:%!$&'*+;=@~-]*)?/,greedy:!0},env:{pattern:/\benv:(?:(?!\d)\w+|"(?:[^"\\=]|\\.)*")/,greedy:!0,inside:{function:/^env/,operator:/^:/,variable:/[\s\S]+/}},hash:{pattern:/\bsha256:[\da-fA-F]{64}\b/,inside:{function:/sha256/,operator:/:/,number:/[\da-fA-F]{64}/}},keyword:/\b(?:as|assert|else|forall|if|in|let|merge|missing|then|toMap|using|with)\b|\u2200/,builtin:/\b(?:None|Some)\b/,boolean:/\b(?:False|True)\b/,number:/\bNaN\b|-?\bInfinity\b|[+-]?\b(?:0x[\da-fA-F]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/,operator:/\/\\|\/\/\\\\|&&|\|\||===|[!=]=|\/\/|->|\+\+|::|[+*#@=:?<>|\\\u2227\u2a53\u2261\u2afd\u03bb\u2192]/,punctuation:/\.\.|[{}\[\](),./]/,"class-name":/\b[A-Z]\w*\b/},t.languages.dhall.string.inside.interpolation.inside.expression.inside=t.languages.dhall}return mv}var bv,GL;function Xbe(){if(GL)return bv;GL=1,bv=e,e.displayName="diff",e.aliases=[];function e(t){(function(n){n.languages.diff={coord:[/^(?:\*{3}|-{3}|\+{3}).*$/m,/^@@.*@@$/m,/^\d.*$/m]};var r={"deleted-sign":"-","deleted-arrow":"<","inserted-sign":"+","inserted-arrow":">",unchanged:" ",diff:"!"};Object.keys(r).forEach(function(a){var o=r[a],s=[];/^\w+$/.test(a)||s.push(/\w+/.exec(a)[0]),a==="diff"&&s.push("bold"),n.languages.diff[a]={pattern:RegExp("^(?:["+o+`].*(?:\r
?|
|(?![\\s\\S])))+`,"m"),alias:s,inside:{line:{pattern:/(.)(?=[\s\S]).*(?:\r\n?|\n)?/,lookbehind:!0},prefix:{pattern:/[\s\S]/,alias:/\w+/.exec(a)[0]}}}}),Object.defineProperty(n.languages.diff,"PREFIXES",{value:r})})(t)}return bv}var yv,HL;function Wn(){if(HL)return yv;HL=1,yv=e,e.displayName="markupTemplating",e.aliases=[];function e(t){(function(n){function r(a,o){return"___"+a.toUpperCase()+o+"___"}Object.defineProperties(n.languages["markup-templating"]={},{buildPlaceholders:{value:function(a,o,s,l){if(a.language===o){var u=a.tokenStack=[];a.code=a.code.replace(s,function(d){if(typeof l=="function"&&!l(d))return d;for(var p=u.length,g;a.code.indexOf(g=r(o,p))!==-1;)++p;return u[p]=d,g}),a.grammar=n.languages.markup}}},tokenizePlaceholders:{value:function(a,o){if(a.language!==o||!a.tokenStack)return;a.grammar=n.languages[o];var s=0,l=Object.keys(a.tokenStack);function u(d){for(var p=0;p<d.length&&!(s>=l.length);p++){var g=d[p];if(typeof g=="string"||g.content&&typeof g.content=="string"){var m=l[s],b=a.tokenStack[m],v=typeof g=="string"?g:g.content,y=r(o,m),k=v.indexOf(y);if(k>-1){++s;var A=v.substring(0,k),x=new n.Token(o,n.tokenize(b,a.grammar),"language-"+o,b),R=v.substring(k+y.length),O=[];A&&O.push.apply(O,u([A])),O.push(x),R&&O.push.apply(O,u([R])),typeof g=="string"?d.splice.apply(d,[p,1].concat(O)):g.content=O}}else g.content&&u(g.content)}return d}u(a.tokens)}}})})(t)}return yv}var vv,$L;function Zbe(){if($L)return vv;$L=1;var e=Wn();vv=t,t.displayName="django",t.aliases=["jinja2"];function t(n){n.register(e),function(r){r.languages.django={comment:/^\{#[\s\S]*?#\}$/,tag:{pattern:/(^\{%[+-]?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%][+-]?|[+-]?[}%]\}$/,alias:"punctuation"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},filter:{pattern:/(\|)\w+/,lookbehind:!0,alias:"function"},test:{pattern:/(\bis\s+(?:not\s+)?)(?!not\b)\w+/,lookbehind:!0,alias:"function"},function:/\b[a-z_]\w+(?=\s*\()/i,keyword:/\b(?:and|as|by|else|for|if|import|in|is|loop|not|or|recursive|with|without)\b/,operator:/[-+%=]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,number:/\b\d+(?:\.\d+)?\b/,boolean:/[Ff]alse|[Nn]one|[Tt]rue/,variable:/\b\w+\b/,punctuation:/[{}[\](),.:;]/};var a=/\{\{[\s\S]*?\}\}|\{%[\s\S]*?%\}|\{#[\s\S]*?#\}/g,o=r.languages["markup-templating"];r.hooks.add("before-tokenize",function(s){o.buildPlaceholders(s,"django",a)}),r.hooks.add("after-tokenize",function(s){o.tokenizePlaceholders(s,"django")}),r.languages.jinja2=r.languages.django,r.hooks.add("before-tokenize",function(s){o.buildPlaceholders(s,"jinja2",a)}),r.hooks.add("after-tokenize",function(s){o.tokenizePlaceholders(s,"jinja2")})}(n)}return vv}var Sv,qL;function Qbe(){if(qL)return Sv;qL=1,Sv=e,e.displayName="dnsZoneFile",e.aliases=[];function e(t){t.languages["dns-zone-file"]={comment:/;.*/,string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},variable:[{pattern:/(^\$ORIGIN[ \t]+)\S+/m,lookbehind:!0},{pattern:/(^|\s)@(?=\s|$)/,lookbehind:!0}],keyword:/^\$(?:INCLUDE|ORIGIN|TTL)(?=\s|$)/m,class:{pattern:/(^|\s)(?:CH|CS|HS|IN)(?=\s|$)/,lookbehind:!0,alias:"keyword"},type:{pattern:/(^|\s)(?:A|A6|AAAA|AFSDB|APL|ATMA|CAA|CDNSKEY|CDS|CERT|CNAME|DHCID|DLV|DNAME|DNSKEY|DS|EID|GID|GPOS|HINFO|HIP|IPSECKEY|ISDN|KEY|KX|LOC|MAILA|MAILB|MB|MD|MF|MG|MINFO|MR|MX|NAPTR|NB|NBSTAT|NIMLOC|NINFO|NS|NSAP|NSAP-PTR|NSEC|NSEC3|NSEC3PARAM|NULL|NXT|OPENPGPKEY|PTR|PX|RKEY|RP|RRSIG|RT|SIG|SINK|SMIMEA|SOA|SPF|SRV|SSHFP|TA|TKEY|TLSA|TSIG|TXT|UID|UINFO|UNSPEC|URI|WKS|X25)(?=\s|$)/,lookbehind:!0,alias:"keyword"},punctuation:/[()]/},t.languages["dns-zone"]=t.languages["dns-zone-file"]}return Sv}var Ev,VL;function Jbe(){if(VL)return Ev;VL=1,Ev=e,e.displayName="docker",e.aliases=["dockerfile"];function e(t){(function(n){var r=/\\[\r\n](?:\s|\\[\r\n]|#.*(?!.))*(?![\s#]|\\[\r\n])/.source,a=/(?:[ \t]+(?![ \t])(?:<SP_BS>)?|<SP_BS>)/.source.replace(/<SP_BS>/g,function(){return r}),o=/"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*"|'(?:[^'\\\r\n]|\\(?:\r\n|[\s\S]))*'/.source,s=/--[\w-]+=(?:<STR>|(?!["'])(?:[^\s\\]|\\.)+)/.source.replace(/<STR>/g,function(){return o}),l={pattern:RegExp(o),greedy:!0},u={pattern:/(^[ \t]*)#.*/m,lookbehind:!0,greedy:!0};function d(p,g){return p=p.replace(/<OPT>/g,function(){return s}).replace(/<SP>/g,function(){return a}),RegExp(p,g)}n.languages.docker={instruction:{pattern:/(^[ \t]*)(?:ADD|ARG|CMD|COPY|ENTRYPOINT|ENV|EXPOSE|FROM|HEALTHCHECK|LABEL|MAINTAINER|ONBUILD|RUN|SHELL|STOPSIGNAL|USER|VOLUME|WORKDIR)(?=\s)(?:\\.|[^\r\n\\])*(?:\\$(?:\s|#.*$)*(?![\s#])(?:\\.|[^\r\n\\])*)*/im,lookbehind:!0,greedy:!0,inside:{options:{pattern:d(/(^(?:ONBUILD<SP>)?\w+<SP>)<OPT>(?:<SP><OPT>)*/.source,"i"),lookbehind:!0,greedy:!0,inside:{property:{pattern:/(^|\s)--[\w-]+/,lookbehind:!0},string:[l,{pattern:/(=)(?!["'])(?:[^\s\\]|\\.)+/,lookbehind:!0}],operator:/\\$/m,punctuation:/=/}},keyword:[{pattern:d(/(^(?:ONBUILD<SP>)?HEALTHCHECK<SP>(?:<OPT><SP>)*)(?:CMD|NONE)\b/.source,"i"),lookbehind:!0,greedy:!0},{pattern:d(/(^(?:ONBUILD<SP>)?FROM<SP>(?:<OPT><SP>)*(?!--)[^ \t\\]+<SP>)AS/.source,"i"),lookbehind:!0,greedy:!0},{pattern:d(/(^ONBUILD<SP>)\w+/.source,"i"),lookbehind:!0,greedy:!0},{pattern:/^\w+/,greedy:!0}],comment:u,string:l,variable:/\$(?:\w+|\{[^{}"'\\]*\})/,operator:/\\$/m}},comment:u},n.languages.dockerfile=n.languages.docker})(t)}return Ev}var wv,WL;function eye(){if(WL)return wv;WL=1,wv=e,e.displayName="dot",e.aliases=["gv"];function e(t){(function(n){var r="(?:"+[/[a-zA-Z_\x80-\uFFFF][\w\x80-\uFFFF]*/.source,/-?(?:\.\d+|\d+(?:\.\d*)?)/.source,/"[^"\\]*(?:\\[\s\S][^"\\]*)*"/.source,/<(?:[^<>]|(?!<!--)<(?:[^<>"']|"[^"]*"|'[^']*')+>|<!--(?:[^-]|-(?!->))*-->)*>/.source].join("|")+")",a={markup:{pattern:/(^<)[\s\S]+(?=>$)/,lookbehind:!0,alias:["language-markup","language-html","language-xml"],inside:n.languages.markup}};function o(s,l){return RegExp(s.replace(/<ID>/g,function(){return r}),l)}n.languages.dot={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\/|^#.*/m,greedy:!0},"graph-name":{pattern:o(/(\b(?:digraph|graph|subgraph)[ \t\r\n]+)<ID>/.source,"i"),lookbehind:!0,greedy:!0,alias:"class-name",inside:a},"attr-value":{pattern:o(/(=[ \t\r\n]*)<ID>/.source),lookbehind:!0,greedy:!0,inside:a},"attr-name":{pattern:o(/([\[;, \t\r\n])<ID>(?=[ \t\r\n]*=)/.source),lookbehind:!0,greedy:!0,inside:a},keyword:/\b(?:digraph|edge|graph|node|strict|subgraph)\b/i,"compass-point":{pattern:/(:[ \t\r\n]*)(?:[ewc_]|[ns][ew]?)(?![\w\x80-\uFFFF])/,lookbehind:!0,alias:"builtin"},node:{pattern:o(/(^|[^-.\w\x80-\uFFFF\\])<ID>/.source),lookbehind:!0,greedy:!0,inside:a},operator:/[=:]|-[->]/,punctuation:/[\[\]{};,]/},n.languages.gv=n.languages.dot})(t)}return wv}var xv,YL;function tye(){if(YL)return xv;YL=1,xv=e,e.displayName="ebnf",e.aliases=[];function e(t){t.languages.ebnf={comment:/\(\*[\s\S]*?\*\)/,string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0},special:{pattern:/\?[^?\r\n]*\?/,greedy:!0,alias:"class-name"},definition:{pattern:/^([\t ]*)[a-z]\w*(?:[ \t]+[a-z]\w*)*(?=\s*=)/im,lookbehind:!0,alias:["rule","keyword"]},rule:/\b[a-z]\w*(?:[ \t]+[a-z]\w*)*\b/i,punctuation:/\([:/]|[:/]\)|[.,;()[\]{}]/,operator:/[-=|*/!]/}}return xv}var kv,KL;function nye(){if(KL)return kv;KL=1,kv=e,e.displayName="editorconfig",e.aliases=[];function e(t){t.languages.editorconfig={comment:/[;#].*/,section:{pattern:/(^[ \t]*)\[.+\]/m,lookbehind:!0,alias:"selector",inside:{regex:/\\\\[\[\]{},!?.*]/,operator:/[!?]|\.\.|\*{1,2}/,punctuation:/[\[\]{},]/}},key:{pattern:/(^[ \t]*)[^\s=]+(?=[ \t]*=)/m,lookbehind:!0,alias:"attr-name"},value:{pattern:/=.*/,alias:"attr-value",inside:{punctuation:/^=/}}}}return kv}var Tv,XL;function rye(){if(XL)return Tv;XL=1,Tv=e,e.displayName="eiffel",e.aliases=[];function e(t){t.languages.eiffel={comment:/--.*/,string:[{pattern:/"([^[]*)\[[\s\S]*?\]\1"/,greedy:!0},{pattern:/"([^{]*)\{[\s\S]*?\}\1"/,greedy:!0},{pattern:/"(?:%(?:(?!\n)\s)*\n\s*%|%\S|[^%"\r\n])*"/,greedy:!0}],char:/'(?:%.|[^%'\r\n])+'/,keyword:/\b(?:across|agent|alias|all|and|as|assign|attached|attribute|check|class|convert|create|Current|debug|deferred|detachable|do|else|elseif|end|ensure|expanded|export|external|feature|from|frozen|if|implies|inherit|inspect|invariant|like|local|loop|not|note|obsolete|old|once|or|Precursor|redefine|rename|require|rescue|Result|retry|select|separate|some|then|undefine|until|variant|Void|when|xor)\b/i,boolean:/\b(?:False|True)\b/i,"class-name":/\b[A-Z][\dA-Z_]*\b/,number:[/\b0[xcb][\da-f](?:_*[\da-f])*\b/i,/(?:\b\d(?:_*\d)*)?\.(?:(?:\d(?:_*\d)*)?e[+-]?)?\d(?:_*\d)*\b|\b\d(?:_*\d)*\b\.?/i],punctuation:/:=|<<|>>|\(\||\|\)|->|\.(?=\w)|[{}[\];(),:?]/,operator:/\\\\|\|\.\.\||\.\.|\/[~\/=]?|[><]=?|[-+*^=~]/}}return Tv}var Av,ZL;function aye(){if(ZL)return Av;ZL=1;var e=Wn();Av=t,t.displayName="ejs",t.aliases=["eta"];function t(n){n.register(e),function(r){r.languages.ejs={delimiter:{pattern:/^<%[-_=]?|[-_]?%>$/,alias:"punctuation"},comment:/^#[\s\S]*/,"language-javascript":{pattern:/[\s\S]+/,inside:r.languages.javascript}},r.hooks.add("before-tokenize",function(a){var o=/<%(?!%)[\s\S]+?%>/g;r.languages["markup-templating"].buildPlaceholders(a,"ejs",o)}),r.hooks.add("after-tokenize",function(a){r.languages["markup-templating"].tokenizePlaceholders(a,"ejs")}),r.languages.eta=r.languages.ejs}(n)}return Av}var Rv,QL;function oye(){if(QL)return Rv;QL=1,Rv=e,e.displayName="elixir",e.aliases=[];function e(t){t.languages.elixir={doc:{pattern:/@(?:doc|moduledoc)\s+(?:("""|''')[\s\S]*?\1|("|')(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2)/,inside:{attribute:/^@\w+/,string:/['"][\s\S]+/}},comment:{pattern:/#.*/,greedy:!0},regex:{pattern:/~[rR](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|[^\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[uismxfr]*/,greedy:!0},string:[{pattern:/~[cCsSwW](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|#\{[^}]+\}|#(?!\{)|[^#\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[csa]?/,greedy:!0,inside:{}},{pattern:/("""|''')[\s\S]*?\1/,greedy:!0,inside:{}},{pattern:/("|')(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{}}],atom:{pattern:/(^|[^:]):\w+/,lookbehind:!0,alias:"symbol"},module:{pattern:/\b[A-Z]\w*\b/,alias:"class-name"},"attr-name":/\b\w+\??:(?!:)/,argument:{pattern:/(^|[^&])&\d+/,lookbehind:!0,alias:"variable"},attribute:{pattern:/@\w+/,alias:"variable"},function:/\b[_a-zA-Z]\w*[?!]?(?:(?=\s*(?:\.\s*)?\()|(?=\/\d))/,number:/\b(?:0[box][a-f\d_]+|\d[\d_]*)(?:\.[\d_]+)?(?:e[+-]?[\d_]+)?\b/i,keyword:/\b(?:after|alias|and|case|catch|cond|def(?:callback|delegate|exception|impl|macro|module|n|np|p|protocol|struct)?|do|else|end|fn|for|if|import|not|or|quote|raise|require|rescue|try|unless|unquote|use|when)\b/,boolean:/\b(?:false|nil|true)\b/,operator:[/\bin\b|&&?|\|[|>]?|\\\\|::|\.\.\.?|\+\+?|-[->]?|<[-=>]|>=|!==?|\B!|=(?:==?|[>~])?|[*\/^]/,{pattern:/([^<])<(?!<)/,lookbehind:!0},{pattern:/([^>])>(?!>)/,lookbehind:!0}],punctuation:/<<|>>|[.,%\[\]{}()]/},t.languages.elixir.string.forEach(function(n){n.inside={interpolation:{pattern:/#\{[^}]+\}/,inside:{delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"},rest:t.languages.elixir}}}})}return Rv}var Cv,JL;function iye(){if(JL)return Cv;JL=1,Cv=e,e.displayName="elm",e.aliases=[];function e(t){t.languages.elm={comment:/--.*|\{-[\s\S]*?-\}/,char:{pattern:/'(?:[^\\'\r\n]|\\(?:[abfnrtv\\']|\d+|x[0-9a-fA-F]+|u\{[0-9a-fA-F]+\}))'/,greedy:!0},string:[{pattern:/"""[\s\S]*?"""/,greedy:!0},{pattern:/"(?:[^\\"\r\n]|\\.)*"/,greedy:!0}],"import-statement":{pattern:/(^[\t ]*)import\s+[A-Z]\w*(?:\.[A-Z]\w*)*(?:\s+as\s+(?:[A-Z]\w*)(?:\.[A-Z]\w*)*)?(?:\s+exposing\s+)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|exposing|import)\b/}},keyword:/\b(?:alias|as|case|else|exposing|if|in|infixl|infixr|let|module|of|then|type)\b/,builtin:/\b(?:abs|acos|always|asin|atan|atan2|ceiling|clamp|compare|cos|curry|degrees|e|flip|floor|fromPolar|identity|isInfinite|isNaN|logBase|max|min|negate|never|not|pi|radians|rem|round|sin|sqrt|tan|toFloat|toPolar|toString|truncate|turns|uncurry|xor)\b/,number:/\b(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|0x[0-9a-f]+)\b/i,operator:/\s\.\s|[+\-/*=.$<>:&|^?%#@~!]{2,}|[+\-/*=$<>:&|^?%#@~!]/,hvariable:/\b(?:[A-Z]\w*\.)*[a-z]\w*\b/,constant:/\b(?:[A-Z]\w*\.)*[A-Z]\w*\b/,punctuation:/[{}[\]|(),.:]/}}return Cv}var _v,e2;function sye(){if(e2)return _v;e2=1;var e=Bp(),t=Wn();_v=n,n.displayName="erb",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){a.languages.erb={delimiter:{pattern:/^(\s*)<%=?|%>(?=\s*$)/,lookbehind:!0,alias:"punctuation"},ruby:{pattern:/\s*\S[\s\S]*/,alias:"language-ruby",inside:a.languages.ruby}},a.hooks.add("before-tokenize",function(o){var s=/<%=?(?:[^\r\n]|[\r\n](?!=begin)|[\r\n]=begin\s(?:[^\r\n]|[\r\n](?!=end))*[\r\n]=end)+?%>/g;a.languages["markup-templating"].buildPlaceholders(o,"erb",s)}),a.hooks.add("after-tokenize",function(o){a.languages["markup-templating"].tokenizePlaceholders(o,"erb")})}(r)}return _v}var Nv,t2;function lye(){if(t2)return Nv;t2=1,Nv=e,e.displayName="erlang",e.aliases=[];function e(t){t.languages.erlang={comment:/%.+/,string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},"quoted-function":{pattern:/'(?:\\.|[^\\'\r\n])+'(?=\()/,alias:"function"},"quoted-atom":{pattern:/'(?:\\.|[^\\'\r\n])+'/,alias:"atom"},boolean:/\b(?:false|true)\b/,keyword:/\b(?:after|case|catch|end|fun|if|of|receive|try|when)\b/,number:[/\$\\?./,/\b\d+#[a-z0-9]+/i,/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i],function:/\b[a-z][\w@]*(?=\()/,variable:{pattern:/(^|[^@])(?:\b|\?)[A-Z_][\w@]*/,lookbehind:!0},operator:[/[=\/<>:]=|=[:\/]=|\+\+?|--?|[=*\/!]|\b(?:and|andalso|band|bnot|bor|bsl|bsr|bxor|div|not|or|orelse|rem|xor)\b/,{pattern:/(^|[^<])<(?!<)/,lookbehind:!0},{pattern:/(^|[^>])>(?!>)/,lookbehind:!0}],atom:/\b[a-z][\w@]*/,punctuation:/[()[\]{}:;,.#|]|<<|>>/}}return Nv}var Ov,n2;function GH(){if(n2)return Ov;n2=1,Ov=e,e.displayName="lua",e.aliases=[];function e(t){t.languages.lua={comment:/^#!.+|--(?:\[(=*)\[[\s\S]*?\]\1\]|.*)/m,string:{pattern:/(["'])(?:(?!\1)[^\\\r\n]|\\z(?:\r\n|\s)|\\(?:\r\n|[^z]))*\1|\[(=*)\[[\s\S]*?\]\2\]/,greedy:!0},number:/\b0x[a-f\d]+(?:\.[a-f\d]*)?(?:p[+-]?\d+)?\b|\b\d+(?:\.\B|(?:\.\d*)?(?:e[+-]?\d+)?\b)|\B\.\d+(?:e[+-]?\d+)?\b/i,keyword:/\b(?:and|break|do|else|elseif|end|false|for|function|goto|if|in|local|nil|not|or|repeat|return|then|true|until|while)\b/,function:/(?!\d)\w+(?=\s*(?:[({]))/,operator:[/[-+*%^&|#]|\/\/?|<[<=]?|>[>=]?|[=~]=?/,{pattern:/(^|[^.])\.\.(?!\.)/,lookbehind:!0}],punctuation:/[\[\](){},;]|\.+|:+/}}return Ov}var Iv,r2;function cye(){if(r2)return Iv;r2=1;var e=GH(),t=Wn();Iv=n,n.displayName="etlua",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){a.languages.etlua={delimiter:{pattern:/^<%[-=]?|-?%>$/,alias:"punctuation"},"language-lua":{pattern:/[\s\S]+/,inside:a.languages.lua}},a.hooks.add("before-tokenize",function(o){var s=/<%[\s\S]+?%>/g;a.languages["markup-templating"].buildPlaceholders(o,"etlua",s)}),a.hooks.add("after-tokenize",function(o){a.languages["markup-templating"].tokenizePlaceholders(o,"etlua")})}(r)}return Iv}var Dv,a2;function uye(){if(a2)return Dv;a2=1,Dv=e,e.displayName="excelFormula",e.aliases=[];function e(t){t.languages["excel-formula"]={comment:{pattern:/(\bN\(\s*)"(?:[^"]|"")*"(?=\s*\))/i,lookbehind:!0,greedy:!0},string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},reference:{pattern:/(?:'[^']*'|(?:[^\s()[\]{}<>*?"';,$&]*\[[^^\s()[\]{}<>*?"']+\])?\w+)!/,greedy:!0,alias:"string",inside:{operator:/!$/,punctuation:/'/,sheet:{pattern:/[^[\]]+$/,alias:"function"},file:{pattern:/\[[^[\]]+\]$/,inside:{punctuation:/[[\]]/}},path:/[\s\S]+/}},"function-name":{pattern:/\b[A-Z]\w*(?=\()/i,alias:"keyword"},range:{pattern:/\$?\b(?:[A-Z]+\$?\d+:\$?[A-Z]+\$?\d+|[A-Z]+:\$?[A-Z]+|\d+:\$?\d+)\b/i,alias:"property",inside:{operator:/:/,cell:/\$?[A-Z]+\$?\d+/i,column:/\$?[A-Z]+/i,row:/\$?\d+/}},cell:{pattern:/\b[A-Z]+\d+\b|\$[A-Za-z]+\$?\d+\b|\b[A-Za-z]+\$\d+\b/,alias:"property"},number:/(?:\b\d+(?:\.\d+)?|\B\.\d+)(?:e[+-]?\d+)?\b/i,boolean:/\b(?:FALSE|TRUE)\b/i,operator:/[-+*/^%=&,]|<[=>]?|>=?/,punctuation:/[[\]();{}|]/},t.languages.xlsx=t.languages.xls=t.languages["excel-formula"]}return Dv}var Lv,o2;function dye(){if(o2)return Lv;o2=1,Lv=e,e.displayName="factor",e.aliases=[];function e(t){(function(n){var r={function:/\b(?:BUGS?|FIX(?:MES?)?|NOTES?|TODOS?|XX+|HACKS?|WARN(?:ING)?|\?{2,}|!{2,})\b/},a={number:/\\[^\s']|%\w/},o={comment:[{pattern:/(^|\s)(?:! .*|!$)/,lookbehind:!0,inside:r},{pattern:/(^|\s)\/\*\s[\s\S]*?\*\/(?=\s|$)/,lookbehind:!0,greedy:!0,inside:r},{pattern:/(^|\s)!\[(={0,6})\[\s[\s\S]*?\]\2\](?=\s|$)/,lookbehind:!0,greedy:!0,inside:r}],number:[{pattern:/(^|\s)[+-]?\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?0(?:b[01]+|o[0-7]+|d\d+|x[\dA-F]+)(?=\s|$)/i,lookbehind:!0},{pattern:/(^|\s)[+-]?\d+\/\d+\.?(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)\+?\d+\+\d+\/\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)-\d+-\d+\/\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?(?:\d*\.\d+|\d+\.\d*|\d+)(?:e[+-]?\d+)?(?=\s|$)/i,lookbehind:!0},{pattern:/(^|\s)NAN:\s+[\da-fA-F]+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?0(?:b1\.[01]*|o1\.[0-7]*|d1\.\d*|x1\.[\dA-F]*)p\d+(?=\s|$)/i,lookbehind:!0}],regexp:{pattern:/(^|\s)R\/\s(?:\\\S|[^\\/])*\/(?:[idmsr]*|[idmsr]+-[idmsr]+)(?=\s|$)/,lookbehind:!0,alias:"number",inside:{variable:/\\\S/,keyword:/[+?*\[\]^$(){}.|]/,operator:{pattern:/(\/)[idmsr]+(?:-[idmsr]+)?/,lookbehind:!0}}},boolean:{pattern:/(^|\s)[tf](?=\s|$)/,lookbehind:!0},"custom-string":{pattern:/(^|\s)[A-Z0-9\-]+"\s(?:\\\S|[^"\\])*"/,lookbehind:!0,greedy:!0,alias:"string",inside:{number:/\\\S|%\w|\//}},"multiline-string":[{pattern:/(^|\s)STRING:\s+\S+(?:\n|\r\n).*(?:\n|\r\n)\s*;(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:{number:a.number,"semicolon-or-setlocal":{pattern:/([\r\n][ \t]*);(?=\s|$)/,lookbehind:!0,alias:"function"}}},{pattern:/(^|\s)HEREDOC:\s+\S+(?:\n|\r\n).*(?:\n|\r\n)\s*\S+(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:a},{pattern:/(^|\s)\[(={0,6})\[\s[\s\S]*?\]\2\](?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:a}],"special-using":{pattern:/(^|\s)USING:(?:\s\S+)*(?=\s+;(?:\s|$))/,lookbehind:!0,alias:"function",inside:{string:{pattern:/(\s)[^:\s]+/,lookbehind:!0}}},"stack-effect-delimiter":[{pattern:/(^|\s)(?:call|eval|execute)?\((?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)--(?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)\)(?=\s|$)/,lookbehind:!0,alias:"operator"}],combinators:{pattern:null,lookbehind:!0,alias:"keyword"},"kernel-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"sequences-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"math-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"constructor-word":{pattern:/(^|\s)<(?!=+>|-+>)\S+>(?=\s|$)/,lookbehind:!0,alias:"keyword"},"other-builtin-syntax":{pattern:null,lookbehind:!0,alias:"operator"},"conventionally-named-word":{pattern:/(^|\s)(?!")(?:(?:change|new|set|with)-\S+|\$\S+|>[^>\s]+|[^:>\s]+>|[^>\s]+>[^>\s]+|\+[^+\s]+\+|[^?\s]+\?|\?[^?\s]+|[^>\s]+>>|>>[^>\s]+|[^<\s]+<<|\([^()\s]+\)|[^!\s]+!|[^*\s]\S*\*|[^.\s]\S*\.)(?=\s|$)/,lookbehind:!0,alias:"keyword"},"colon-syntax":{pattern:/(^|\s)(?:[A-Z0-9\-]+#?)?:{1,2}\s+(?:;\S+|(?!;)\S+)(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"function"},"semicolon-or-setlocal":{pattern:/(\s)(?:;|:>)(?=\s|$)/,lookbehind:!0,alias:"function"},"curly-brace-literal-delimiter":[{pattern:/(^|\s)[a-z]*\{(?=\s)/i,lookbehind:!0,alias:"operator"},{pattern:/(\s)\}(?=\s|$)/,lookbehind:!0,alias:"operator"}],"quotation-delimiter":[{pattern:/(^|\s)\[(?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)\](?=\s|$)/,lookbehind:!0,alias:"operator"}],"normal-word":{pattern:/(^|\s)[^"\s]\S*(?=\s|$)/,lookbehind:!0},string:{pattern:/"(?:\\\S|[^"\\])*"/,greedy:!0,inside:a}},s=function(p){return(p+"").replace(/([.?*+\^$\[\]\\(){}|\-])/g,"\\$1")},l=function(p){return new RegExp("(^|\\s)(?:"+p.map(s).join("|")+")(?=\\s|$)")},u={"kernel-builtin":["or","2nipd","4drop","tuck","wrapper","nip","wrapper?","callstack>array","die","dupd","callstack","callstack?","3dup","hashcode","pick","4nip","build",">boolean","nipd","clone","5nip","eq?","?","=","swapd","2over","clear","2dup","get-retainstack","not","tuple?","dup","3nipd","call","-rotd","object","drop","assert=","assert?","-rot","execute","boa","get-callstack","curried?","3drop","pickd","overd","over","roll","3nip","swap","and","2nip","rotd","throw","(clone)","hashcode*","spin","reach","4dup","equal?","get-datastack","assert","2drop","<wrapper>","boolean?","identity-hashcode","identity-tuple?","null","composed?","new","5drop","rot","-roll","xor","identity-tuple","boolean"],"other-builtin-syntax":["=======","recursive","flushable",">>","<<<<<<","M\\","B","PRIVATE>","\\","======","final","inline","delimiter","deprecated","<PRIVATE",">>>>>>","<<<<<<<","parse-complex","malformed-complex","read-only",">>>>>>>","call-next-method","<<","foldable","$","$[","${"],"sequences-builtin":["member-eq?","mismatch","append","assert-sequence=","longer","repetition","clone-like","3sequence","assert-sequence?","last-index-from","reversed","index-from","cut*","pad-tail","join-as","remove-eq!","concat-as","but-last","snip","nths","nth","sequence","longest","slice?","<slice>","remove-nth","tail-slice","empty?","tail*","member?","virtual-sequence?","set-length","drop-prefix","iota","unclip","bounds-error?","unclip-last-slice","non-negative-integer-expected","non-negative-integer-expected?","midpoint@","longer?","?set-nth","?first","rest-slice","prepend-as","prepend","fourth","sift","subseq-start","new-sequence","?last","like","first4","1sequence","reverse","slice","virtual@","repetition?","set-last","index","4sequence","max-length","set-second","immutable-sequence","first2","first3","supremum","unclip-slice","suffix!","insert-nth","tail","3append","short","suffix","concat","flip","immutable?","reverse!","2sequence","sum","delete-all","indices","snip-slice","<iota>","check-slice","sequence?","head","append-as","halves","sequence=","collapse-slice","?second","slice-error?","product","bounds-check?","bounds-check","immutable","virtual-exemplar","harvest","remove","pad-head","last","set-fourth","cartesian-product","remove-eq","shorten","shorter","reversed?","shorter?","shortest","head-slice","pop*","tail-slice*","but-last-slice","iota?","append!","cut-slice","new-resizable","head-slice*","sequence-hashcode","pop","set-nth","?nth","second","join","immutable-sequence?","<reversed>","3append-as","virtual-sequence","subseq?","remove-nth!","length","last-index","lengthen","assert-sequence","copy","move","third","first","tail?","set-first","prefix","bounds-error","<repetition>","exchange","surround","cut","min-length","set-third","push-all","head?","subseq-start-from","delete-slice","rest","sum-lengths","head*","infimum","remove!","glue","slice-error","subseq","push","replace-slice","subseq-as","unclip-last"],"math-builtin":["number=","next-power-of-2","?1+","fp-special?","imaginary-part","float>bits","number?","fp-infinity?","bignum?","fp-snan?","denominator","gcd","*","+","fp-bitwise=","-","u>=","/",">=","bitand","power-of-2?","log2-expects-positive","neg?","<","log2",">","integer?","number","bits>double","2/","zero?","bits>float","float?","shift","ratio?","rect>","even?","ratio","fp-sign","bitnot",">fixnum","complex?","/i","integer>fixnum","/f","sgn",">bignum","next-float","u<","u>","mod","recip","rational",">float","2^","integer","fixnum?","neg","fixnum","sq","bignum",">rect","bit?","fp-qnan?","simple-gcd","complex","<fp-nan>","real",">fraction","double>bits","bitor","rem","fp-nan-payload","real-part","log2-expects-positive?","prev-float","align","unordered?","float","fp-nan?","abs","bitxor","integer>fixnum-strict","u<=","odd?","<=","/mod",">integer","real?","rational?","numerator"]};Object.keys(u).forEach(function(p){o[p].pattern=l(u[p])});var d=["2bi","while","2tri","bi*","4dip","both?","same?","tri@","curry","prepose","3bi","?if","tri*","2keep","3keep","curried","2keepd","when","2bi*","2tri*","4keep","bi@","keepdd","do","unless*","tri-curry","if*","loop","bi-curry*","when*","2bi@","2tri@","with","2with","either?","bi","until","3dip","3curry","tri-curry*","tri-curry@","bi-curry","keepd","compose","2dip","if","3tri","unless","tuple","keep","2curry","tri","most","while*","dip","composed","bi-curry@","find-last-from","trim-head-slice","map-as","each-from","none?","trim-tail","partition","if-empty","accumulate*","reject!","find-from","accumulate-as","collector-for-as","reject","map","map-sum","accumulate!","2each-from","follow","supremum-by","map!","unless-empty","collector","padding","reduce-index","replicate-as","infimum-by","trim-tail-slice","count","find-index","filter","accumulate*!","reject-as","map-integers","map-find","reduce","selector","interleave","2map","filter-as","binary-reduce","map-index-as","find","produce","filter!","replicate","cartesian-map","cartesian-each","find-index-from","map-find-last","3map-as","3map","find-last","selector-as","2map-as","2map-reduce","accumulate","each","each-index","accumulate*-as","when-empty","all?","collector-as","push-either","new-like","collector-for","2selector","push-if","2all?","map-reduce","3each","any?","trim-slice","2reduce","change-nth","produce-as","2each","trim","trim-head","cartesian-find","map-index","if-zero","each-integer","unless-zero","(find-integer)","when-zero","find-last-integer","(all-integers?)","times","(each-integer)","find-integer","all-integers?","unless-negative","if-positive","when-positive","when-negative","unless-positive","if-negative","case","2cleave","cond>quot","case>quot","3cleave","wrong-values","to-fixed-point","alist>quot","cond","cleave","call-effect","recursive-hashcode","spread","deep-spread>quot","2||","0||","n||","0&&","2&&","3||","1||","1&&","n&&","3&&","smart-unless*","keep-inputs","reduce-outputs","smart-when*","cleave>array","smart-with","smart-apply","smart-if","inputs/outputs","output>sequence-n","map-outputs","map-reduce-outputs","dropping","output>array","smart-map-reduce","smart-2map-reduce","output>array-n","nullary","input<sequence","append-outputs","drop-inputs","inputs","smart-2reduce","drop-outputs","smart-reduce","preserving","smart-when","outputs","append-outputs-as","smart-unless","smart-if*","sum-outputs","input<sequence-unsafe","output>sequence"];o.combinators.pattern=l(d),n.languages.factor=o})(t)}return Lv}var Mv,i2;function fye(){if(i2)return Mv;i2=1,Mv=e,e.displayName="$false",e.aliases=[];function e(t){(function(n){n.languages.false={comment:{pattern:/\{[^}]*\}/},string:{pattern:/"[^"]*"/,greedy:!0},"character-code":{pattern:/'(?:[^\r]|\r\n?)/,alias:"number"},"assembler-code":{pattern:/\d+`/,alias:"important"},number:/\d+/,operator:/[-!#$%&'*+,./:;=>?@\\^_`|~ßø]/,punctuation:/\[|\]/,variable:/[a-z]/,"non-standard":{pattern:/[()<BDO®]/,alias:"bold"}}})(t)}return Mv}var Pv,s2;function pye(){if(s2)return Pv;s2=1,Pv=e,e.displayName="firestoreSecurityRules",e.aliases=[];function e(t){t.languages["firestore-security-rules"]=t.languages.extend("clike",{comment:/\/\/.*/,keyword:/\b(?:allow|function|if|match|null|return|rules_version|service)\b/,operator:/&&|\|\||[<>!=]=?|[-+*/%]|\b(?:in|is)\b/}),delete t.languages["firestore-security-rules"]["class-name"],t.languages.insertBefore("firestore-security-rules","keyword",{path:{pattern:/(^|[\s(),])(?:\/(?:[\w\xA0-\uFFFF]+|\{[\w\xA0-\uFFFF]+(?:=\*\*)?\}|\$\([\w\xA0-\uFFFF.]+\)))+/,lookbehind:!0,greedy:!0,inside:{variable:{pattern:/\{[\w\xA0-\uFFFF]+(?:=\*\*)?\}|\$\([\w\xA0-\uFFFF.]+\)/,inside:{operator:/=/,keyword:/\*\*/,punctuation:/[.$(){}]/}},punctuation:/\//}},method:{pattern:/(\ballow\s+)[a-z]+(?:\s*,\s*[a-z]+)*(?=\s*[:;])/,lookbehind:!0,alias:"builtin",inside:{punctuation:/,/}}})}return Pv}var Fv,l2;function gye(){if(l2)return Fv;l2=1,Fv=e,e.displayName="flow",e.aliases=[];function e(t){(function(n){n.languages.flow=n.languages.extend("javascript",{}),n.languages.insertBefore("flow","keyword",{type:[{pattern:/\b(?:[Bb]oolean|Function|[Nn]umber|[Ss]tring|any|mixed|null|void)\b/,alias:"tag"}]}),n.languages.flow["function-variable"].pattern=/(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=\s*(?:function\b|(?:\([^()]*\)(?:\s*:\s*\w+)?|(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/i,delete n.languages.flow.parameter,n.languages.insertBefore("flow","operator",{"flow-punctuation":{pattern:/\{\||\|\}/,alias:"punctuation"}}),Array.isArray(n.languages.flow.keyword)||(n.languages.flow.keyword=[n.languages.flow.keyword]),n.languages.flow.keyword.unshift({pattern:/(^|[^$]\b)(?:Class|declare|opaque|type)\b(?!\$)/,lookbehind:!0},{pattern:/(^|[^$]\B)\$(?:Diff|Enum|Exact|Keys|ObjMap|PropertyType|Record|Shape|Subtype|Supertype|await)\b(?!\$)/,lookbehind:!0})})(t)}return Fv}var zv,c2;function hye(){if(c2)return zv;c2=1,zv=e,e.displayName="fortran",e.aliases=[];function e(t){t.languages.fortran={"quoted-number":{pattern:/[BOZ](['"])[A-F0-9]+\1/i,alias:"number"},string:{pattern:/(?:\b\w+_)?(['"])(?:\1\1|&(?:\r\n?|\n)(?:[ \t]*!.*(?:\r\n?|\n)|(?![ \t]*!))|(?!\1).)*(?:\1|&)/,inside:{comment:{pattern:/(&(?:\r\n?|\n)\s*)!.*/,lookbehind:!0}}},comment:{pattern:/!.*/,greedy:!0},boolean:/\.(?:FALSE|TRUE)\.(?:_\w+)?/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[ED][+-]?\d+)?(?:_\w+)?/i,keyword:[/\b(?:CHARACTER|COMPLEX|DOUBLE ?PRECISION|INTEGER|LOGICAL|REAL)\b/i,/\b(?:END ?)?(?:BLOCK ?DATA|DO|FILE|FORALL|FUNCTION|IF|INTERFACE|MODULE(?! PROCEDURE)|PROGRAM|SELECT|SUBROUTINE|TYPE|WHERE)\b/i,/\b(?:ALLOCATABLE|ALLOCATE|BACKSPACE|CALL|CASE|CLOSE|COMMON|CONTAINS|CONTINUE|CYCLE|DATA|DEALLOCATE|DIMENSION|DO|END|EQUIVALENCE|EXIT|EXTERNAL|FORMAT|GO ?TO|IMPLICIT(?: NONE)?|INQUIRE|INTENT|INTRINSIC|MODULE PROCEDURE|NAMELIST|NULLIFY|OPEN|OPTIONAL|PARAMETER|POINTER|PRINT|PRIVATE|PUBLIC|READ|RETURN|REWIND|SAVE|SELECT|STOP|TARGET|WHILE|WRITE)\b/i,/\b(?:ASSIGNMENT|DEFAULT|ELEMENTAL|ELSE|ELSEIF|ELSEWHERE|ENTRY|IN|INCLUDE|INOUT|KIND|NULL|ONLY|OPERATOR|OUT|PURE|RECURSIVE|RESULT|SEQUENCE|STAT|THEN|USE)\b/i],operator:[/\*\*|\/\/|=>|[=\/]=|[<>]=?|::|[+\-*=%]|\.[A-Z]+\./i,{pattern:/(^|(?!\().)\/(?!\))/,lookbehind:!0}],punctuation:/\(\/|\/\)|[(),;:&]/}}return zv}var Bv,u2;function mye(){if(u2)return Bv;u2=1,Bv=e,e.displayName="fsharp",e.aliases=[];function e(t){t.languages.fsharp=t.languages.extend("clike",{comment:[{pattern:/(^|[^\\])\(\*(?!\))[\s\S]*?\*\)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(?:"""[\s\S]*?"""|@"(?:""|[^"])*"|"(?:\\[\s\S]|[^\\"])*")B?/,greedy:!0},"class-name":{pattern:/(\b(?:exception|inherit|interface|new|of|type)\s+|\w\s*:\s*|\s:\??>\s*)[.\w]+\b(?:\s*(?:->|\*)\s*[.\w]+\b)*(?!\s*[:.])/,lookbehind:!0,inside:{operator:/->|\*/,punctuation:/\./}},keyword:/\b(?:let|return|use|yield)(?:!\B|\b)|\b(?:abstract|and|as|asr|assert|atomic|base|begin|break|checked|class|component|const|constraint|constructor|continue|default|delegate|do|done|downcast|downto|eager|elif|else|end|event|exception|extern|external|false|finally|fixed|for|fun|function|functor|global|if|in|include|inherit|inline|interface|internal|land|lazy|lor|lsl|lsr|lxor|match|member|method|mixin|mod|module|mutable|namespace|new|not|null|object|of|open|or|override|parallel|private|process|protected|public|pure|rec|sealed|select|sig|static|struct|tailcall|then|to|trait|true|try|type|upcast|val|virtual|void|volatile|when|while|with)\b/,number:[/\b0x[\da-fA-F]+(?:LF|lf|un)?\b/,/\b0b[01]+(?:uy|y)?\b/,/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[fm]|e[+-]?\d+)?\b/i,/\b\d+(?:[IlLsy]|UL|u[lsy]?)?\b/],operator:/([<>~&^])\1\1|([*.:<>&])\2|<-|->|[!=:]=|<?\|{1,3}>?|\??(?:<=|>=|<>|[-+*/%=<>])\??|[!?^&]|~[+~-]|:>|:\?>?/}),t.languages.insertBefore("fsharp","keyword",{preprocessor:{pattern:/(^[\t ]*)#.*/m,lookbehind:!0,alias:"property",inside:{directive:{pattern:/(^#)\b(?:else|endif|if|light|line|nowarn)\b/,lookbehind:!0,alias:"keyword"}}}}),t.languages.insertBefore("fsharp","punctuation",{"computation-expression":{pattern:/\b[_a-z]\w*(?=\s*\{)/i,alias:"keyword"}}),t.languages.insertBefore("fsharp","string",{annotation:{pattern:/\[<.+?>\]/,greedy:!0,inside:{punctuation:/^\[<|>\]$/,"class-name":{pattern:/^\w+$|(^|;\s*)[A-Z]\w*(?=\()/,lookbehind:!0},"annotation-content":{pattern:/[\s\S]+/,inside:t.languages.fsharp}}},char:{pattern:/'(?:[^\\']|\\(?:.|\d{3}|x[a-fA-F\d]{2}|u[a-fA-F\d]{4}|U[a-fA-F\d]{8}))'B?/,greedy:!0}})}return Bv}var jv,d2;function bye(){if(d2)return jv;d2=1;var e=Wn();jv=t,t.displayName="ftl",t.aliases=[];function t(n){n.register(e),function(r){for(var a=/[^<()"']|\((?:<expr>)*\)|<(?!#--)|<#--(?:[^-]|-(?!->))*-->|"(?:[^\\"]|\\.)*"|'(?:[^\\']|\\.)*'/.source,o=0;o<2;o++)a=a.replace(/<expr>/g,function(){return a});a=a.replace(/<expr>/g,/[^\s\S]/.source);var s={comment:/<#--[\s\S]*?-->/,string:[{pattern:/\br("|')(?:(?!\1)[^\\]|\\.)*\1/,greedy:!0},{pattern:RegExp(/("|')(?:(?!\1|\$\{)[^\\]|\\.|\$\{(?:(?!\})(?:<expr>))*\})*\1/.source.replace(/<expr>/g,function(){return a})),greedy:!0,inside:{interpolation:{pattern:RegExp(/((?:^|[^\\])(?:\\\\)*)\$\{(?:(?!\})(?:<expr>))*\}/.source.replace(/<expr>/g,function(){return a})),lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:null}}}}],keyword:/\b(?:as)\b/,boolean:/\b(?:false|true)\b/,"builtin-function":{pattern:/((?:^|[^?])\?\s*)\w+/,lookbehind:!0,alias:"function"},function:/\b\w+(?=\s*\()/,number:/\b\d+(?:\.\d+)?\b/,operator:/\.\.[<*!]?|->|--|\+\+|&&|\|\||\?{1,2}|[-+*/%!=<>]=?|\b(?:gt|gte|lt|lte)\b/,punctuation:/[,;.:()[\]{}]/};s.string[1].inside.interpolation.inside.rest=s,r.languages.ftl={"ftl-comment":{pattern:/^<#--[\s\S]*/,alias:"comment"},"ftl-directive":{pattern:/^<[\s\S]+>$/,inside:{directive:{pattern:/(^<\/?)[#@][a-z]\w*/i,lookbehind:!0,alias:"keyword"},punctuation:/^<\/?|\/?>$/,content:{pattern:/\s*\S[\s\S]*/,alias:"ftl",inside:s}}},"ftl-interpolation":{pattern:/^\$\{[\s\S]*\}$/,inside:{punctuation:/^\$\{|\}$/,content:{pattern:/\s*\S[\s\S]*/,alias:"ftl",inside:s}}}},r.hooks.add("before-tokenize",function(l){var u=RegExp(/<#--[\s\S]*?-->|<\/?[#@][a-zA-Z](?:<expr>)*?>|\$\{(?:<expr>)*?\}/.source.replace(/<expr>/g,function(){return a}),"gi");r.languages["markup-templating"].buildPlaceholders(l,"ftl",u)}),r.hooks.add("after-tokenize",function(l){r.languages["markup-templating"].tokenizePlaceholders(l,"ftl")})}(n)}return jv}var Uv,f2;function yye(){if(f2)return Uv;f2=1,Uv=e,e.displayName="gap",e.aliases=[];function e(t){t.languages.gap={shell:{pattern:/^gap>[\s\S]*?(?=^gap>|$(?![\s\S]))/m,greedy:!0,inside:{gap:{pattern:/^(gap>).+(?:(?:\r(?:\n|(?!\n))|\n)>.*)*/,lookbehind:!0,inside:null},punctuation:/^gap>/}},comment:{pattern:/#.*/,greedy:!0},string:{pattern:/(^|[^\\'"])(?:'(?:[^\r\n\\']|\\.){1,10}'|"(?:[^\r\n\\"]|\\.)*"(?!")|"""[\s\S]*?""")/,lookbehind:!0,greedy:!0,inside:{continuation:{pattern:/([\r\n])>/,lookbehind:!0,alias:"punctuation"}}},keyword:/\b(?:Assert|Info|IsBound|QUIT|TryNextMethod|Unbind|and|atomic|break|continue|do|elif|else|end|fi|for|function|if|in|local|mod|not|od|or|quit|readonly|readwrite|rec|repeat|return|then|until|while)\b/,boolean:/\b(?:false|true)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:{pattern:/(^|[^\w.]|\.\.)(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?(?:_[a-z]?)?(?=$|[^\w.]|\.\.)/,lookbehind:!0},continuation:{pattern:/([\r\n])>/,lookbehind:!0,alias:"punctuation"},operator:/->|[-+*/^~=!]|<>|[<>]=?|:=|\.\./,punctuation:/[()[\]{},;.:]/},t.languages.gap.shell.inside.gap.inside=t.languages.gap}return Uv}var Gv,p2;function vye(){if(p2)return Gv;p2=1,Gv=e,e.displayName="gcode",e.aliases=[];function e(t){t.languages.gcode={comment:/;.*|\B\(.*?\)\B/,string:{pattern:/"(?:""|[^"])*"/,greedy:!0},keyword:/\b[GM]\d+(?:\.\d+)?\b/,property:/\b[A-Z]/,checksum:{pattern:/(\*)\d+/,lookbehind:!0,alias:"number"},punctuation:/[:*]/}}return Gv}var Hv,g2;function Sye(){if(g2)return Hv;g2=1,Hv=e,e.displayName="gdscript",e.aliases=[];function e(t){t.languages.gdscript={comment:/#.*/,string:{pattern:/@?(?:("|')(?:(?!\1)[^\n\\]|\\[\s\S])*\1(?!"|')|"""(?:[^\\]|\\[\s\S])*?""")/,greedy:!0},"class-name":{pattern:/(^(?:class|class_name|extends)[ \t]+|^export\([ \t]*|\bas[ \t]+|(?:\b(?:const|var)[ \t]|[,(])[ \t]*\w+[ \t]*:[ \t]*|->[ \t]*)[a-zA-Z_]\w*/m,lookbehind:!0},keyword:/\b(?:and|as|assert|break|breakpoint|class|class_name|const|continue|elif|else|enum|export|extends|for|func|if|in|is|master|mastersync|match|not|null|onready|or|pass|preload|puppet|puppetsync|remote|remotesync|return|self|setget|signal|static|tool|var|while|yield)\b/,function:/\b[a-z_]\w*(?=[ \t]*\()/i,variable:/\$\w+/,number:[/\b0b[01_]+\b|\b0x[\da-fA-F_]+\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.[\d_]+)(?:e[+-]?[\d_]+)?\b/,/\b(?:INF|NAN|PI|TAU)\b/],constant:/\b[A-Z][A-Z_\d]*\b/,boolean:/\b(?:false|true)\b/,operator:/->|:=|&&|\|\||<<|>>|[-+*/%&|!<>=]=?|[~^]/,punctuation:/[.:,;()[\]{}]/}}return Hv}var $v,h2;function Eye(){if(h2)return $v;h2=1,$v=e,e.displayName="gedcom",e.aliases=[];function e(t){t.languages.gedcom={"line-value":{pattern:/(^[\t ]*\d+ +(?:@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@ +)?\w+ ).+/m,lookbehind:!0,inside:{pointer:{pattern:/^@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@$/,alias:"variable"}}},tag:{pattern:/(^[\t ]*\d+ +(?:@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@ +)?)\w+/m,lookbehind:!0,alias:"string"},level:{pattern:/(^[\t ]*)\d+/m,lookbehind:!0,alias:"number"},pointer:{pattern:/@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@/,alias:"variable"}}}return $v}var qv,m2;function wye(){if(m2)return qv;m2=1,qv=e,e.displayName="gherkin",e.aliases=[];function e(t){(function(n){var r=/(?:\r?\n|\r)[ \t]*\|.+\|(?:(?!\|).)*/.source;n.languages.gherkin={pystring:{pattern:/("""|''')[\s\S]+?\1/,alias:"string"},comment:{pattern:/(^[ \t]*)#.*/m,lookbehind:!0},tag:{pattern:/(^[ \t]*)@\S*/m,lookbehind:!0},feature:{pattern:/((?:^|\r?\n|\r)[ \t]*)(?:Ability|Ahoy matey!|Arwedd|Aspekt|Besigheid Behoefte|Business Need|Caracteristica|Característica|Egenskab|Egenskap|Eiginleiki|Feature|Fīča|Fitur|Fonctionnalité|Fonksyonalite|Funcionalidade|Funcionalitat|Functionalitate|Funcţionalitate|Funcționalitate|Functionaliteit|Fungsi|Funkcia|Funkcija|Funkcionalitāte|Funkcionalnost|Funkcja|Funksie|Funktionalität|Funktionalitéit|Funzionalità|Hwaet|Hwæt|Jellemző|Karakteristik|Lastnost|Mak|Mogucnost|laH|Mogućnost|Moznosti|Možnosti|OH HAI|Omadus|Ominaisuus|Osobina|Özellik|Potrzeba biznesowa|perbogh|poQbogh malja'|Požadavek|Požiadavka|Pretty much|Qap|Qu'meH 'ut|Savybė|Tính năng|Trajto|Vermoë|Vlastnosť|Właściwość|Značilnost|Δυνατότητα|Λειτουργία|Могућност|Мөмкинлек|Особина|Свойство|Үзенчәлеклелек|Функционал|Функционалност|Функция|Функціонал|תכונה|خاصية|خصوصیت|صلاحیت|کاروبار کی ضرورت|وِیژگی|रूप लेख|ਖਾਸੀਅਤ|ਨਕਸ਼ ਨੁਹਾਰ|ਮੁਹਾਂਦਰਾ|గుణము|ಹೆಚ್ಚಳ|ความต้องการทางธุรกิจ|ความสามารถ|โครงหลัก|기능|フィーチャ|功能|機能):(?:[^:\r\n]+(?:\r?\n|\r|$))*/,lookbehind:!0,inside:{important:{pattern:/(:)[^\r\n]+/,lookbehind:!0},keyword:/[^:\r\n]+:/}},scenario:{pattern:/(^[ \t]*)(?:Abstract Scenario|Abstrakt Scenario|Achtergrond|Aer|Ær|Agtergrond|All y'all|Antecedentes|Antecedents|Atburðarás|Atburðarásir|Awww, look mate|B4|Background|Baggrund|Bakgrund|Bakgrunn|Bakgrunnur|Beispiele|Beispiller|Bối cảnh|Cefndir|Cenario|Cenário|Cenario de Fundo|Cenário de Fundo|Cenarios|Cenários|Contesto|Context|Contexte|Contexto|Conto|Contoh|Contone|Dæmi|Dasar|Dead men tell no tales|Delineacao do Cenario|Delineação do Cenário|Dis is what went down|Dữ liệu|Dyagram Senaryo|Dyagram senaryo|Egzanp|Ejemplos|Eksempler|Ekzemploj|Enghreifftiau|Esbozo do escenario|Escenari|Escenario|Esempi|Esquema de l'escenari|Esquema del escenario|Esquema do Cenario|Esquema do Cenário|EXAMPLZ|Examples|Exempel|Exemple|Exemples|Exemplos|First off|Fono|Forgatókönyv|Forgatókönyv vázlat|Fundo|Geçmiş|Grundlage|Hannergrond|ghantoH|Háttér|Heave to|Istorik|Juhtumid|Keadaan|Khung kịch bản|Khung tình huống|Kịch bản|Koncept|Konsep skenario|Kontèks|Kontekst|Kontekstas|Konteksts|Kontext|Konturo de la scenaro|Latar Belakang|lut chovnatlh|lut|lutmey|Lýsing Atburðarásar|Lýsing Dæma|MISHUN SRSLY|MISHUN|Menggariskan Senario|mo'|Náčrt Scenára|Náčrt Scénáře|Náčrt Scenáru|Oris scenarija|Örnekler|Osnova|Osnova Scenára|Osnova scénáře|Osnutek|Ozadje|Paraugs|Pavyzdžiai|Példák|Piemēri|Plan du scénario|Plan du Scénario|Plan Senaryo|Plan senaryo|Plang vum Szenario|Pozadí|Pozadie|Pozadina|Príklady|Příklady|Primer|Primeri|Primjeri|Przykłady|Raamstsenaarium|Reckon it's like|Rerefons|Scenár|Scénář|Scenarie|Scenarij|Scenarijai|Scenarijaus šablonas|Scenariji|Scenārijs|Scenārijs pēc parauga|Scenarijus|Scenario|Scénario|Scenario Amlinellol|Scenario Outline|Scenario Template|Scenariomal|Scenariomall|Scenarios|Scenariu|Scenariusz|Scenaro|Schema dello scenario|Se ðe|Se the|Se þe|Senario|Senaryo Deskripsyon|Senaryo deskripsyon|Senaryo|Senaryo taslağı|Shiver me timbers|Situācija|Situai|Situasie Uiteensetting|Situasie|Skenario konsep|Skenario|Skica|Structura scenariu|Structură scenariu|Struktura scenarija|Stsenaarium|Swa hwaer swa|Swa|Swa hwær swa|Szablon scenariusza|Szenario|Szenariogrundriss|Tapaukset|Tapaus|Tapausaihio|Taust|Tausta|Template Keadaan|Template Senario|Template Situai|The thing of it is|Tình huống|Variantai|Voorbeelde|Voorbeelden|Wharrimean is|Yo-ho-ho|You'll wanna|Założenia|Παραδείγματα|Περιγραφή Σεναρίου|Σενάρια|Σενάριο|Υπόβαθρο|Кереш|Контекст|Концепт|Мисаллар|Мисоллар|Основа|Передумова|Позадина|Предистория|Предыстория|Приклади|Пример|Примери|Примеры|Рамка на сценарий|Скица|Структура сценарија|Структура сценария|Структура сценарію|Сценарий|Сценарий структураси|Сценарийның төзелеше|Сценарији|Сценарио|Сценарій|Тарих|Үрнәкләр|דוגמאות|רקע|תבנית תרחיש|תרחיש|الخلفية|الگوی سناریو|امثلة|پس منظر|زمینه|سناریو|سيناريو|سيناريو مخطط|مثالیں|منظر نامے کا خاکہ|منظرنامہ|نمونه ها|उदाहरण|परिदृश्य|परिदृश्य रूपरेखा|पृष्ठभूमि|ਉਦਾਹਰਨਾਂ|ਪਟਕਥਾ|ਪਟਕਥਾ ਢਾਂਚਾ|ਪਟਕਥਾ ਰੂਪ ਰੇਖਾ|ਪਿਛੋਕੜ|ఉదాహరణలు|కథనం|నేపథ్యం|సన్నివేశం|ಉದಾಹರಣೆಗಳು|ಕಥಾಸಾರಾಂಶ|ವಿವರಣೆ|ಹಿನ್ನೆಲೆ|โครงสร้างของเหตุการณ์|ชุดของตัวอย่าง|ชุดของเหตุการณ์|แนวคิด|สรุปเหตุการณ์|เหตุการณ์|배경|시나리오|시나리오 개요|예|サンプル|シナリオ|シナリオアウトライン|シナリオテンプレ|シナリオテンプレート|テンプレ|例|例子|剧本|剧本大纲|劇本|劇本大綱|场景|场景大纲|場景|場景大綱|背景):[^:\r\n]*/m,lookbehind:!0,inside:{important:{pattern:/(:)[^\r\n]*/,lookbehind:!0},keyword:/[^:\r\n]+:/}},"table-body":{pattern:RegExp("("+r+")(?:"+r+")+"),lookbehind:!0,inside:{outline:{pattern:/<[^>]+>/,alias:"variable"},td:{pattern:/\s*[^\s|][^|]*/,alias:"string"},punctuation:/\|/}},"table-head":{pattern:RegExp(r),inside:{th:{pattern:/\s*[^\s|][^|]*/,alias:"variable"},punctuation:/\|/}},atrule:{pattern:/(^[ \t]+)(?:'a|'ach|'ej|7|a|A také|A taktiež|A tiež|A zároveň|Aber|Ac|Adott|Akkor|Ak|Aleshores|Ale|Ali|Allora|Alors|Als|Ama|Amennyiben|Amikor|Ampak|an|AN|Ananging|And y'all|And|Angenommen|Anrhegedig a|An|Apabila|Atès|Atesa|Atunci|Avast!|Aye|A|awer|Bagi|Banjur|Bet|Biết|Blimey!|Buh|But at the end of the day I reckon|But y'all|But|BUT|Cal|Când|Cand|Cando|Ce|Cuando|Če|Ða ðe|Ða|Dadas|Dada|Dados|Dado|DaH ghu' bejlu'|dann|Dann|Dano|Dan|Dar|Dat fiind|Data|Date fiind|Date|Dati fiind|Dati|Daţi fiind|Dați fiind|DEN|Dato|De|Den youse gotta|Dengan|Diberi|Diyelim ki|Donada|Donat|Donitaĵo|Do|Dun|Duota|Ðurh|Eeldades|Ef|Eğer ki|Entao|Então|Entón|E|En|Entonces|Epi|És|Etant donnée|Etant donné|Et|Étant données|Étant donnée|Étant donné|Etant données|Etant donnés|Étant donnés|Fakat|Gangway!|Gdy|Gegeben seien|Gegeben sei|Gegeven|Gegewe|ghu' noblu'|Gitt|Given y'all|Given|Givet|Givun|Ha|Cho|I CAN HAZ|In|Ir|It's just unbelievable|I|Ja|Jeśli|Jeżeli|Kad|Kada|Kadar|Kai|Kaj|Když|Keď|Kemudian|Ketika|Khi|Kiedy|Ko|Kuid|Kui|Kun|Lan|latlh|Le sa a|Let go and haul|Le|Lè sa a|Lè|Logo|Lorsqu'<|Lorsque|mä|Maar|Mais|Mając|Ma|Majd|Maka|Manawa|Mas|Men|Menawa|Mutta|Nalika|Nalikaning|Nanging|Når|När|Nato|Nhưng|Niin|Njuk|O zaman|Och|Og|Oletetaan|Ond|Onda|Oraz|Pak|Pero|Però|Podano|Pokiaľ|Pokud|Potem|Potom|Privzeto|Pryd|Quan|Quand|Quando|qaSDI'|Så|Sed|Se|Siis|Sipoze ke|Sipoze Ke|Sipoze|Si|Şi|Și|Soit|Stel|Tada|Tad|Takrat|Tak|Tapi|Ter|Tetapi|Tha the|Tha|Then y'all|Then|Thì|Thurh|Toda|Too right|Un|Und|ugeholl|Và|vaj|Vendar|Ve|wann|Wanneer|WEN|Wenn|When y'all|When|Wtedy|Wun|Y'know|Yeah nah|Yna|Youse know like when|Youse know when youse got|Y|Za predpokladu|Za předpokladu|Zadan|Zadani|Zadano|Zadate|Zadato|Zakładając|Zaradi|Zatati|Þa þe|Þa|Þá|Þegar|Þurh|Αλλά|Δεδομένου|Και|Όταν|Τότε|А також|Агар|Але|Али|Аммо|А|Әгәр|Әйтик|Әмма|Бирок|Ва|Вә|Дадено|Дано|Допустим|Если|Задате|Задати|Задато|И|І|К тому же|Када|Кад|Когато|Когда|Коли|Ләкин|Лекин|Нәтиҗәдә|Нехай|Но|Онда|Припустимо, що|Припустимо|Пусть|Также|Та|Тогда|Тоді|То|Унда|Һәм|Якщо|אבל|אזי|אז|בהינתן|וגם|כאשר|آنگاه|اذاً|اگر|اما|اور|با فرض|بالفرض|بفرض|پھر|تب|ثم|جب|عندما|فرض کیا|لكن|لیکن|متى|هنگامی|و|अगर|और|कदा|किन्तु|चूंकि|जब|तथा|तदा|तब|परन्तु|पर|यदि|ਅਤੇ|ਜਦੋਂ|ਜਿਵੇਂ ਕਿ|ਜੇਕਰ|ਤਦ|ਪਰ|అప్పుడు|ఈ పరిస్థితిలో|కాని|చెప్పబడినది|మరియు|ಆದರೆ|ನಂತರ|ನೀಡಿದ|ಮತ್ತು|ಸ್ಥಿತಿಯನ್ನು|กำหนดให้|ดังนั้น|แต่|เมื่อ|และ|그러면<|그리고<|단<|만약<|만일<|먼저<|조건<|하지만<|かつ<|しかし<|ただし<|ならば<|もし<|並且<|但し<|但是<|假如<|假定<|假設<|假设<|前提<|同时<|同時<|并且<|当<|當<|而且<|那么<|那麼<)(?=[ \t])/m,lookbehind:!0},string:{pattern:/"(?:\\.|[^"\\\r\n])*"|'(?:\\.|[^'\\\r\n])*'/,inside:{outline:{pattern:/<[^>]+>/,alias:"variable"}}},outline:{pattern:/<[^>]+>/,alias:"variable"}}})(t)}return qv}var Vv,b2;function xye(){if(b2)return Vv;b2=1,Vv=e,e.displayName="git",e.aliases=[];function e(t){t.languages.git={comment:/^#.*/m,deleted:/^[-–].*/m,inserted:/^\+.*/m,string:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,command:{pattern:/^.*\$ git .*$/m,inside:{parameter:/\s--?\w+/}},coord:/^@@.*@@$/m,"commit-sha1":/^commit \w{40}$/m}}return Vv}var Wv,y2;function kye(){if(y2)return Wv;y2=1;var e=Ci();Wv=t,t.displayName="glsl",t.aliases=[];function t(n){n.register(e),n.languages.glsl=n.languages.extend("c",{keyword:/\b(?:active|asm|atomic_uint|attribute|[ibdu]?vec[234]|bool|break|buffer|case|cast|centroid|class|coherent|common|const|continue|d?mat[234](?:x[234])?|default|discard|do|double|else|enum|extern|external|false|filter|fixed|flat|float|for|fvec[234]|goto|half|highp|hvec[234]|[iu]?sampler2DMS(?:Array)?|[iu]?sampler2DRect|[iu]?samplerBuffer|[iu]?samplerCube|[iu]?samplerCubeArray|[iu]?sampler[123]D|[iu]?sampler[12]DArray|[iu]?image2DMS(?:Array)?|[iu]?image2DRect|[iu]?imageBuffer|[iu]?imageCube|[iu]?imageCubeArray|[iu]?image[123]D|[iu]?image[12]DArray|if|in|inline|inout|input|int|interface|invariant|layout|long|lowp|mediump|namespace|noinline|noperspective|out|output|partition|patch|precise|precision|public|readonly|resource|restrict|return|sample|sampler[12]DArrayShadow|sampler[12]DShadow|sampler2DRectShadow|sampler3DRect|samplerCubeArrayShadow|samplerCubeShadow|shared|short|sizeof|smooth|static|struct|subroutine|superp|switch|template|this|true|typedef|uint|uniform|union|unsigned|using|varying|void|volatile|while|writeonly)\b/})}return Wv}var Yv,v2;function Tye(){if(v2)return Yv;v2=1,Yv=e,e.displayName="gml",e.aliases=[];function e(t){t.languages.gamemakerlanguage=t.languages.gml=t.languages.extend("clike",{keyword:/\b(?:break|case|continue|default|do|else|enum|exit|for|globalvar|if|repeat|return|switch|until|var|while)\b/,number:/(?:\b0x[\da-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ulf]{0,4}/i,operator:/--|\+\+|[-+%/=]=?|!=|\*\*?=?|<[<=>]?|>[=>]?|&&?|\^\^?|\|\|?|~|\b(?:and|at|not|or|with|xor)\b/,constant:/\b(?:GM_build_date|GM_version|action_(?:continue|restart|reverse|stop)|all|gamespeed_(?:fps|microseconds)|global|local|noone|other|pi|pointer_(?:invalid|null)|self|timezone_(?:local|utc)|undefined|ev_(?:create|destroy|step|alarm|keyboard|mouse|collision|other|draw|draw_(?:begin|end|post|pre)|keypress|keyrelease|trigger|(?:left|middle|no|right)_button|(?:left|middle|right)_press|(?:left|middle|right)_release|mouse_(?:enter|leave|wheel_down|wheel_up)|global_(?:left|middle|right)_button|global_(?:left|middle|right)_press|global_(?:left|middle|right)_release|joystick(?:1|2)_(?:button1|button2|button3|button4|button5|button6|button7|button8|down|left|right|up)|outside|boundary|game_start|game_end|room_start|room_end|no_more_lives|animation_end|end_of_path|no_more_health|user\d|gui|gui_begin|gui_end|step_(?:begin|end|normal))|vk_(?:alt|anykey|backspace|control|delete|down|end|enter|escape|home|insert|left|nokey|pagedown|pageup|pause|printscreen|return|right|shift|space|tab|up|f\d|numpad\d|add|decimal|divide|lalt|lcontrol|lshift|multiply|ralt|rcontrol|rshift|subtract)|achievement_(?:filter_(?:all_players|favorites_only|friends_only)|friends_info|info|leaderboard_info|our_info|pic_loaded|show_(?:achievement|bank|friend_picker|leaderboard|profile|purchase_prompt|ui)|type_challenge|type_score_challenge)|asset_(?:font|object|path|room|script|shader|sound|sprite|tiles|timeline|unknown)|audio_(?:3d|falloff_(?:exponent_distance|exponent_distance_clamped|inverse_distance|inverse_distance_clamped|linear_distance|linear_distance_clamped|none)|mono|new_system|old_system|stereo)|bm_(?:add|complex|dest_alpha|dest_color|dest_colour|inv_dest_alpha|inv_dest_color|inv_dest_colour|inv_src_alpha|inv_src_color|inv_src_colour|max|normal|one|src_alpha|src_alpha_sat|src_color|src_colour|subtract|zero)|browser_(?:chrome|firefox|ie|ie_mobile|not_a_browser|opera|safari|safari_mobile|tizen|unknown|windows_store)|buffer_(?:bool|f16|f32|f64|fast|fixed|generalerror|grow|invalidtype|network|outofbounds|outofspace|s16|s32|s8|seek_end|seek_relative|seek_start|string|text|u16|u32|u64|u8|vbuffer|wrap)|c_(?:aqua|black|blue|dkgray|fuchsia|gray|green|lime|ltgray|maroon|navy|olive|orange|purple|red|silver|teal|white|yellow)|cmpfunc_(?:always|equal|greater|greaterequal|less|lessequal|never|notequal)|cr_(?:appstart|arrow|beam|cross|default|drag|handpoint|hourglass|none|size_all|size_nesw|size_ns|size_nwse|size_we|uparrow)|cull_(?:clockwise|counterclockwise|noculling)|device_(?:emulator|tablet)|device_ios_(?:ipad|ipad_retina|iphone|iphone5|iphone6|iphone6plus|iphone_retina|unknown)|display_(?:landscape|landscape_flipped|portrait|portrait_flipped)|dll_(?:cdecl|cdel|stdcall)|ds_type_(?:grid|list|map|priority|queue|stack)|ef_(?:cloud|ellipse|explosion|firework|flare|rain|ring|smoke|smokeup|snow|spark|star)|fa_(?:archive|bottom|center|directory|hidden|left|middle|readonly|right|sysfile|top|volumeid)|fb_login_(?:default|fallback_to_webview|forcing_safari|forcing_webview|no_fallback_to_webview|use_system_account)|iap_(?:available|canceled|ev_consume|ev_product|ev_purchase|ev_restore|ev_storeload|failed|purchased|refunded|status_available|status_loading|status_processing|status_restoring|status_unavailable|status_uninitialised|storeload_failed|storeload_ok|unavailable)|leaderboard_type_(?:number|time_mins_secs)|lighttype_(?:dir|point)|matrix_(?:projection|view|world)|mb_(?:any|left|middle|none|right)|network_(?:config_(?:connect_timeout|disable_reliable_udp|enable_reliable_udp|use_non_blocking_socket)|socket_(?:bluetooth|tcp|udp)|type_(?:connect|data|disconnect|non_blocking_connect))|of_challenge_(?:lose|tie|win)|os_(?:android|ios|linux|macosx|ps3|ps4|psvita|unknown|uwp|win32|win8native|windows|winphone|xboxone)|phy_debug_render_(?:aabb|collision_pairs|coms|core_shapes|joints|obb|shapes)|phy_joint_(?:anchor_1_x|anchor_1_y|anchor_2_x|anchor_2_y|angle|angle_limits|damping_ratio|frequency|length_1|length_2|lower_angle_limit|max_force|max_length|max_motor_force|max_motor_torque|max_torque|motor_force|motor_speed|motor_torque|reaction_force_x|reaction_force_y|reaction_torque|speed|translation|upper_angle_limit)|phy_particle_data_flag_(?:category|color|colour|position|typeflags|velocity)|phy_particle_flag_(?:colormixing|colourmixing|elastic|powder|spring|tensile|viscous|wall|water|zombie)|phy_particle_group_flag_(?:rigid|solid)|pr_(?:linelist|linestrip|pointlist|trianglefan|trianglelist|trianglestrip)|ps_(?:distr|shape)_(?:diamond|ellipse|gaussian|invgaussian|line|linear|rectangle)|pt_shape_(?:circle|cloud|disk|explosion|flare|line|pixel|ring|smoke|snow|spark|sphere|square|star)|ty_(?:real|string)|gp_(?:face\d|axislh|axislv|axisrh|axisrv|padd|padl|padr|padu|select|shoulderl|shoulderlb|shoulderr|shoulderrb|start|stickl|stickr)|lb_disp_(?:none|numeric|time_ms|time_sec)|lb_sort_(?:ascending|descending|none)|ov_(?:achievements|community|friends|gamegroup|players|settings)|ugc_(?:filetype_(?:community|microtrans)|list_(?:Favorited|Followed|Published|Subscribed|UsedOrPlayed|VotedDown|VotedOn|VotedUp|WillVoteLater)|match_(?:AllGuides|Artwork|Collections|ControllerBindings|IntegratedGuides|Items|Items_Mtx|Items_ReadyToUse|Screenshots|UsableInGame|Videos|WebGuides)|query_(?:AcceptedForGameRankedByAcceptanceDate|CreatedByFriendsRankedByPublicationDate|FavoritedByFriendsRankedByPublicationDate|NotYetRated)|query_RankedBy(?:NumTimesReported|PublicationDate|TextSearch|TotalVotesAsc|Trend|Vote|VotesUp)|result_success|sortorder_CreationOrder(?:Asc|Desc)|sortorder_(?:ForModeration|LastUpdatedDesc|SubscriptionDateDesc|TitleAsc|VoteScoreDesc)|visibility_(?:friends_only|private|public))|vertex_usage_(?:binormal|blendindices|blendweight|color|colour|depth|fog|normal|position|psize|sample|tangent|texcoord|textcoord)|vertex_type_(?:float\d|color|colour|ubyte4)|input_type|layerelementtype_(?:background|instance|oldtilemap|particlesystem|sprite|tile|tilemap|undefined)|se_(?:chorus|compressor|echo|equalizer|flanger|gargle|none|reverb)|text_type|tile_(?:flip|index_mask|mirror|rotate)|(?:obj|rm|scr|spr)\w+)\b/,variable:/\b(?:alarm|application_surface|async_load|background_(?:alpha|blend|color|colour|foreground|height|hspeed|htiled|index|showcolor|showcolour|visible|vspeed|vtiled|width|x|xscale|y|yscale)|bbox_(?:bottom|left|right|top)|browser_(?:height|width)|caption_(?:health|lives|score)|current_(?:day|hour|minute|month|second|time|weekday|year)|cursor_sprite|debug_mode|delta_time|direction|display_aa|error_(?:last|occurred)|event_(?:action|number|object|type)|fps|fps_real|friction|game_(?:display|project|save)_(?:id|name)|gamemaker_(?:pro|registered|version)|gravity|gravity_direction|(?:h|v)speed|health|iap_data|id|image_(?:alpha|angle|blend|depth|index|number|speed|xscale|yscale)|instance_(?:count|id)|keyboard_(?:key|lastchar|lastkey|string)|layer|lives|mask_index|mouse_(?:button|lastbutton|x|y)|object_index|os_(?:browser|device|type|version)|path_(?:endaction|index|orientation|position|positionprevious|scale|speed)|persistent|phy_(?:rotation|(?:col_normal|collision|com|linear_velocity|position|speed)_(?:x|y)|angular_(?:damping|velocity)|position_(?:x|y)previous|speed|linear_damping|bullet|fixed_rotation|active|mass|inertia|dynamic|kinematic|sleeping|collision_points)|pointer_(?:invalid|null)|room|room_(?:caption|first|height|last|persistent|speed|width)|score|secure_mode|show_(?:health|lives|score)|solid|speed|sprite_(?:height|index|width|xoffset|yoffset)|temp_directory|timeline_(?:index|loop|position|running|speed)|transition_(?:color|kind|steps)|undefined|view_(?:angle|current|enabled|(?:h|v)(?:border|speed)|(?:h|w|x|y)port|(?:h|w|x|y)view|object|surface_id|visible)|visible|webgl_enabled|working_directory|(?:x|y)(?:previous|start)|x|y|argument(?:_relitive|_count|\d)|argument|global|local|other|self)\b/})}return Yv}var Kv,S2;function Aye(){if(S2)return Kv;S2=1,Kv=e,e.displayName="gn",e.aliases=["gni"];function e(t){t.languages.gn={comment:{pattern:/#.*/,greedy:!0},"string-literal":{pattern:/(^|[^\\"])"(?:[^\r\n"\\]|\\.)*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\{[\s\S]*?\}|[a-zA-Z_]\w*|0x[a-fA-F0-9]{2})/,lookbehind:!0,inside:{number:/^\$0x[\s\S]{2}$/,variable:/^\$\w+$/,"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}},string:/[\s\S]+/}},keyword:/\b(?:else|if)\b/,boolean:/\b(?:false|true)\b/,"builtin-function":{pattern:/\b(?:assert|defined|foreach|import|pool|print|template|tool|toolchain)(?=\s*\()/i,alias:"keyword"},function:/\b[a-z_]\w*(?=\s*\()/i,constant:/\b(?:current_cpu|current_os|current_toolchain|default_toolchain|host_cpu|host_os|root_build_dir|root_gen_dir|root_out_dir|target_cpu|target_gen_dir|target_os|target_out_dir)\b/,number:/-?\b\d+\b/,operator:/[-+!=<>]=?|&&|\|\|/,punctuation:/[(){}[\],.]/},t.languages.gn["string-literal"].inside.interpolation.inside.expression.inside=t.languages.gn,t.languages.gni=t.languages.gn}return Kv}var Xv,E2;function Rye(){if(E2)return Xv;E2=1,Xv=e,e.displayName="goModule",e.aliases=[];function e(t){t.languages["go-mod"]=t.languages["go-module"]={comment:{pattern:/\/\/.*/,greedy:!0},version:{pattern:/(^|[\s()[\],])v\d+\.\d+\.\d+(?:[+-][-+.\w]*)?(?![^\s()[\],])/,lookbehind:!0,alias:"number"},"go-version":{pattern:/((?:^|\s)go\s+)\d+(?:\.\d+){1,2}/,lookbehind:!0,alias:"number"},keyword:{pattern:/^([ \t]*)(?:exclude|go|module|replace|require|retract)\b/m,lookbehind:!0},operator:/=>/,punctuation:/[()[\],]/}}return Xv}var Zv,w2;function Cye(){if(w2)return Zv;w2=1,Zv=e,e.displayName="go",e.aliases=[];function e(t){t.languages.go=t.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\.|[^"\\\r\n])*"|`[^`]*`/,lookbehind:!0,greedy:!0},keyword:/\b(?:break|case|chan|const|continue|default|defer|else|fallthrough|for|func|go(?:to)?|if|import|interface|map|package|range|return|select|struct|switch|type|var)\b/,boolean:/\b(?:_|false|iota|nil|true)\b/,number:[/\b0(?:b[01_]+|o[0-7_]+)i?\b/i,/\b0x(?:[a-f\d_]+(?:\.[a-f\d_]*)?|\.[a-f\d_]+)(?:p[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,/(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?[\d_]+)?i?(?!\w)/i],operator:/[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\./,builtin:/\b(?:append|bool|byte|cap|close|complex|complex(?:64|128)|copy|delete|error|float(?:32|64)|u?int(?:8|16|32|64)?|imag|len|make|new|panic|print(?:ln)?|real|recover|rune|string|uintptr)\b/}),t.languages.insertBefore("go","string",{char:{pattern:/'(?:\\.|[^'\\\r\n]){0,10}'/,greedy:!0}}),delete t.languages.go["class-name"]}return Zv}var Qv,x2;function _ye(){if(x2)return Qv;x2=1,Qv=e,e.displayName="graphql",e.aliases=[];function e(t){t.languages.graphql={comment:/#.*/,description:{pattern:/(?:"""(?:[^"]|(?!""")")*"""|"(?:\\.|[^\\"\r\n])*")(?=\s*[a-z_])/i,greedy:!0,alias:"string",inside:{"language-markdown":{pattern:/(^"(?:"")?)(?!\1)[\s\S]+(?=\1$)/,lookbehind:!0,inside:t.languages.markdown}}},string:{pattern:/"""(?:[^"]|(?!""")")*"""|"(?:\\.|[^\\"\r\n])*"/,greedy:!0},number:/(?:\B-|\b)\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,boolean:/\b(?:false|true)\b/,variable:/\$[a-z_]\w*/i,directive:{pattern:/@[a-z_]\w*/i,alias:"function"},"attr-name":{pattern:/\b[a-z_]\w*(?=\s*(?:\((?:[^()"]|"(?:\\.|[^\\"\r\n])*")*\))?:)/i,greedy:!0},"atom-input":{pattern:/\b[A-Z]\w*Input\b/,alias:"class-name"},scalar:/\b(?:Boolean|Float|ID|Int|String)\b/,constant:/\b[A-Z][A-Z_\d]*\b/,"class-name":{pattern:/(\b(?:enum|implements|interface|on|scalar|type|union)\s+|&\s*|:\s*|\[)[A-Z_]\w*/,lookbehind:!0},fragment:{pattern:/(\bfragment\s+|\.{3}\s*(?!on\b))[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},"definition-mutation":{pattern:/(\bmutation\s+)[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},"definition-query":{pattern:/(\bquery\s+)[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},keyword:/\b(?:directive|enum|extend|fragment|implements|input|interface|mutation|on|query|repeatable|scalar|schema|subscription|type|union)\b/,operator:/[!=|&]|\.{3}/,"property-query":/\w+(?=\s*\()/,object:/\w+(?=\s*\{)/,punctuation:/[!(){}\[\]:=,]/,property:/\w+/},t.hooks.add("after-tokenize",function(r){if(r.language!=="graphql")return;var a=r.tokens.filter(function(A){return typeof A!="string"&&A.type!=="comment"&&A.type!=="scalar"}),o=0;function s(A){return a[o+A]}function l(A,x){x=x||0;for(var R=0;R<A.length;R++){var O=s(R+x);if(!O||O.type!==A[R])return!1}return!0}function u(A,x){for(var R=1,O=o;O<a.length;O++){var N=a[O],C=N.content;if(N.type==="punctuation"&&typeof C=="string"){if(A.test(C))R++;else if(x.test(C)&&(R--,R===0))return O}}return-1}function d(A,x){var R=A.alias;R?Array.isArray(R)||(A.alias=R=[R]):A.alias=R=[],R.push(x)}for(;o<a.length;){var p=a[o++];if(p.type==="keyword"&&p.content==="mutation"){var g=[];if(l(["definition-mutation","punctuation"])&&s(1).content==="("){o+=2;var m=u(/^\($/,/^\)$/);if(m===-1)continue;for(;o<m;o++){var b=s(0);b.type==="variable"&&(d(b,"variable-input"),g.push(b.content))}o=m+1}if(l(["punctuation","property-query"])&&s(0).content==="{"&&(o++,d(s(0),"property-mutation"),g.length>0)){var v=u(/^\{$/,/^\}$/);if(v===-1)continue;for(var y=o;y<v;y++){var k=a[y];k.type==="variable"&&g.indexOf(k.content)>=0&&d(k,"variable-input")}}}}})}return Qv}var Jv,k2;function Nye(){if(k2)return Jv;k2=1,Jv=e,e.displayName="groovy",e.aliases=[];function e(t){t.languages.groovy=t.languages.extend("clike",{string:[{pattern:/("""|''')(?:[^\\]|\\[\s\S])*?\1|\$\/(?:[^/$]|\$(?:[/$]|(?![/$]))|\/(?!\$))*\/\$/,greedy:!0},{pattern:/(["'/])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0}],keyword:/\b(?:abstract|as|assert|boolean|break|byte|case|catch|char|class|const|continue|def|default|do|double|else|enum|extends|final|finally|float|for|goto|if|implements|import|in|instanceof|int|interface|long|native|new|package|private|protected|public|return|short|static|strictfp|super|switch|synchronized|this|throw|throws|trait|transient|try|void|volatile|while)\b/,number:/\b(?:0b[01_]+|0x[\da-f_]+(?:\.[\da-f_p\-]+)?|[\d_]+(?:\.[\d_]+)?(?:e[+-]?\d+)?)[glidf]?\b/i,operator:{pattern:/(^|[^.])(?:~|==?~?|\?[.:]?|\*(?:[.=]|\*=?)?|\.[@&]|\.\.<|\.\.(?!\.)|-[-=>]?|\+[+=]?|!=?|<(?:<=?|=>?)?|>(?:>>?=?|=)?|&[&=]?|\|[|=]?|\/=?|\^=?|%=?)/,lookbehind:!0},punctuation:/\.+|[{}[\];(),:$]/}),t.languages.insertBefore("groovy","string",{shebang:{pattern:/#!.+/,alias:"comment"}}),t.languages.insertBefore("groovy","punctuation",{"spock-block":/\b(?:and|cleanup|expect|given|setup|then|when|where):/}),t.languages.insertBefore("groovy","function",{annotation:{pattern:/(^|[^.])@\w+/,lookbehind:!0,alias:"punctuation"}}),t.hooks.add("wrap",function(n){if(n.language==="groovy"&&n.type==="string"){var r=n.content.value[0];if(r!="'"){var a=/([^\\])(?:\$(?:\{.*?\}|[\w.]+))/;r==="$"&&(a=/([^\$])(?:\$(?:\{.*?\}|[\w.]+))/),n.content.value=n.content.value.replace(/&lt;/g,"<").replace(/&amp;/g,"&"),n.content=t.highlight(n.content.value,{expression:{pattern:a,lookbehind:!0,inside:t.languages.groovy}}),n.classes.push(r==="/"?"regex":"gstring")}}})}return Jv}var eS,T2;function Oye(){if(T2)return eS;T2=1;var e=Bp();eS=t,t.displayName="haml",t.aliases=[];function t(n){n.register(e),function(r){r.languages.haml={"multiline-comment":{pattern:/((?:^|\r?\n|\r)([\t ]*))(?:\/|-#).*(?:(?:\r?\n|\r)\2[\t ].+)*/,lookbehind:!0,alias:"comment"},"multiline-code":[{pattern:/((?:^|\r?\n|\r)([\t ]*)(?:[~-]|[&!]?=)).*,[\t ]*(?:(?:\r?\n|\r)\2[\t ].*,[\t ]*)*(?:(?:\r?\n|\r)\2[\t ].+)/,lookbehind:!0,inside:r.languages.ruby},{pattern:/((?:^|\r?\n|\r)([\t ]*)(?:[~-]|[&!]?=)).*\|[\t ]*(?:(?:\r?\n|\r)\2[\t ].*\|[\t ]*)*/,lookbehind:!0,inside:r.languages.ruby}],filter:{pattern:/((?:^|\r?\n|\r)([\t ]*)):[\w-]+(?:(?:\r?\n|\r)(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/,lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"symbol"}}},markup:{pattern:/((?:^|\r?\n|\r)[\t ]*)<.+/,lookbehind:!0,inside:r.languages.markup},doctype:{pattern:/((?:^|\r?\n|\r)[\t ]*)!!!(?: .+)?/,lookbehind:!0},tag:{pattern:/((?:^|\r?\n|\r)[\t ]*)[%.#][\w\-#.]*[\w\-](?:\([^)]+\)|\{(?:\{[^}]+\}|[^{}])+\}|\[[^\]]+\])*[\/<>]*/,lookbehind:!0,inside:{attributes:[{pattern:/(^|[^#])\{(?:\{[^}]+\}|[^{}])+\}/,lookbehind:!0,inside:r.languages.ruby},{pattern:/\([^)]+\)/,inside:{"attr-value":{pattern:/(=\s*)(?:"(?:\\.|[^\\"\r\n])*"|[^)\s]+)/,lookbehind:!0},"attr-name":/[\w:-]+(?=\s*!?=|\s*[,)])/,punctuation:/[=(),]/}},{pattern:/\[[^\]]+\]/,inside:r.languages.ruby}],punctuation:/[<>]/}},code:{pattern:/((?:^|\r?\n|\r)[\t ]*(?:[~-]|[&!]?=)).+/,lookbehind:!0,inside:r.languages.ruby},interpolation:{pattern:/#\{[^}]+\}/,inside:{delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"},ruby:{pattern:/[\s\S]+/,inside:r.languages.ruby}}},punctuation:{pattern:/((?:^|\r?\n|\r)[\t ]*)[~=\-&!]+/,lookbehind:!0}};for(var a="((?:^|\\r?\\n|\\r)([\\t ]*)):{{filter_name}}(?:(?:\\r?\\n|\\r)(?:\\2[\\t ].+|\\s*?(?=\\r?\\n|\\r)))+",o=["css",{filter:"coffee",language:"coffeescript"},"erb","javascript","less","markdown","ruby","scss","textile"],s={},l=0,u=o.length;l<u;l++){var d=o[l];d=typeof d=="string"?{filter:d,language:d}:d,r.languages[d.language]&&(s["filter-"+d.filter]={pattern:RegExp(a.replace("{{filter_name}}",function(){return d.filter})),lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"symbol"},text:{pattern:/[\s\S]+/,alias:[d.language,"language-"+d.language],inside:r.languages[d.language]}}})}r.languages.insertBefore("haml","filter",s)}(n)}return eS}var tS,A2;function Iye(){if(A2)return tS;A2=1;var e=Wn();tS=t,t.displayName="handlebars",t.aliases=["hbs"];function t(n){n.register(e),function(r){r.languages.handlebars={comment:/\{\{![\s\S]*?\}\}/,delimiter:{pattern:/^\{\{\{?|\}\}\}?$/,alias:"punctuation"},string:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][+-]?\d+)?/,boolean:/\b(?:false|true)\b/,block:{pattern:/^(\s*(?:~\s*)?)[#\/]\S+?(?=\s*(?:~\s*)?$|\s)/,lookbehind:!0,alias:"keyword"},brackets:{pattern:/\[[^\]]+\]/,inside:{punctuation:/\[|\]/,variable:/[\s\S]+/}},punctuation:/[!"#%&':()*+,.\/;<=>@\[\\\]^`{|}~]/,variable:/[^!"#%&'()*+,\/;<=>@\[\\\]^`{|}~\s]+/},r.hooks.add("before-tokenize",function(a){var o=/\{\{\{[\s\S]+?\}\}\}|\{\{[\s\S]+?\}\}/g;r.languages["markup-templating"].buildPlaceholders(a,"handlebars",o)}),r.hooks.add("after-tokenize",function(a){r.languages["markup-templating"].tokenizePlaceholders(a,"handlebars")}),r.languages.hbs=r.languages.handlebars}(n)}return tS}var nS,R2;function SA(){if(R2)return nS;R2=1,nS=e,e.displayName="haskell",e.aliases=["hs"];function e(t){t.languages.haskell={comment:{pattern:/(^|[^-!#$%*+=?&@|~.:<>^\\\/])(?:--(?:(?=.)[^-!#$%*+=?&@|~.:<>^\\\/].*|$)|\{-[\s\S]*?-\})/m,lookbehind:!0},char:{pattern:/'(?:[^\\']|\\(?:[abfnrtv\\"'&]|\^[A-Z@[\]^_]|ACK|BEL|BS|CAN|CR|DC1|DC2|DC3|DC4|DEL|DLE|EM|ENQ|EOT|ESC|ETB|ETX|FF|FS|GS|HT|LF|NAK|NUL|RS|SI|SO|SOH|SP|STX|SUB|SYN|US|VT|\d+|o[0-7]+|x[0-9a-fA-F]+))'/,alias:"string"},string:{pattern:/"(?:[^\\"]|\\(?:\S|\s+\\))*"/,greedy:!0},keyword:/\b(?:case|class|data|deriving|do|else|if|in|infixl|infixr|instance|let|module|newtype|of|primitive|then|type|where)\b/,"import-statement":{pattern:/(^[\t ]*)import\s+(?:qualified\s+)?(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*(?:\s+as\s+(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*)?(?:\s+hiding\b)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|hiding|import|qualified)\b/,punctuation:/\./}},builtin:/\b(?:abs|acos|acosh|all|and|any|appendFile|approxRational|asTypeOf|asin|asinh|atan|atan2|atanh|basicIORun|break|catch|ceiling|chr|compare|concat|concatMap|const|cos|cosh|curry|cycle|decodeFloat|denominator|digitToInt|div|divMod|drop|dropWhile|either|elem|encodeFloat|enumFrom|enumFromThen|enumFromThenTo|enumFromTo|error|even|exp|exponent|fail|filter|flip|floatDigits|floatRadix|floatRange|floor|fmap|foldl|foldl1|foldr|foldr1|fromDouble|fromEnum|fromInt|fromInteger|fromIntegral|fromRational|fst|gcd|getChar|getContents|getLine|group|head|id|inRange|index|init|intToDigit|interact|ioError|isAlpha|isAlphaNum|isAscii|isControl|isDenormalized|isDigit|isHexDigit|isIEEE|isInfinite|isLower|isNaN|isNegativeZero|isOctDigit|isPrint|isSpace|isUpper|iterate|last|lcm|length|lex|lexDigits|lexLitChar|lines|log|logBase|lookup|map|mapM|mapM_|max|maxBound|maximum|maybe|min|minBound|minimum|mod|negate|not|notElem|null|numerator|odd|or|ord|otherwise|pack|pi|pred|primExitWith|print|product|properFraction|putChar|putStr|putStrLn|quot|quotRem|range|rangeSize|read|readDec|readFile|readFloat|readHex|readIO|readInt|readList|readLitChar|readLn|readOct|readParen|readSigned|reads|readsPrec|realToFrac|recip|rem|repeat|replicate|return|reverse|round|scaleFloat|scanl|scanl1|scanr|scanr1|seq|sequence|sequence_|show|showChar|showInt|showList|showLitChar|showParen|showSigned|showString|shows|showsPrec|significand|signum|sin|sinh|snd|sort|span|splitAt|sqrt|subtract|succ|sum|tail|take|takeWhile|tan|tanh|threadToIOResult|toEnum|toInt|toInteger|toLower|toRational|toUpper|truncate|uncurry|undefined|unlines|until|unwords|unzip|unzip3|userError|words|writeFile|zip|zip3|zipWith|zipWith3)\b/,number:/\b(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|0o[0-7]+|0x[0-9a-f]+)\b/i,operator:[{pattern:/`(?:[A-Z][\w']*\.)*[_a-z][\w']*`/,greedy:!0},{pattern:/(\s)\.(?=\s)/,lookbehind:!0},/[-!#$%*+=?&@|~:<>^\\\/][-!#$%*+=?&@|~.:<>^\\\/]*|\.[-!#$%*+=?&@|~.:<>^\\\/]+/],hvariable:{pattern:/\b(?:[A-Z][\w']*\.)*[_a-z][\w']*/,inside:{punctuation:/\./}},constant:{pattern:/\b(?:[A-Z][\w']*\.)*[A-Z][\w']*/,inside:{punctuation:/\./}},punctuation:/[{}[\];(),.:]/},t.languages.hs=t.languages.haskell}return nS}var rS,C2;function Dye(){if(C2)return rS;C2=1,rS=e,e.displayName="haxe",e.aliases=[];function e(t){t.languages.haxe=t.languages.extend("clike",{string:{pattern:/"(?:[^"\\]|\\[\s\S])*"/,greedy:!0},"class-name":[{pattern:/(\b(?:abstract|class|enum|extends|implements|interface|new|typedef)\s+)[A-Z_]\w*/,lookbehind:!0},/\b[A-Z]\w*/],keyword:/\bthis\b|\b(?:abstract|as|break|case|cast|catch|class|continue|default|do|dynamic|else|enum|extends|extern|final|for|from|function|if|implements|import|in|inline|interface|macro|new|null|operator|overload|override|package|private|public|return|static|super|switch|throw|to|try|typedef|untyped|using|var|while)(?!\.)\b/,function:{pattern:/\b[a-z_]\w*(?=\s*(?:<[^<>]*>\s*)?\()/i,greedy:!0},operator:/\.{3}|\+\+|--|&&|\|\||->|=>|(?:<<?|>{1,3}|[-+*/%!=&|^])=?|[?:~]/}),t.languages.insertBefore("haxe","string",{"string-interpolation":{pattern:/'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,inside:{interpolation:{pattern:/(^|[^\\])\$(?:\w+|\{[^{}]+\})/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:t.languages.haxe}}},string:/[\s\S]+/}}}),t.languages.insertBefore("haxe","class-name",{regex:{pattern:/~\/(?:[^\/\\\r\n]|\\.)+\/[a-z]*/,greedy:!0,inside:{"regex-flags":/\b[a-z]+$/,"regex-source":{pattern:/^(~\/)[\s\S]+(?=\/$)/,lookbehind:!0,alias:"language-regex",inside:t.languages.regex},"regex-delimiter":/^~\/|\/$/}}}),t.languages.insertBefore("haxe","keyword",{preprocessor:{pattern:/#(?:else|elseif|end|if)\b.*/,alias:"property"},metadata:{pattern:/@:?[\w.]+/,alias:"symbol"},reification:{pattern:/\$(?:\w+|(?=\{))/,alias:"important"}})}return rS}var aS,_2;function Lye(){if(_2)return aS;_2=1,aS=e,e.displayName="hcl",e.aliases=[];function e(t){t.languages.hcl={comment:/(?:\/\/|#).*|\/\*[\s\S]*?(?:\*\/|$)/,heredoc:{pattern:/<<-?(\w+\b)[\s\S]*?^[ \t]*\1/m,greedy:!0,alias:"string"},keyword:[{pattern:/(?:data|resource)\s+(?:"(?:\\[\s\S]|[^\\"])*")(?=\s+"[\w-]+"\s+\{)/i,inside:{type:{pattern:/(resource|data|\s+)(?:"(?:\\[\s\S]|[^\\"])*")/i,lookbehind:!0,alias:"variable"}}},{pattern:/(?:backend|module|output|provider|provisioner|variable)\s+(?:[\w-]+|"(?:\\[\s\S]|[^\\"])*")\s+(?=\{)/i,inside:{type:{pattern:/(backend|module|output|provider|provisioner|variable)\s+(?:[\w-]+|"(?:\\[\s\S]|[^\\"])*")\s+/i,lookbehind:!0,alias:"variable"}}},/[\w-]+(?=\s+\{)/],property:[/[-\w\.]+(?=\s*=(?!=))/,/"(?:\\[\s\S]|[^\\"])+"(?=\s*[:=])/],string:{pattern:/"(?:[^\\$"]|\\[\s\S]|\$(?:(?=")|\$+(?!\$)|[^"${])|\$\{(?:[^{}"]|"(?:[^\\"]|\\[\s\S])*")*\})*"/,greedy:!0,inside:{interpolation:{pattern:/(^|[^$])\$\{(?:[^{}"]|"(?:[^\\"]|\\[\s\S])*")*\}/,lookbehind:!0,inside:{type:{pattern:/(\b(?:count|data|local|module|path|self|terraform|var)\b\.)[\w\*]+/i,lookbehind:!0,alias:"variable"},keyword:/\b(?:count|data|local|module|path|self|terraform|var)\b/i,function:/\w+(?=\()/,string:{pattern:/"(?:\\[\s\S]|[^\\"])*"/,greedy:!0},number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,punctuation:/[!\$#%&'()*+,.\/;<=>@\[\\\]^`{|}~?:]/}}}},number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,boolean:/\b(?:false|true)\b/i,punctuation:/[=\[\]{}]/}}return aS}var oS,N2;function Mye(){if(N2)return oS;N2=1;var e=Ci();oS=t,t.displayName="hlsl",t.aliases=[];function t(n){n.register(e),n.languages.hlsl=n.languages.extend("c",{"class-name":[n.languages.c["class-name"],/\b(?:AppendStructuredBuffer|BlendState|Buffer|ByteAddressBuffer|CompileShader|ComputeShader|ConsumeStructuredBuffer|DepthStencilState|DepthStencilView|DomainShader|GeometryShader|Hullshader|InputPatch|LineStream|OutputPatch|PixelShader|PointStream|RWBuffer|RWByteAddressBuffer|RWStructuredBuffer|RWTexture(?:1D|1DArray|2D|2DArray|3D)|RasterizerState|RenderTargetView|SamplerComparisonState|SamplerState|StructuredBuffer|Texture(?:1D|1DArray|2D|2DArray|2DMS|2DMSArray|3D|Cube|CubeArray)|TriangleStream|VertexShader)\b/],keyword:[/\b(?:asm|asm_fragment|auto|break|case|catch|cbuffer|centroid|char|class|column_major|compile|compile_fragment|const|const_cast|continue|default|delete|discard|do|dynamic_cast|else|enum|explicit|export|extern|for|friend|fxgroup|goto|groupshared|if|in|inline|inout|interface|line|lineadj|linear|long|matrix|mutable|namespace|new|nointerpolation|noperspective|operator|out|packoffset|pass|pixelfragment|point|precise|private|protected|public|register|reinterpret_cast|return|row_major|sample|sampler|shared|short|signed|sizeof|snorm|stateblock|stateblock_state|static|static_cast|string|struct|switch|tbuffer|technique|technique10|technique11|template|texture|this|throw|triangle|triangleadj|try|typedef|typename|uniform|union|unorm|unsigned|using|vector|vertexfragment|virtual|void|volatile|while)\b/,/\b(?:bool|double|dword|float|half|int|min(?:10float|12int|16(?:float|int|uint))|uint)(?:[1-4](?:x[1-4])?)?\b/],number:/(?:(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+)?|\b0x[\da-fA-F]+)[fFhHlLuU]?\b/,boolean:/\b(?:false|true)\b/})}return oS}var iS,O2;function Pye(){if(O2)return iS;O2=1,iS=e,e.displayName="hoon",e.aliases=[];function e(t){t.languages.hoon={comment:{pattern:/::.*/,greedy:!0},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},constant:/%(?:\.[ny]|[\w-]+)/,"class-name":/@(?:[a-z0-9-]*[a-z0-9])?|\*/i,function:/(?:\+[-+] {2})?(?:[a-z](?:[a-z0-9-]*[a-z0-9])?)/,keyword:/\.[\^\+\*=\?]|![><:\.=\?!]|=[>|:,\.\-\^<+;/~\*\?]|\?[>|:\.\-\^<\+&~=@!]|\|[\$_%:\.\-\^~\*=@\?]|\+[|\$\+\*]|:[_\-\^\+~\*]|%[_:\.\-\^\+~\*=]|\^[|:\.\-\+&~\*=\?]|\$[|_%:<>\-\^&~@=\?]|;[:<\+;\/~\*=]|~[>|\$_%<\+\/&=\?!]|--|==/}}return iS}var sS,I2;function Fye(){if(I2)return sS;I2=1,sS=e,e.displayName="hpkp",e.aliases=[];function e(t){t.languages.hpkp={directive:{pattern:/\b(?:includeSubDomains|max-age|pin-sha256|preload|report-to|report-uri|strict)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}return sS}var lS,D2;function zye(){if(D2)return lS;D2=1,lS=e,e.displayName="hsts",e.aliases=[];function e(t){t.languages.hsts={directive:{pattern:/\b(?:includeSubDomains|max-age|preload)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}return lS}var cS,L2;function Bye(){if(L2)return cS;L2=1,cS=e,e.displayName="http",e.aliases=[];function e(t){(function(n){function r(g){return RegExp("(^(?:"+g+"):[ 	]*(?![ 	]))[^]+","i")}n.languages.http={"request-line":{pattern:/^(?:CONNECT|DELETE|GET|HEAD|OPTIONS|PATCH|POST|PRI|PUT|SEARCH|TRACE)\s(?:https?:\/\/|\/)\S*\sHTTP\/[\d.]+/m,inside:{method:{pattern:/^[A-Z]+\b/,alias:"property"},"request-target":{pattern:/^(\s)(?:https?:\/\/|\/)\S*(?=\s)/,lookbehind:!0,alias:"url",inside:n.languages.uri},"http-version":{pattern:/^(\s)HTTP\/[\d.]+/,lookbehind:!0,alias:"property"}}},"response-status":{pattern:/^HTTP\/[\d.]+ \d+ .+/m,inside:{"http-version":{pattern:/^HTTP\/[\d.]+/,alias:"property"},"status-code":{pattern:/^(\s)\d+(?=\s)/,lookbehind:!0,alias:"number"},"reason-phrase":{pattern:/^(\s).+/,lookbehind:!0,alias:"string"}}},header:{pattern:/^[\w-]+:.+(?:(?:\r\n?|\n)[ \t].+)*/m,inside:{"header-value":[{pattern:r(/Content-Security-Policy/.source),lookbehind:!0,alias:["csp","languages-csp"],inside:n.languages.csp},{pattern:r(/Public-Key-Pins(?:-Report-Only)?/.source),lookbehind:!0,alias:["hpkp","languages-hpkp"],inside:n.languages.hpkp},{pattern:r(/Strict-Transport-Security/.source),lookbehind:!0,alias:["hsts","languages-hsts"],inside:n.languages.hsts},{pattern:r(/[^:]+/.source),lookbehind:!0}],"header-name":{pattern:/^[^:]+/,alias:"keyword"},punctuation:/^:/}}};var a=n.languages,o={"application/javascript":a.javascript,"application/json":a.json||a.javascript,"application/xml":a.xml,"text/xml":a.xml,"text/html":a.html,"text/css":a.css,"text/plain":a.plain},s={"application/json":!0,"application/xml":!0};function l(g){var m=g.replace(/^[a-z]+\//,""),b="\\w+/(?:[\\w.-]+\\+)+"+m+"(?![+\\w.-])";return"(?:"+g+"|"+b+")"}var u;for(var d in o)if(o[d]){u=u||{};var p=s[d]?l(d):d;u[d.replace(/\//g,"-")]={pattern:RegExp("("+/content-type:\s*/.source+p+/(?:(?:\r\n?|\n)[\w-].*)*(?:\r(?:\n|(?!\n))|\n)/.source+")"+/[^ \t\w-][\s\S]*/.source,"i"),lookbehind:!0,inside:o[d]}}u&&n.languages.insertBefore("http","header",u)})(t)}return cS}var uS,M2;function jye(){if(M2)return uS;M2=1,uS=e,e.displayName="ichigojam",e.aliases=[];function e(t){t.languages.ichigojam={comment:/(?:\B'|REM)(?:[^\n\r]*)/i,string:{pattern:/"(?:""|[!#$%&'()*,\/:;<=>?^\w +\-.])*"/,greedy:!0},number:/\B#[0-9A-F]+|\B`[01]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,keyword:/\b(?:BEEP|BPS|CASE|CLEAR|CLK|CLO|CLP|CLS|CLT|CLV|CONT|COPY|ELSE|END|FILE|FILES|FOR|GOSUB|GOTO|GSB|IF|INPUT|KBD|LED|LET|LIST|LOAD|LOCATE|LRUN|NEW|NEXT|OUT|PLAY|POKE|PRINT|PWM|REM|RENUM|RESET|RETURN|RIGHT|RTN|RUN|SAVE|SCROLL|SLEEP|SRND|STEP|STOP|SUB|TEMPO|THEN|TO|UART|VIDEO|WAIT)(?:\$|\b)/i,function:/\b(?:ABS|ANA|ASC|BIN|BTN|DEC|END|FREE|HELP|HEX|I2CR|I2CW|IN|INKEY|LEN|LINE|PEEK|RND|SCR|SOUND|STR|TICK|USR|VER|VPEEK|ZER)(?:\$|\b)/i,label:/(?:\B@\S+)/,operator:/<[=>]?|>=?|\|\||&&|[+\-*\/=|&^~!]|\b(?:AND|NOT|OR)\b/i,punctuation:/[\[,;:()\]]/}}return uS}var dS,P2;function Uye(){if(P2)return dS;P2=1,dS=e,e.displayName="icon",e.aliases=[];function e(t){t.languages.icon={comment:/#.*/,string:{pattern:/(["'])(?:(?!\1)[^\\\r\n_]|\\.|_(?!\1)(?:\r\n|[\s\S]))*\1/,greedy:!0},number:/\b(?:\d+r[a-z\d]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b|\.\d+\b/i,"builtin-keyword":{pattern:/&(?:allocated|ascii|clock|collections|cset|current|date|dateline|digits|dump|e|error(?:number|text|value)?|errout|fail|features|file|host|input|lcase|letters|level|line|main|null|output|phi|pi|pos|progname|random|regions|source|storage|subject|time|trace|ucase|version)\b/,alias:"variable"},directive:{pattern:/\$\w+/,alias:"builtin"},keyword:/\b(?:break|by|case|create|default|do|else|end|every|fail|global|if|initial|invocable|link|local|next|not|of|procedure|record|repeat|return|static|suspend|then|to|until|while)\b/,function:/\b(?!\d)\w+(?=\s*[({]|\s*!\s*\[)/,operator:/[+-]:(?!=)|(?:[\/?@^%&]|\+\+?|--?|==?=?|~==?=?|\*\*?|\|\|\|?|<(?:->?|<?=?)|>>?=?)(?::=)?|:(?:=:?)?|[!.\\|~]/,punctuation:/[\[\](){},;]/}}return dS}var fS,F2;function Gye(){if(F2)return fS;F2=1,fS=e,e.displayName="icuMessageFormat",e.aliases=[];function e(t){(function(n){function r(d,p){return p<=0?/[]/.source:d.replace(/<SELF>/g,function(){return r(d,p-1)})}var a=/'[{}:=,](?:[^']|'')*'(?!')/,o={pattern:/''/,greedy:!0,alias:"operator"},s={pattern:a,greedy:!0,inside:{escape:o}},l=r(/\{(?:[^{}']|'(?![{},'])|''|<STR>|<SELF>)*\}/.source.replace(/<STR>/g,function(){return a.source}),8),u={pattern:RegExp(l),inside:{message:{pattern:/^(\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:null},"message-delimiter":{pattern:/./,alias:"punctuation"}}};n.languages["icu-message-format"]={argument:{pattern:RegExp(l),greedy:!0,inside:{content:{pattern:/^(\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:{"argument-name":{pattern:/^(\s*)[^{}:=,\s]+/,lookbehind:!0},"choice-style":{pattern:/^(\s*,\s*choice\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{punctuation:/\|/,range:{pattern:/^(\s*)[+-]?(?:\d+(?:\.\d*)?|\u221e)\s*[<#\u2264]/,lookbehind:!0,inside:{operator:/[<#\u2264]/,number:/\S+/}},rest:null}},"plural-style":{pattern:/^(\s*,\s*(?:plural|selectordinal)\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{offset:/^offset:\s*\d+/,"nested-message":u,selector:{pattern:/=\d+|[^{}:=,\s]+/,inside:{keyword:/^(?:few|many|one|other|two|zero)$/}}}},"select-style":{pattern:/^(\s*,\s*select\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{"nested-message":u,selector:{pattern:/[^{}:=,\s]+/,inside:{keyword:/^other$/}}}},keyword:/\b(?:choice|plural|select|selectordinal)\b/,"arg-type":{pattern:/\b(?:date|duration|number|ordinal|spellout|time)\b/,alias:"keyword"},"arg-skeleton":{pattern:/(,\s*)::[^{}:=,\s]+/,lookbehind:!0},"arg-style":{pattern:/(,\s*)(?:currency|full|integer|long|medium|percent|short)(?=\s*$)/,lookbehind:!0},"arg-style-text":{pattern:RegExp(/(^\s*,\s*(?=\S))/.source+r(/(?:[^{}']|'[^']*'|\{(?:<SELF>)?\})+/.source,8)+"$"),lookbehind:!0,alias:"string"},punctuation:/,/}},"argument-delimiter":{pattern:/./,alias:"operator"}}},escape:o,string:s},u.inside.message.inside=n.languages["icu-message-format"],n.languages["icu-message-format"].argument.inside.content.inside["choice-style"].inside.rest=n.languages["icu-message-format"]})(t)}return fS}var pS,z2;function Hye(){if(z2)return pS;z2=1;var e=SA();pS=t,t.displayName="idris",t.aliases=["idr"];function t(n){n.register(e),n.languages.idris=n.languages.extend("haskell",{comment:{pattern:/(?:(?:--|\|\|\|).*$|\{-[\s\S]*?-\})/m},keyword:/\b(?:Type|case|class|codata|constructor|corecord|data|do|dsl|else|export|if|implementation|implicit|import|impossible|in|infix|infixl|infixr|instance|interface|let|module|mutual|namespace|of|parameters|partial|postulate|private|proof|public|quoteGoal|record|rewrite|syntax|then|total|using|where|with)\b/,builtin:void 0}),n.languages.insertBefore("idris","keyword",{"import-statement":{pattern:/(^\s*import\s+)(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*/m,lookbehind:!0,inside:{punctuation:/\./}}}),n.languages.idr=n.languages.idris}return pS}var gS,B2;function $ye(){if(B2)return gS;B2=1,gS=e,e.displayName="iecst",e.aliases=[];function e(t){t.languages.iecst={comment:[{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\(\*[\s\S]*?(?:\*\)|$)|\{[\s\S]*?(?:\}|$))/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:[/\b(?:END_)?(?:PROGRAM|CONFIGURATION|INTERFACE|FUNCTION_BLOCK|FUNCTION|ACTION|TRANSITION|TYPE|STRUCT|(?:INITIAL_)?STEP|NAMESPACE|LIBRARY|CHANNEL|FOLDER|RESOURCE|VAR_(?:ACCESS|CONFIG|EXTERNAL|GLOBAL|INPUT|IN_OUT|OUTPUT|TEMP)|VAR|METHOD|PROPERTY)\b/i,/\b(?:AT|BY|(?:END_)?(?:CASE|FOR|IF|REPEAT|WHILE)|CONSTANT|CONTINUE|DO|ELSE|ELSIF|EXIT|EXTENDS|FROM|GET|GOTO|IMPLEMENTS|JMP|NON_RETAIN|OF|PRIVATE|PROTECTED|PUBLIC|RETAIN|RETURN|SET|TASK|THEN|TO|UNTIL|USING|WITH|__CATCH|__ENDTRY|__FINALLY|__TRY)\b/],"class-name":/\b(?:ANY|ARRAY|BOOL|BYTE|U?(?:D|L|S)?INT|(?:D|L)?WORD|DATE(?:_AND_TIME)?|DT|L?REAL|POINTER|STRING|TIME(?:_OF_DAY)?|TOD)\b/,address:{pattern:/%[IQM][XBWDL][\d.]*|%[IQ][\d.]*/,alias:"symbol"},number:/\b(?:16#[\da-f]+|2#[01_]+|0x[\da-f]+)\b|\b(?:D|DT|T|TOD)#[\d_shmd:]*|\b[A-Z]*#[\d.,_]*|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,boolean:/\b(?:FALSE|NULL|TRUE)\b/,operator:/S?R?:?=>?|&&?|\*\*?|<[=>]?|>=?|[-:^/+#]|\b(?:AND|EQ|EXPT|GE|GT|LE|LT|MOD|NE|NOT|OR|XOR)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,punctuation:/[()[\].,;]/}}return gS}var hS,j2;function qye(){if(j2)return hS;j2=1,hS=e,e.displayName="ignore",e.aliases=["gitignore","hgignore","npmignore"];function e(t){(function(n){n.languages.ignore={comment:/^#.*/m,entry:{pattern:/\S(?:.*(?:(?:\\ )|\S))?/,alias:"string",inside:{operator:/^!|\*\*?|\?/,regex:{pattern:/(^|[^\\])\[[^\[\]]*\]/,lookbehind:!0},punctuation:/\//}}},n.languages.gitignore=n.languages.ignore,n.languages.hgignore=n.languages.ignore,n.languages.npmignore=n.languages.ignore})(t)}return hS}var mS,U2;function Vye(){if(U2)return mS;U2=1,mS=e,e.displayName="inform7",e.aliases=[];function e(t){t.languages.inform7={string:{pattern:/"[^"]*"/,inside:{substitution:{pattern:/\[[^\[\]]+\]/,inside:{delimiter:{pattern:/\[|\]/,alias:"punctuation"}}}}},comment:{pattern:/\[[^\[\]]+\]/,greedy:!0},title:{pattern:/^[ \t]*(?:book|chapter|part(?! of)|section|table|volume)\b.+/im,alias:"important"},number:{pattern:/(^|[^-])(?:\b\d+(?:\.\d+)?(?:\^\d+)?(?:(?!\d)\w+)?|\b(?:eight|eleven|five|four|nine|one|seven|six|ten|three|twelve|two))\b(?!-)/i,lookbehind:!0},verb:{pattern:/(^|[^-])\b(?:answering|applying to|are|asking|attacking|be(?:ing)?|burning|buying|called|carries|carry(?! out)|carrying|climbing|closing|conceal(?:ing|s)?|consulting|contain(?:ing|s)?|cutting|drinking|dropping|eating|enclos(?:es?|ing)|entering|examining|exiting|getting|giving|going|ha(?:s|ve|ving)|hold(?:ing|s)?|impl(?:ies|y)|incorporat(?:es?|ing)|inserting|is|jumping|kissing|listening|locking|looking|mean(?:ing|s)?|opening|provid(?:es?|ing)|pulling|pushing|putting|relat(?:es?|ing)|removing|searching|see(?:ing|s)?|setting|showing|singing|sleeping|smelling|squeezing|support(?:ing|s)?|swearing|switching|taking|tasting|telling|thinking|throwing|touching|turning|tying|unlock(?:ing|s)?|var(?:ies|y|ying)|waiting|waking|waving|wear(?:ing|s)?)\b(?!-)/i,lookbehind:!0,alias:"operator"},keyword:{pattern:/(^|[^-])\b(?:after|before|carry out|check|continue the action|definition(?= *:)|do nothing|else|end (?:if|the story|unless)|every turn|if|include|instead(?: of)?|let|move|no|now|otherwise|repeat|report|resume the story|rule for|running through|say(?:ing)?|stop the action|test|try(?:ing)?|understand|unless|use|when|while|yes)\b(?!-)/i,lookbehind:!0},property:{pattern:/(^|[^-])\b(?:adjacent(?! to)|carried|closed|concealed|contained|dark|described|edible|empty|enclosed|enterable|even|female|fixed in place|full|handled|held|improper-named|incorporated|inedible|invisible|lighted|lit|lock(?:able|ed)|male|marked for listing|mentioned|negative|neuter|non-(?:empty|full|recurring)|odd|opaque|open(?:able)?|plural-named|portable|positive|privately-named|proper-named|provided|publically-named|pushable between rooms|recurring|related|rubbing|scenery|seen|singular-named|supported|swinging|switch(?:able|ed(?: off| on)?)|touch(?:able|ed)|transparent|unconcealed|undescribed|unlit|unlocked|unmarked for listing|unmentioned|unopenable|untouchable|unvisited|variable|visible|visited|wearable|worn)\b(?!-)/i,lookbehind:!0,alias:"symbol"},position:{pattern:/(^|[^-])\b(?:above|adjacent to|back side of|below|between|down|east|everywhere|front side|here|in|inside(?: from)?|north(?:east|west)?|nowhere|on(?: top of)?|other side|outside(?: from)?|parts? of|regionally in|south(?:east|west)?|through|up|west|within)\b(?!-)/i,lookbehind:!0,alias:"keyword"},type:{pattern:/(^|[^-])\b(?:actions?|activit(?:ies|y)|actors?|animals?|backdrops?|containers?|devices?|directions?|doors?|holders?|kinds?|lists?|m[ae]n|nobody|nothing|nouns?|numbers?|objects?|people|persons?|player(?:'s holdall)?|regions?|relations?|rooms?|rule(?:book)?s?|scenes?|someone|something|supporters?|tables?|texts?|things?|time|vehicles?|wom[ae]n)\b(?!-)/i,lookbehind:!0,alias:"variable"},punctuation:/[.,:;(){}]/},t.languages.inform7.string.inside.substitution.inside.rest=t.languages.inform7,t.languages.inform7.string.inside.substitution.inside.rest.text={pattern:/\S(?:\s*\S)*/,alias:"comment"}}return mS}var bS,G2;function Wye(){if(G2)return bS;G2=1,bS=e,e.displayName="ini",e.aliases=[];function e(t){t.languages.ini={comment:{pattern:/(^[ \f\t\v]*)[#;][^\n\r]*/m,lookbehind:!0},section:{pattern:/(^[ \f\t\v]*)\[[^\n\r\]]*\]?/m,lookbehind:!0,inside:{"section-name":{pattern:/(^\[[ \f\t\v]*)[^ \f\t\v\]]+(?:[ \f\t\v]+[^ \f\t\v\]]+)*/,lookbehind:!0,alias:"selector"},punctuation:/\[|\]/}},key:{pattern:/(^[ \f\t\v]*)[^ \f\n\r\t\v=]+(?:[ \f\t\v]+[^ \f\n\r\t\v=]+)*(?=[ \f\t\v]*=)/m,lookbehind:!0,alias:"attr-name"},value:{pattern:/(=[ \f\t\v]*)[^ \f\n\r\t\v]+(?:[ \f\t\v]+[^ \f\n\r\t\v]+)*/,lookbehind:!0,alias:"attr-value",inside:{"inner-value":{pattern:/^("|').+(?=\1$)/,lookbehind:!0}}},punctuation:/=/}}return bS}var yS,H2;function Yye(){if(H2)return yS;H2=1,yS=e,e.displayName="io",e.aliases=[];function e(t){t.languages.io={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\/\/.*|#.*)/,lookbehind:!0,greedy:!0},"triple-quoted-string":{pattern:/"""(?:\\[\s\S]|(?!""")[^\\])*"""/,greedy:!0,alias:"string"},string:{pattern:/"(?:\\.|[^\\\r\n"])*"/,greedy:!0},keyword:/\b(?:activate|activeCoroCount|asString|block|break|call|catch|clone|collectGarbage|compileString|continue|do|doFile|doMessage|doString|else|elseif|exit|for|foreach|forward|getEnvironmentVariable|getSlot|hasSlot|if|ifFalse|ifNil|ifNilEval|ifTrue|isActive|isNil|isResumable|list|message|method|parent|pass|pause|perform|performWithArgList|print|println|proto|raise|raiseResumable|removeSlot|resend|resume|schedulerSleepSeconds|self|sender|setSchedulerSleepSeconds|setSlot|shallowCopy|slotNames|super|system|then|thisBlock|thisContext|try|type|uniqueId|updateSlot|wait|while|write|yield)\b/,builtin:/\b(?:Array|AudioDevice|AudioMixer|BigNum|Block|Box|Buffer|CFunction|CGI|Color|Curses|DBM|DNSResolver|DOConnection|DOProxy|DOServer|Date|Directory|Duration|DynLib|Error|Exception|FFT|File|Fnmatch|Font|Future|GL|GLE|GLScissor|GLU|GLUCylinder|GLUQuadric|GLUSphere|GLUT|Host|Image|Importer|LinkList|List|Lobby|Locals|MD5|MP3Decoder|MP3Encoder|Map|Message|Movie|Notification|Number|Object|OpenGL|Point|Protos|Random|Regex|SGML|SGMLElement|SGMLParser|SQLite|Sequence|Server|ShowMessage|SleepyCat|SleepyCatCursor|Socket|SocketManager|Sound|Soup|Store|String|Tree|UDPSender|UPDReceiver|URL|User|Warning|WeakLink)\b/,boolean:/\b(?:false|nil|true)\b/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e-?\d+)?/i,operator:/[=!*/%+\-^&|]=|>>?=?|<<?=?|:?:?=|\+\+?|--?|\*\*?|\/\/?|%|\|\|?|&&?|\b(?:and|not|or|return)\b|@@?|\?\??|\.\./,punctuation:/[{}[\];(),.:]/}}return yS}var vS,$2;function Kye(){if($2)return vS;$2=1,vS=e,e.displayName="j",e.aliases=[];function e(t){t.languages.j={comment:{pattern:/\bNB\..*/,greedy:!0},string:{pattern:/'(?:''|[^'\r\n])*'/,greedy:!0},keyword:/\b(?:(?:CR|LF|adverb|conjunction|def|define|dyad|monad|noun|verb)\b|(?:assert|break|case|catch[dt]?|continue|do|else|elseif|end|fcase|for|for_\w+|goto_\w+|if|label_\w+|return|select|throw|try|while|whilst)\.)/,verb:{pattern:/(?!\^:|;\.|[=!][.:])(?:\{(?:\.|::?)?|p(?:\.\.?|:)|[=!\]]|[<>+*\-%$|,#][.:]?|[?^]\.?|[;\[]:?|[~}"i][.:]|[ACeEIjLor]\.|(?:[_\/\\qsux]|_?\d):)/,alias:"keyword"},number:/\b_?(?:(?!\d:)\d+(?:\.\d+)?(?:(?:ad|ar|[ejpx])_?\d+(?:\.\d+)?)*(?:b_?[\da-z]+(?:\.[\da-z]+)?)?|_\b(?!\.))/,adverb:{pattern:/[~}]|[\/\\]\.?|[bfM]\.|t[.:]/,alias:"builtin"},operator:/[=a][.:]|_\./,conjunction:{pattern:/&(?:\.:?|:)?|[.:@][.:]?|[!D][.:]|[;dHT]\.|`:?|[\^LS]:|"/,alias:"variable"},punctuation:/[()]/}}return vS}var SS,q2;function EA(){if(q2)return SS;q2=1,SS=e,e.displayName="java",e.aliases=[];function e(t){(function(n){var r=/\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/,a=/(^|[^\w.])(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source,o={pattern:RegExp(a+/[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}},punctuation:/\./}};n.languages.java=n.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\.|[^"\\\r\n])*"/,lookbehind:!0,greedy:!0},"class-name":[o,{pattern:RegExp(a+/[A-Z]\w*(?=\s+\w+\s*[;,=()])/.source),lookbehind:!0,inside:o.inside}],keyword:r,function:[n.languages.clike.function,{pattern:/(::\s*)[a-z_]\w*/,lookbehind:!0}],number:/\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i,operator:{pattern:/(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m,lookbehind:!0}}),n.languages.insertBefore("java","string",{"triple-quoted-string":{pattern:/"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/,greedy:!0,alias:"string"},char:{pattern:/'(?:\\.|[^'\\\r\n]){1,6}'/,greedy:!0}}),n.languages.insertBefore("java","class-name",{annotation:{pattern:/(^|[^.])@\w+(?:\s*\.\s*\w+)*/,lookbehind:!0,alias:"punctuation"},generics:{pattern:/<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/,inside:{"class-name":o,keyword:r,punctuation:/[<>(),.:]/,operator:/[?&|]/}},namespace:{pattern:RegExp(/(\b(?:exports|import(?:\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\s+)(?!<keyword>)[a-z]\w*(?:\.[a-z]\w*)*\.?/.source.replace(/<keyword>/g,function(){return r.source})),lookbehind:!0,inside:{punctuation:/\./}}})})(t)}return SS}var ES,V2;function jp(){if(V2)return ES;V2=1,ES=e,e.displayName="javadoclike",e.aliases=[];function e(t){(function(n){var r=n.languages.javadoclike={parameter:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*@(?:arg|arguments|param)\s+)\w+/m,lookbehind:!0},keyword:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*|\{)@[a-z][a-zA-Z-]+\b/m,lookbehind:!0},punctuation:/[{}]/};function a(s,l){var u="doc-comment",d=n.languages[s];if(d){var p=d[u];if(!p){var g={};g[u]={pattern:/(^|[^\\])\/\*\*[^/][\s\S]*?(?:\*\/|$)/,lookbehind:!0,alias:"comment"},d=n.languages.insertBefore(s,"comment",g),p=d[u]}if(p instanceof RegExp&&(p=d[u]={pattern:p}),Array.isArray(p))for(var m=0,b=p.length;m<b;m++)p[m]instanceof RegExp&&(p[m]={pattern:p[m]}),l(p[m]);else l(p)}}function o(s,l){typeof s=="string"&&(s=[s]),s.forEach(function(u){a(u,function(d){d.inside||(d.inside={}),d.inside.rest=l})})}Object.defineProperty(r,"addSupport",{value:o}),r.addSupport(["java","javascript","php"],r)})(t)}return ES}var wS,W2;function Xye(){if(W2)return wS;W2=1;var e=EA(),t=jp();wS=n,n.displayName="javadoc",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var o=/(^(?:[\t ]*(?:\*\s*)*))[^*\s].*$/m,s=/#\s*\w+(?:\s*\([^()]*\))?/.source,l=/(?:\b[a-zA-Z]\w+\s*\.\s*)*\b[A-Z]\w*(?:\s*<mem>)?|<mem>/.source.replace(/<mem>/g,function(){return s});a.languages.javadoc=a.languages.extend("javadoclike",{}),a.languages.insertBefore("javadoc","keyword",{reference:{pattern:RegExp(/(@(?:exception|link|linkplain|see|throws|value)\s+(?:\*\s*)?)/.source+"(?:"+l+")"),lookbehind:!0,inside:{function:{pattern:/(#\s*)\w+(?=\s*\()/,lookbehind:!0},field:{pattern:/(#\s*)\w+/,lookbehind:!0},namespace:{pattern:/\b(?:[a-z]\w*\s*\.\s*)+/,inside:{punctuation:/\./}},"class-name":/\b[A-Z]\w*/,keyword:a.languages.java.keyword,punctuation:/[#()[\],.]/}},"class-name":{pattern:/(@param\s+)<[A-Z]\w*>/,lookbehind:!0,inside:{punctuation:/[.<>]/}},"code-section":[{pattern:/(\{@code\s+(?!\s))(?:[^\s{}]|\s+(?![\s}])|\{(?:[^{}]|\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*\})+(?=\s*\})/,lookbehind:!0,inside:{code:{pattern:o,lookbehind:!0,inside:a.languages.java,alias:"language-java"}}},{pattern:/(<(code|pre|tt)>(?!<code>)\s*)\S(?:\S|\s+\S)*?(?=\s*<\/\2>)/,lookbehind:!0,inside:{line:{pattern:o,lookbehind:!0,inside:{tag:a.languages.markup.tag,entity:a.languages.markup.entity,code:{pattern:/.+/,inside:a.languages.java,alias:"language-java"}}}}}],tag:a.languages.markup.tag,entity:a.languages.markup.entity}),a.languages.javadoclike.addSupport("java",a.languages.javadoc)}(r)}return wS}var xS,Y2;function Zye(){if(Y2)return xS;Y2=1,xS=e,e.displayName="javastacktrace",e.aliases=[];function e(t){t.languages.javastacktrace={summary:{pattern:/^([\t ]*)(?:(?:Caused by:|Suppressed:|Exception in thread "[^"]*")[\t ]+)?[\w$.]+(?::.*)?$/m,lookbehind:!0,inside:{keyword:{pattern:/^([\t ]*)(?:(?:Caused by|Suppressed)(?=:)|Exception in thread)/m,lookbehind:!0},string:{pattern:/^(\s*)"[^"]*"/,lookbehind:!0},exceptions:{pattern:/^(:?\s*)[\w$.]+(?=:|$)/,lookbehind:!0,inside:{"class-name":/[\w$]+$/,namespace:/\b[a-z]\w*\b/,punctuation:/\./}},message:{pattern:/(:\s*)\S.*/,lookbehind:!0,alias:"string"},punctuation:/:/}},"stack-frame":{pattern:/^([\t ]*)at (?:[\w$./]|@[\w$.+-]*\/)+(?:<init>)?\([^()]*\)/m,lookbehind:!0,inside:{keyword:{pattern:/^(\s*)at(?= )/,lookbehind:!0},source:[{pattern:/(\()\w+\.\w+:\d+(?=\))/,lookbehind:!0,inside:{file:/^\w+\.\w+/,punctuation:/:/,"line-number":{pattern:/\b\d+\b/,alias:"number"}}},{pattern:/(\()[^()]*(?=\))/,lookbehind:!0,inside:{keyword:/^(?:Native Method|Unknown Source)$/}}],"class-name":/[\w$]+(?=\.(?:<init>|[\w$]+)\()/,function:/(?:<init>|[\w$]+)(?=\()/,"class-loader":{pattern:/(\s)[a-z]\w*(?:\.[a-z]\w*)*(?=\/[\w@$.]*\/)/,lookbehind:!0,alias:"namespace",inside:{punctuation:/\./}},module:{pattern:/([\s/])[a-z]\w*(?:\.[a-z]\w*)*(?:@[\w$.+-]*)?(?=\/)/,lookbehind:!0,inside:{version:{pattern:/(@)[\s\S]+/,lookbehind:!0,alias:"number"},punctuation:/[@.]/}},namespace:{pattern:/(?:\b[a-z]\w*\.)+/,inside:{punctuation:/\./}},punctuation:/[()/.]/}},more:{pattern:/^([\t ]*)\.{3} \d+ [a-z]+(?: [a-z]+)*/m,lookbehind:!0,inside:{punctuation:/\.{3}/,number:/\d+/,keyword:/\b[a-z]+(?: [a-z]+)*\b/}}}}return xS}var kS,K2;function Qye(){if(K2)return kS;K2=1,kS=e,e.displayName="jexl",e.aliases=[];function e(t){t.languages.jexl={string:/(["'])(?:\\[\s\S]|(?!\1)[^\\])*\1/,transform:{pattern:/(\|\s*)[a-zA-Zа-яА-Я_\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$][\wа-яА-Я\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$]*/,alias:"function",lookbehind:!0},function:/[a-zA-Zа-яА-Я_\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$][\wа-яА-Я\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$]*\s*(?=\()/,number:/\b\d+(?:\.\d+)?\b|\B\.\d+\b/,operator:/[<>!]=?|-|\+|&&|==|\|\|?|\/\/?|[?:*^%]/,boolean:/\b(?:false|true)\b/,keyword:/\bin\b/,punctuation:/[{}[\](),.]/}}return kS}var TS,X2;function Jye(){if(X2)return TS;X2=1,TS=e,e.displayName="jolie",e.aliases=[];function e(t){t.languages.jolie=t.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\[\s\S]|[^"\\])*"/,lookbehind:!0,greedy:!0},"class-name":{pattern:/((?:\b(?:as|courier|embed|in|inputPort|outputPort|service)\b|@)[ \t]*)\w+/,lookbehind:!0},keyword:/\b(?:as|cH|comp|concurrent|constants|courier|cset|csets|default|define|else|embed|embedded|execution|exit|extender|for|foreach|forward|from|global|if|import|in|include|init|inputPort|install|instanceof|interface|is_defined|linkIn|linkOut|main|new|nullProcess|outputPort|over|private|provide|public|scope|sequential|service|single|spawn|synchronized|this|throw|throws|type|undef|until|while|with)\b/,function:/\b[a-z_]\w*(?=[ \t]*[@(])/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?l?/i,operator:/-[-=>]?|\+[+=]?|<[<=]?|[>=*!]=?|&&|\|\||[?\/%^@|]/,punctuation:/[()[\]{},;.:]/,builtin:/\b(?:Byte|any|bool|char|double|enum|float|int|length|long|ranges|regex|string|undefined|void)\b/}),t.languages.insertBefore("jolie","keyword",{aggregates:{pattern:/(\bAggregates\s*:\s*)(?:\w+(?:\s+with\s+\w+)?\s*,\s*)*\w+(?:\s+with\s+\w+)?/,lookbehind:!0,inside:{keyword:/\bwith\b/,"class-name":/\w+/,punctuation:/,/}},redirects:{pattern:/(\bRedirects\s*:\s*)(?:\w+\s*=>\s*\w+\s*,\s*)*(?:\w+\s*=>\s*\w+)/,lookbehind:!0,inside:{punctuation:/,/,"class-name":/\w+/,operator:/=>/}},property:{pattern:/\b(?:Aggregates|[Ii]nterfaces|Java|Javascript|Jolie|[Ll]ocation|OneWay|[Pp]rotocol|Redirects|RequestResponse)\b(?=[ \t]*:)/}})}return TS}var AS,Z2;function eve(){if(Z2)return AS;Z2=1,AS=e,e.displayName="jq",e.aliases=[];function e(t){(function(n){var r=/\\\((?:[^()]|\([^()]*\))*\)/.source,a=RegExp(/(^|[^\\])"(?:[^"\r\n\\]|\\[^\r\n(]|__)*"/.source.replace(/__/g,function(){return r})),o={interpolation:{pattern:RegExp(/((?:^|[^\\])(?:\\{2})*)/.source+r),lookbehind:!0,inside:{content:{pattern:/^(\\\()[\s\S]+(?=\)$)/,lookbehind:!0,inside:null},punctuation:/^\\\(|\)$/}}},s=n.languages.jq={comment:/#.*/,property:{pattern:RegExp(a.source+/(?=\s*:(?!:))/.source),lookbehind:!0,greedy:!0,inside:o},string:{pattern:a,lookbehind:!0,greedy:!0,inside:o},function:{pattern:/(\bdef\s+)[a-z_]\w+/i,lookbehind:!0},variable:/\B\$\w+/,"property-literal":{pattern:/\b[a-z_]\w*(?=\s*:(?!:))/i,alias:"property"},keyword:/\b(?:as|break|catch|def|elif|else|end|foreach|if|import|include|label|module|modulemeta|null|reduce|then|try|while)\b/,boolean:/\b(?:false|true)\b/,number:/(?:\b\d+\.|\B\.)?\b\d+(?:[eE][+-]?\d+)?\b/,operator:[{pattern:/\|=?/,alias:"pipe"},/\.\.|[!=<>]?=|\?\/\/|\/\/=?|[-+*/%]=?|[<>?]|\b(?:and|not|or)\b/],"c-style-function":{pattern:/\b[a-z_]\w*(?=\s*\()/i,alias:"function"},punctuation:/::|[()\[\]{},:;]|\.(?=\s*[\[\w$])/,dot:{pattern:/\./,alias:"important"}};o.interpolation.inside.content.inside=s})(t)}return AS}var RS,Q2;function tve(){if(Q2)return RS;Q2=1,RS=e,e.displayName="jsExtras",e.aliases=[];function e(t){(function(n){n.languages.insertBefore("javascript","function-variable",{"method-variable":{pattern:RegExp("(\\.\\s*)"+n.languages.javascript["function-variable"].pattern.source),lookbehind:!0,alias:["function-variable","method","function","property-access"]}}),n.languages.insertBefore("javascript","function",{method:{pattern:RegExp("(\\.\\s*)"+n.languages.javascript.function.source),lookbehind:!0,alias:["function","property-access"]}}),n.languages.insertBefore("javascript","constant",{"known-class-name":[{pattern:/\b(?:(?:Float(?:32|64)|(?:Int|Uint)(?:8|16|32)|Uint8Clamped)?Array|ArrayBuffer|BigInt|Boolean|DataView|Date|Error|Function|Intl|JSON|(?:Weak)?(?:Map|Set)|Math|Number|Object|Promise|Proxy|Reflect|RegExp|String|Symbol|WebAssembly)\b/,alias:"class-name"},{pattern:/\b(?:[A-Z]\w*)Error\b/,alias:"class-name"}]});function r(d,p){return RegExp(d.replace(/<ID>/g,function(){return/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*/.source}),p)}n.languages.insertBefore("javascript","keyword",{imports:{pattern:r(/(\bimport\b\s*)(?:<ID>(?:\s*,\s*(?:\*\s*as\s+<ID>|\{[^{}]*\}))?|\*\s*as\s+<ID>|\{[^{}]*\})(?=\s*\bfrom\b)/.source),lookbehind:!0,inside:n.languages.javascript},exports:{pattern:r(/(\bexport\b\s*)(?:\*(?:\s*as\s+<ID>)?(?=\s*\bfrom\b)|\{[^{}]*\})/.source),lookbehind:!0,inside:n.languages.javascript}}),n.languages.javascript.keyword.unshift({pattern:/\b(?:as|default|export|from|import)\b/,alias:"module"},{pattern:/\b(?:await|break|catch|continue|do|else|finally|for|if|return|switch|throw|try|while|yield)\b/,alias:"control-flow"},{pattern:/\bnull\b/,alias:["null","nil"]},{pattern:/\bundefined\b/,alias:"nil"}),n.languages.insertBefore("javascript","operator",{spread:{pattern:/\.{3}/,alias:"operator"},arrow:{pattern:/=>/,alias:"operator"}}),n.languages.insertBefore("javascript","punctuation",{"property-access":{pattern:r(/(\.\s*)#?<ID>/.source),lookbehind:!0},"maybe-class-name":{pattern:/(^|[^$\w\xA0-\uFFFF])[A-Z][$\w\xA0-\uFFFF]+/,lookbehind:!0},dom:{pattern:/\b(?:document|(?:local|session)Storage|location|navigator|performance|window)\b/,alias:"variable"},console:{pattern:/\bconsole(?=\s*\.)/,alias:"class-name"}});for(var a=["function","function-variable","method","method-variable","property-access"],o=0;o<a.length;o++){var s=a[o],l=n.languages.javascript[s];n.util.type(l)==="RegExp"&&(l=n.languages.javascript[s]={pattern:l});var u=l.inside||{};l.inside=u,u["maybe-class-name"]=/^[A-Z][\s\S]*/}})(t)}return RS}var CS,J2;function nve(){if(J2)return CS;J2=1,CS=e,e.displayName="jsTemplates",e.aliases=[];function e(t){(function(n){var r=n.languages.javascript["template-string"],a=r.pattern.source,o=r.inside.interpolation,s=o.inside["interpolation-punctuation"],l=o.pattern.source;function u(y,k){if(n.languages[y])return{pattern:RegExp("((?:"+k+")\\s*)"+a),lookbehind:!0,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},"embedded-code":{pattern:/[\s\S]+/,alias:y}}}}n.languages.javascript["template-string"]=[u("css",/\b(?:styled(?:\([^)]*\))?(?:\s*\.\s*\w+(?:\([^)]*\))*)*|css(?:\s*\.\s*(?:global|resolve))?|createGlobalStyle|keyframes)/.source),u("html",/\bhtml|\.\s*(?:inner|outer)HTML\s*\+?=/.source),u("svg",/\bsvg/.source),u("markdown",/\b(?:markdown|md)/.source),u("graphql",/\b(?:gql|graphql(?:\s*\.\s*experimental)?)/.source),u("sql",/\bsql/.source),r].filter(Boolean);function d(y,k){return"___"+k.toUpperCase()+"_"+y+"___"}function p(y,k,A){var x={code:y,grammar:k,language:A};return n.hooks.run("before-tokenize",x),x.tokens=n.tokenize(x.code,x.grammar),n.hooks.run("after-tokenize",x),x.tokens}function g(y){var k={};k["interpolation-punctuation"]=s;var A=n.tokenize(y,k);if(A.length===3){var x=[1,1];x.push.apply(x,p(A[1],n.languages.javascript,"javascript")),A.splice.apply(A,x)}return new n.Token("interpolation",A,o.alias,y)}function m(y,k,A){var x=n.tokenize(y,{interpolation:{pattern:RegExp(l),lookbehind:!0}}),R=0,O={},N=x.map(function(I){if(typeof I=="string")return I;for(var D=I.content,U;y.indexOf(U=d(R++,A))!==-1;);return O[U]=D,U}).join(""),C=p(N,k,A),_=Object.keys(O);R=0;function M(I){for(var D=0;D<I.length;D++){if(R>=_.length)return;var U=I[D];if(typeof U=="string"||typeof U.content=="string"){var $=_[R],B=typeof U=="string"?U:U.content,W=B.indexOf($);if(W!==-1){++R;var K=B.substring(0,W),H=g(O[$]),G=B.substring(W+$.length),z=[];if(K&&z.push(K),z.push(H),G){var Y=[G];M(Y),z.push.apply(z,Y)}typeof U=="string"?(I.splice.apply(I,[D,1].concat(z)),D+=z.length-1):U.content=z}}else{var L=U.content;Array.isArray(L)?M(L):M([L])}}}return M(C),new n.Token(A,C,"language-"+A,y)}var b={javascript:!0,js:!0,typescript:!0,ts:!0,jsx:!0,tsx:!0};n.hooks.add("after-tokenize",function(y){if(!(y.language in b))return;function k(A){for(var x=0,R=A.length;x<R;x++){var O=A[x];if(typeof O!="string"){var N=O.content;if(!Array.isArray(N)){typeof N!="string"&&k([N]);continue}if(O.type==="template-string"){var C=N[1];if(N.length===3&&typeof C!="string"&&C.type==="embedded-code"){var _=v(C),M=C.alias,I=Array.isArray(M)?M[0]:M,D=n.languages[I];if(!D)continue;N[1]=m(_,D,I)}}else k(N)}}}k(y.tokens)});function v(y){return typeof y=="string"?y:Array.isArray(y)?y.map(v).join(""):v(y.content)}})(t)}return CS}var _S,eM;function wA(){if(eM)return _S;eM=1,_S=e,e.displayName="typescript",e.aliases=["ts"];function e(t){(function(n){n.languages.typescript=n.languages.extend("javascript",{"class-name":{pattern:/(\b(?:class|extends|implements|instanceof|interface|new|type)\s+)(?!keyof\b)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?:\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>)?/,lookbehind:!0,greedy:!0,inside:null},builtin:/\b(?:Array|Function|Promise|any|boolean|console|never|number|string|symbol|unknown)\b/}),n.languages.typescript.keyword.push(/\b(?:abstract|declare|is|keyof|readonly|require)\b/,/\b(?:asserts|infer|interface|module|namespace|type)\b(?=\s*(?:[{_$a-zA-Z\xA0-\uFFFF]|$))/,/\btype\b(?=\s*(?:[\{*]|$))/),delete n.languages.typescript.parameter,delete n.languages.typescript["literal-property"];var r=n.languages.extend("typescript",{});delete r["class-name"],n.languages.typescript["class-name"].inside=r,n.languages.insertBefore("typescript","function",{decorator:{pattern:/@[$\w\xA0-\uFFFF]+/,inside:{at:{pattern:/^@/,alias:"operator"},function:/^[\s\S]+/}},"generic-function":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>(?=\s*\()/,greedy:!0,inside:{function:/^#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*/,generic:{pattern:/<[\s\S]+/,alias:"class-name",inside:r}}}}),n.languages.ts=n.languages.typescript})(t)}return _S}var NS,tM;function rve(){if(tM)return NS;tM=1;var e=jp(),t=wA();NS=n,n.displayName="jsdoc",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var o=a.languages.javascript,s=/\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})+\}/.source,l="(@(?:arg|argument|param|property)\\s+(?:"+s+"\\s+)?)";a.languages.jsdoc=a.languages.extend("javadoclike",{parameter:{pattern:RegExp(l+/(?:(?!\s)[$\w\xA0-\uFFFF.])+(?=\s|$)/.source),lookbehind:!0,inside:{punctuation:/\./}}}),a.languages.insertBefore("jsdoc","keyword",{"optional-parameter":{pattern:RegExp(l+/\[(?:(?!\s)[$\w\xA0-\uFFFF.])+(?:=[^[\]]+)?\](?=\s|$)/.source),lookbehind:!0,inside:{parameter:{pattern:/(^\[)[$\w\xA0-\uFFFF\.]+/,lookbehind:!0,inside:{punctuation:/\./}},code:{pattern:/(=)[\s\S]*(?=\]$)/,lookbehind:!0,inside:o,alias:"language-javascript"},punctuation:/[=[\]]/}},"class-name":[{pattern:RegExp(/(@(?:augments|class|extends|interface|memberof!?|template|this|typedef)\s+(?:<TYPE>\s+)?)[A-Z]\w*(?:\.[A-Z]\w*)*/.source.replace(/<TYPE>/g,function(){return s})),lookbehind:!0,inside:{punctuation:/\./}},{pattern:RegExp("(@[a-z]+\\s+)"+s),lookbehind:!0,inside:{string:o.string,number:o.number,boolean:o.boolean,keyword:a.languages.typescript.keyword,operator:/=>|\.\.\.|[&|?:*]/,punctuation:/[.,;=<>{}()[\]]/}}],example:{pattern:/(@example\s+(?!\s))(?:[^@\s]|\s+(?!\s))+?(?=\s*(?:\*\s*)?(?:@\w|\*\/))/,lookbehind:!0,inside:{code:{pattern:/^([\t ]*(?:\*\s*)?)\S.*$/m,lookbehind:!0,inside:o,alias:"language-javascript"}}}}),a.languages.javadoclike.addSupport("javascript",a.languages.jsdoc)}(r)}return NS}var OS,nM;function xA(){if(nM)return OS;nM=1,OS=e,e.displayName="json",e.aliases=["webmanifest"];function e(t){t.languages.json={property:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/,lookbehind:!0,greedy:!0},string:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/,lookbehind:!0,greedy:!0},comment:{pattern:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,punctuation:/[{}[\],]/,operator:/:/,boolean:/\b(?:false|true)\b/,null:{pattern:/\bnull\b/,alias:"keyword"}},t.languages.webmanifest=t.languages.json}return OS}var IS,rM;function ave(){if(rM)return IS;rM=1;var e=xA();IS=t,t.displayName="json5",t.aliases=[];function t(n){n.register(e),function(r){var a=/("|')(?:\\(?:\r\n?|\n|.)|(?!\1)[^\\\r\n])*\1/;r.languages.json5=r.languages.extend("json",{property:[{pattern:RegExp(a.source+"(?=\\s*:)"),greedy:!0},{pattern:/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/,alias:"unquoted"}],string:{pattern:a,greedy:!0},number:/[+-]?\b(?:NaN|Infinity|0x[a-fA-F\d]+)\b|[+-]?(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+\b)?/})}(n)}return IS}var DS,aM;function ove(){if(aM)return DS;aM=1;var e=xA();DS=t,t.displayName="jsonp",t.aliases=[];function t(n){n.register(e),n.languages.jsonp=n.languages.extend("json",{punctuation:/[{}[\]();,.]/}),n.languages.insertBefore("jsonp","punctuation",{function:/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*\()/})}return DS}var LS,oM;function ive(){if(oM)return LS;oM=1,LS=e,e.displayName="jsstacktrace",e.aliases=[];function e(t){t.languages.jsstacktrace={"error-message":{pattern:/^\S.*/m,alias:"string"},"stack-frame":{pattern:/(^[ \t]+)at[ \t].*/m,lookbehind:!0,inside:{"not-my-code":{pattern:/^at[ \t]+(?!\s)(?:node\.js|<unknown>|.*(?:node_modules|\(<anonymous>\)|\(<unknown>|<anonymous>$|\(internal\/|\(node\.js)).*/m,alias:"comment"},filename:{pattern:/(\bat\s+(?!\s)|\()(?:[a-zA-Z]:)?[^():]+(?=:)/,lookbehind:!0,alias:"url"},function:{pattern:/(\bat\s+(?:new\s+)?)(?!\s)[_$a-zA-Z\xA0-\uFFFF<][.$\w\xA0-\uFFFF<>]*/,lookbehind:!0,inside:{punctuation:/\./}},punctuation:/[()]/,keyword:/\b(?:at|new)\b/,alias:{pattern:/\[(?:as\s+)?(?!\s)[_$a-zA-Z\xA0-\uFFFF][$\w\xA0-\uFFFF]*\]/,alias:"variable"},"line-number":{pattern:/:\d+(?::\d+)?\b/,alias:"number",inside:{punctuation:/:/}}}}}}return LS}var MS,iM;function HH(){if(iM)return MS;iM=1,MS=e,e.displayName="jsx",e.aliases=[];function e(t){(function(n){var r=n.util.clone(n.languages.javascript),a=/(?:\s|\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))\*\/)/.source,o=/(?:\{(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])*\})/.source,s=/(?:\{<S>*\.{3}(?:[^{}]|<BRACES>)*\})/.source;function l(p,g){return p=p.replace(/<S>/g,function(){return a}).replace(/<BRACES>/g,function(){return o}).replace(/<SPREAD>/g,function(){return s}),RegExp(p,g)}s=l(s).source,n.languages.jsx=n.languages.extend("markup",r),n.languages.jsx.tag.pattern=l(/<\/?(?:[\w.:-]+(?:<S>+(?:[\w.:$-]+(?:=(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s{'"/>=]+|<BRACES>))?|<SPREAD>))*<S>*\/?)?>/.source),n.languages.jsx.tag.inside.tag.pattern=/^<\/?[^\s>\/]*/,n.languages.jsx.tag.inside["attr-value"].pattern=/=(?!\{)(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s'">]+)/,n.languages.jsx.tag.inside.tag.inside["class-name"]=/^[A-Z]\w*(?:\.[A-Z]\w*)*$/,n.languages.jsx.tag.inside.comment=r.comment,n.languages.insertBefore("inside","attr-name",{spread:{pattern:l(/<SPREAD>/.source),inside:n.languages.jsx}},n.languages.jsx.tag),n.languages.insertBefore("inside","special-attr",{script:{pattern:l(/=<BRACES>/.source),alias:"language-javascript",inside:{"script-punctuation":{pattern:/^=(?=\{)/,alias:"punctuation"},rest:n.languages.jsx}}},n.languages.jsx.tag);var u=function(p){return p?typeof p=="string"?p:typeof p.content=="string"?p.content:p.content.map(u).join(""):""},d=function(p){for(var g=[],m=0;m<p.length;m++){var b=p[m],v=!1;if(typeof b!="string"&&(b.type==="tag"&&b.content[0]&&b.content[0].type==="tag"?b.content[0].content[0].content==="</"?g.length>0&&g[g.length-1].tagName===u(b.content[0].content[1])&&g.pop():b.content[b.content.length-1].content==="/>"||g.push({tagName:u(b.content[0].content[1]),openedBraces:0}):g.length>0&&b.type==="punctuation"&&b.content==="{"?g[g.length-1].openedBraces++:g.length>0&&g[g.length-1].openedBraces>0&&b.type==="punctuation"&&b.content==="}"?g[g.length-1].openedBraces--:v=!0),(v||typeof b=="string")&&g.length>0&&g[g.length-1].openedBraces===0){var y=u(b);m<p.length-1&&(typeof p[m+1]=="string"||p[m+1].type==="plain-text")&&(y+=u(p[m+1]),p.splice(m+1,1)),m>0&&(typeof p[m-1]=="string"||p[m-1].type==="plain-text")&&(y=u(p[m-1])+y,p.splice(m-1,1),m--),p[m]=new n.Token("plain-text",y,null,y)}b.content&&typeof b.content!="string"&&d(b.content)}};n.hooks.add("after-tokenize",function(p){p.language!=="jsx"&&p.language!=="tsx"||d(p.tokens)})})(t)}return MS}var PS,sM;function sve(){if(sM)return PS;sM=1,PS=e,e.displayName="julia",e.aliases=[];function e(t){t.languages.julia={comment:{pattern:/(^|[^\\])(?:#=(?:[^#=]|=(?!#)|#(?!=)|#=(?:[^#=]|=(?!#)|#(?!=))*=#)*=#|#.*)/,lookbehind:!0},regex:{pattern:/r"(?:\\.|[^"\\\r\n])*"[imsx]{0,4}/,greedy:!0},string:{pattern:/"""[\s\S]+?"""|(?:\b\w+)?"(?:\\.|[^"\\\r\n])*"|`(?:[^\\`\r\n]|\\.)*`/,greedy:!0},char:{pattern:/(^|[^\w'])'(?:\\[^\r\n][^'\r\n]*|[^\\\r\n])'/,lookbehind:!0,greedy:!0},keyword:/\b(?:abstract|baremodule|begin|bitstype|break|catch|ccall|const|continue|do|else|elseif|end|export|finally|for|function|global|if|immutable|import|importall|in|let|local|macro|module|print|println|quote|return|struct|try|type|typealias|using|while)\b/,boolean:/\b(?:false|true)\b/,number:/(?:\b(?=\d)|\B(?=\.))(?:0[box])?(?:[\da-f]+(?:_[\da-f]+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[efp][+-]?\d+(?:_\d+)*)?j?/i,operator:/&&|\|\||[-+*^%÷⊻&$\\]=?|\/[\/=]?|!=?=?|\|[=>]?|<(?:<=?|[=:|])?|>(?:=|>>?=?)?|==?=?|[~≠≤≥'√∛]/,punctuation:/::?|[{}[\]();,.?]/,constant:/\b(?:(?:Inf|NaN)(?:16|32|64)?|im|pi)\b|[πℯ]/}}return PS}var FS,lM;function lve(){if(lM)return FS;lM=1,FS=e,e.displayName="keepalived",e.aliases=[];function e(t){t.languages.keepalived={comment:{pattern:/[#!].*/,greedy:!0},string:{pattern:/(^|[^\\])(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/,lookbehind:!0,greedy:!0},ip:{pattern:RegExp(/\b(?:(?:(?:[\da-f]{1,4}:){7}[\da-f]{1,4}|(?:[\da-f]{1,4}:){6}:[\da-f]{1,4}|(?:[\da-f]{1,4}:){5}:(?:[\da-f]{1,4}:)?[\da-f]{1,4}|(?:[\da-f]{1,4}:){4}:(?:[\da-f]{1,4}:){0,2}[\da-f]{1,4}|(?:[\da-f]{1,4}:){3}:(?:[\da-f]{1,4}:){0,3}[\da-f]{1,4}|(?:[\da-f]{1,4}:){2}:(?:[\da-f]{1,4}:){0,4}[\da-f]{1,4}|(?:[\da-f]{1,4}:){6}<ipv4>|(?:[\da-f]{1,4}:){0,5}:<ipv4>|::(?:[\da-f]{1,4}:){0,5}<ipv4>|[\da-f]{1,4}::(?:[\da-f]{1,4}:){0,5}[\da-f]{1,4}|::(?:[\da-f]{1,4}:){0,6}[\da-f]{1,4}|(?:[\da-f]{1,4}:){1,7}:)(?:\/\d{1,3})?|<ipv4>(?:\/\d{1,2})?)\b/.source.replace(/<ipv4>/g,function(){return/(?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)\.){3}(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d))/.source}),"i"),alias:"number"},path:{pattern:/(\s)\/(?:[^\/\s]+\/)*[^\/\s]*|\b[a-zA-Z]:\\(?:[^\\\s]+\\)*[^\\\s]*/,lookbehind:!0,alias:"string"},variable:/\$\{?\w+\}?/,email:{pattern:/[\w-]+@[\w-]+(?:\.[\w-]{2,3}){1,2}/,alias:"string"},"conditional-configuration":{pattern:/@\^?[\w-]+/,alias:"variable"},operator:/=/,property:/\b(?:BFD_CHECK|DNS_CHECK|FILE_CHECK|HTTP_GET|MISC_CHECK|NAME|PING_CHECK|SCRIPTS|SMTP_CHECK|SSL|SSL_GET|TCP_CHECK|UDP_CHECK|accept|advert_int|alpha|auth_pass|auth_type|authentication|bfd_cpu_affinity|bfd_instance|bfd_no_swap|bfd_priority|bfd_process_name|bfd_rlimit_rttime|bfd_rt_priority|bind_if|bind_port|bindto|ca|certificate|check_unicast_src|checker|checker_cpu_affinity|checker_log_all_failures|checker_no_swap|checker_priority|checker_rlimit_rttime|checker_rt_priority|child_wait_time|connect_ip|connect_port|connect_timeout|dbus_service_name|debug|default_interface|delay|delay_before_retry|delay_loop|digest|dont_track_primary|dynamic|dynamic_interfaces|enable_(?:dbus|script_security|sni|snmp_checker|snmp_rfc|snmp_rfcv2|snmp_rfcv3|snmp_vrrp|traps)|end|fall|fast_recovery|file|flag-[123]|fork_delay|full_command|fwmark|garp_group|garp_interval|garp_lower_prio_delay|garp_lower_prio_repeat|garp_master_delay|garp_master_refresh|garp_master_refresh_repeat|garp_master_repeat|global_defs|global_tracking|gna_interval|group|ha_suspend|hashed|helo_name|higher_prio_send_advert|hoplimit|http_protocol|hysteresis|idle_tx|include|inhibit_on_failure|init_fail|init_file|instance|interface|interfaces|interval|ip_family|ipvs_process_name|keepalived.conf|kernel_rx_buf_size|key|linkbeat_interfaces|linkbeat_use_polling|log_all_failures|log_unknown_vrids|lower_prio_no_advert|lthreshold|lvs_flush|lvs_flush_onstop|lvs_method|lvs_netlink_cmd_rcv_bufs|lvs_netlink_cmd_rcv_bufs_force|lvs_netlink_monitor_rcv_bufs|lvs_netlink_monitor_rcv_bufs_force|lvs_notify_fifo|lvs_notify_fifo_script|lvs_sched|lvs_sync_daemon|max_auto_priority|max_hops|mcast_src_ip|mh-fallback|mh-port|min_auto_priority_delay|min_rx|min_tx|misc_dynamic|misc_path|misc_timeout|multiplier|name|namespace_with_ipsets|native_ipv6|neighbor_ip|net_namespace|net_namespace_ipvs|nftables|nftables_counters|nftables_ifindex|nftables_priority|no_accept|no_checker_emails|no_email_faults|nopreempt|notification_email|notification_email_from|notify|notify_backup|notify_deleted|notify_down|notify_fault|notify_fifo|notify_fifo_script|notify_master|notify_master_rx_lower_pri|notify_priority_changes|notify_stop|notify_up|old_unicast_checksum|omega|ops|param_match|passive|password|path|persistence_engine|persistence_granularity|persistence_timeout|preempt|preempt_delay|priority|process|process_monitor_rcv_bufs|process_monitor_rcv_bufs_force|process_name|process_names|promote_secondaries|protocol|proxy_arp|proxy_arp_pvlan|quorum|quorum_down|quorum_max|quorum_up|random_seed|real_server|regex|regex_max_offset|regex_min_offset|regex_no_match|regex_options|regex_stack|reload_repeat|reload_time_file|require_reply|retry|rise|router_id|rs_init_notifies|script|script_user|sh-fallback|sh-port|shutdown_script|shutdown_script_timeout|skip_check_adv_addr|smtp_alert|smtp_alert_checker|smtp_alert_vrrp|smtp_connect_timeout|smtp_helo_name|smtp_server|snmp_socket|sorry_server|sorry_server_inhibit|sorry_server_lvs_method|source_ip|start|startup_script|startup_script_timeout|state|static_ipaddress|static_routes|static_rules|status_code|step|strict_mode|sync_group_tracking_weight|terminate_delay|timeout|track_bfd|track_file|track_group|track_interface|track_process|track_script|track_src_ip|ttl|type|umask|unicast_peer|unicast_src_ip|unicast_ttl|url|use_ipvlan|use_pid_dir|use_vmac|user|uthreshold|val[123]|version|virtual_ipaddress|virtual_ipaddress_excluded|virtual_router_id|virtual_routes|virtual_rules|virtual_server|virtual_server_group|virtualhost|vmac_xmit_base|vrrp|vrrp_(?:check_unicast_src|cpu_affinity|garp_interval|garp_lower_prio_delay|garp_lower_prio_repeat|garp_master_delay|garp_master_refresh|garp_master_refresh_repeat|garp_master_repeat|gna_interval|higher_prio_send_advert|instance|ipsets|iptables|lower_prio_no_advert|mcast_group4|mcast_group6|min_garp|netlink_cmd_rcv_bufs|netlink_cmd_rcv_bufs_force|netlink_monitor_rcv_bufs|netlink_monitor_rcv_bufs_force|no_swap|notify_fifo|notify_fifo_script|notify_priority_changes|priority|process_name|rlimit_rttime|rt_priority|rx_bufs_multiplier|rx_bufs_policy|script|skip_check_adv_addr|startup_delay|strict|sync_group|track_process|version)|warmup|weight)\b/,constant:/\b(?:A|AAAA|AH|BACKUP|CNAME|DR|MASTER|MX|NAT|NS|PASS|SCTP|SOA|TCP|TUN|TXT|UDP|dh|fo|lblc|lblcr|lc|mh|nq|ovf|rr|sed|sh|wlc|wrr)\b/,number:{pattern:/(^|[^\w.-])-?\d+(?:\.\d+)?/,lookbehind:!0},boolean:/\b(?:false|no|off|on|true|yes)\b/,punctuation:/[\{\}]/}}return FS}var zS,cM;function cve(){if(cM)return zS;cM=1,zS=e,e.displayName="keyman",e.aliases=[];function e(t){t.languages.keyman={comment:{pattern:/\bc .*/i,greedy:!0},string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0},"virtual-key":{pattern:/\[\s*(?:(?:ALT|CAPS|CTRL|LALT|LCTRL|NCAPS|RALT|RCTRL|SHIFT)\s+)*(?:[TKU]_[\w?]+|[A-E]\d\d?|"[^"\r\n]*"|'[^'\r\n]*')\s*\]/i,greedy:!0,alias:"function"},"header-keyword":{pattern:/&\w+/,alias:"bold"},"header-statement":{pattern:/\b(?:bitmap|bitmaps|caps always off|caps on only|copyright|hotkey|language|layout|message|name|shift frees caps|version)\b/i,alias:"bold"},"rule-keyword":{pattern:/\b(?:any|baselayout|beep|call|context|deadkey|dk|if|index|layer|notany|nul|outs|platform|reset|return|save|set|store|use)\b/i,alias:"keyword"},"structural-keyword":{pattern:/\b(?:ansi|begin|group|match|nomatch|unicode|using keys)\b/i,alias:"keyword"},"compile-target":{pattern:/\$(?:keyman|keymanonly|keymanweb|kmfl|weaver):/i,alias:"property"},number:/\b(?:U\+[\dA-F]+|d\d+|x[\da-f]+|\d+)\b/i,operator:/[+>\\$]|\.\./,punctuation:/[()=,]/}}return zS}var BS,uM;function uve(){if(uM)return BS;uM=1,BS=e,e.displayName="kotlin",e.aliases=["kt","kts"];function e(t){(function(n){n.languages.kotlin=n.languages.extend("clike",{keyword:{pattern:/(^|[^.])\b(?:abstract|actual|annotation|as|break|by|catch|class|companion|const|constructor|continue|crossinline|data|do|dynamic|else|enum|expect|external|final|finally|for|fun|get|if|import|in|infix|init|inline|inner|interface|internal|is|lateinit|noinline|null|object|open|operator|out|override|package|private|protected|public|reified|return|sealed|set|super|suspend|tailrec|this|throw|to|try|typealias|val|var|vararg|when|where|while)\b/,lookbehind:!0},function:[{pattern:/(?:`[^\r\n`]+`|\b\w+)(?=\s*\()/,greedy:!0},{pattern:/(\.)(?:`[^\r\n`]+`|\w+)(?=\s*\{)/,lookbehind:!0,greedy:!0}],number:/\b(?:0[xX][\da-fA-F]+(?:_[\da-fA-F]+)*|0[bB][01]+(?:_[01]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?[fFL]?)\b/,operator:/\+[+=]?|-[-=>]?|==?=?|!(?:!|==?)?|[\/*%<>]=?|[?:]:?|\.\.|&&|\|\||\b(?:and|inv|or|shl|shr|ushr|xor)\b/}),delete n.languages.kotlin["class-name"];var r={"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:n.languages.kotlin}};n.languages.insertBefore("kotlin","string",{"string-literal":[{pattern:/"""(?:[^$]|\$(?:(?!\{)|\{[^{}]*\}))*?"""/,alias:"multiline",inside:{interpolation:{pattern:/\$(?:[a-z_]\w*|\{[^{}]*\})/i,inside:r},string:/[\s\S]+/}},{pattern:/"(?:[^"\\\r\n$]|\\.|\$(?:(?!\{)|\{[^{}]*\}))*"/,alias:"singleline",inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:[a-z_]\w*|\{[^{}]*\})/i,lookbehind:!0,inside:r},string:/[\s\S]+/}}],char:{pattern:/'(?:[^'\\\r\n]|\\(?:.|u[a-fA-F0-9]{0,4}))'/,greedy:!0}}),delete n.languages.kotlin.string,n.languages.insertBefore("kotlin","keyword",{annotation:{pattern:/\B@(?:\w+:)?(?:[A-Z]\w*|\[[^\]]+\])/,alias:"builtin"}}),n.languages.insertBefore("kotlin","function",{label:{pattern:/\b\w+@|@\w+\b/,alias:"symbol"}}),n.languages.kt=n.languages.kotlin,n.languages.kts=n.languages.kotlin})(t)}return BS}var jS,dM;function dve(){if(dM)return jS;dM=1,jS=e,e.displayName="kumir",e.aliases=["kum"];function e(t){(function(n){var r=/\s\x00-\x1f\x22-\x2f\x3a-\x3f\x5b-\x5e\x60\x7b-\x7e/.source;function a(o,s){return RegExp(o.replace(/<nonId>/g,r),s)}n.languages.kumir={comment:{pattern:/\|.*/},prolog:{pattern:/#.*/,greedy:!0},string:{pattern:/"[^\n\r"]*"|'[^\n\r']*'/,greedy:!0},boolean:{pattern:a(/(^|[<nonId>])(?:да|нет)(?=[<nonId>]|$)/.source),lookbehind:!0},"operator-word":{pattern:a(/(^|[<nonId>])(?:и|или|не)(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"keyword"},"system-variable":{pattern:a(/(^|[<nonId>])знач(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"keyword"},type:[{pattern:a(/(^|[<nonId>])(?:вещ|лит|лог|сим|цел)(?:\x20*таб)?(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"builtin"},{pattern:a(/(^|[<nonId>])(?:компл|сканкод|файл|цвет)(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"important"}],keyword:{pattern:a(/(^|[<nonId>])(?:алг|арг(?:\x20*рез)?|ввод|ВКЛЮЧИТЬ|вс[её]|выбор|вывод|выход|дано|для|до|дс|если|иначе|исп|использовать|кон(?:(?:\x20+|_)исп)?|кц(?:(?:\x20+|_)при)?|надо|нач|нс|нц|от|пауза|пока|при|раза?|рез|стоп|таб|то|утв|шаг)(?=[<nonId>]|$)/.source),lookbehind:!0},name:{pattern:a(/(^|[<nonId>])[^\d<nonId>][^<nonId>]*(?:\x20+[^<nonId>]+)*(?=[<nonId>]|$)/.source),lookbehind:!0},number:{pattern:a(/(^|[<nonId>])(?:\B\$[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)(?=[<nonId>]|$)/.source,"i"),lookbehind:!0},punctuation:/:=|[(),:;\[\]]/,"operator-char":{pattern:/\*\*?|<[=>]?|>=?|[-+/=]/,alias:"operator"}},n.languages.kum=n.languages.kumir})(t)}return jS}var US,fM;function fve(){if(fM)return US;fM=1,US=e,e.displayName="kusto",e.aliases=[];function e(t){t.languages.kusto={comment:{pattern:/\/\/.*/,greedy:!0},string:{pattern:/```[\s\S]*?```|[hH]?(?:"(?:[^\r\n\\"]|\\.)*"|'(?:[^\r\n\\']|\\.)*'|@(?:"[^\r\n"]*"|'[^\r\n']*'))/,greedy:!0},verb:{pattern:/(\|\s*)[a-z][\w-]*/i,lookbehind:!0,alias:"keyword"},command:{pattern:/\.[a-z][a-z\d-]*\b/,alias:"keyword"},"class-name":/\b(?:bool|datetime|decimal|dynamic|guid|int|long|real|string|timespan)\b/,keyword:/\b(?:access|alias|and|anti|as|asc|auto|between|by|(?:contains|(?:ends|starts)with|has(?:perfix|suffix)?)(?:_cs)?|database|declare|desc|external|from|fullouter|has_all|in|ingestion|inline|inner|innerunique|into|(?:left|right)(?:anti(?:semi)?|inner|outer|semi)?|let|like|local|not|of|on|or|pattern|print|query_parameters|range|restrict|schema|set|step|table|tables|to|view|where|with|matches\s+regex|nulls\s+(?:first|last))(?![\w-])/,boolean:/\b(?:false|null|true)\b/,function:/\b[a-z_]\w*(?=\s*\()/,datetime:[{pattern:/\b(?:(?:Fri|Friday|Mon|Monday|Sat|Saturday|Sun|Sunday|Thu|Thursday|Tue|Tuesday|Wed|Wednesday)\s*,\s*)?\d{1,2}(?:\s+|-)(?:Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)(?:\s+|-)\d{2}\s+\d{2}:\d{2}(?::\d{2})?(?:\s*(?:\b(?:[A-Z]|(?:[ECMT][DS]|GM|U)T)|[+-]\d{4}))?\b/,alias:"number"},{pattern:/[+-]?\b(?:\d{4}-\d{2}-\d{2}(?:[ T]\d{2}:\d{2}(?::\d{2}(?:\.\d+)?)?)?|\d{2}:\d{2}(?::\d{2}(?:\.\d+)?)?)Z?/,alias:"number"}],number:/\b(?:0x[0-9A-Fa-f]+|\d+(?:\.\d+)?(?:[Ee][+-]?\d+)?)(?:(?:min|sec|[mnµ]s|[dhms]|microsecond|tick)\b)?|[+-]?\binf\b/,operator:/=>|[!=]~|[!=<>]=?|[-+*/%|]|\.\./,punctuation:/[()\[\]{},;.:]/}}return US}var GS,pM;function pve(){if(pM)return GS;pM=1,GS=e,e.displayName="latex",e.aliases=["tex","context"];function e(t){(function(n){var r=/\\(?:[^a-z()[\]]|[a-z*]+)/i,a={"equation-command":{pattern:r,alias:"regex"}};n.languages.latex={comment:/%.*/,cdata:{pattern:/(\\begin\{((?:lstlisting|verbatim)\*?)\})[\s\S]*?(?=\\end\{\2\})/,lookbehind:!0},equation:[{pattern:/\$\$(?:\\[\s\S]|[^\\$])+\$\$|\$(?:\\[\s\S]|[^\\$])+\$|\\\([\s\S]*?\\\)|\\\[[\s\S]*?\\\]/,inside:a,alias:"string"},{pattern:/(\\begin\{((?:align|eqnarray|equation|gather|math|multline)\*?)\})[\s\S]*?(?=\\end\{\2\})/,lookbehind:!0,inside:a,alias:"string"}],keyword:{pattern:/(\\(?:begin|cite|documentclass|end|label|ref|usepackage)(?:\[[^\]]+\])?\{)[^}]+(?=\})/,lookbehind:!0},url:{pattern:/(\\url\{)[^}]+(?=\})/,lookbehind:!0},headline:{pattern:/(\\(?:chapter|frametitle|paragraph|part|section|subparagraph|subsection|subsubparagraph|subsubsection|subsubsubparagraph)\*?(?:\[[^\]]+\])?\{)[^}]+(?=\})/,lookbehind:!0,alias:"class-name"},function:{pattern:r,alias:"selector"},punctuation:/[[\]{}&]/},n.languages.tex=n.languages.latex,n.languages.context=n.languages.latex})(t)}return GS}var HS,gM;function Up(){if(gM)return HS;gM=1;var e=Wn();HS=t,t.displayName="php",t.aliases=[];function t(n){n.register(e),function(r){var a=/\/\*[\s\S]*?\*\/|\/\/.*|#(?!\[).*/,o=[{pattern:/\b(?:false|true)\b/i,alias:"boolean"},{pattern:/(::\s*)\b[a-z_]\w*\b(?!\s*\()/i,greedy:!0,lookbehind:!0},{pattern:/(\b(?:case|const)\s+)\b[a-z_]\w*(?=\s*[;=])/i,greedy:!0,lookbehind:!0},/\b(?:null)\b/i,/\b[A-Z_][A-Z0-9_]*\b(?!\s*\()/],s=/\b0b[01]+(?:_[01]+)*\b|\b0o[0-7]+(?:_[0-7]+)*\b|\b0x[\da-f]+(?:_[\da-f]+)*\b|(?:\b\d+(?:_\d+)*\.?(?:\d+(?:_\d+)*)?|\B\.\d+)(?:e[+-]?\d+)?/i,l=/<?=>|\?\?=?|\.{3}|\??->|[!=]=?=?|::|\*\*=?|--|\+\+|&&|\|\||<<|>>|[?~]|[/^|%*&<>.+-]=?/,u=/[{}\[\](),:;]/;r.languages.php={delimiter:{pattern:/\?>$|^<\?(?:php(?=\s)|=)?/i,alias:"important"},comment:a,variable:/\$+(?:\w+\b|(?=\{))/,package:{pattern:/(namespace\s+|use\s+(?:function\s+)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,lookbehind:!0,inside:{punctuation:/\\/}},"class-name-definition":{pattern:/(\b(?:class|enum|interface|trait)\s+)\b[a-z_]\w*(?!\\)\b/i,lookbehind:!0,alias:"class-name"},"function-definition":{pattern:/(\bfunction\s+)[a-z_]\w*(?=\s*\()/i,lookbehind:!0,alias:"function"},keyword:[{pattern:/(\(\s*)\b(?:array|bool|boolean|float|int|integer|object|string)\b(?=\s*\))/i,alias:"type-casting",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|object|self|static|string)\b(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|object|self|static|string|void)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/\b(?:array(?!\s*\()|bool|float|int|iterable|mixed|object|string|void)\b/i,alias:"type-declaration",greedy:!0},{pattern:/(\|\s*)(?:false|null)\b|\b(?:false|null)(?=\s*\|)/i,alias:"type-declaration",greedy:!0,lookbehind:!0},{pattern:/\b(?:parent|self|static)(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(\byield\s+)from\b/i,lookbehind:!0},/\bclass\b/i,{pattern:/((?:^|[^\s>:]|(?:^|[^-])>|(?:^|[^:]):)\s*)\b(?:abstract|and|array|as|break|callable|case|catch|clone|const|continue|declare|default|die|do|echo|else|elseif|empty|enddeclare|endfor|endforeach|endif|endswitch|endwhile|enum|eval|exit|extends|final|finally|fn|for|foreach|function|global|goto|if|implements|include|include_once|instanceof|insteadof|interface|isset|list|match|namespace|new|or|parent|print|private|protected|public|require|require_once|return|self|static|switch|throw|trait|try|unset|use|var|while|xor|yield|__halt_compiler)\b/i,lookbehind:!0}],"argument-name":{pattern:/([(,]\s+)\b[a-z_]\w*(?=\s*:(?!:))/i,lookbehind:!0},"class-name":[{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self|\s+static))\s+|\bcatch\s*\()\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/(\|\s*)\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/\b[a-z_]\w*(?!\\)\b(?=\s*\|)/i,greedy:!0},{pattern:/(\|\s*)(?:\\?\b[a-z_]\w*)+\b/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(?:\\?\b[a-z_]\w*)+\b(?=\s*\|)/i,alias:"class-name-fully-qualified",greedy:!0,inside:{punctuation:/\\/}},{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self\b|\s+static\b))\s+|\bcatch\s*\()(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*\$)/i,alias:"type-declaration",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-declaration"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*::)/i,alias:["class-name-fully-qualified","static-context"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/([(,?]\s*)[a-z_]\w*(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-hint"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b[a-z_]\w*(?!\\)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:["class-name-fully-qualified","return-type"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:o,function:{pattern:/(^|[^\\\w])\\?[a-z_](?:[\w\\]*\w)?(?=\s*\()/i,lookbehind:!0,inside:{punctuation:/\\/}},property:{pattern:/(->\s*)\w+/,lookbehind:!0},number:s,operator:l,punctuation:u};var d={pattern:/\{\$(?:\{(?:\{[^{}]+\}|[^{}]+)\}|[^{}])+\}|(^|[^\\{])\$+(?:\w+(?:\[[^\r\n\[\]]+\]|->\w+)?)/,lookbehind:!0,inside:r.languages.php},p=[{pattern:/<<<'([^']+)'[\r\n](?:.*[\r\n])*?\1;/,alias:"nowdoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<'[^']+'|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<'?|[';]$/}}}},{pattern:/<<<(?:"([^"]+)"[\r\n](?:.*[\r\n])*?\1;|([a-z_]\w*)[\r\n](?:.*[\r\n])*?\2;)/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<(?:"[^"]+"|[a-z_]\w*)|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<"?|[";]$/}},interpolation:d}},{pattern:/`(?:\\[\s\S]|[^\\`])*`/,alias:"backtick-quoted-string",greedy:!0},{pattern:/'(?:\\[\s\S]|[^\\'])*'/,alias:"single-quoted-string",greedy:!0},{pattern:/"(?:\\[\s\S]|[^\\"])*"/,alias:"double-quoted-string",greedy:!0,inside:{interpolation:d}}];r.languages.insertBefore("php","variable",{string:p,attribute:{pattern:/#\[(?:[^"'\/#]|\/(?![*/])|\/\/.*$|#(?!\[).*$|\/\*(?:[^*]|\*(?!\/))*\*\/|"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*')+\](?=\s*[a-z$#])/im,greedy:!0,inside:{"attribute-content":{pattern:/^(#\[)[\s\S]+(?=\]$)/,lookbehind:!0,inside:{comment:a,string:p,"attribute-class-name":[{pattern:/([^:]|^)\b[a-z_]\w*(?!\\)\b/i,alias:"class-name",greedy:!0,lookbehind:!0},{pattern:/([^:]|^)(?:\\?\b[a-z_]\w*)+/i,alias:["class-name","class-name-fully-qualified"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:o,number:s,operator:l,punctuation:u}},delimiter:{pattern:/^#\[|\]$/,alias:"punctuation"}}}}),r.hooks.add("before-tokenize",function(g){if(/<\?/.test(g.code)){var m=/<\?(?:[^"'/#]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|(?:\/\/|#(?!\[))(?:[^?\n\r]|\?(?!>))*(?=$|\?>|[\r\n])|#\[|\/\*(?:[^*]|\*(?!\/))*(?:\*\/|$))*?(?:\?>|$)/g;r.languages["markup-templating"].buildPlaceholders(g,"php",m)}}),r.hooks.add("after-tokenize",function(g){r.languages["markup-templating"].tokenizePlaceholders(g,"php")})}(n)}return HS}var $S,hM;function gve(){if(hM)return $S;hM=1;var e=Wn(),t=Up();$S=n,n.displayName="latte",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){a.languages.latte={comment:/^\{\*[\s\S]*/,"latte-tag":{pattern:/(^\{(?:\/(?=[a-z]))?)(?:[=_]|[a-z]\w*\b(?!\())/i,lookbehind:!0,alias:"important"},delimiter:{pattern:/^\{\/?|\}$/,alias:"punctuation"},php:{pattern:/\S(?:[\s\S]*\S)?/,alias:"language-php",inside:a.languages.php}};var o=a.languages.extend("markup",{});a.languages.insertBefore("inside","attr-value",{"n-attr":{pattern:/n:[\w-]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+))?/,inside:{"attr-name":{pattern:/^[^\s=]+/,alias:"important"},"attr-value":{pattern:/=[\s\S]+/,inside:{punctuation:[/^=/,{pattern:/^(\s*)["']|["']$/,lookbehind:!0}],php:{pattern:/\S(?:[\s\S]*\S)?/,inside:a.languages.php}}}}}},o.tag),a.hooks.add("before-tokenize",function(s){if(s.language==="latte"){var l=/\{\*[\s\S]*?\*\}|\{[^'"\s{}*](?:[^"'/{}]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|\/\*(?:[^*]|\*(?!\/))*\*\/)*\}/g;a.languages["markup-templating"].buildPlaceholders(s,"latte",l),s.grammar=o}}),a.hooks.add("after-tokenize",function(s){a.languages["markup-templating"].tokenizePlaceholders(s,"latte")})}(r)}return $S}var qS,mM;function hve(){if(mM)return qS;mM=1,qS=e,e.displayName="less",e.aliases=[];function e(t){t.languages.less=t.languages.extend("css",{comment:[/\/\*[\s\S]*?\*\//,{pattern:/(^|[^\\])\/\/.*/,lookbehind:!0}],atrule:{pattern:/@[\w-](?:\((?:[^(){}]|\([^(){}]*\))*\)|[^(){};\s]|\s+(?!\s))*?(?=\s*\{)/,inside:{punctuation:/[:()]/}},selector:{pattern:/(?:@\{[\w-]+\}|[^{};\s@])(?:@\{[\w-]+\}|\((?:[^(){}]|\([^(){}]*\))*\)|[^(){};@\s]|\s+(?!\s))*?(?=\s*\{)/,inside:{variable:/@+[\w-]+/}},property:/(?:@\{[\w-]+\}|[\w-])+(?:\+_?)?(?=\s*:)/,operator:/[+\-*\/]/}),t.languages.insertBefore("less","property",{variable:[{pattern:/@[\w-]+\s*:/,inside:{punctuation:/:/}},/@@?[\w-]+/],"mixin-usage":{pattern:/([{;]\s*)[.#](?!\d)[\w-].*?(?=[(;])/,lookbehind:!0,alias:"function"}})}return qS}var VS,bM;function kA(){if(bM)return VS;bM=1,VS=e,e.displayName="scheme",e.aliases=[];function e(t){(function(n){n.languages.scheme={comment:/;.*|#;\s*(?:\((?:[^()]|\([^()]*\))*\)|\[(?:[^\[\]]|\[[^\[\]]*\])*\])|#\|(?:[^#|]|#(?!\|)|\|(?!#)|#\|(?:[^#|]|#(?!\|)|\|(?!#))*\|#)*\|#/,string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},symbol:{pattern:/'[^()\[\]#'\s]+/,greedy:!0},char:{pattern:/#\\(?:[ux][a-fA-F\d]+\b|[-a-zA-Z]+\b|[\uD800-\uDBFF][\uDC00-\uDFFF]|\S)/,greedy:!0},"lambda-parameter":[{pattern:/((?:^|[^'`#])[(\[]lambda\s+)(?:[^|()\[\]'\s]+|\|(?:[^\\|]|\\.)*\|)/,lookbehind:!0},{pattern:/((?:^|[^'`#])[(\[]lambda\s+[(\[])[^()\[\]']+/,lookbehind:!0}],keyword:{pattern:/((?:^|[^'`#])[(\[])(?:begin|case(?:-lambda)?|cond(?:-expand)?|define(?:-library|-macro|-record-type|-syntax|-values)?|defmacro|delay(?:-force)?|do|else|except|export|guard|if|import|include(?:-ci|-library-declarations)?|lambda|let(?:rec)?(?:-syntax|-values|\*)?|let\*-values|only|parameterize|prefix|(?:quasi-?)?quote|rename|set!|syntax-(?:case|rules)|unless|unquote(?:-splicing)?|when)(?=[()\[\]\s]|$)/,lookbehind:!0},builtin:{pattern:/((?:^|[^'`#])[(\[])(?:abs|and|append|apply|assoc|ass[qv]|binary-port\?|boolean=?\?|bytevector(?:-append|-copy|-copy!|-length|-u8-ref|-u8-set!|\?)?|caar|cadr|call-with-(?:current-continuation|port|values)|call\/cc|car|cdar|cddr|cdr|ceiling|char(?:->integer|-ready\?|\?|<\?|<=\?|=\?|>\?|>=\?)|close-(?:input-port|output-port|port)|complex\?|cons|current-(?:error|input|output)-port|denominator|dynamic-wind|eof-object\??|eq\?|equal\?|eqv\?|error|error-object(?:-irritants|-message|\?)|eval|even\?|exact(?:-integer-sqrt|-integer\?|\?)?|expt|features|file-error\?|floor(?:-quotient|-remainder|\/)?|flush-output-port|for-each|gcd|get-output-(?:bytevector|string)|inexact\??|input-port(?:-open\?|\?)|integer(?:->char|\?)|lcm|length|list(?:->string|->vector|-copy|-ref|-set!|-tail|\?)?|make-(?:bytevector|list|parameter|string|vector)|map|max|member|memq|memv|min|modulo|negative\?|newline|not|null\?|number(?:->string|\?)|numerator|odd\?|open-(?:input|output)-(?:bytevector|string)|or|output-port(?:-open\?|\?)|pair\?|peek-char|peek-u8|port\?|positive\?|procedure\?|quotient|raise|raise-continuable|rational\?|rationalize|read-(?:bytevector|bytevector!|char|error\?|line|string|u8)|real\?|remainder|reverse|round|set-c[ad]r!|square|string(?:->list|->number|->symbol|->utf8|->vector|-append|-copy|-copy!|-fill!|-for-each|-length|-map|-ref|-set!|\?|<\?|<=\?|=\?|>\?|>=\?)?|substring|symbol(?:->string|\?|=\?)|syntax-error|textual-port\?|truncate(?:-quotient|-remainder|\/)?|u8-ready\?|utf8->string|values|vector(?:->list|->string|-append|-copy|-copy!|-fill!|-for-each|-length|-map|-ref|-set!|\?)?|with-exception-handler|write-(?:bytevector|char|string|u8)|zero\?)(?=[()\[\]\s]|$)/,lookbehind:!0},operator:{pattern:/((?:^|[^'`#])[(\[])(?:[-+*%/]|[<>]=?|=>?)(?=[()\[\]\s]|$)/,lookbehind:!0},number:{pattern:RegExp(r({"<ureal dec>":/\d+(?:\/\d+)|(?:\d+(?:\.\d*)?|\.\d+)(?:[esfdl][+-]?\d+)?/.source,"<real dec>":/[+-]?<ureal dec>|[+-](?:inf|nan)\.0/.source,"<imaginary dec>":/[+-](?:<ureal dec>|(?:inf|nan)\.0)?i/.source,"<complex dec>":/<real dec>(?:@<real dec>|<imaginary dec>)?|<imaginary dec>/.source,"<num dec>":/(?:#d(?:#[ei])?|#[ei](?:#d)?)?<complex dec>/.source,"<ureal box>":/[0-9a-f]+(?:\/[0-9a-f]+)?/.source,"<real box>":/[+-]?<ureal box>|[+-](?:inf|nan)\.0/.source,"<imaginary box>":/[+-](?:<ureal box>|(?:inf|nan)\.0)?i/.source,"<complex box>":/<real box>(?:@<real box>|<imaginary box>)?|<imaginary box>/.source,"<num box>":/#[box](?:#[ei])?|(?:#[ei])?#[box]<complex box>/.source,"<number>":/(^|[()\[\]\s])(?:<num dec>|<num box>)(?=[()\[\]\s]|$)/.source}),"i"),lookbehind:!0},boolean:{pattern:/(^|[()\[\]\s])#(?:[ft]|false|true)(?=[()\[\]\s]|$)/,lookbehind:!0},function:{pattern:/((?:^|[^'`#])[(\[])(?:[^|()\[\]'\s]+|\|(?:[^\\|]|\\.)*\|)(?=[()\[\]\s]|$)/,lookbehind:!0},identifier:{pattern:/(^|[()\[\]\s])\|(?:[^\\|]|\\.)*\|(?=[()\[\]\s]|$)/,lookbehind:!0,greedy:!0},punctuation:/[()\[\]']/};function r(a){for(var o in a)a[o]=a[o].replace(/<[\w\s]+>/g,function(s){return"(?:"+a[s].trim()+")"});return a[o]}})(t)}return VS}var WS,yM;function mve(){if(yM)return WS;yM=1;var e=kA();WS=t,t.displayName="lilypond",t.aliases=[];function t(n){n.register(e),function(r){for(var a=/\((?:[^();"#\\]|\\[\s\S]|;.*(?!.)|"(?:[^"\\]|\\.)*"|#(?:\{(?:(?!#\})[\s\S])*#\}|[^{])|<expr>)*\)/.source,o=5,s=0;s<o;s++)a=a.replace(/<expr>/g,function(){return a});a=a.replace(/<expr>/g,/[^\s\S]/.source);var l=r.languages.lilypond={comment:/%(?:(?!\{).*|\{[\s\S]*?%\})/,"embedded-scheme":{pattern:RegExp(/(^|[=\s])#(?:"(?:[^"\\]|\\.)*"|[^\s()"]*(?:[^\s()]|<expr>))/.source.replace(/<expr>/g,function(){return a}),"m"),lookbehind:!0,greedy:!0,inside:{scheme:{pattern:/^(#)[\s\S]+$/,lookbehind:!0,alias:"language-scheme",inside:{"embedded-lilypond":{pattern:/#\{[\s\S]*?#\}/,greedy:!0,inside:{punctuation:/^#\{|#\}$/,lilypond:{pattern:/[\s\S]+/,alias:"language-lilypond",inside:null}}},rest:r.languages.scheme}},punctuation:/#/}},string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},"class-name":{pattern:/(\\new\s+)[\w-]+/,lookbehind:!0},keyword:{pattern:/\\[a-z][-\w]*/i,inside:{punctuation:/^\\/}},operator:/[=|]|<<|>>/,punctuation:{pattern:/(^|[a-z\d])(?:'+|,+|[_^]?-[_^]?(?:[-+^!>._]|(?=\d))|[_^]\.?|[.!])|[{}()[\]<>^~]|\\[()[\]<>\\!]|--|__/,lookbehind:!0},number:/\b\d+(?:\/\d+)?\b/};l["embedded-scheme"].inside.scheme.inside["embedded-lilypond"].inside.lilypond.inside=l,r.languages.ly=l}(n)}return WS}var YS,vM;function bve(){if(vM)return YS;vM=1;var e=Wn();YS=t,t.displayName="liquid",t.aliases=[];function t(n){n.register(e),n.languages.liquid={comment:{pattern:/(^\{%\s*comment\s*%\})[\s\S]+(?=\{%\s*endcomment\s*%\}$)/,lookbehind:!0},delimiter:{pattern:/^\{(?:\{\{|[%\{])-?|-?(?:\}\}|[%\}])\}$/,alias:"punctuation"},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},keyword:/\b(?:as|assign|break|(?:end)?(?:capture|case|comment|for|form|if|paginate|raw|style|tablerow|unless)|continue|cycle|decrement|echo|else|elsif|in|include|increment|limit|liquid|offset|range|render|reversed|section|when|with)\b/,object:/\b(?:address|all_country_option_tags|article|block|blog|cart|checkout|collection|color|country|country_option_tags|currency|current_page|current_tags|customer|customer_address|date|discount_allocation|discount_application|external_video|filter|filter_value|font|forloop|fulfillment|generic_file|gift_card|group|handle|image|line_item|link|linklist|localization|location|measurement|media|metafield|model|model_source|order|page|page_description|page_image|page_title|part|policy|product|product_option|recommendations|request|robots|routes|rule|script|search|selling_plan|selling_plan_allocation|selling_plan_group|shipping_method|shop|shop_locale|sitemap|store_availability|tax_line|template|theme|transaction|unit_price_measurement|user_agent|variant|video|video_source)\b/,function:[{pattern:/(\|\s*)\w+/,lookbehind:!0,alias:"filter"},{pattern:/(\.\s*)(?:first|last|size)/,lookbehind:!0}],boolean:/\b(?:false|nil|true)\b/,range:{pattern:/\.\./,alias:"operator"},number:/\b\d+(?:\.\d+)?\b/,operator:/[!=]=|<>|[<>]=?|[|?:=-]|\b(?:and|contains(?=\s)|or)\b/,punctuation:/[.,\[\]()]/,empty:{pattern:/\bempty\b/,alias:"keyword"}},n.hooks.add("before-tokenize",function(r){var a=/\{%\s*comment\s*%\}[\s\S]*?\{%\s*endcomment\s*%\}|\{(?:%[\s\S]*?%|\{\{[\s\S]*?\}\}|\{[\s\S]*?\})\}/g,o=!1;n.languages["markup-templating"].buildPlaceholders(r,"liquid",a,function(s){var l=/^\{%-?\s*(\w+)/.exec(s);if(l){var u=l[1];if(u==="raw"&&!o)return o=!0,!0;if(u==="endraw")return o=!1,!0}return!o})}),n.hooks.add("after-tokenize",function(r){n.languages["markup-templating"].tokenizePlaceholders(r,"liquid")})}return YS}var KS,SM;function yve(){if(SM)return KS;SM=1,KS=e,e.displayName="lisp",e.aliases=[];function e(t){(function(n){function r(y){return RegExp(/(\()/.source+"(?:"+y+")"+/(?=[\s\)])/.source)}function a(y){return RegExp(/([\s([])/.source+"(?:"+y+")"+/(?=[\s)])/.source)}var o=/(?!\d)[-+*/~!@$%^=<>{}\w]+/.source,s="&"+o,l="(\\()",u="(?=\\))",d="(?=\\s)",p=/(?:[^()]|\((?:[^()]|\((?:[^()]|\((?:[^()]|\((?:[^()]|\([^()]*\))*\))*\))*\))*\))*/.source,g={heading:{pattern:/;;;.*/,alias:["comment","title"]},comment:/;.*/,string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0,inside:{argument:/[-A-Z]+(?=[.,\s])/,symbol:RegExp("`"+o+"'")}},"quoted-symbol":{pattern:RegExp("#?'"+o),alias:["variable","symbol"]},"lisp-property":{pattern:RegExp(":"+o),alias:"property"},splice:{pattern:RegExp(",@?"+o),alias:["symbol","variable"]},keyword:[{pattern:RegExp(l+"(?:and|(?:cl-)?letf|cl-loop|cond|cons|error|if|(?:lexical-)?let\\*?|message|not|null|or|provide|require|setq|unless|use-package|when|while)"+d),lookbehind:!0},{pattern:RegExp(l+"(?:append|by|collect|concat|do|finally|for|in|return)"+d),lookbehind:!0}],declare:{pattern:r(/declare/.source),lookbehind:!0,alias:"keyword"},interactive:{pattern:r(/interactive/.source),lookbehind:!0,alias:"keyword"},boolean:{pattern:a(/nil|t/.source),lookbehind:!0},number:{pattern:a(/[-+]?\d+(?:\.\d*)?/.source),lookbehind:!0},defvar:{pattern:RegExp(l+"def(?:const|custom|group|var)\\s+"+o),lookbehind:!0,inside:{keyword:/^def[a-z]+/,variable:RegExp(o)}},defun:{pattern:RegExp(l+/(?:cl-)?(?:defmacro|defun\*?)\s+/.source+o+/\s+\(/.source+p+/\)/.source),lookbehind:!0,greedy:!0,inside:{keyword:/^(?:cl-)?def\S+/,arguments:null,function:{pattern:RegExp("(^\\s)"+o),lookbehind:!0},punctuation:/[()]/}},lambda:{pattern:RegExp(l+"lambda\\s+\\(\\s*(?:&?"+o+"(?:\\s+&?"+o+")*\\s*)?\\)"),lookbehind:!0,greedy:!0,inside:{keyword:/^lambda/,arguments:null,punctuation:/[()]/}},car:{pattern:RegExp(l+o),lookbehind:!0},punctuation:[/(?:['`,]?\(|[)\[\]])/,{pattern:/(\s)\.(?=\s)/,lookbehind:!0}]},m={"lisp-marker":RegExp(s),varform:{pattern:RegExp(/\(/.source+o+/\s+(?=\S)/.source+p+/\)/.source),inside:g},argument:{pattern:RegExp(/(^|[\s(])/.source+o),lookbehind:!0,alias:"variable"},rest:g},b="\\S+(?:\\s+\\S+)*",v={pattern:RegExp(l+p+u),lookbehind:!0,inside:{"rest-vars":{pattern:RegExp("&(?:body|rest)\\s+"+b),inside:m},"other-marker-vars":{pattern:RegExp("&(?:aux|optional)\\s+"+b),inside:m},keys:{pattern:RegExp("&key\\s+"+b+"(?:\\s+&allow-other-keys)?"),inside:m},argument:{pattern:RegExp(o),alias:"variable"},punctuation:/[()]/}};g.lambda.inside.arguments=v,g.defun.inside.arguments=n.util.clone(v),g.defun.inside.arguments.inside.sublist=v,n.languages.lisp=g,n.languages.elisp=g,n.languages.emacs=g,n.languages["emacs-lisp"]=g})(t)}return KS}var XS,EM;function vve(){if(EM)return XS;EM=1,XS=e,e.displayName="livescript",e.aliases=[];function e(t){t.languages.livescript={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0},{pattern:/(^|[^\\])#.*/,lookbehind:!0}],"interpolated-string":{pattern:/(^|[^"])("""|")(?:\\[\s\S]|(?!\2)[^\\])*\2(?!")/,lookbehind:!0,greedy:!0,inside:{variable:{pattern:/(^|[^\\])#[a-z_](?:-?[a-z]|[\d_])*/m,lookbehind:!0},interpolation:{pattern:/(^|[^\\])#\{[^}]+\}/m,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^#\{|\}$/,alias:"variable"}}},string:/[\s\S]+/}},string:[{pattern:/('''|')(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},{pattern:/<\[[\s\S]*?\]>/,greedy:!0},/\\[^\s,;\])}]+/],regex:[{pattern:/\/\/(?:\[[^\r\n\]]*\]|\\.|(?!\/\/)[^\\\[])+\/\/[gimyu]{0,5}/,greedy:!0,inside:{comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0}}},{pattern:/\/(?:\[[^\r\n\]]*\]|\\.|[^/\\\r\n\[])+\/[gimyu]{0,5}/,greedy:!0}],keyword:{pattern:/(^|(?!-).)\b(?:break|case|catch|class|const|continue|default|do|else|extends|fallthrough|finally|for(?: ever)?|function|if|implements|it|let|loop|new|null|otherwise|own|return|super|switch|that|then|this|throw|try|unless|until|var|void|when|while|yield)(?!-)\b/m,lookbehind:!0},"keyword-operator":{pattern:/(^|[^-])\b(?:(?:delete|require|typeof)!|(?:and|by|delete|export|from|import(?: all)?|in|instanceof|is(?: not|nt)?|not|of|or|til|to|typeof|with|xor)(?!-)\b)/m,lookbehind:!0,alias:"operator"},boolean:{pattern:/(^|[^-])\b(?:false|no|off|on|true|yes)(?!-)\b/m,lookbehind:!0},argument:{pattern:/(^|(?!\.&\.)[^&])&(?!&)\d*/m,lookbehind:!0,alias:"variable"},number:/\b(?:\d+~[\da-z]+|\d[\d_]*(?:\.\d[\d_]*)?(?:[a-z]\w*)?)/i,identifier:/[a-z_](?:-?[a-z]|[\d_])*/i,operator:[{pattern:/( )\.(?= )/,lookbehind:!0},/\.(?:[=~]|\.\.?)|\.(?:[&|^]|<<|>>>?)\.|:(?:=|:=?)|&&|\|[|>]|<(?:<<?<?|--?!?|~~?!?|[|=?])?|>[>=?]?|-(?:->?|>)?|\+\+?|@@?|%%?|\*\*?|!(?:~?=|--?>|~?~>)?|~(?:~?>|=)?|==?|\^\^?|[\/?]/],punctuation:/[(){}\[\]|.,:;`]/},t.languages.livescript["interpolated-string"].inside.interpolation.inside.rest=t.languages.livescript}return XS}var ZS,wM;function Sve(){if(wM)return ZS;wM=1,ZS=e,e.displayName="llvm",e.aliases=[];function e(t){(function(n){n.languages.llvm={comment:/;.*/,string:{pattern:/"[^"]*"/,greedy:!0},boolean:/\b(?:false|true)\b/,variable:/[%@!#](?:(?!\d)(?:[-$.\w]|\\[a-f\d]{2})+|\d+)/i,label:/(?!\d)(?:[-$.\w]|\\[a-f\d]{2})+:/i,type:{pattern:/\b(?:double|float|fp128|half|i[1-9]\d*|label|metadata|ppc_fp128|token|void|x86_fp80|x86_mmx)\b/,alias:"class-name"},keyword:/\b[a-z_][a-z_0-9]*\b/,number:/[+-]?\b\d+(?:\.\d+)?(?:[eE][+-]?\d+)?\b|\b0x[\dA-Fa-f]+\b|\b0xK[\dA-Fa-f]{20}\b|\b0x[ML][\dA-Fa-f]{32}\b|\b0xH[\dA-Fa-f]{4}\b/,punctuation:/[{}[\];(),.!*=<>]/}})(t)}return ZS}var QS,xM;function Eve(){if(xM)return QS;xM=1,QS=e,e.displayName="log",e.aliases=[];function e(t){t.languages.log={string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?![st] | \w)(?:[^'\\\r\n]|\\.)*'/,greedy:!0},exception:{pattern:/(^|[^\w.])[a-z][\w.]*(?:Error|Exception):.*(?:(?:\r\n?|\n)[ \t]*(?:at[ \t].+|\.{3}.*|Caused by:.*))+(?:(?:\r\n?|\n)[ \t]*\.\.\. .*)?/,lookbehind:!0,greedy:!0,alias:["javastacktrace","language-javastacktrace"],inside:t.languages.javastacktrace||{keyword:/\bat\b/,function:/[a-z_][\w$]*(?=\()/,punctuation:/[.:()]/}},level:[{pattern:/\b(?:ALERT|CRIT|CRITICAL|EMERG|EMERGENCY|ERR|ERROR|FAILURE|FATAL|SEVERE)\b/,alias:["error","important"]},{pattern:/\b(?:WARN|WARNING|WRN)\b/,alias:["warning","important"]},{pattern:/\b(?:DISPLAY|INF|INFO|NOTICE|STATUS)\b/,alias:["info","keyword"]},{pattern:/\b(?:DBG|DEBUG|FINE)\b/,alias:["debug","keyword"]},{pattern:/\b(?:FINER|FINEST|TRACE|TRC|VERBOSE|VRB)\b/,alias:["trace","comment"]}],property:{pattern:/((?:^|[\]|])[ \t]*)[a-z_](?:[\w-]|\b\/\b)*(?:[. ]\(?\w(?:[\w-]|\b\/\b)*\)?)*:(?=\s)/im,lookbehind:!0},separator:{pattern:/(^|[^-+])-{3,}|={3,}|\*{3,}|- - /m,lookbehind:!0,alias:"comment"},url:/\b(?:file|ftp|https?):\/\/[^\s|,;'"]*[^\s|,;'">.]/,email:{pattern:/(^|\s)[-\w+.]+@[a-z][a-z0-9-]*(?:\.[a-z][a-z0-9-]*)+(?=\s)/,lookbehind:!0,alias:"url"},"ip-address":{pattern:/\b(?:\d{1,3}(?:\.\d{1,3}){3})\b/,alias:"constant"},"mac-address":{pattern:/\b[a-f0-9]{2}(?::[a-f0-9]{2}){5}\b/i,alias:"constant"},domain:{pattern:/(^|\s)[a-z][a-z0-9-]*(?:\.[a-z][a-z0-9-]*)*\.[a-z][a-z0-9-]+(?=\s)/,lookbehind:!0,alias:"constant"},uuid:{pattern:/\b[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\b/i,alias:"constant"},hash:{pattern:/\b(?:[a-f0-9]{32}){1,2}\b/i,alias:"constant"},"file-path":{pattern:/\b[a-z]:[\\/][^\s|,;:(){}\[\]"']+|(^|[\s:\[\](>|])\.{0,2}\/\w[^\s|,;:(){}\[\]"']*/i,lookbehind:!0,greedy:!0,alias:"string"},date:{pattern:RegExp(/\b\d{4}[-/]\d{2}[-/]\d{2}(?:T(?=\d{1,2}:)|(?=\s\d{1,2}:))/.source+"|"+/\b\d{1,4}[-/ ](?:\d{1,2}|Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)[-/ ]\d{2,4}T?\b/.source+"|"+/\b(?:(?:Fri|Mon|Sat|Sun|Thu|Tue|Wed)(?:\s{1,2}(?:Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep))?|Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)\s{1,2}\d{1,2}\b/.source,"i"),alias:"number"},time:{pattern:/\b\d{1,2}:\d{1,2}:\d{1,2}(?:[.,:]\d+)?(?:\s?[+-]\d{2}:?\d{2}|Z)?\b/,alias:"number"},boolean:/\b(?:false|null|true)\b/i,number:{pattern:/(^|[^.\w])(?:0x[a-f0-9]+|0o[0-7]+|0b[01]+|v?\d[\da-f]*(?:\.\d+)*(?:e[+-]?\d+)?[a-z]{0,3}\b)\b(?!\.\w)/i,lookbehind:!0},operator:/[;:?<=>~/@!$%&+\-|^(){}*#]/,punctuation:/[\[\].,]/}}return QS}var JS,kM;function wve(){if(kM)return JS;kM=1,JS=e,e.displayName="lolcode",e.aliases=[];function e(t){t.languages.lolcode={comment:[/\bOBTW\s[\s\S]*?\sTLDR\b/,/\bBTW.+/],string:{pattern:/"(?::.|[^":])*"/,inside:{variable:/:\{[^}]+\}/,symbol:[/:\([a-f\d]+\)/i,/:\[[^\]]+\]/,/:[)>o":]/]},greedy:!0},number:/(?:\B-)?(?:\b\d+(?:\.\d*)?|\B\.\d+)/,symbol:{pattern:/(^|\s)(?:A )?(?:BUKKIT|NOOB|NUMBAR|NUMBR|TROOF|YARN)(?=\s|,|$)/,lookbehind:!0,inside:{keyword:/A(?=\s)/}},label:{pattern:/((?:^|\s)(?:IM IN YR|IM OUTTA YR) )[a-zA-Z]\w*/,lookbehind:!0,alias:"string"},function:{pattern:/((?:^|\s)(?:HOW IZ I|I IZ|IZ) )[a-zA-Z]\w*/,lookbehind:!0},keyword:[{pattern:/(^|\s)(?:AN|FOUND YR|GIMMEH|GTFO|HAI|HAS A|HOW IZ I|I HAS A|I IZ|IF U SAY SO|IM IN YR|IM OUTTA YR|IS NOW(?: A)?|ITZ(?: A)?|IZ|KTHX|KTHXBYE|LIEK(?: A)?|MAEK|MEBBE|MKAY|NERFIN|NO WAI|O HAI IM|O RLY\?|OIC|OMG|OMGWTF|R|SMOOSH|SRS|TIL|UPPIN|VISIBLE|WILE|WTF\?|YA RLY|YR)(?=\s|,|$)/,lookbehind:!0},/'Z(?=\s|,|$)/],boolean:{pattern:/(^|\s)(?:FAIL|WIN)(?=\s|,|$)/,lookbehind:!0},variable:{pattern:/(^|\s)IT(?=\s|,|$)/,lookbehind:!0},operator:{pattern:/(^|\s)(?:NOT|BOTH SAEM|DIFFRINT|(?:ALL|ANY|BIGGR|BOTH|DIFF|EITHER|MOD|PRODUKT|QUOSHUNT|SMALLR|SUM|WON) OF)(?=\s|,|$)/,lookbehind:!0},punctuation:/\.{3}|…|,|!/}}return JS}var eE,TM;function xve(){if(TM)return eE;TM=1,eE=e,e.displayName="magma",e.aliases=[];function e(t){t.languages.magma={output:{pattern:/^(>.*(?:\r(?:\n|(?!\n))|\n))(?!>)(?:.+|(?:\r(?:\n|(?!\n))|\n)(?!>).*)(?:(?:\r(?:\n|(?!\n))|\n)(?!>).*)*/m,lookbehind:!0,greedy:!0},comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/(^|[^\\"])"(?:[^\r\n\\"]|\\.)*"/,lookbehind:!0,greedy:!0},keyword:/\b(?:_|adj|and|assert|assert2|assert3|assigned|break|by|case|cat|catch|clear|cmpeq|cmpne|continue|declare|default|delete|diff|div|do|elif|else|end|eq|error|eval|exists|exit|for|forall|forward|fprintf|freeze|function|ge|gt|if|iload|import|in|intrinsic|is|join|le|load|local|lt|meet|mod|ne|not|notadj|notin|notsubset|or|print|printf|procedure|quit|random|read|readi|repeat|require|requirege|requirerange|restore|return|save|sdiff|select|subset|then|time|to|try|until|vprint|vprintf|vtime|when|where|while|xor)\b/,boolean:/\b(?:false|true)\b/,generator:{pattern:/\b[a-z_]\w*(?=\s*<)/i,alias:"class-name"},function:/\b[a-z_]\w*(?=\s*\()/i,number:{pattern:/(^|[^\w.]|\.\.)(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?(?:_[a-z]?)?(?=$|[^\w.]|\.\.)/,lookbehind:!0},operator:/->|[-+*/^~!|#=]|:=|\.\./,punctuation:/[()[\]{}<>,;.:]/}}return eE}var tE,AM;function kve(){if(AM)return tE;AM=1,tE=e,e.displayName="makefile",e.aliases=[];function e(t){t.languages.makefile={comment:{pattern:/(^|[^\\])#(?:\\(?:\r\n|[\s\S])|[^\\\r\n])*/,lookbehind:!0},string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},"builtin-target":{pattern:/\.[A-Z][^:#=\s]+(?=\s*:(?!=))/,alias:"builtin"},target:{pattern:/^(?:[^:=\s]|[ \t]+(?![\s:]))+(?=\s*:(?!=))/m,alias:"symbol",inside:{variable:/\$+(?:(?!\$)[^(){}:#=\s]+|(?=[({]))/}},variable:/\$+(?:(?!\$)[^(){}:#=\s]+|\([@*%<^+?][DF]\)|(?=[({]))/,keyword:/-include\b|\b(?:define|else|endef|endif|export|ifn?def|ifn?eq|include|override|private|sinclude|undefine|unexport|vpath)\b/,function:{pattern:/(\()(?:abspath|addsuffix|and|basename|call|dir|error|eval|file|filter(?:-out)?|findstring|firstword|flavor|foreach|guile|if|info|join|lastword|load|notdir|or|origin|patsubst|realpath|shell|sort|strip|subst|suffix|value|warning|wildcard|word(?:list|s)?)(?=[ \t])/,lookbehind:!0},operator:/(?:::|[?:+!])?=|[|@]/,punctuation:/[:;(){}]/}}return tE}var nE,RM;function Tve(){if(RM)return nE;RM=1,nE=e,e.displayName="markdown",e.aliases=["md"];function e(t){(function(n){var r=/(?:\\.|[^\\\n\r]|(?:\n|\r\n?)(?![\r\n]))/.source;function a(m){return m=m.replace(/<inner>/g,function(){return r}),RegExp(/((?:^|[^\\])(?:\\{2})*)/.source+"(?:"+m+")")}var o=/(?:\\.|``(?:[^`\r\n]|`(?!`))+``|`[^`\r\n]+`|[^\\|\r\n`])+/.source,s=/\|?__(?:\|__)+\|?(?:(?:\n|\r\n?)|(?![\s\S]))/.source.replace(/__/g,function(){return o}),l=/\|?[ \t]*:?-{3,}:?[ \t]*(?:\|[ \t]*:?-{3,}:?[ \t]*)+\|?(?:\n|\r\n?)/.source;n.languages.markdown=n.languages.extend("markup",{}),n.languages.insertBefore("markdown","prolog",{"front-matter-block":{pattern:/(^(?:\s*[\r\n])?)---(?!.)[\s\S]*?[\r\n]---(?!.)/,lookbehind:!0,greedy:!0,inside:{punctuation:/^---|---$/,"front-matter":{pattern:/\S+(?:\s+\S+)*/,alias:["yaml","language-yaml"],inside:n.languages.yaml}}},blockquote:{pattern:/^>(?:[\t ]*>)*/m,alias:"punctuation"},table:{pattern:RegExp("^"+s+l+"(?:"+s+")*","m"),inside:{"table-data-rows":{pattern:RegExp("^("+s+l+")(?:"+s+")*$"),lookbehind:!0,inside:{"table-data":{pattern:RegExp(o),inside:n.languages.markdown},punctuation:/\|/}},"table-line":{pattern:RegExp("^("+s+")"+l+"$"),lookbehind:!0,inside:{punctuation:/\||:?-{3,}:?/}},"table-header-row":{pattern:RegExp("^"+s+"$"),inside:{"table-header":{pattern:RegExp(o),alias:"important",inside:n.languages.markdown},punctuation:/\|/}}}},code:[{pattern:/((?:^|\n)[ \t]*\n|(?:^|\r\n?)[ \t]*\r\n?)(?: {4}|\t).+(?:(?:\n|\r\n?)(?: {4}|\t).+)*/,lookbehind:!0,alias:"keyword"},{pattern:/^```[\s\S]*?^```$/m,greedy:!0,inside:{"code-block":{pattern:/^(```.*(?:\n|\r\n?))[\s\S]+?(?=(?:\n|\r\n?)^```$)/m,lookbehind:!0},"code-language":{pattern:/^(```).+/,lookbehind:!0},punctuation:/```/}}],title:[{pattern:/\S.*(?:\n|\r\n?)(?:==+|--+)(?=[ \t]*$)/m,alias:"important",inside:{punctuation:/==+$|--+$/}},{pattern:/(^\s*)#.+/m,lookbehind:!0,alias:"important",inside:{punctuation:/^#+|#+$/}}],hr:{pattern:/(^\s*)([*-])(?:[\t ]*\2){2,}(?=\s*$)/m,lookbehind:!0,alias:"punctuation"},list:{pattern:/(^\s*)(?:[*+-]|\d+\.)(?=[\t ].)/m,lookbehind:!0,alias:"punctuation"},"url-reference":{pattern:/!?\[[^\]]+\]:[\t ]+(?:\S+|<(?:\\.|[^>\\])+>)(?:[\t ]+(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\)))?/,inside:{variable:{pattern:/^(!?\[)[^\]]+/,lookbehind:!0},string:/(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\))$/,punctuation:/^[\[\]!:]|[<>]/},alias:"url"},bold:{pattern:a(/\b__(?:(?!_)<inner>|_(?:(?!_)<inner>)+_)+__\b|\*\*(?:(?!\*)<inner>|\*(?:(?!\*)<inner>)+\*)+\*\*/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^..)[\s\S]+(?=..$)/,lookbehind:!0,inside:{}},punctuation:/\*\*|__/}},italic:{pattern:a(/\b_(?:(?!_)<inner>|__(?:(?!_)<inner>)+__)+_\b|\*(?:(?!\*)<inner>|\*\*(?:(?!\*)<inner>)+\*\*)+\*/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^.)[\s\S]+(?=.$)/,lookbehind:!0,inside:{}},punctuation:/[*_]/}},strike:{pattern:a(/(~~?)(?:(?!~)<inner>)+\2/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^~~?)[\s\S]+(?=\1$)/,lookbehind:!0,inside:{}},punctuation:/~~?/}},"code-snippet":{pattern:/(^|[^\\`])(?:``[^`\r\n]+(?:`[^`\r\n]+)*``(?!`)|`[^`\r\n]+`(?!`))/,lookbehind:!0,greedy:!0,alias:["code","keyword"]},url:{pattern:a(/!?\[(?:(?!\])<inner>)+\](?:\([^\s)]+(?:[\t ]+"(?:\\.|[^"\\])*")?\)|[ \t]?\[(?:(?!\])<inner>)+\])/.source),lookbehind:!0,greedy:!0,inside:{operator:/^!/,content:{pattern:/(^\[)[^\]]+(?=\])/,lookbehind:!0,inside:{}},variable:{pattern:/(^\][ \t]?\[)[^\]]+(?=\]$)/,lookbehind:!0},url:{pattern:/(^\]\()[^\s)]+/,lookbehind:!0},string:{pattern:/(^[ \t]+)"(?:\\.|[^"\\])*"(?=\)$)/,lookbehind:!0}}}}),["url","bold","italic","strike"].forEach(function(m){["url","bold","italic","strike","code-snippet"].forEach(function(b){m!==b&&(n.languages.markdown[m].inside.content.inside[b]=n.languages.markdown[b])})}),n.hooks.add("after-tokenize",function(m){if(m.language!=="markdown"&&m.language!=="md")return;function b(v){if(!(!v||typeof v=="string"))for(var y=0,k=v.length;y<k;y++){var A=v[y];if(A.type!=="code"){b(A.content);continue}var x=A.content[1],R=A.content[3];if(x&&R&&x.type==="code-language"&&R.type==="code-block"&&typeof x.content=="string"){var O=x.content.replace(/\b#/g,"sharp").replace(/\b\+\+/g,"pp");O=(/[a-z][\w-]*/i.exec(O)||[""])[0].toLowerCase();var N="language-"+O;R.alias?typeof R.alias=="string"?R.alias=[R.alias,N]:R.alias.push(N):R.alias=[N]}}}b(m.tokens)}),n.hooks.add("wrap",function(m){if(m.type==="code-block"){for(var b="",v=0,y=m.classes.length;v<y;v++){var k=m.classes[v],A=/language-(.+)/.exec(k);if(A){b=A[1];break}}var x=n.languages[b];if(x)m.content=n.highlight(g(m.content.value),x,b);else if(b&&b!=="none"&&n.plugins.autoloader){var R="md-"+new Date().valueOf()+"-"+Math.floor(Math.random()*1e16);m.attributes.id=R,n.plugins.autoloader.loadLanguages(b,function(){var O=document.getElementById(R);O&&(O.innerHTML=n.highlight(O.textContent,n.languages[b],b))})}}});var u=RegExp(n.languages.markup.tag.pattern.source,"gi"),d={amp:"&",lt:"<",gt:">",quot:'"'},p=String.fromCodePoint||String.fromCharCode;function g(m){var b=m.replace(u,"");return b=b.replace(/&(\w{1,8}|#x?[\da-f]{1,8});/gi,function(v,y){if(y=y.toLowerCase(),y[0]==="#"){var k;return y[1]==="x"?k=parseInt(y.slice(2),16):k=Number(y.slice(1)),p(k)}else{var A=d[y];return A||v}}),b}n.languages.md=n.languages.markdown})(t)}return nE}var rE,CM;function Ave(){if(CM)return rE;CM=1,rE=e,e.displayName="matlab",e.aliases=[];function e(t){t.languages.matlab={comment:[/%\{[\s\S]*?\}%/,/%.+/],string:{pattern:/\B'(?:''|[^'\r\n])*'/,greedy:!0},number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+)?(?:[ij])?|\b[ij]\b/,keyword:/\b(?:NaN|break|case|catch|continue|else|elseif|end|for|function|if|inf|otherwise|parfor|pause|pi|return|switch|try|while)\b/,function:/\b(?!\d)\w+(?=\s*\()/,operator:/\.?[*^\/\\']|[+\-:@]|[<>=~]=?|&&?|\|\|?/,punctuation:/\.{3}|[.,;\[\](){}!]/}}return rE}var aE,_M;function Rve(){if(_M)return aE;_M=1,aE=e,e.displayName="maxscript",e.aliases=[];function e(t){(function(n){var r=/\b(?:about|and|animate|as|at|attributes|by|case|catch|collect|continue|coordsys|do|else|exit|fn|for|from|function|global|if|in|local|macroscript|mapped|max|not|of|off|on|or|parameters|persistent|plugin|rcmenu|return|rollout|set|struct|then|throw|to|tool|try|undo|utility|when|where|while|with)\b/i;n.languages.maxscript={comment:{pattern:/\/\*[\s\S]*?(?:\*\/|$)|--.*/,greedy:!0},string:{pattern:/(^|[^"\\@])(?:"(?:[^"\\]|\\[\s\S])*"|@"[^"]*")/,lookbehind:!0,greedy:!0},path:{pattern:/\$(?:[\w/\\.*?]|'[^']*')*/,greedy:!0,alias:"string"},"function-call":{pattern:RegExp("((?:"+(/^/.source+"|"+/[;=<>+\-*/^({\[]/.source+"|"+/\b(?:and|by|case|catch|collect|do|else|if|in|not|or|return|then|to|try|where|while|with)\b/.source)+")[ 	]*)(?!"+r.source+")"+/[a-z_]\w*\b/.source+"(?=[ 	]*(?:"+("(?!"+r.source+")"+/[a-z_]/.source+"|"+/\d|-\.?\d/.source+"|"+/[({'"$@#?]/.source)+"))","im"),lookbehind:!0,greedy:!0,alias:"function"},"function-definition":{pattern:/(\b(?:fn|function)\s+)\w+\b/i,lookbehind:!0,alias:"function"},argument:{pattern:/\b[a-z_]\w*(?=:)/i,alias:"attr-name"},keyword:r,boolean:/\b(?:false|true)\b/,time:{pattern:/(^|[^\w.])(?:(?:(?:\d+(?:\.\d*)?|\.\d+)(?:[eEdD][+-]\d+|[LP])?[msft])+|\d+:\d+(?:\.\d*)?)(?![\w.:])/,lookbehind:!0,alias:"number"},number:[{pattern:/(^|[^\w.])(?:(?:\d+(?:\.\d*)?|\.\d+)(?:[eEdD][+-]\d+|[LP])?|0x[a-fA-F0-9]+)(?![\w.:])/,lookbehind:!0},/\b(?:e|pi)\b/],constant:/\b(?:dontcollect|ok|silentValue|undefined|unsupplied)\b/,color:{pattern:/\b(?:black|blue|brown|gray|green|orange|red|white|yellow)\b/i,alias:"constant"},operator:/[-+*/<>=!]=?|[&^?]|#(?!\()/,punctuation:/[()\[\]{}.:,;]|#(?=\()|\\$/m}})(t)}return aE}var oE,NM;function Cve(){if(NM)return oE;NM=1,oE=e,e.displayName="mel",e.aliases=[];function e(t){t.languages.mel={comment:/\/\/.*/,code:{pattern:/`(?:\\.|[^\\`\r\n])*`/,greedy:!0,alias:"italic",inside:{delimiter:{pattern:/^`|`$/,alias:"punctuation"}}},string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},variable:/\$\w+/,number:/\b0x[\da-fA-F]+\b|\b\d+(?:\.\d*)?|\B\.\d+/,flag:{pattern:/-[^\d\W]\w*/,alias:"operator"},keyword:/\b(?:break|case|continue|default|do|else|float|for|global|if|in|int|matrix|proc|return|string|switch|vector|while)\b/,function:/\b\w+(?=\()|\b(?:CBG|HfAddAttractorToAS|HfAssignAS|HfBuildEqualMap|HfBuildFurFiles|HfBuildFurImages|HfCancelAFR|HfConnectASToHF|HfCreateAttractor|HfDeleteAS|HfEditAS|HfPerformCreateAS|HfRemoveAttractorFromAS|HfSelectAttached|HfSelectAttractors|HfUnAssignAS|Mayatomr|about|abs|addAttr|addAttributeEditorNodeHelp|addDynamic|addNewShelfTab|addPP|addPanelCategory|addPrefixToName|advanceToNextDrivenKey|affectedNet|affects|aimConstraint|air|alias|aliasAttr|align|alignCtx|alignCurve|alignSurface|allViewFit|ambientLight|angle|angleBetween|animCone|animCurveEditor|animDisplay|animView|annotate|appendStringArray|applicationName|applyAttrPreset|applyTake|arcLenDimContext|arcLengthDimension|arclen|arrayMapper|art3dPaintCtx|artAttrCtx|artAttrPaintVertexCtx|artAttrSkinPaintCtx|artAttrTool|artBuildPaintMenu|artFluidAttrCtx|artPuttyCtx|artSelectCtx|artSetPaintCtx|artUserPaintCtx|assignCommand|assignInputDevice|assignViewportFactories|attachCurve|attachDeviceAttr|attachSurface|attrColorSliderGrp|attrCompatibility|attrControlGrp|attrEnumOptionMenu|attrEnumOptionMenuGrp|attrFieldGrp|attrFieldSliderGrp|attrNavigationControlGrp|attrPresetEditWin|attributeExists|attributeInfo|attributeMenu|attributeQuery|autoKeyframe|autoPlace|bakeClip|bakeFluidShading|bakePartialHistory|bakeResults|bakeSimulation|basename|basenameEx|batchRender|bessel|bevel|bevelPlus|binMembership|bindSkin|blend2|blendShape|blendShapeEditor|blendShapePanel|blendTwoAttr|blindDataType|boneLattice|boundary|boxDollyCtx|boxZoomCtx|bufferCurve|buildBookmarkMenu|buildKeyframeMenu|button|buttonManip|cacheFile|cacheFileCombine|cacheFileMerge|cacheFileTrack|camera|cameraView|canCreateManip|canvas|capitalizeString|catch|catchQuiet|ceil|changeSubdivComponentDisplayLevel|changeSubdivRegion|channelBox|character|characterMap|characterOutlineEditor|characterize|chdir|checkBox|checkBoxGrp|checkDefaultRenderGlobals|choice|circle|circularFillet|clamp|clear|clearCache|clip|clipEditor|clipEditorCurrentTimeCtx|clipSchedule|clipSchedulerOutliner|clipTrimBefore|closeCurve|closeSurface|cluster|cmdFileOutput|cmdScrollFieldExecuter|cmdScrollFieldReporter|cmdShell|coarsenSubdivSelectionList|collision|color|colorAtPoint|colorEditor|colorIndex|colorIndexSliderGrp|colorSliderButtonGrp|colorSliderGrp|columnLayout|commandEcho|commandLine|commandPort|compactHairSystem|componentEditor|compositingInterop|computePolysetVolume|condition|cone|confirmDialog|connectAttr|connectControl|connectDynamic|connectJoint|connectionInfo|constrain|constrainValue|constructionHistory|container|containsMultibyte|contextInfo|control|convertFromOldLayers|convertIffToPsd|convertLightmap|convertSolidTx|convertTessellation|convertUnit|copyArray|copyFlexor|copyKey|copySkinWeights|cos|cpButton|cpCache|cpClothSet|cpCollision|cpConstraint|cpConvClothToMesh|cpForces|cpGetSolverAttr|cpPanel|cpProperty|cpRigidCollisionFilter|cpSeam|cpSetEdit|cpSetSolverAttr|cpSolver|cpSolverTypes|cpTool|cpUpdateClothUVs|createDisplayLayer|createDrawCtx|createEditor|createLayeredPsdFile|createMotionField|createNewShelf|createNode|createRenderLayer|createSubdivRegion|cross|crossProduct|ctxAbort|ctxCompletion|ctxEditMode|ctxTraverse|currentCtx|currentTime|currentTimeCtx|currentUnit|curve|curveAddPtCtx|curveCVCtx|curveEPCtx|curveEditorCtx|curveIntersect|curveMoveEPCtx|curveOnSurface|curveSketchCtx|cutKey|cycleCheck|cylinder|dagPose|date|defaultLightListCheckBox|defaultNavigation|defineDataServer|defineVirtualDevice|deformer|deg_to_rad|delete|deleteAttr|deleteShadingGroupsAndMaterials|deleteShelfTab|deleteUI|deleteUnusedBrushes|delrandstr|detachCurve|detachDeviceAttr|detachSurface|deviceEditor|devicePanel|dgInfo|dgdirty|dgeval|dgtimer|dimWhen|directKeyCtx|directionalLight|dirmap|dirname|disable|disconnectAttr|disconnectJoint|diskCache|displacementToPoly|displayAffected|displayColor|displayCull|displayLevelOfDetail|displayPref|displayRGBColor|displaySmoothness|displayStats|displayString|displaySurface|distanceDimContext|distanceDimension|doBlur|dolly|dollyCtx|dopeSheetEditor|dot|dotProduct|doubleProfileBirailSurface|drag|dragAttrContext|draggerContext|dropoffLocator|duplicate|duplicateCurve|duplicateSurface|dynCache|dynControl|dynExport|dynExpression|dynGlobals|dynPaintEditor|dynParticleCtx|dynPref|dynRelEdPanel|dynRelEditor|dynamicLoad|editAttrLimits|editDisplayLayerGlobals|editDisplayLayerMembers|editRenderLayerAdjustment|editRenderLayerGlobals|editRenderLayerMembers|editor|editorTemplate|effector|emit|emitter|enableDevice|encodeString|endString|endsWith|env|equivalent|equivalentTol|erf|error|eval|evalDeferred|evalEcho|event|exactWorldBoundingBox|exclusiveLightCheckBox|exec|executeForEachObject|exists|exp|expression|expressionEditorListen|extendCurve|extendSurface|extrude|fcheck|fclose|feof|fflush|fgetline|fgetword|file|fileBrowserDialog|fileDialog|fileExtension|fileInfo|filetest|filletCurve|filter|filterCurve|filterExpand|filterStudioImport|findAllIntersections|findAnimCurves|findKeyframe|findMenuItem|findRelatedSkinCluster|finder|firstParentOf|fitBspline|flexor|floatEq|floatField|floatFieldGrp|floatScrollBar|floatSlider|floatSlider2|floatSliderButtonGrp|floatSliderGrp|floor|flow|fluidCacheInfo|fluidEmitter|fluidVoxelInfo|flushUndo|fmod|fontDialog|fopen|formLayout|format|fprint|frameLayout|fread|freeFormFillet|frewind|fromNativePath|fwrite|gamma|gauss|geometryConstraint|getApplicationVersionAsFloat|getAttr|getClassification|getDefaultBrush|getFileList|getFluidAttr|getInputDeviceRange|getMayaPanelTypes|getModifiers|getPanel|getParticleAttr|getPluginResource|getenv|getpid|glRender|glRenderEditor|globalStitch|gmatch|goal|gotoBindPose|grabColor|gradientControl|gradientControlNoAttr|graphDollyCtx|graphSelectContext|graphTrackCtx|gravity|grid|gridLayout|group|groupObjectsByName|hardenPointCurve|hardware|hardwareRenderPanel|headsUpDisplay|headsUpMessage|help|helpLine|hermite|hide|hilite|hitTest|hotBox|hotkey|hotkeyCheck|hsv_to_rgb|hudButton|hudSlider|hudSliderButton|hwReflectionMap|hwRender|hwRenderLoad|hyperGraph|hyperPanel|hyperShade|hypot|iconTextButton|iconTextCheckBox|iconTextRadioButton|iconTextRadioCollection|iconTextScrollList|iconTextStaticLabel|ikHandle|ikHandleCtx|ikHandleDisplayScale|ikSolver|ikSplineHandleCtx|ikSystem|ikSystemInfo|ikfkDisplayMethod|illustratorCurves|image|imfPlugins|inheritTransform|insertJoint|insertJointCtx|insertKeyCtx|insertKnotCurve|insertKnotSurface|instance|instanceable|instancer|intField|intFieldGrp|intScrollBar|intSlider|intSliderGrp|interToUI|internalVar|intersect|iprEngine|isAnimCurve|isConnected|isDirty|isParentOf|isSameObject|isTrue|isValidObjectName|isValidString|isValidUiName|isolateSelect|itemFilter|itemFilterAttr|itemFilterRender|itemFilterType|joint|jointCluster|jointCtx|jointDisplayScale|jointLattice|keyTangent|keyframe|keyframeOutliner|keyframeRegionCurrentTimeCtx|keyframeRegionDirectKeyCtx|keyframeRegionDollyCtx|keyframeRegionInsertKeyCtx|keyframeRegionMoveKeyCtx|keyframeRegionScaleKeyCtx|keyframeRegionSelectKeyCtx|keyframeRegionSetKeyCtx|keyframeRegionTrackCtx|keyframeStats|lassoContext|lattice|latticeDeformKeyCtx|launch|launchImageEditor|layerButton|layeredShaderPort|layeredTexturePort|layout|layoutDialog|lightList|lightListEditor|lightListPanel|lightlink|lineIntersection|linearPrecision|linstep|listAnimatable|listAttr|listCameras|listConnections|listDeviceAttachments|listHistory|listInputDeviceAxes|listInputDeviceButtons|listInputDevices|listMenuAnnotation|listNodeTypes|listPanelCategories|listRelatives|listSets|listTransforms|listUnselected|listerEditor|loadFluid|loadNewShelf|loadPlugin|loadPluginLanguageResources|loadPrefObjects|localizedPanelLabel|lockNode|loft|log|longNameOf|lookThru|ls|lsThroughFilter|lsType|lsUI|mag|makeIdentity|makeLive|makePaintable|makeRoll|makeSingleSurface|makeTubeOn|makebot|manipMoveContext|manipMoveLimitsCtx|manipOptions|manipRotateContext|manipRotateLimitsCtx|manipScaleContext|manipScaleLimitsCtx|marker|match|max|memory|menu|menuBarLayout|menuEditor|menuItem|menuItemToShelf|menuSet|menuSetPref|messageLine|min|minimizeApp|mirrorJoint|modelCurrentTimeCtx|modelEditor|modelPanel|mouse|movIn|movOut|move|moveIKtoFK|moveKeyCtx|moveVertexAlongDirection|multiProfileBirailSurface|mute|nParticle|nameCommand|nameField|namespace|namespaceInfo|newPanelItems|newton|nodeCast|nodeIconButton|nodeOutliner|nodePreset|nodeType|noise|nonLinear|normalConstraint|normalize|nurbsBoolean|nurbsCopyUVSet|nurbsCube|nurbsEditUV|nurbsPlane|nurbsSelect|nurbsSquare|nurbsToPoly|nurbsToPolygonsPref|nurbsToSubdiv|nurbsToSubdivPref|nurbsUVSet|nurbsViewDirectionVector|objExists|objectCenter|objectLayer|objectType|objectTypeUI|obsoleteProc|oceanNurbsPreviewPlane|offsetCurve|offsetCurveOnSurface|offsetSurface|openGLExtension|openMayaPref|optionMenu|optionMenuGrp|optionVar|orbit|orbitCtx|orientConstraint|outlinerEditor|outlinerPanel|overrideModifier|paintEffectsDisplay|pairBlend|palettePort|paneLayout|panel|panelConfiguration|panelHistory|paramDimContext|paramDimension|paramLocator|parent|parentConstraint|particle|particleExists|particleInstancer|particleRenderInfo|partition|pasteKey|pathAnimation|pause|pclose|percent|performanceOptions|pfxstrokes|pickWalk|picture|pixelMove|planarSrf|plane|play|playbackOptions|playblast|plugAttr|plugNode|pluginInfo|pluginResourceUtil|pointConstraint|pointCurveConstraint|pointLight|pointMatrixMult|pointOnCurve|pointOnSurface|pointPosition|poleVectorConstraint|polyAppend|polyAppendFacetCtx|polyAppendVertex|polyAutoProjection|polyAverageNormal|polyAverageVertex|polyBevel|polyBlendColor|polyBlindData|polyBoolOp|polyBridgeEdge|polyCacheMonitor|polyCheck|polyChipOff|polyClipboard|polyCloseBorder|polyCollapseEdge|polyCollapseFacet|polyColorBlindData|polyColorDel|polyColorPerVertex|polyColorSet|polyCompare|polyCone|polyCopyUV|polyCrease|polyCreaseCtx|polyCreateFacet|polyCreateFacetCtx|polyCube|polyCut|polyCutCtx|polyCylinder|polyCylindricalProjection|polyDelEdge|polyDelFacet|polyDelVertex|polyDuplicateAndConnect|polyDuplicateEdge|polyEditUV|polyEditUVShell|polyEvaluate|polyExtrudeEdge|polyExtrudeFacet|polyExtrudeVertex|polyFlipEdge|polyFlipUV|polyForceUV|polyGeoSampler|polyHelix|polyInfo|polyInstallAction|polyLayoutUV|polyListComponentConversion|polyMapCut|polyMapDel|polyMapSew|polyMapSewMove|polyMergeEdge|polyMergeEdgeCtx|polyMergeFacet|polyMergeFacetCtx|polyMergeUV|polyMergeVertex|polyMirrorFace|polyMoveEdge|polyMoveFacet|polyMoveFacetUV|polyMoveUV|polyMoveVertex|polyNormal|polyNormalPerVertex|polyNormalizeUV|polyOptUvs|polyOptions|polyOutput|polyPipe|polyPlanarProjection|polyPlane|polyPlatonicSolid|polyPoke|polyPrimitive|polyPrism|polyProjection|polyPyramid|polyQuad|polyQueryBlindData|polyReduce|polySelect|polySelectConstraint|polySelectConstraintMonitor|polySelectCtx|polySelectEditCtx|polySeparate|polySetToFaceNormal|polySewEdge|polyShortestPathCtx|polySmooth|polySoftEdge|polySphere|polySphericalProjection|polySplit|polySplitCtx|polySplitEdge|polySplitRing|polySplitVertex|polyStraightenUVBorder|polySubdivideEdge|polySubdivideFacet|polyToSubdiv|polyTorus|polyTransfer|polyTriangulate|polyUVSet|polyUnite|polyWedgeFace|popen|popupMenu|pose|pow|preloadRefEd|print|progressBar|progressWindow|projFileViewer|projectCurve|projectTangent|projectionContext|projectionManip|promptDialog|propModCtx|propMove|psdChannelOutliner|psdEditTextureFile|psdExport|psdTextureFile|putenv|pwd|python|querySubdiv|quit|rad_to_deg|radial|radioButton|radioButtonGrp|radioCollection|radioMenuItemCollection|rampColorPort|rand|randomizeFollicles|randstate|rangeControl|readTake|rebuildCurve|rebuildSurface|recordAttr|recordDevice|redo|reference|referenceEdit|referenceQuery|refineSubdivSelectionList|refresh|refreshAE|registerPluginResource|rehash|reloadImage|removeJoint|removeMultiInstance|removePanelCategory|rename|renameAttr|renameSelectionList|renameUI|render|renderGlobalsNode|renderInfo|renderLayerButton|renderLayerParent|renderLayerPostProcess|renderLayerUnparent|renderManip|renderPartition|renderQualityNode|renderSettings|renderThumbnailUpdate|renderWindowEditor|renderWindowSelectContext|renderer|reorder|reorderDeformers|requires|reroot|resampleFluid|resetAE|resetPfxToPolyCamera|resetTool|resolutionNode|retarget|reverseCurve|reverseSurface|revolve|rgb_to_hsv|rigidBody|rigidSolver|roll|rollCtx|rootOf|rot|rotate|rotationInterpolation|roundConstantRadius|rowColumnLayout|rowLayout|runTimeCommand|runup|sampleImage|saveAllShelves|saveAttrPreset|saveFluid|saveImage|saveInitialState|saveMenu|savePrefObjects|savePrefs|saveShelf|saveToolSettings|scale|scaleBrushBrightness|scaleComponents|scaleConstraint|scaleKey|scaleKeyCtx|sceneEditor|sceneUIReplacement|scmh|scriptCtx|scriptEditorInfo|scriptJob|scriptNode|scriptTable|scriptToShelf|scriptedPanel|scriptedPanelType|scrollField|scrollLayout|sculpt|searchPathArray|seed|selLoadSettings|select|selectContext|selectCurveCV|selectKey|selectKeyCtx|selectKeyframeRegionCtx|selectMode|selectPref|selectPriority|selectType|selectedNodes|selectionConnection|separator|setAttr|setAttrEnumResource|setAttrMapping|setAttrNiceNameResource|setConstraintRestPosition|setDefaultShadingGroup|setDrivenKeyframe|setDynamic|setEditCtx|setEditor|setFluidAttr|setFocus|setInfinity|setInputDeviceMapping|setKeyCtx|setKeyPath|setKeyframe|setKeyframeBlendshapeTargetWts|setMenuMode|setNodeNiceNameResource|setNodeTypeFlag|setParent|setParticleAttr|setPfxToPolyCamera|setPluginResource|setProject|setStampDensity|setStartupMessage|setState|setToolTo|setUITemplate|setXformManip|sets|shadingConnection|shadingGeometryRelCtx|shadingLightRelCtx|shadingNetworkCompare|shadingNode|shapeCompare|shelfButton|shelfLayout|shelfTabLayout|shellField|shortNameOf|showHelp|showHidden|showManipCtx|showSelectionInTitle|showShadingGroupAttrEditor|showWindow|sign|simplify|sin|singleProfileBirailSurface|size|sizeBytes|skinCluster|skinPercent|smoothCurve|smoothTangentSurface|smoothstep|snap2to2|snapKey|snapMode|snapTogetherCtx|snapshot|soft|softMod|softModCtx|sort|sound|soundControl|source|spaceLocator|sphere|sphrand|spotLight|spotLightPreviewPort|spreadSheetEditor|spring|sqrt|squareSurface|srtContext|stackTrace|startString|startsWith|stitchAndExplodeShell|stitchSurface|stitchSurfacePoints|strcmp|stringArrayCatenate|stringArrayContains|stringArrayCount|stringArrayInsertAtIndex|stringArrayIntersector|stringArrayRemove|stringArrayRemoveAtIndex|stringArrayRemoveDuplicates|stringArrayRemoveExact|stringArrayToString|stringToStringArray|strip|stripPrefixFromName|stroke|subdAutoProjection|subdCleanTopology|subdCollapse|subdDuplicateAndConnect|subdEditUV|subdListComponentConversion|subdMapCut|subdMapSewMove|subdMatchTopology|subdMirror|subdToBlind|subdToPoly|subdTransferUVsToCache|subdiv|subdivCrease|subdivDisplaySmoothness|substitute|substituteAllString|substituteGeometry|substring|surface|surfaceSampler|surfaceShaderList|swatchDisplayPort|switchTable|symbolButton|symbolCheckBox|sysFile|system|tabLayout|tan|tangentConstraint|texLatticeDeformContext|texManipContext|texMoveContext|texMoveUVShellContext|texRotateContext|texScaleContext|texSelectContext|texSelectShortestPathCtx|texSmudgeUVContext|texWinToolCtx|text|textCurves|textField|textFieldButtonGrp|textFieldGrp|textManip|textScrollList|textToShelf|textureDisplacePlane|textureHairColor|texturePlacementContext|textureWindow|threadCount|threePointArcCtx|timeControl|timePort|timerX|toNativePath|toggle|toggleAxis|toggleWindowVisibility|tokenize|tokenizeList|tolerance|tolower|toolButton|toolCollection|toolDropped|toolHasOptions|toolPropertyWindow|torus|toupper|trace|track|trackCtx|transferAttributes|transformCompare|transformLimits|translator|trim|trunc|truncateFluidCache|truncateHairCache|tumble|tumbleCtx|turbulence|twoPointArcCtx|uiRes|uiTemplate|unassignInputDevice|undo|undoInfo|ungroup|uniform|unit|unloadPlugin|untangleUV|untitledFileName|untrim|upAxis|updateAE|userCtx|uvLink|uvSnapshot|validateShelfName|vectorize|view2dToolCtx|viewCamera|viewClipPlane|viewFit|viewHeadOn|viewLookAt|viewManip|viewPlace|viewSet|visor|volumeAxis|vortex|waitCursor|warning|webBrowser|webBrowserPrefs|whatIs|window|windowPref|wire|wireContext|workspace|wrinkle|wrinkleContext|writeTake|xbmLangPathList|xform)\b/,operator:[/\+[+=]?|-[-=]?|&&|\|\||[<>]=|[*\/!=]=?|[%^]/,{pattern:/(^|[^<])<(?!<)/,lookbehind:!0},{pattern:/(^|[^>])>(?!>)/,lookbehind:!0}],punctuation:/<<|>>|[.,:;?\[\](){}]/},t.languages.mel.code.inside.rest=t.languages.mel}return oE}var iE,OM;function _ve(){if(OM)return iE;OM=1,iE=e,e.displayName="mermaid",e.aliases=[];function e(t){t.languages.mermaid={comment:{pattern:/%%.*/,greedy:!0},style:{pattern:/^([ \t]*(?:classDef|linkStyle|style)[ \t]+[\w$-]+[ \t]+)\w.*[^\s;]/m,lookbehind:!0,inside:{property:/\b\w[\w-]*(?=[ \t]*:)/,operator:/:/,punctuation:/,/}},"inter-arrow-label":{pattern:/([^<>ox.=-])(?:-[-.]|==)(?![<>ox.=-])[ \t]*(?:"[^"\r\n]*"|[^\s".=-](?:[^\r\n.=-]*[^\s.=-])?)[ \t]*(?:\.+->?|--+[->]|==+[=>])(?![<>ox.=-])/,lookbehind:!0,greedy:!0,inside:{arrow:{pattern:/(?:\.+->?|--+[->]|==+[=>])$/,alias:"operator"},label:{pattern:/^([\s\S]{2}[ \t]*)\S(?:[\s\S]*\S)?/,lookbehind:!0,alias:"property"},"arrow-head":{pattern:/^\S+/,alias:["arrow","operator"]}}},arrow:[{pattern:/(^|[^{}|o.-])[|}][|o](?:--|\.\.)[|o][|{](?![{}|o.-])/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>ox.=-])(?:[<ox](?:==+|--+|-\.*-)[>ox]?|(?:==+|--+|-\.*-)[>ox]|===+|---+|-\.+-)(?![<>ox.=-])/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>()x-])(?:--?(?:>>|[x>)])(?![<>()x])|(?:<<|[x<(])--?(?!-))/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>|*o.-])(?:[*o]--|--[*o]|<\|?(?:--|\.\.)|(?:--|\.\.)\|?>|--|\.\.)(?![<>|*o.-])/,lookbehind:!0,alias:"operator"}],label:{pattern:/(^|[^|<])\|(?:[^\r\n"|]|"[^"\r\n]*")+\|/,lookbehind:!0,greedy:!0,alias:"property"},text:{pattern:/(?:[(\[{]+|\b>)(?:[^\r\n"()\[\]{}]|"[^"\r\n]*")+(?:[)\]}]+|>)/,alias:"string"},string:{pattern:/"[^"\r\n]*"/,greedy:!0},annotation:{pattern:/<<(?:abstract|choice|enumeration|fork|interface|join|service)>>|\[\[(?:choice|fork|join)\]\]/i,alias:"important"},keyword:[{pattern:/(^[ \t]*)(?:action|callback|class|classDef|classDiagram|click|direction|erDiagram|flowchart|gantt|gitGraph|graph|journey|link|linkStyle|pie|requirementDiagram|sequenceDiagram|stateDiagram|stateDiagram-v2|style|subgraph)(?![\w$-])/m,lookbehind:!0,greedy:!0},{pattern:/(^[ \t]*)(?:activate|alt|and|as|autonumber|deactivate|else|end(?:[ \t]+note)?|loop|opt|par|participant|rect|state|note[ \t]+(?:over|(?:left|right)[ \t]+of))(?![\w$-])/im,lookbehind:!0,greedy:!0}],entity:/#[a-z0-9]+;/,operator:{pattern:/(\w[ \t]*)&(?=[ \t]*\w)|:::|:/,lookbehind:!0},punctuation:/[(){};]/}}return iE}var sE,IM;function Nve(){if(IM)return sE;IM=1,sE=e,e.displayName="mizar",e.aliases=[];function e(t){t.languages.mizar={comment:/::.+/,keyword:/@proof\b|\b(?:according|aggregate|all|and|antonym|are|as|associativity|assume|asymmetry|attr|be|begin|being|by|canceled|case|cases|clusters?|coherence|commutativity|compatibility|connectedness|consider|consistency|constructors|contradiction|correctness|def|deffunc|define|definitions?|defpred|do|does|end|environ|equals|ex|exactly|existence|for|from|func|given|hence|hereby|holds|idempotence|identity|iff?|implies|involutiveness|irreflexivity|is|it|let|means|mode|non|not|notations?|now|of|or|otherwise|over|per|pred|prefix|projectivity|proof|provided|qua|reconsider|redefine|reduce|reducibility|reflexivity|registrations?|requirements|reserve|sch|schemes?|section|selector|set|sethood|st|struct|such|suppose|symmetry|synonym|take|that|the|then|theorems?|thesis|thus|to|transitivity|uniqueness|vocabular(?:ies|y)|when|where|with|wrt)\b/,parameter:{pattern:/\$(?:10|\d)/,alias:"variable"},variable:/\b\w+(?=:)/,number:/(?:\b|-)\d+\b/,operator:/\.\.\.|->|&|\.?=/,punctuation:/\(#|#\)|[,:;\[\](){}]/}}return sE}var lE,DM;function Ove(){if(DM)return lE;DM=1,lE=e,e.displayName="mongodb",e.aliases=[];function e(t){(function(n){var r=["$eq","$gt","$gte","$in","$lt","$lte","$ne","$nin","$and","$not","$nor","$or","$exists","$type","$expr","$jsonSchema","$mod","$regex","$text","$where","$geoIntersects","$geoWithin","$near","$nearSphere","$all","$elemMatch","$size","$bitsAllClear","$bitsAllSet","$bitsAnyClear","$bitsAnySet","$comment","$elemMatch","$meta","$slice","$currentDate","$inc","$min","$max","$mul","$rename","$set","$setOnInsert","$unset","$addToSet","$pop","$pull","$push","$pullAll","$each","$position","$slice","$sort","$bit","$addFields","$bucket","$bucketAuto","$collStats","$count","$currentOp","$facet","$geoNear","$graphLookup","$group","$indexStats","$limit","$listLocalSessions","$listSessions","$lookup","$match","$merge","$out","$planCacheStats","$project","$redact","$replaceRoot","$replaceWith","$sample","$set","$skip","$sort","$sortByCount","$unionWith","$unset","$unwind","$setWindowFields","$abs","$accumulator","$acos","$acosh","$add","$addToSet","$allElementsTrue","$and","$anyElementTrue","$arrayElemAt","$arrayToObject","$asin","$asinh","$atan","$atan2","$atanh","$avg","$binarySize","$bsonSize","$ceil","$cmp","$concat","$concatArrays","$cond","$convert","$cos","$dateFromParts","$dateToParts","$dateFromString","$dateToString","$dayOfMonth","$dayOfWeek","$dayOfYear","$degreesToRadians","$divide","$eq","$exp","$filter","$first","$floor","$function","$gt","$gte","$hour","$ifNull","$in","$indexOfArray","$indexOfBytes","$indexOfCP","$isArray","$isNumber","$isoDayOfWeek","$isoWeek","$isoWeekYear","$last","$last","$let","$literal","$ln","$log","$log10","$lt","$lte","$ltrim","$map","$max","$mergeObjects","$meta","$min","$millisecond","$minute","$mod","$month","$multiply","$ne","$not","$objectToArray","$or","$pow","$push","$radiansToDegrees","$range","$reduce","$regexFind","$regexFindAll","$regexMatch","$replaceOne","$replaceAll","$reverseArray","$round","$rtrim","$second","$setDifference","$setEquals","$setIntersection","$setIsSubset","$setUnion","$size","$sin","$slice","$split","$sqrt","$stdDevPop","$stdDevSamp","$strcasecmp","$strLenBytes","$strLenCP","$substr","$substrBytes","$substrCP","$subtract","$sum","$switch","$tan","$toBool","$toDate","$toDecimal","$toDouble","$toInt","$toLong","$toObjectId","$toString","$toLower","$toUpper","$trim","$trunc","$type","$week","$year","$zip","$count","$dateAdd","$dateDiff","$dateSubtract","$dateTrunc","$getField","$rand","$sampleRate","$setField","$unsetField","$comment","$explain","$hint","$max","$maxTimeMS","$min","$orderby","$query","$returnKey","$showDiskLoc","$natural"],a=["ObjectId","Code","BinData","DBRef","Timestamp","NumberLong","NumberDecimal","MaxKey","MinKey","RegExp","ISODate","UUID"];r=r.map(function(s){return s.replace("$","\\$")});var o="(?:"+r.join("|")+")\\b";n.languages.mongodb=n.languages.extend("javascript",{}),n.languages.insertBefore("mongodb","string",{property:{pattern:/(?:(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)(?=\s*:)/,greedy:!0,inside:{keyword:RegExp(`^(['"])?`+o+"(?:\\1)?$")}}}),n.languages.mongodb.string.inside={url:{pattern:/https?:\/\/[-\w@:%.+~#=]{1,256}\.[a-z0-9()]{1,6}\b[-\w()@:%+.~#?&/=]*/i,greedy:!0},entity:{pattern:/\b(?:(?:[01]?\d\d?|2[0-4]\d|25[0-5])\.){3}(?:[01]?\d\d?|2[0-4]\d|25[0-5])\b/,greedy:!0}},n.languages.insertBefore("mongodb","constant",{builtin:{pattern:RegExp("\\b(?:"+a.join("|")+")\\b"),alias:"keyword"}})})(t)}return lE}var cE,LM;function Ive(){if(LM)return cE;LM=1,cE=e,e.displayName="monkey",e.aliases=[];function e(t){t.languages.monkey={comment:{pattern:/^#Rem\s[\s\S]*?^#End|'.+/im,greedy:!0},string:{pattern:/"[^"\r\n]*"/,greedy:!0},preprocessor:{pattern:/(^[ \t]*)#.+/m,lookbehind:!0,greedy:!0,alias:"property"},function:/\b\w+(?=\()/,"type-char":{pattern:/\b[?%#$]/,alias:"class-name"},number:{pattern:/((?:\.\.)?)(?:(?:\b|\B-\.?|\B\.)\d+(?:(?!\.\.)\.\d*)?|\$[\da-f]+)/i,lookbehind:!0},keyword:/\b(?:Abstract|Array|Bool|Case|Catch|Class|Const|Continue|Default|Eachin|Else|ElseIf|End|EndIf|Exit|Extends|Extern|False|Field|Final|Float|For|Forever|Function|Global|If|Implements|Import|Inline|Int|Interface|Local|Method|Module|New|Next|Null|Object|Private|Property|Public|Repeat|Return|Select|Self|Step|Strict|String|Super|Then|Throw|To|True|Try|Until|Void|Wend|While)\b/i,operator:/\.\.|<[=>]?|>=?|:?=|(?:[+\-*\/&~|]|\b(?:Mod|Shl|Shr)\b)=?|\b(?:And|Not|Or)\b/i,punctuation:/[.,:;()\[\]]/}}return cE}var uE,MM;function Dve(){if(MM)return uE;MM=1,uE=e,e.displayName="moonscript",e.aliases=["moon"];function e(t){t.languages.moonscript={comment:/--.*/,string:[{pattern:/'[^']*'|\[(=*)\[[\s\S]*?\]\1\]/,greedy:!0},{pattern:/"[^"]*"/,greedy:!0,inside:{interpolation:{pattern:/#\{[^{}]*\}/,inside:{moonscript:{pattern:/(^#\{)[\s\S]+(?=\})/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/#\{|\}/,alias:"punctuation"}}}}}],"class-name":[{pattern:/(\b(?:class|extends)[ \t]+)\w+/,lookbehind:!0},/\b[A-Z]\w*/],keyword:/\b(?:class|continue|do|else|elseif|export|extends|for|from|if|import|in|local|nil|return|self|super|switch|then|unless|using|when|while|with)\b/,variable:/@@?\w*/,property:{pattern:/\b(?!\d)\w+(?=:)|(:)(?!\d)\w+/,lookbehind:!0},function:{pattern:/\b(?:_G|_VERSION|assert|collectgarbage|coroutine\.(?:create|resume|running|status|wrap|yield)|debug\.(?:debug|getfenv|gethook|getinfo|getlocal|getmetatable|getregistry|getupvalue|setfenv|sethook|setlocal|setmetatable|setupvalue|traceback)|dofile|error|getfenv|getmetatable|io\.(?:close|flush|input|lines|open|output|popen|read|stderr|stdin|stdout|tmpfile|type|write)|ipairs|load|loadfile|loadstring|math\.(?:abs|acos|asin|atan|atan2|ceil|cos|cosh|deg|exp|floor|fmod|frexp|ldexp|log|log10|max|min|modf|pi|pow|rad|random|randomseed|sin|sinh|sqrt|tan|tanh)|module|next|os\.(?:clock|date|difftime|execute|exit|getenv|remove|rename|setlocale|time|tmpname)|package\.(?:cpath|loaded|loadlib|path|preload|seeall)|pairs|pcall|print|rawequal|rawget|rawset|require|select|setfenv|setmetatable|string\.(?:byte|char|dump|find|format|gmatch|gsub|len|lower|match|rep|reverse|sub|upper)|table\.(?:concat|insert|maxn|remove|sort)|tonumber|tostring|type|unpack|xpcall)\b/,inside:{punctuation:/\./}},boolean:/\b(?:false|true)\b/,number:/(?:\B\.\d+|\b\d+\.\d+|\b\d+(?=[eE]))(?:[eE][-+]?\d+)?\b|\b(?:0x[a-fA-F\d]+|\d+)(?:U?LL)?\b/,operator:/\.{3}|[-=]>|~=|(?:[-+*/%<>!=]|\.\.)=?|[:#^]|\b(?:and|or)\b=?|\b(?:not)\b/,punctuation:/[.,()[\]{}\\]/},t.languages.moonscript.string[1].inside.interpolation.inside.moonscript.inside=t.languages.moonscript,t.languages.moon=t.languages.moonscript}return uE}var dE,PM;function Lve(){if(PM)return dE;PM=1,dE=e,e.displayName="n1ql",e.aliases=[];function e(t){t.languages.n1ql={comment:{pattern:/\/\*[\s\S]*?(?:$|\*\/)|--.*/,greedy:!0},string:{pattern:/(["'])(?:\\[\s\S]|(?!\1)[^\\]|\1\1)*\1/,greedy:!0},identifier:{pattern:/`(?:\\[\s\S]|[^\\`]|``)*`/,greedy:!0},parameter:/\$[\w.]+/,keyword:/\b(?:ADVISE|ALL|ALTER|ANALYZE|AS|ASC|AT|BEGIN|BINARY|BOOLEAN|BREAK|BUCKET|BUILD|BY|CALL|CAST|CLUSTER|COLLATE|COLLECTION|COMMIT|COMMITTED|CONNECT|CONTINUE|CORRELATE|CORRELATED|COVER|CREATE|CURRENT|DATABASE|DATASET|DATASTORE|DECLARE|DECREMENT|DELETE|DERIVED|DESC|DESCRIBE|DISTINCT|DO|DROP|EACH|ELEMENT|EXCEPT|EXCLUDE|EXECUTE|EXPLAIN|FETCH|FILTER|FLATTEN|FLUSH|FOLLOWING|FOR|FORCE|FROM|FTS|FUNCTION|GOLANG|GRANT|GROUP|GROUPS|GSI|HASH|HAVING|IF|IGNORE|ILIKE|INCLUDE|INCREMENT|INDEX|INFER|INLINE|INNER|INSERT|INTERSECT|INTO|IS|ISOLATION|JAVASCRIPT|JOIN|KEY|KEYS|KEYSPACE|KNOWN|LANGUAGE|LAST|LEFT|LET|LETTING|LEVEL|LIMIT|LSM|MAP|MAPPING|MATCHED|MATERIALIZED|MERGE|MINUS|MISSING|NAMESPACE|NEST|NL|NO|NTH_VALUE|NULL|NULLS|NUMBER|OBJECT|OFFSET|ON|OPTION|OPTIONS|ORDER|OTHERS|OUTER|OVER|PARSE|PARTITION|PASSWORD|PATH|POOL|PRECEDING|PREPARE|PRIMARY|PRIVATE|PRIVILEGE|PROBE|PROCEDURE|PUBLIC|RANGE|RAW|REALM|REDUCE|RENAME|RESPECT|RETURN|RETURNING|REVOKE|RIGHT|ROLE|ROLLBACK|ROW|ROWS|SATISFIES|SAVEPOINT|SCHEMA|SCOPE|SELECT|SELF|SEMI|SET|SHOW|SOME|START|STATISTICS|STRING|SYSTEM|TIES|TO|TRAN|TRANSACTION|TRIGGER|TRUNCATE|UNBOUNDED|UNDER|UNION|UNIQUE|UNKNOWN|UNNEST|UNSET|UPDATE|UPSERT|USE|USER|USING|VALIDATE|VALUE|VALUES|VIA|VIEW|WHERE|WHILE|WINDOW|WITH|WORK|XOR)\b/i,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:FALSE|TRUE)\b/i,number:/(?:\b\d+\.|\B\.)\d+e[+\-]?\d+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,operator:/[-+*\/%]|!=|==?|\|\||<[>=]?|>=?|\b(?:AND|ANY|ARRAY|BETWEEN|CASE|ELSE|END|EVERY|EXISTS|FIRST|IN|LIKE|NOT|OR|THEN|VALUED|WHEN|WITHIN)\b/i,punctuation:/[;[\](),.{}:]/}}return dE}var fE,FM;function Mve(){if(FM)return fE;FM=1,fE=e,e.displayName="n4js",e.aliases=["n4jsd"];function e(t){t.languages.n4js=t.languages.extend("javascript",{keyword:/\b(?:Array|any|boolean|break|case|catch|class|const|constructor|continue|debugger|declare|default|delete|do|else|enum|export|extends|false|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|module|new|null|number|package|private|protected|public|return|set|static|string|super|switch|this|throw|true|try|typeof|var|void|while|with|yield)\b/}),t.languages.insertBefore("n4js","constant",{annotation:{pattern:/@+\w+/,alias:"operator"}}),t.languages.n4jsd=t.languages.n4js}return fE}var pE,zM;function Pve(){if(zM)return pE;zM=1,pE=e,e.displayName="nand2tetrisHdl",e.aliases=[];function e(t){t.languages["nand2tetris-hdl"]={comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,keyword:/\b(?:BUILTIN|CHIP|CLOCKED|IN|OUT|PARTS)\b/,boolean:/\b(?:false|true)\b/,function:/\b[A-Za-z][A-Za-z0-9]*(?=\()/,number:/\b\d+\b/,operator:/=|\.\./,punctuation:/[{}[\];(),:]/}}return pE}var gE,BM;function Fve(){if(BM)return gE;BM=1,gE=e,e.displayName="naniscript",e.aliases=[];function e(t){(function(n){var r=/\{[^\r\n\[\]{}]*\}/,a={"quoted-string":{pattern:/"(?:[^"\\]|\\.)*"/,alias:"operator"},"command-param-id":{pattern:/(\s)\w+:/,lookbehind:!0,alias:"property"},"command-param-value":[{pattern:r,alias:"selector"},{pattern:/([\t ])\S+/,lookbehind:!0,greedy:!0,alias:"operator"},{pattern:/\S(?:.*\S)?/,alias:"operator"}]};n.languages.naniscript={comment:{pattern:/^([\t ]*);.*/m,lookbehind:!0},define:{pattern:/^>.+/m,alias:"tag",inside:{value:{pattern:/(^>\w+[\t ]+)(?!\s)[^{}\r\n]+/,lookbehind:!0,alias:"operator"},key:{pattern:/(^>)\w+/,lookbehind:!0}}},label:{pattern:/^([\t ]*)#[\t ]*\w+[\t ]*$/m,lookbehind:!0,alias:"regex"},command:{pattern:/^([\t ]*)@\w+(?=[\t ]|$).*/m,lookbehind:!0,alias:"function",inside:{"command-name":/^@\w+/,expression:{pattern:r,greedy:!0,alias:"selector"},"command-params":{pattern:/\s*\S[\s\S]*/,inside:a}}},"generic-text":{pattern:/(^[ \t]*)[^#@>;\s].*/m,lookbehind:!0,alias:"punctuation",inside:{"escaped-char":/\\[{}\[\]"]/,expression:{pattern:r,greedy:!0,alias:"selector"},"inline-command":{pattern:/\[[\t ]*\w[^\r\n\[\]]*\]/,greedy:!0,alias:"function",inside:{"command-params":{pattern:/(^\[[\t ]*\w+\b)[\s\S]+(?=\]$)/,lookbehind:!0,inside:a},"command-param-name":{pattern:/^(\[[\t ]*)\w+/,lookbehind:!0,alias:"name"},"start-stop-char":/[\[\]]/}}}}},n.languages.nani=n.languages.naniscript,n.hooks.add("after-tokenize",function(l){var u=l.tokens;u.forEach(function(d){if(typeof d!="string"&&d.type==="generic-text"){var p=s(d);o(p)||(d.type="bad-line",d.content=p)}})});function o(l){for(var u="[]{}",d=[],p=0;p<l.length;p++){var g=l[p],m=u.indexOf(g);if(m!==-1){if(m%2===0)d.push(m+1);else if(d.pop()!==m)return!1}}return d.length===0}function s(l){return typeof l=="string"?l:Array.isArray(l)?l.map(s).join(""):s(l.content)}})(t)}return gE}var hE,jM;function zve(){if(jM)return hE;jM=1,hE=e,e.displayName="nasm",e.aliases=[];function e(t){t.languages.nasm={comment:/;.*$/m,string:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,label:{pattern:/(^\s*)[A-Za-z._?$][\w.?$@~#]*:/m,lookbehind:!0,alias:"function"},keyword:[/\[?BITS (?:16|32|64)\]?/,{pattern:/(^\s*)section\s*[a-z.]+:?/im,lookbehind:!0},/(?:extern|global)[^;\r\n]*/i,/(?:CPU|DEFAULT|FLOAT).*$/m],register:{pattern:/\b(?:st\d|[xyz]mm\d\d?|[cdt]r\d|r\d\d?[bwd]?|[er]?[abcd]x|[abcd][hl]|[er]?(?:bp|di|si|sp)|[cdefgs]s)\b/i,alias:"variable"},number:/(?:\b|(?=\$))(?:0[hx](?:\.[\da-f]+|[\da-f]+(?:\.[\da-f]+)?)(?:p[+-]?\d+)?|\d[\da-f]+[hx]|\$\d[\da-f]*|0[oq][0-7]+|[0-7]+[oq]|0[by][01]+|[01]+[by]|0[dt]\d+|(?:\d+(?:\.\d+)?|\.\d+)(?:\.?e[+-]?\d+)?[dt]?)\b/i,operator:/[\[\]*+\-\/%<>=&|$!]/}}return hE}var mE,UM;function Bve(){if(UM)return mE;UM=1,mE=e,e.displayName="neon",e.aliases=[];function e(t){t.languages.neon={comment:{pattern:/#.*/,greedy:!0},datetime:{pattern:/(^|[[{(=:,\s])\d\d\d\d-\d\d?-\d\d?(?:(?:[Tt]| +)\d\d?:\d\d:\d\d(?:\.\d*)? *(?:Z|[-+]\d\d?(?::?\d\d)?)?)?(?=$|[\]}),\s])/,lookbehind:!0,alias:"number"},key:{pattern:/(^|[[{(,\s])[^,:=[\]{}()'"\s]+(?=\s*:(?:$|[\]}),\s])|\s*=)/,lookbehind:!0,alias:"atrule"},number:{pattern:/(^|[[{(=:,\s])[+-]?(?:0x[\da-fA-F]+|0o[0-7]+|0b[01]+|(?:\d+(?:\.\d*)?|\.?\d+)(?:[eE][+-]?\d+)?)(?=$|[\]}),:=\s])/,lookbehind:!0},boolean:{pattern:/(^|[[{(=:,\s])(?:false|no|true|yes)(?=$|[\]}),:=\s])/i,lookbehind:!0},null:{pattern:/(^|[[{(=:,\s])(?:null)(?=$|[\]}),:=\s])/i,lookbehind:!0,alias:"keyword"},string:{pattern:/(^|[[{(=:,\s])(?:('''|""")\r?\n(?:(?:[^\r\n]|\r?\n(?![\t ]*\2))*\r?\n)?[\t ]*\2|'[^'\r\n]*'|"(?:\\.|[^\\"\r\n])*")/,lookbehind:!0,greedy:!0},literal:{pattern:/(^|[[{(=:,\s])(?:[^#"',:=[\]{}()\s`-]|[:-][^"',=[\]{}()\s])(?:[^,:=\]})(\s]|:(?![\s,\]})]|$)|[ \t]+[^#,:=\]})(\s])*/,lookbehind:!0,alias:"string"},punctuation:/[,:=[\]{}()-]/}}return mE}var bE,GM;function jve(){if(GM)return bE;GM=1,bE=e,e.displayName="nevod",e.aliases=[];function e(t){t.languages.nevod={comment:/\/\/.*|(?:\/\*[\s\S]*?(?:\*\/|$))/,string:{pattern:/(?:"(?:""|[^"])*"(?!")|'(?:''|[^'])*'(?!'))!?\*?/,greedy:!0,inside:{"string-attrs":/!$|!\*$|\*$/}},namespace:{pattern:/(@namespace\s+)[a-zA-Z0-9\-.]+(?=\s*\{)/,lookbehind:!0},pattern:{pattern:/(@pattern\s+)?#?[a-zA-Z0-9\-.]+(?:\s*\(\s*(?:~\s*)?[a-zA-Z0-9\-.]+\s*(?:,\s*(?:~\s*)?[a-zA-Z0-9\-.]*)*\))?(?=\s*=)/,lookbehind:!0,inside:{"pattern-name":{pattern:/^#?[a-zA-Z0-9\-.]+/,alias:"class-name"},fields:{pattern:/\(.*\)/,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},punctuation:/[,()]/,operator:{pattern:/~/,alias:"field-hidden-mark"}}}}},search:{pattern:/(@search\s+|#)[a-zA-Z0-9\-.]+(?:\.\*)?(?=\s*;)/,alias:"function",lookbehind:!0},keyword:/@(?:having|inside|namespace|outside|pattern|require|search|where)\b/,"standard-pattern":{pattern:/\b(?:Alpha|AlphaNum|Any|Blank|End|LineBreak|Num|NumAlpha|Punct|Space|Start|Symbol|Word|WordBreak)\b(?:\([a-zA-Z0-9\-.,\s+]*\))?/,inside:{"standard-pattern-name":{pattern:/^[a-zA-Z0-9\-.]+/,alias:"builtin"},quantifier:{pattern:/\b\d+(?:\s*\+|\s*-\s*\d+)?(?!\w)/,alias:"number"},"standard-pattern-attr":{pattern:/[a-zA-Z0-9\-.]+/,alias:"builtin"},punctuation:/[,()]/}},quantifier:{pattern:/\b\d+(?:\s*\+|\s*-\s*\d+)?(?!\w)/,alias:"number"},operator:[{pattern:/=/,alias:"pattern-def"},{pattern:/&/,alias:"conjunction"},{pattern:/~/,alias:"exception"},{pattern:/\?/,alias:"optionality"},{pattern:/[[\]]/,alias:"repetition"},{pattern:/[{}]/,alias:"variation"},{pattern:/[+_]/,alias:"sequence"},{pattern:/\.{2,3}/,alias:"span"}],"field-capture":[{pattern:/([a-zA-Z0-9\-.]+\s*\()\s*[a-zA-Z0-9\-.]+\s*:\s*[a-zA-Z0-9\-.]+(?:\s*,\s*[a-zA-Z0-9\-.]+\s*:\s*[a-zA-Z0-9\-.]+)*(?=\s*\))/,lookbehind:!0,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},colon:/:/}},{pattern:/[a-zA-Z0-9\-.]+\s*:/,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},colon:/:/}}],punctuation:/[:;,()]/,name:/[a-zA-Z0-9\-.]+/}}return bE}var yE,HM;function Uve(){if(HM)return yE;HM=1,yE=e,e.displayName="nginx",e.aliases=[];function e(t){(function(n){var r=/\$(?:\w[a-z\d]*(?:_[^\x00-\x1F\s"'\\()$]*)?|\{[^}\s"'\\]+\})/i;n.languages.nginx={comment:{pattern:/(^|[\s{};])#.*/,lookbehind:!0,greedy:!0},directive:{pattern:/(^|\s)\w(?:[^;{}"'\\\s]|\\.|"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*'|\s+(?:#.*(?!.)|(?![#\s])))*?(?=\s*[;{])/,lookbehind:!0,greedy:!0,inside:{string:{pattern:/((?:^|[^\\])(?:\\\\)*)(?:"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*')/,lookbehind:!0,greedy:!0,inside:{escape:{pattern:/\\["'\\nrt]/,alias:"entity"},variable:r}},comment:{pattern:/(\s)#.*/,lookbehind:!0,greedy:!0},keyword:{pattern:/^\S+/,greedy:!0},boolean:{pattern:/(\s)(?:off|on)(?!\S)/,lookbehind:!0},number:{pattern:/(\s)\d+[a-z]*(?!\S)/i,lookbehind:!0},variable:r}},punctuation:/[{};]/}})(t)}return yE}var vE,$M;function Gve(){if($M)return vE;$M=1,vE=e,e.displayName="nim",e.aliases=[];function e(t){t.languages.nim={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/(?:\b(?!\d)(?:\w|\\x[89a-fA-F][0-9a-fA-F])+)?(?:"""[\s\S]*?"""(?!")|"(?:\\[\s\S]|""|[^"\\])*")/,greedy:!0},char:{pattern:/'(?:\\(?:\d+|x[\da-fA-F]{0,2}|.)|[^'])'/,greedy:!0},function:{pattern:/(?:(?!\d)(?:\w|\\x[89a-fA-F][0-9a-fA-F])+|`[^`\r\n]+`)\*?(?:\[[^\]]+\])?(?=\s*\()/,greedy:!0,inside:{operator:/\*$/}},identifier:{pattern:/`[^`\r\n]+`/,greedy:!0,inside:{punctuation:/`/}},number:/\b(?:0[xXoObB][\da-fA-F_]+|\d[\d_]*(?:(?!\.\.)\.[\d_]*)?(?:[eE][+-]?\d[\d_]*)?)(?:'?[iuf]\d*)?/,keyword:/\b(?:addr|as|asm|atomic|bind|block|break|case|cast|concept|const|continue|converter|defer|discard|distinct|do|elif|else|end|enum|except|export|finally|for|from|func|generic|if|import|include|interface|iterator|let|macro|method|mixin|nil|object|out|proc|ptr|raise|ref|return|static|template|try|tuple|type|using|var|when|while|with|without|yield)\b/,operator:{pattern:/(^|[({\[](?=\.\.)|(?![({\[]\.).)(?:(?:[=+\-*\/<>@$~&%|!?^:\\]|\.\.|\.(?![)}\]]))+|\b(?:and|div|in|is|isnot|mod|not|notin|of|or|shl|shr|xor)\b)/m,lookbehind:!0},punctuation:/[({\[]\.|\.[)}\]]|[`(){}\[\],:]/}}return vE}var SE,qM;function Hve(){if(qM)return SE;qM=1,SE=e,e.displayName="nix",e.aliases=[];function e(t){t.languages.nix={comment:{pattern:/\/\*[\s\S]*?\*\/|#.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\[\s\S])*"|''(?:(?!'')[\s\S]|''(?:'|\\|\$\{))*''/,greedy:!0,inside:{interpolation:{pattern:/(^|(?:^|(?!'').)[^\\])\$\{(?:[^{}]|\{[^}]*\})*\}/,lookbehind:!0,inside:null}}},url:[/\b(?:[a-z]{3,7}:\/\/)[\w\-+%~\/.:#=?&]+/,{pattern:/([^\/])(?:[\w\-+%~.:#=?&]*(?!\/\/)[\w\-+%~\/.:#=?&])?(?!\/\/)\/[\w\-+%~\/.:#=?&]*/,lookbehind:!0}],antiquotation:{pattern:/\$(?=\{)/,alias:"important"},number:/\b\d+\b/,keyword:/\b(?:assert|builtins|else|if|in|inherit|let|null|or|then|with)\b/,function:/\b(?:abort|add|all|any|attrNames|attrValues|baseNameOf|compareVersions|concatLists|currentSystem|deepSeq|derivation|dirOf|div|elem(?:At)?|fetch(?:Tarball|url)|filter(?:Source)?|fromJSON|genList|getAttr|getEnv|hasAttr|hashString|head|import|intersectAttrs|is(?:Attrs|Bool|Function|Int|List|Null|String)|length|lessThan|listToAttrs|map|mul|parseDrvName|pathExists|read(?:Dir|File)|removeAttrs|replaceStrings|seq|sort|stringLength|sub(?:string)?|tail|throw|to(?:File|JSON|Path|String|XML)|trace|typeOf)\b|\bfoldl'\B/,boolean:/\b(?:false|true)\b/,operator:/[=!<>]=?|\+\+?|\|\||&&|\/\/|->?|[?@]/,punctuation:/[{}()[\].,:;]/},t.languages.nix.string.inside.interpolation.inside=t.languages.nix}return SE}var EE,VM;function $ve(){if(VM)return EE;VM=1,EE=e,e.displayName="nsis",e.aliases=[];function e(t){t.languages.nsis={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|[#;].*)/,lookbehind:!0,greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:{pattern:/(^[\t ]*)(?:Abort|Add(?:BrandingImage|Size)|AdvSplash|Allow(?:RootDirInstall|SkipFiles)|AutoCloseWindow|BG(?:Font|Gradient|Image)|Banner|BrandingText|BringToFront|CRCCheck|Call(?:InstDLL)?|Caption|ChangeUI|CheckBitmap|ClearErrors|CompletedText|ComponentText|CopyFiles|Create(?:Directory|Font|ShortCut)|Delete(?:INISec|INIStr|RegKey|RegValue)?|Detail(?:Print|sButtonText)|Dialer|Dir(?:Text|Var|Verify)|EnableWindow|Enum(?:RegKey|RegValue)|Exch|Exec(?:Shell(?:Wait)?|Wait)?|ExpandEnvStrings|File(?:BufSize|Close|ErrorText|Open|Read|ReadByte|ReadUTF16LE|ReadWord|Seek|Write|WriteByte|WriteUTF16LE|WriteWord)?|Find(?:Close|First|Next|Window)|FlushINI|Get(?:CurInstType|CurrentAddress|DLLVersion(?:Local)?|DlgItem|ErrorLevel|FileTime(?:Local)?|FullPathName|Function(?:Address|End)?|InstDirError|LabelAddress|TempFileName)|Goto|HideWindow|Icon|If(?:Abort|Errors|FileExists|RebootFlag|Silent)|InitPluginsDir|InstProgressFlags|Inst(?:Type(?:GetText|SetText)?)|Install(?:ButtonText|Colors|Dir(?:RegKey)?)|Int(?:64|Ptr)?CmpU?|Int(?:64)?Fmt|Int(?:Ptr)?Op|IsWindow|Lang(?:DLL|String)|License(?:BkColor|Data|ForceSelection|LangString|Text)|LoadLanguageFile|LockWindow|Log(?:Set|Text)|Manifest(?:DPIAware|SupportedOS)|Math|MessageBox|MiscButtonText|NSISdl|Name|Nop|OutFile|PE(?:DllCharacteristics|SubsysVer)|Page(?:Callbacks)?|Pop|Push|Quit|RMDir|Read(?:EnvStr|INIStr|RegDWORD|RegStr)|Reboot|RegDLL|Rename|RequestExecutionLevel|ReserveFile|Return|SearchPath|Section(?:End|GetFlags|GetInstTypes|GetSize|GetText|Group|In|SetFlags|SetInstTypes|SetSize|SetText)?|SendMessage|Set(?:AutoClose|BrandingImage|Compress|Compressor(?:DictSize)?|CtlColors|CurInstType|DatablockOptimize|DateSave|Details(?:Print|View)|ErrorLevel|Errors|FileAttributes|Font|OutPath|Overwrite|PluginUnload|RebootFlag|RegView|ShellVarContext|Silent)|Show(?:InstDetails|UninstDetails|Window)|Silent(?:Install|UnInstall)|Sleep|SpaceTexts|Splash|StartMenu|Str(?:CmpS?|Cpy|Len)|SubCaption|System|UnRegDLL|Unicode|UninstPage|Uninstall(?:ButtonText|Caption|Icon|SubCaption|Text)|UserInfo|VI(?:AddVersionKey|FileVersion|ProductVersion)|VPatch|Var|WindowIcon|Write(?:INIStr|Reg(?:Bin|DWORD|ExpandStr|MultiStr|None|Str)|Uninstaller)|XPStyle|ns(?:Dialogs|Exec))\b/m,lookbehind:!0},property:/\b(?:ARCHIVE|FILE_(?:ATTRIBUTE_ARCHIVE|ATTRIBUTE_NORMAL|ATTRIBUTE_OFFLINE|ATTRIBUTE_READONLY|ATTRIBUTE_SYSTEM|ATTRIBUTE_TEMPORARY)|HK(?:(?:CR|CU|LM)(?:32|64)?|DD|PD|U)|HKEY_(?:CLASSES_ROOT|CURRENT_CONFIG|CURRENT_USER|DYN_DATA|LOCAL_MACHINE|PERFORMANCE_DATA|USERS)|ID(?:ABORT|CANCEL|IGNORE|NO|OK|RETRY|YES)|MB_(?:ABORTRETRYIGNORE|DEFBUTTON1|DEFBUTTON2|DEFBUTTON3|DEFBUTTON4|ICONEXCLAMATION|ICONINFORMATION|ICONQUESTION|ICONSTOP|OK|OKCANCEL|RETRYCANCEL|RIGHT|RTLREADING|SETFOREGROUND|TOPMOST|USERICON|YESNO)|NORMAL|OFFLINE|READONLY|SHCTX|SHELL_CONTEXT|SYSTEM|TEMPORARY|admin|all|auto|both|colored|false|force|hide|highest|lastused|leave|listonly|none|normal|notset|off|on|open|print|show|silent|silentlog|smooth|textonly|true|user)\b/,constant:/\$\{[!\w\.:\^-]+\}|\$\([!\w\.:\^-]+\)/,variable:/\$\w[\w\.]*/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/--?|\+\+?|<=?|>=?|==?=?|&&?|\|\|?|[?*\/~^%]/,punctuation:/[{}[\];(),.:]/,important:{pattern:/(^[\t ]*)!(?:addincludedir|addplugindir|appendfile|cd|define|delfile|echo|else|endif|error|execute|finalize|getdllversion|gettlbversion|if|ifdef|ifmacrodef|ifmacrondef|ifndef|include|insertmacro|macro|macroend|makensis|packhdr|pragma|searchparse|searchreplace|system|tempfile|undef|verbose|warning)\b/im,lookbehind:!0}}}return EE}var wE,WM;function qve(){if(WM)return wE;WM=1;var e=Ci();wE=t,t.displayName="objectivec",t.aliases=["objc"];function t(n){n.register(e),n.languages.objectivec=n.languages.extend("c",{string:{pattern:/@?"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},keyword:/\b(?:asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|in|inline|int|long|register|return|self|short|signed|sizeof|static|struct|super|switch|typedef|typeof|union|unsigned|void|volatile|while)\b|(?:@interface|@end|@implementation|@protocol|@class|@public|@protected|@private|@property|@try|@catch|@finally|@throw|@synthesize|@dynamic|@selector)\b/,operator:/-[->]?|\+\+?|!=?|<<?=?|>>?=?|==?|&&?|\|\|?|[~^%?*\/@]/}),delete n.languages.objectivec["class-name"],n.languages.objc=n.languages.objectivec}return wE}var xE,YM;function Vve(){if(YM)return xE;YM=1,xE=e,e.displayName="ocaml",e.aliases=[];function e(t){t.languages.ocaml={comment:{pattern:/\(\*[\s\S]*?\*\)/,greedy:!0},char:{pattern:/'(?:[^\\\r\n']|\\(?:.|[ox]?[0-9a-f]{1,3}))'/i,greedy:!0},string:[{pattern:/"(?:\\(?:[\s\S]|\r\n)|[^\\\r\n"])*"/,greedy:!0},{pattern:/\{([a-z_]*)\|[\s\S]*?\|\1\}/,greedy:!0}],number:[/\b(?:0b[01][01_]*|0o[0-7][0-7_]*)\b/i,/\b0x[a-f0-9][a-f0-9_]*(?:\.[a-f0-9_]*)?(?:p[+-]?\d[\d_]*)?(?!\w)/i,/\b\d[\d_]*(?:\.[\d_]*)?(?:e[+-]?\d[\d_]*)?(?!\w)/i],directive:{pattern:/\B#\w+/,alias:"property"},label:{pattern:/\B~\w+/,alias:"property"},"type-variable":{pattern:/\B'\w+/,alias:"function"},variant:{pattern:/`\w+/,alias:"symbol"},keyword:/\b(?:as|assert|begin|class|constraint|do|done|downto|else|end|exception|external|for|fun|function|functor|if|in|include|inherit|initializer|lazy|let|match|method|module|mutable|new|nonrec|object|of|open|private|rec|sig|struct|then|to|try|type|val|value|virtual|when|where|while|with)\b/,boolean:/\b(?:false|true)\b/,"operator-like-punctuation":{pattern:/\[[<>|]|[>|]\]|\{<|>\}/,alias:"punctuation"},operator:/\.[.~]|:[=>]|[=<>@^|&+\-*\/$%!?~][!$%&*+\-.\/:<=>?@^|~]*|\b(?:and|asr|land|lor|lsl|lsr|lxor|mod|or)\b/,punctuation:/;;|::|[(){}\[\].,:;#]|\b_\b/}}return xE}var kE,KM;function Wve(){if(KM)return kE;KM=1;var e=Ci();kE=t,t.displayName="opencl",t.aliases=[];function t(n){n.register(e),function(r){r.languages.opencl=r.languages.extend("c",{keyword:/\b(?:(?:__)?(?:constant|global|kernel|local|private|read_only|read_write|write_only)|__attribute__|auto|(?:bool|u?(?:char|int|long|short)|half|quad)(?:2|3|4|8|16)?|break|case|complex|const|continue|(?:double|float)(?:16(?:x(?:1|2|4|8|16))?|1x(?:1|2|4|8|16)|2(?:x(?:1|2|4|8|16))?|3|4(?:x(?:1|2|4|8|16))?|8(?:x(?:1|2|4|8|16))?)?|default|do|else|enum|extern|for|goto|if|imaginary|inline|packed|pipe|register|restrict|return|signed|sizeof|static|struct|switch|typedef|uniform|union|unsigned|void|volatile|while)\b/,number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[fuhl]{0,4}/i,boolean:/\b(?:false|true)\b/,"constant-opencl-kernel":{pattern:/\b(?:CHAR_(?:BIT|MAX|MIN)|CLK_(?:ADDRESS_(?:CLAMP(?:_TO_EDGE)?|NONE|REPEAT)|FILTER_(?:LINEAR|NEAREST)|(?:GLOBAL|LOCAL)_MEM_FENCE|NORMALIZED_COORDS_(?:FALSE|TRUE))|CL_(?:BGRA|(?:HALF_)?FLOAT|INTENSITY|LUMINANCE|A?R?G?B?[Ax]?|(?:(?:UN)?SIGNED|[US]NORM)_(?:INT(?:8|16|32))|UNORM_(?:INT_101010|SHORT_(?:555|565)))|(?:DBL|FLT|HALF)_(?:DIG|EPSILON|(?:MAX|MIN)(?:(?:_10)?_EXP)?|MANT_DIG)|FLT_RADIX|HUGE_VALF?|(?:INT|LONG|SCHAR|SHRT)_(?:MAX|MIN)|INFINITY|MAXFLOAT|M_(?:[12]_PI|2_SQRTPI|E|LN(?:2|10)|LOG(?:2|10)E?|PI(?:_[24])?|SQRT(?:1_2|2))(?:_F|_H)?|NAN|(?:UCHAR|UINT|ULONG|USHRT)_MAX)\b/,alias:"constant"}}),r.languages.insertBefore("opencl","class-name",{"builtin-type":{pattern:/\b(?:_cl_(?:command_queue|context|device_id|event|kernel|mem|platform_id|program|sampler)|cl_(?:image_format|mem_fence_flags)|clk_event_t|event_t|image(?:1d_(?:array_|buffer_)?t|2d_(?:array_(?:depth_|msaa_depth_|msaa_)?|depth_|msaa_depth_|msaa_)?t|3d_t)|intptr_t|ndrange_t|ptrdiff_t|queue_t|reserve_id_t|sampler_t|size_t|uintptr_t)\b/,alias:"keyword"}});var a={"type-opencl-host":{pattern:/\b(?:cl_(?:GLenum|GLint|GLuin|addressing_mode|bitfield|bool|buffer_create_type|build_status|channel_(?:order|type)|(?:u?(?:char|int|long|short)|double|float)(?:2|3|4|8|16)?|command_(?:queue(?:_info|_properties)?|type)|context(?:_info|_properties)?|device_(?:exec_capabilities|fp_config|id|info|local_mem_type|mem_cache_type|type)|(?:event|sampler)(?:_info)?|filter_mode|half|image_info|kernel(?:_info|_work_group_info)?|map_flags|mem(?:_flags|_info|_object_type)?|platform_(?:id|info)|profiling_info|program(?:_build_info|_info)?))\b/,alias:"keyword"},"boolean-opencl-host":{pattern:/\bCL_(?:FALSE|TRUE)\b/,alias:"boolean"},"constant-opencl-host":{pattern:/\bCL_(?:A|ABGR|ADDRESS_(?:CLAMP(?:_TO_EDGE)?|MIRRORED_REPEAT|NONE|REPEAT)|ARGB|BGRA|BLOCKING|BUFFER_CREATE_TYPE_REGION|BUILD_(?:ERROR|IN_PROGRESS|NONE|PROGRAM_FAILURE|SUCCESS)|COMMAND_(?:ACQUIRE_GL_OBJECTS|BARRIER|COPY_(?:BUFFER(?:_RECT|_TO_IMAGE)?|IMAGE(?:_TO_BUFFER)?)|FILL_(?:BUFFER|IMAGE)|MAP(?:_BUFFER|_IMAGE)|MARKER|MIGRATE(?:_SVM)?_MEM_OBJECTS|NATIVE_KERNEL|NDRANGE_KERNEL|READ_(?:BUFFER(?:_RECT)?|IMAGE)|RELEASE_GL_OBJECTS|SVM_(?:FREE|MAP|MEMCPY|MEMFILL|UNMAP)|TASK|UNMAP_MEM_OBJECT|USER|WRITE_(?:BUFFER(?:_RECT)?|IMAGE))|COMPILER_NOT_AVAILABLE|COMPILE_PROGRAM_FAILURE|COMPLETE|CONTEXT_(?:DEVICES|INTEROP_USER_SYNC|NUM_DEVICES|PLATFORM|PROPERTIES|REFERENCE_COUNT)|DEPTH(?:_STENCIL)?|DEVICE_(?:ADDRESS_BITS|AFFINITY_DOMAIN_(?:L[1-4]_CACHE|NEXT_PARTITIONABLE|NUMA)|AVAILABLE|BUILT_IN_KERNELS|COMPILER_AVAILABLE|DOUBLE_FP_CONFIG|ENDIAN_LITTLE|ERROR_CORRECTION_SUPPORT|EXECUTION_CAPABILITIES|EXTENSIONS|GLOBAL_(?:MEM_(?:CACHELINE_SIZE|CACHE_SIZE|CACHE_TYPE|SIZE)|VARIABLE_PREFERRED_TOTAL_SIZE)|HOST_UNIFIED_MEMORY|IL_VERSION|IMAGE(?:2D_MAX_(?:HEIGHT|WIDTH)|3D_MAX_(?:DEPTH|HEIGHT|WIDTH)|_BASE_ADDRESS_ALIGNMENT|_MAX_ARRAY_SIZE|_MAX_BUFFER_SIZE|_PITCH_ALIGNMENT|_SUPPORT)|LINKER_AVAILABLE|LOCAL_MEM_SIZE|LOCAL_MEM_TYPE|MAX_(?:CLOCK_FREQUENCY|COMPUTE_UNITS|CONSTANT_ARGS|CONSTANT_BUFFER_SIZE|GLOBAL_VARIABLE_SIZE|MEM_ALLOC_SIZE|NUM_SUB_GROUPS|ON_DEVICE_(?:EVENTS|QUEUES)|PARAMETER_SIZE|PIPE_ARGS|READ_IMAGE_ARGS|READ_WRITE_IMAGE_ARGS|SAMPLERS|WORK_GROUP_SIZE|WORK_ITEM_DIMENSIONS|WORK_ITEM_SIZES|WRITE_IMAGE_ARGS)|MEM_BASE_ADDR_ALIGN|MIN_DATA_TYPE_ALIGN_SIZE|NAME|NATIVE_VECTOR_WIDTH_(?:CHAR|DOUBLE|FLOAT|HALF|INT|LONG|SHORT)|NOT_(?:AVAILABLE|FOUND)|OPENCL_C_VERSION|PARENT_DEVICE|PARTITION_(?:AFFINITY_DOMAIN|BY_AFFINITY_DOMAIN|BY_COUNTS|BY_COUNTS_LIST_END|EQUALLY|FAILED|MAX_SUB_DEVICES|PROPERTIES|TYPE)|PIPE_MAX_(?:ACTIVE_RESERVATIONS|PACKET_SIZE)|PLATFORM|PREFERRED_(?:GLOBAL_ATOMIC_ALIGNMENT|INTEROP_USER_SYNC|LOCAL_ATOMIC_ALIGNMENT|PLATFORM_ATOMIC_ALIGNMENT|VECTOR_WIDTH_(?:CHAR|DOUBLE|FLOAT|HALF|INT|LONG|SHORT))|PRINTF_BUFFER_SIZE|PROFILE|PROFILING_TIMER_RESOLUTION|QUEUE_(?:ON_(?:DEVICE_(?:MAX_SIZE|PREFERRED_SIZE|PROPERTIES)|HOST_PROPERTIES)|PROPERTIES)|REFERENCE_COUNT|SINGLE_FP_CONFIG|SUB_GROUP_INDEPENDENT_FORWARD_PROGRESS|SVM_(?:ATOMICS|CAPABILITIES|COARSE_GRAIN_BUFFER|FINE_GRAIN_BUFFER|FINE_GRAIN_SYSTEM)|TYPE(?:_ACCELERATOR|_ALL|_CPU|_CUSTOM|_DEFAULT|_GPU)?|VENDOR(?:_ID)?|VERSION)|DRIVER_VERSION|EVENT_(?:COMMAND_(?:EXECUTION_STATUS|QUEUE|TYPE)|CONTEXT|REFERENCE_COUNT)|EXEC_(?:KERNEL|NATIVE_KERNEL|STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)|FILTER_(?:LINEAR|NEAREST)|FLOAT|FP_(?:CORRECTLY_ROUNDED_DIVIDE_SQRT|DENORM|FMA|INF_NAN|ROUND_TO_INF|ROUND_TO_NEAREST|ROUND_TO_ZERO|SOFT_FLOAT)|GLOBAL|HALF_FLOAT|IMAGE_(?:ARRAY_SIZE|BUFFER|DEPTH|ELEMENT_SIZE|FORMAT|FORMAT_MISMATCH|FORMAT_NOT_SUPPORTED|HEIGHT|NUM_MIP_LEVELS|NUM_SAMPLES|ROW_PITCH|SLICE_PITCH|WIDTH)|INTENSITY|INVALID_(?:ARG_INDEX|ARG_SIZE|ARG_VALUE|BINARY|BUFFER_SIZE|BUILD_OPTIONS|COMMAND_QUEUE|COMPILER_OPTIONS|CONTEXT|DEVICE|DEVICE_PARTITION_COUNT|DEVICE_QUEUE|DEVICE_TYPE|EVENT|EVENT_WAIT_LIST|GLOBAL_OFFSET|GLOBAL_WORK_SIZE|GL_OBJECT|HOST_PTR|IMAGE_DESCRIPTOR|IMAGE_FORMAT_DESCRIPTOR|IMAGE_SIZE|KERNEL|KERNEL_ARGS|KERNEL_DEFINITION|KERNEL_NAME|LINKER_OPTIONS|MEM_OBJECT|MIP_LEVEL|OPERATION|PIPE_SIZE|PLATFORM|PROGRAM|PROGRAM_EXECUTABLE|PROPERTY|QUEUE_PROPERTIES|SAMPLER|VALUE|WORK_DIMENSION|WORK_GROUP_SIZE|WORK_ITEM_SIZE)|KERNEL_(?:ARG_(?:ACCESS_(?:NONE|QUALIFIER|READ_ONLY|READ_WRITE|WRITE_ONLY)|ADDRESS_(?:CONSTANT|GLOBAL|LOCAL|PRIVATE|QUALIFIER)|INFO_NOT_AVAILABLE|NAME|TYPE_(?:CONST|NAME|NONE|PIPE|QUALIFIER|RESTRICT|VOLATILE))|ATTRIBUTES|COMPILE_NUM_SUB_GROUPS|COMPILE_WORK_GROUP_SIZE|CONTEXT|EXEC_INFO_SVM_FINE_GRAIN_SYSTEM|EXEC_INFO_SVM_PTRS|FUNCTION_NAME|GLOBAL_WORK_SIZE|LOCAL_MEM_SIZE|LOCAL_SIZE_FOR_SUB_GROUP_COUNT|MAX_NUM_SUB_GROUPS|MAX_SUB_GROUP_SIZE_FOR_NDRANGE|NUM_ARGS|PREFERRED_WORK_GROUP_SIZE_MULTIPLE|PRIVATE_MEM_SIZE|PROGRAM|REFERENCE_COUNT|SUB_GROUP_COUNT_FOR_NDRANGE|WORK_GROUP_SIZE)|LINKER_NOT_AVAILABLE|LINK_PROGRAM_FAILURE|LOCAL|LUMINANCE|MAP_(?:FAILURE|READ|WRITE|WRITE_INVALIDATE_REGION)|MEM_(?:ALLOC_HOST_PTR|ASSOCIATED_MEMOBJECT|CONTEXT|COPY_HOST_PTR|COPY_OVERLAP|FLAGS|HOST_NO_ACCESS|HOST_PTR|HOST_READ_ONLY|HOST_WRITE_ONLY|KERNEL_READ_AND_WRITE|MAP_COUNT|OBJECT_(?:ALLOCATION_FAILURE|BUFFER|IMAGE1D|IMAGE1D_ARRAY|IMAGE1D_BUFFER|IMAGE2D|IMAGE2D_ARRAY|IMAGE3D|PIPE)|OFFSET|READ_ONLY|READ_WRITE|REFERENCE_COUNT|SIZE|SVM_ATOMICS|SVM_FINE_GRAIN_BUFFER|TYPE|USES_SVM_POINTER|USE_HOST_PTR|WRITE_ONLY)|MIGRATE_MEM_OBJECT_(?:CONTENT_UNDEFINED|HOST)|MISALIGNED_SUB_BUFFER_OFFSET|NONE|NON_BLOCKING|OUT_OF_(?:HOST_MEMORY|RESOURCES)|PIPE_(?:MAX_PACKETS|PACKET_SIZE)|PLATFORM_(?:EXTENSIONS|HOST_TIMER_RESOLUTION|NAME|PROFILE|VENDOR|VERSION)|PROFILING_(?:COMMAND_(?:COMPLETE|END|QUEUED|START|SUBMIT)|INFO_NOT_AVAILABLE)|PROGRAM_(?:BINARIES|BINARY_SIZES|BINARY_TYPE(?:_COMPILED_OBJECT|_EXECUTABLE|_LIBRARY|_NONE)?|BUILD_(?:GLOBAL_VARIABLE_TOTAL_SIZE|LOG|OPTIONS|STATUS)|CONTEXT|DEVICES|IL|KERNEL_NAMES|NUM_DEVICES|NUM_KERNELS|REFERENCE_COUNT|SOURCE)|QUEUED|QUEUE_(?:CONTEXT|DEVICE|DEVICE_DEFAULT|ON_DEVICE|ON_DEVICE_DEFAULT|OUT_OF_ORDER_EXEC_MODE_ENABLE|PROFILING_ENABLE|PROPERTIES|REFERENCE_COUNT|SIZE)|R|RA|READ_(?:ONLY|WRITE)_CACHE|RG|RGB|RGBA|RGBx|RGx|RUNNING|Rx|SAMPLER_(?:ADDRESSING_MODE|CONTEXT|FILTER_MODE|LOD_MAX|LOD_MIN|MIP_FILTER_MODE|NORMALIZED_COORDS|REFERENCE_COUNT)|(?:UN)?SIGNED_INT(?:8|16|32)|SNORM_INT(?:8|16)|SUBMITTED|SUCCESS|UNORM_INT(?:8|16|24|_101010|_101010_2)|UNORM_SHORT_(?:555|565)|VERSION_(?:1_0|1_1|1_2|2_0|2_1)|sBGRA|sRGB|sRGBA|sRGBx)\b/,alias:"constant"},"function-opencl-host":{pattern:/\bcl(?:BuildProgram|CloneKernel|CompileProgram|Create(?:Buffer|CommandQueue(?:WithProperties)?|Context|ContextFromType|Image|Image2D|Image3D|Kernel|KernelsInProgram|Pipe|ProgramWith(?:Binary|BuiltInKernels|IL|Source)|Sampler|SamplerWithProperties|SubBuffer|SubDevices|UserEvent)|Enqueue(?:(?:Barrier|Marker)(?:WithWaitList)?|Copy(?:Buffer(?:Rect|ToImage)?|Image(?:ToBuffer)?)|(?:Fill|Map)(?:Buffer|Image)|MigrateMemObjects|NDRangeKernel|NativeKernel|(?:Read|Write)(?:Buffer(?:Rect)?|Image)|SVM(?:Free|Map|MemFill|Memcpy|MigrateMem|Unmap)|Task|UnmapMemObject|WaitForEvents)|Finish|Flush|Get(?:CommandQueueInfo|ContextInfo|Device(?:AndHostTimer|IDs|Info)|Event(?:Profiling)?Info|ExtensionFunctionAddress(?:ForPlatform)?|HostTimer|ImageInfo|Kernel(?:ArgInfo|Info|SubGroupInfo|WorkGroupInfo)|MemObjectInfo|PipeInfo|Platform(?:IDs|Info)|Program(?:Build)?Info|SamplerInfo|SupportedImageFormats)|LinkProgram|(?:Release|Retain)(?:CommandQueue|Context|Device|Event|Kernel|MemObject|Program|Sampler)|SVM(?:Alloc|Free)|Set(?:CommandQueueProperty|DefaultDeviceCommandQueue|EventCallback|Kernel|Kernel(?:Arg(?:SVMPointer)?|ExecInfo)|MemObjectDestructorCallback|UserEventStatus)|Unload(?:Platform)?Compiler|WaitForEvents)\b/,alias:"function"}};r.languages.insertBefore("c","keyword",a),r.languages.cpp&&(a["type-opencl-host-cpp"]={pattern:/\b(?:Buffer|BufferGL|BufferRenderGL|CommandQueue|Context|Device|DeviceCommandQueue|EnqueueArgs|Event|Image|Image1D|Image1DArray|Image1DBuffer|Image2D|Image2DArray|Image2DGL|Image3D|Image3DGL|ImageFormat|ImageGL|Kernel|KernelFunctor|LocalSpaceArg|Memory|NDRange|Pipe|Platform|Program|SVMAllocator|SVMTraitAtomic|SVMTraitCoarse|SVMTraitFine|SVMTraitReadOnly|SVMTraitReadWrite|SVMTraitWriteOnly|Sampler|UserEvent)\b/,alias:"keyword"},r.languages.insertBefore("cpp","keyword",a))}(n)}return kE}var TE,XM;function Yve(){if(XM)return TE;XM=1,TE=e,e.displayName="openqasm",e.aliases=["qasm"];function e(t){t.languages.openqasm={comment:/\/\*[\s\S]*?\*\/|\/\/.*/,string:{pattern:/"[^"\r\n\t]*"|'[^'\r\n\t]*'/,greedy:!0},keyword:/\b(?:CX|OPENQASM|U|barrier|boxas|boxto|break|const|continue|ctrl|def|defcal|defcalgrammar|delay|else|end|for|gate|gphase|if|in|include|inv|kernel|lengthof|let|measure|pow|reset|return|rotary|stretchinf|while)\b|#pragma\b/,"class-name":/\b(?:angle|bit|bool|creg|fixed|float|int|length|qreg|qubit|stretch|uint)\b/,function:/\b(?:cos|exp|ln|popcount|rotl|rotr|sin|sqrt|tan)\b(?=\s*\()/,constant:/\b(?:euler|pi|tau)\b|π|𝜏|ℇ/,number:{pattern:/(^|[^.\w$])(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?(?:dt|ns|us|µs|ms|s)?/i,lookbehind:!0},operator:/->|>>=?|<<=?|&&|\|\||\+\+|--|[!=<>&|~^+\-*/%]=?|@/,punctuation:/[(){}\[\];,:.]/},t.languages.qasm=t.languages.openqasm}return TE}var AE,ZM;function Kve(){if(ZM)return AE;ZM=1,AE=e,e.displayName="oz",e.aliases=[];function e(t){t.languages.oz={comment:{pattern:/\/\*[\s\S]*?\*\/|%.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\[\s\S])*"/,greedy:!0},atom:{pattern:/'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,alias:"builtin"},keyword:/\$|\[\]|\b(?:_|at|attr|case|catch|choice|class|cond|declare|define|dis|else(?:case|if)?|end|export|fail|false|feat|finally|from|fun|functor|if|import|in|local|lock|meth|nil|not|of|or|prepare|proc|prop|raise|require|self|skip|then|thread|true|try|unit)\b/,function:[/\b[a-z][A-Za-z\d]*(?=\()/,{pattern:/(\{)[A-Z][A-Za-z\d]*\b/,lookbehind:!0}],number:/\b(?:0[bx][\da-f]+|\d+(?:\.\d*)?(?:e~?\d+)?)\b|&(?:[^\\]|\\(?:\d{3}|.))/i,variable:/`(?:[^`\\]|\\.)+`/,"attr-name":/\b\w+(?=[ \t]*:(?![:=]))/,operator:/:(?:=|::?)|<[-:=]?|=(?:=|<?:?)|>=?:?|\\=:?|!!?|[|#+\-*\/,~^@]|\b(?:andthen|div|mod|orelse)\b/,punctuation:/[\[\](){}.:;?]/}}return AE}var RE,QM;function Xve(){if(QM)return RE;QM=1,RE=e,e.displayName="parigp",e.aliases=[];function e(t){t.languages.parigp={comment:/\/\*[\s\S]*?\*\/|\\\\.*/,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"/,greedy:!0},keyword:function(){var n=["breakpoint","break","dbg_down","dbg_err","dbg_up","dbg_x","forcomposite","fordiv","forell","forpart","forprime","forstep","forsubgroup","forvec","for","iferr","if","local","my","next","return","until","while"];return n=n.map(function(r){return r.split("").join(" *")}).join("|"),RegExp("\\b(?:"+n+")\\b")}(),function:/\b\w(?:[\w ]*\w)?(?= *\()/,number:{pattern:/((?:\. *\. *)?)(?:\b\d(?: *\d)*(?: *(?!\. *\.)\.(?: *\d)*)?|\. *\d(?: *\d)*)(?: *e *(?:[+-] *)?\d(?: *\d)*)?/i,lookbehind:!0},operator:/\. *\.|[*\/!](?: *=)?|%(?: *=|(?: *#)?(?: *')*)?|\+(?: *[+=])?|-(?: *[-=>])?|<(?: *>|(?: *<)?(?: *=)?)?|>(?: *>)?(?: *=)?|=(?: *=){0,2}|\\(?: *\/)?(?: *=)?|&(?: *&)?|\| *\||['#~^]/,punctuation:/[\[\]{}().,:;|]/}}return RE}var CE,JM;function Zve(){if(JM)return CE;JM=1,CE=e,e.displayName="parser",e.aliases=[];function e(t){(function(n){var r=n.languages.parser=n.languages.extend("markup",{keyword:{pattern:/(^|[^^])(?:\^(?:case|eval|for|if|switch|throw)\b|@(?:BASE|CLASS|GET(?:_DEFAULT)?|OPTIONS|SET_DEFAULT|USE)\b)/,lookbehind:!0},variable:{pattern:/(^|[^^])\B\$(?:\w+|(?=[.{]))(?:(?:\.|::?)\w+)*(?:\.|::?)?/,lookbehind:!0,inside:{punctuation:/\.|:+/}},function:{pattern:/(^|[^^])\B[@^]\w+(?:(?:\.|::?)\w+)*(?:\.|::?)?/,lookbehind:!0,inside:{keyword:{pattern:/(^@)(?:GET_|SET_)/,lookbehind:!0},punctuation:/\.|:+/}},escape:{pattern:/\^(?:[$^;@()\[\]{}"':]|#[a-f\d]*)/i,alias:"builtin"},punctuation:/[\[\](){};]/});r=n.languages.insertBefore("parser","keyword",{"parser-comment":{pattern:/(\s)#.*/,lookbehind:!0,alias:"comment"},expression:{pattern:/(^|[^^])\((?:[^()]|\((?:[^()]|\((?:[^()])*\))*\))*\)/,greedy:!0,lookbehind:!0,inside:{string:{pattern:/(^|[^^])(["'])(?:(?!\2)[^^]|\^[\s\S])*\2/,lookbehind:!0},keyword:r.keyword,variable:r.variable,function:r.function,boolean:/\b(?:false|true)\b/,number:/\b(?:0x[a-f\d]+|\d+(?:\.\d*)?(?:e[+-]?\d+)?)\b/i,escape:r.escape,operator:/[~+*\/\\%]|!(?:\|\|?|=)?|&&?|\|\|?|==|<[<=]?|>[>=]?|-[fd]?|\b(?:def|eq|ge|gt|in|is|le|lt|ne)\b/,punctuation:r.punctuation}}}),n.languages.insertBefore("inside","punctuation",{expression:r.expression,keyword:r.keyword,variable:r.variable,function:r.function,escape:r.escape,"parser-punctuation":{pattern:r.punctuation,alias:"punctuation"}},r.tag.inside["attr-value"])})(t)}return CE}var _E,eP;function Qve(){if(eP)return _E;eP=1,_E=e,e.displayName="pascal",e.aliases=["objectpascal"];function e(t){t.languages.pascal={directive:{pattern:/\{\$[\s\S]*?\}/,greedy:!0,alias:["marco","property"]},comment:{pattern:/\(\*[\s\S]*?\*\)|\{[\s\S]*?\}|\/\/.*/,greedy:!0},string:{pattern:/(?:'(?:''|[^'\r\n])*'(?!')|#[&$%]?[a-f\d]+)+|\^[a-z]/i,greedy:!0},asm:{pattern:/(\basm\b)[\s\S]+?(?=\bend\s*[;[])/i,lookbehind:!0,greedy:!0,inside:null},keyword:[{pattern:/(^|[^&])\b(?:absolute|array|asm|begin|case|const|constructor|destructor|do|downto|else|end|file|for|function|goto|if|implementation|inherited|inline|interface|label|nil|object|of|operator|packed|procedure|program|record|reintroduce|repeat|self|set|string|then|to|type|unit|until|uses|var|while|with)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:dispose|exit|false|new|true)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:class|dispinterface|except|exports|finalization|finally|initialization|inline|library|on|out|packed|property|raise|resourcestring|threadvar|try)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:absolute|abstract|alias|assembler|bitpacked|break|cdecl|continue|cppdecl|cvar|default|deprecated|dynamic|enumerator|experimental|export|external|far|far16|forward|generic|helper|implements|index|interrupt|iochecks|local|message|name|near|nodefault|noreturn|nostackframe|oldfpccall|otherwise|overload|override|pascal|platform|private|protected|public|published|read|register|reintroduce|result|safecall|saveregisters|softfloat|specialize|static|stdcall|stored|strict|unaligned|unimplemented|varargs|virtual|write)\b/i,lookbehind:!0}],number:[/(?:[&%]\d+|\$[a-f\d]+)/i,/\b\d+(?:\.\d+)?(?:e[+-]?\d+)?/i],operator:[/\.\.|\*\*|:=|<[<=>]?|>[>=]?|[+\-*\/]=?|[@^=]/,{pattern:/(^|[^&])\b(?:and|as|div|exclude|in|include|is|mod|not|or|shl|shr|xor)\b/,lookbehind:!0}],punctuation:/\(\.|\.\)|[()\[\]:;,.]/},t.languages.pascal.asm.inside=t.languages.extend("pascal",{asm:void 0,keyword:void 0,operator:void 0}),t.languages.objectpascal=t.languages.pascal}return _E}var NE,tP;function Jve(){if(tP)return NE;tP=1,NE=e,e.displayName="pascaligo",e.aliases=[];function e(t){(function(n){var r=/\((?:[^()]|\((?:[^()]|\([^()]*\))*\))*\)/.source,a=/(?:\b\w+(?:<braces>)?|<braces>)/.source.replace(/<braces>/g,function(){return r}),o=n.languages.pascaligo={comment:/\(\*[\s\S]+?\*\)|\/\/.*/,string:{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1|\^[a-z]/i,greedy:!0},"class-name":[{pattern:RegExp(/(\btype\s+\w+\s+is\s+)<type>/.source.replace(/<type>/g,function(){return a}),"i"),lookbehind:!0,inside:null},{pattern:RegExp(/<type>(?=\s+is\b)/.source.replace(/<type>/g,function(){return a}),"i"),inside:null},{pattern:RegExp(/(:\s*)<type>/.source.replace(/<type>/g,function(){return a})),lookbehind:!0,inside:null}],keyword:{pattern:/(^|[^&])\b(?:begin|block|case|const|else|end|fail|for|from|function|if|is|nil|of|remove|return|skip|then|type|var|while|with)\b/i,lookbehind:!0},boolean:{pattern:/(^|[^&])\b(?:False|True)\b/i,lookbehind:!0},builtin:{pattern:/(^|[^&])\b(?:bool|int|list|map|nat|record|string|unit)\b/i,lookbehind:!0},function:/\b\w+(?=\s*\()/,number:[/%[01]+|&[0-7]+|\$[a-f\d]+/i,/\b\d+(?:\.\d+)?(?:e[+-]?\d+)?(?:mtz|n)?/i],operator:/->|=\/=|\.\.|\*\*|:=|<[<=>]?|>[>=]?|[+\-*\/]=?|[@^=|]|\b(?:and|mod|or)\b/,punctuation:/\(\.|\.\)|[()\[\]:;,.{}]/},s=["comment","keyword","builtin","operator","punctuation"].reduce(function(l,u){return l[u]=o[u],l},{});o["class-name"].forEach(function(l){l.inside=s})})(t)}return NE}var OE,nP;function eSe(){if(nP)return OE;nP=1,OE=e,e.displayName="pcaxis",e.aliases=["px"];function e(t){t.languages.pcaxis={string:/"[^"]*"/,keyword:{pattern:/((?:^|;)\s*)[-A-Z\d]+(?:\s*\[[-\w]+\])?(?:\s*\("[^"]*"(?:,\s*"[^"]*")*\))?(?=\s*=)/,lookbehind:!0,greedy:!0,inside:{keyword:/^[-A-Z\d]+/,language:{pattern:/^(\s*)\[[-\w]+\]/,lookbehind:!0,inside:{punctuation:/^\[|\]$/,property:/[-\w]+/}},"sub-key":{pattern:/^(\s*)\S[\s\S]*/,lookbehind:!0,inside:{parameter:{pattern:/"[^"]*"/,alias:"property"},punctuation:/^\(|\)$|,/}}}},operator:/=/,tlist:{pattern:/TLIST\s*\(\s*\w+(?:(?:\s*,\s*"[^"]*")+|\s*,\s*"[^"]*"-"[^"]*")?\s*\)/,greedy:!0,inside:{function:/^TLIST/,property:{pattern:/^(\s*\(\s*)\w+/,lookbehind:!0},string:/"[^"]*"/,punctuation:/[(),]/,operator:/-/}},punctuation:/[;,]/,number:{pattern:/(^|\s)\d+(?:\.\d+)?(?!\S)/,lookbehind:!0},boolean:/NO|YES/},t.languages.px=t.languages.pcaxis}return OE}var IE,rP;function tSe(){if(rP)return IE;rP=1,IE=e,e.displayName="peoplecode",e.aliases=["pcode"];function e(t){t.languages.peoplecode={comment:RegExp([/\/\*[\s\S]*?\*\//.source,/\bREM[^;]*;/.source,/<\*(?:[^<*]|\*(?!>)|<(?!\*)|<\*(?:(?!\*>)[\s\S])*\*>)*\*>/.source,/\/\+[\s\S]*?\+\//.source].join("|")),string:{pattern:/'(?:''|[^'\r\n])*'(?!')|"(?:""|[^"\r\n])*"(?!")/,greedy:!0},variable:/%\w+/,"function-definition":{pattern:/((?:^|[^\w-])(?:function|method)\s+)\w+/i,lookbehind:!0,alias:"function"},"class-name":{pattern:/((?:^|[^-\w])(?:as|catch|class|component|create|extends|global|implements|instance|local|of|property|returns)\s+)\w+(?::\w+)*/i,lookbehind:!0,inside:{punctuation:/:/}},keyword:/\b(?:abstract|alias|as|catch|class|component|constant|create|declare|else|end-(?:class|evaluate|for|function|get|if|method|set|try|while)|evaluate|extends|for|function|get|global|if|implements|import|instance|library|local|method|null|of|out|peopleCode|private|program|property|protected|readonly|ref|repeat|returns?|set|step|then|throw|to|try|until|value|when(?:-other)?|while)\b/i,"operator-keyword":{pattern:/\b(?:and|not|or)\b/i,alias:"operator"},function:/[_a-z]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/i,number:/\b\d+(?:\.\d+)?\b/,operator:/<>|[<>]=?|!=|\*\*|[-+*/|=@]/,punctuation:/[:.;,()[\]]/},t.languages.pcode=t.languages.peoplecode}return IE}var DE,aP;function nSe(){if(aP)return DE;aP=1,DE=e,e.displayName="perl",e.aliases=[];function e(t){(function(n){var r=/(?:\((?:[^()\\]|\\[\s\S])*\)|\{(?:[^{}\\]|\\[\s\S])*\}|\[(?:[^[\]\\]|\\[\s\S])*\]|<(?:[^<>\\]|\\[\s\S])*>)/.source;n.languages.perl={comment:[{pattern:/(^\s*)=\w[\s\S]*?=cut.*/m,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\$])#.*/,lookbehind:!0,greedy:!0}],string:[{pattern:RegExp(/\b(?:q|qq|qw|qx)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/([a-zA-Z0-9])(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,r].join("|")+")"),greedy:!0},{pattern:/("|`)(?:(?!\1)[^\\]|\\[\s\S])*\1/,greedy:!0},{pattern:/'(?:[^'\\\r\n]|\\.)*'/,greedy:!0}],regex:[{pattern:RegExp(/\b(?:m|qr)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/([a-zA-Z0-9])(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,r].join("|")+")"+/[msixpodualngc]*/.source),greedy:!0},{pattern:RegExp(/(^|[^-])\b(?:s|tr|y)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\2)[^\\]|\\[\s\S])*\2(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,/([a-zA-Z0-9])(?:(?!\3)[^\\]|\\[\s\S])*\3(?:(?!\3)[^\\]|\\[\s\S])*\3/.source,r+/\s*/.source+r].join("|")+")"+/[msixpodualngcer]*/.source),lookbehind:!0,greedy:!0},{pattern:/\/(?:[^\/\\\r\n]|\\.)*\/[msixpodualngc]*(?=\s*(?:$|[\r\n,.;})&|\-+*~<>!?^]|(?:and|cmp|eq|ge|gt|le|lt|ne|not|or|x|xor)\b))/,greedy:!0}],variable:[/[&*$@%]\{\^[A-Z]+\}/,/[&*$@%]\^[A-Z_]/,/[&*$@%]#?(?=\{)/,/[&*$@%]#?(?:(?:::)*'?(?!\d)[\w$]+(?![\w$]))+(?:::)*/,/[&*$@%]\d+/,/(?!%=)[$@%][!"#$%&'()*+,\-.\/:;<=>?@[\\\]^_`{|}~]/],filehandle:{pattern:/<(?![<=])\S*?>|\b_\b/,alias:"symbol"},"v-string":{pattern:/v\d+(?:\.\d+)*|\d+(?:\.\d+){2,}/,alias:"string"},function:{pattern:/(\bsub[ \t]+)\w+/,lookbehind:!0},keyword:/\b(?:any|break|continue|default|delete|die|do|else|elsif|eval|for|foreach|given|goto|if|last|local|my|next|our|package|print|redo|require|return|say|state|sub|switch|undef|unless|until|use|when|while)\b/,number:/\b(?:0x[\dA-Fa-f](?:_?[\dA-Fa-f])*|0b[01](?:_?[01])*|(?:(?:\d(?:_?\d)*)?\.)?\d(?:_?\d)*(?:[Ee][+-]?\d+)?)\b/,operator:/-[rwxoRWXOezsfdlpSbctugkTBMAC]\b|\+[+=]?|-[-=>]?|\*\*?=?|\/\/?=?|=[=~>]?|~[~=]?|\|\|?=?|&&?=?|<(?:=>?|<=?)?|>>?=?|![~=]?|[%^]=?|\.(?:=|\.\.?)?|[\\?]|\bx(?:=|\b)|\b(?:and|cmp|eq|ge|gt|le|lt|ne|not|or|xor)\b/,punctuation:/[{}[\];(),:]/}})(t)}return DE}var LE,oP;function rSe(){if(oP)return LE;oP=1;var e=Up();LE=t,t.displayName="phpExtras",t.aliases=[];function t(n){n.register(e),n.languages.insertBefore("php","variable",{this:{pattern:/\$this\b/,alias:"keyword"},global:/\$(?:GLOBALS|HTTP_RAW_POST_DATA|_(?:COOKIE|ENV|FILES|GET|POST|REQUEST|SERVER|SESSION)|argc|argv|http_response_header|php_errormsg)\b/,scope:{pattern:/\b[\w\\]+::/,inside:{keyword:/\b(?:parent|self|static)\b/,punctuation:/::|\\/}}})}return LE}var ME,iP;function aSe(){if(iP)return ME;iP=1;var e=Up(),t=jp();ME=n,n.displayName="phpdoc",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var o=/(?:\b[a-zA-Z]\w*|[|\\[\]])+/.source;a.languages.phpdoc=a.languages.extend("javadoclike",{parameter:{pattern:RegExp("(@(?:global|param|property(?:-read|-write)?|var)\\s+(?:"+o+"\\s+)?)\\$\\w+"),lookbehind:!0}}),a.languages.insertBefore("phpdoc","keyword",{"class-name":[{pattern:RegExp("(@(?:global|package|param|property(?:-read|-write)?|return|subpackage|throws|var)\\s+)"+o),lookbehind:!0,inside:{keyword:/\b(?:array|bool|boolean|callback|double|false|float|int|integer|mixed|null|object|resource|self|string|true|void)\b/,punctuation:/[|\\[\]()]/}}]}),a.languages.javadoclike.addSupport("php",a.languages.phpdoc)}(r)}return ME}var PE,sP;function oSe(){if(sP)return PE;sP=1;var e=yA();PE=t,t.displayName="plsql",t.aliases=[];function t(n){n.register(e),n.languages.plsql=n.languages.extend("sql",{comment:{pattern:/\/\*[\s\S]*?\*\/|--.*/,greedy:!0},keyword:/\b(?:A|ACCESSIBLE|ADD|AGENT|AGGREGATE|ALL|ALTER|AND|ANY|ARRAY|AS|ASC|AT|ATTRIBUTE|AUTHID|AVG|BEGIN|BETWEEN|BFILE_BASE|BINARY|BLOB_BASE|BLOCK|BODY|BOTH|BOUND|BULK|BY|BYTE|C|CALL|CALLING|CASCADE|CASE|CHAR|CHARACTER|CHARSET|CHARSETFORM|CHARSETID|CHAR_BASE|CHECK|CLOB_BASE|CLONE|CLOSE|CLUSTER|CLUSTERS|COLAUTH|COLLECT|COLUMNS|COMMENT|COMMIT|COMMITTED|COMPILED|COMPRESS|CONNECT|CONSTANT|CONSTRUCTOR|CONTEXT|CONTINUE|CONVERT|COUNT|CRASH|CREATE|CREDENTIAL|CURRENT|CURSOR|CUSTOMDATUM|DANGLING|DATA|DATE|DATE_BASE|DAY|DECLARE|DEFAULT|DEFINE|DELETE|DESC|DETERMINISTIC|DIRECTORY|DISTINCT|DOUBLE|DROP|DURATION|ELEMENT|ELSE|ELSIF|EMPTY|END|ESCAPE|EXCEPT|EXCEPTION|EXCEPTIONS|EXCLUSIVE|EXECUTE|EXISTS|EXIT|EXTERNAL|FETCH|FINAL|FIRST|FIXED|FLOAT|FOR|FORALL|FORCE|FROM|FUNCTION|GENERAL|GOTO|GRANT|GROUP|HASH|HAVING|HEAP|HIDDEN|HOUR|IDENTIFIED|IF|IMMEDIATE|IMMUTABLE|IN|INCLUDING|INDEX|INDEXES|INDICATOR|INDICES|INFINITE|INSERT|INSTANTIABLE|INT|INTERFACE|INTERSECT|INTERVAL|INTO|INVALIDATE|IS|ISOLATION|JAVA|LANGUAGE|LARGE|LEADING|LENGTH|LEVEL|LIBRARY|LIKE|LIKE2|LIKE4|LIKEC|LIMIT|LIMITED|LOCAL|LOCK|LONG|LOOP|MAP|MAX|MAXLEN|MEMBER|MERGE|MIN|MINUS|MINUTE|MOD|MODE|MODIFY|MONTH|MULTISET|MUTABLE|NAME|NAN|NATIONAL|NATIVE|NCHAR|NEW|NOCOMPRESS|NOCOPY|NOT|NOWAIT|NULL|NUMBER_BASE|OBJECT|OCICOLL|OCIDATE|OCIDATETIME|OCIDURATION|OCIINTERVAL|OCILOBLOCATOR|OCINUMBER|OCIRAW|OCIREF|OCIREFCURSOR|OCIROWID|OCISTRING|OCITYPE|OF|OLD|ON|ONLY|OPAQUE|OPEN|OPERATOR|OPTION|OR|ORACLE|ORADATA|ORDER|ORGANIZATION|ORLANY|ORLVARY|OTHERS|OUT|OVERLAPS|OVERRIDING|PACKAGE|PARALLEL_ENABLE|PARAMETER|PARAMETERS|PARENT|PARTITION|PASCAL|PERSISTABLE|PIPE|PIPELINED|PLUGGABLE|POLYMORPHIC|PRAGMA|PRECISION|PRIOR|PRIVATE|PROCEDURE|PUBLIC|RAISE|RANGE|RAW|READ|RECORD|REF|REFERENCE|RELIES_ON|REM|REMAINDER|RENAME|RESOURCE|RESULT|RESULT_CACHE|RETURN|RETURNING|REVERSE|REVOKE|ROLLBACK|ROW|SAMPLE|SAVE|SAVEPOINT|SB1|SB2|SB4|SECOND|SEGMENT|SELECT|SELF|SEPARATE|SEQUENCE|SERIALIZABLE|SET|SHARE|SHORT|SIZE|SIZE_T|SOME|SPARSE|SQL|SQLCODE|SQLDATA|SQLNAME|SQLSTATE|STANDARD|START|STATIC|STDDEV|STORED|STRING|STRUCT|STYLE|SUBMULTISET|SUBPARTITION|SUBSTITUTABLE|SUBTYPE|SUM|SYNONYM|TABAUTH|TABLE|TDO|THE|THEN|TIME|TIMESTAMP|TIMEZONE_ABBR|TIMEZONE_HOUR|TIMEZONE_MINUTE|TIMEZONE_REGION|TO|TRAILING|TRANSACTION|TRANSACTIONAL|TRUSTED|TYPE|UB1|UB2|UB4|UNDER|UNION|UNIQUE|UNPLUG|UNSIGNED|UNTRUSTED|UPDATE|USE|USING|VALIST|VALUE|VALUES|VARIABLE|VARIANCE|VARRAY|VARYING|VIEW|VIEWS|VOID|WHEN|WHERE|WHILE|WITH|WORK|WRAPPED|WRITE|YEAR|ZONE)\b/i,operator:/:=?|=>|[<>^~!]=|\.\.|\|\||\*\*|[-+*/%<>=@]/}),n.languages.insertBefore("plsql","operator",{label:{pattern:/<<\s*\w+\s*>>/,alias:"symbol"}})}return PE}var FE,lP;function iSe(){if(lP)return FE;lP=1,FE=e,e.displayName="powerquery",e.aliases=[];function e(t){t.languages.powerquery={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0,greedy:!0},"quoted-identifier":{pattern:/#"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},string:{pattern:/(?:#!)?"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},constant:[/\bDay\.(?:Friday|Monday|Saturday|Sunday|Thursday|Tuesday|Wednesday)\b/,/\bTraceLevel\.(?:Critical|Error|Information|Verbose|Warning)\b/,/\bOccurrence\.(?:All|First|Last)\b/,/\bOrder\.(?:Ascending|Descending)\b/,/\bRoundingMode\.(?:AwayFromZero|Down|ToEven|TowardZero|Up)\b/,/\bMissingField\.(?:Error|Ignore|UseNull)\b/,/\bQuoteStyle\.(?:Csv|None)\b/,/\bJoinKind\.(?:FullOuter|Inner|LeftAnti|LeftOuter|RightAnti|RightOuter)\b/,/\bGroupKind\.(?:Global|Local)\b/,/\bExtraValues\.(?:Error|Ignore|List)\b/,/\bJoinAlgorithm\.(?:Dynamic|LeftHash|LeftIndex|PairwiseHash|RightHash|RightIndex|SortMerge)\b/,/\bJoinSide\.(?:Left|Right)\b/,/\bPrecision\.(?:Decimal|Double)\b/,/\bRelativePosition\.From(?:End|Start)\b/,/\bTextEncoding\.(?:Ascii|BigEndianUnicode|Unicode|Utf16|Utf8|Windows)\b/,/\b(?:Any|Binary|Date|DateTime|DateTimeZone|Duration|Function|Int16|Int32|Int64|Int8|List|Logical|None|Number|Record|Table|Text|Time)\.Type\b/,/\bnull\b/],boolean:/\b(?:false|true)\b/,keyword:/\b(?:and|as|each|else|error|if|in|is|let|meta|not|nullable|optional|or|otherwise|section|shared|then|try|type)\b|#(?:binary|date|datetime|datetimezone|duration|infinity|nan|sections|shared|table|time)\b/,function:{pattern:/(^|[^#\w.])[a-z_][\w.]*(?=\s*\()/i,lookbehind:!0},"data-type":{pattern:/\b(?:any|anynonnull|binary|date|datetime|datetimezone|duration|function|list|logical|none|number|record|table|text|time)\b/,alias:"class-name"},number:{pattern:/\b0x[\da-f]+\b|(?:[+-]?(?:\b\d+\.)?\b\d+|[+-]\.\d+|(^|[^.])\B\.\d+)(?:e[+-]?\d+)?\b/i,lookbehind:!0},operator:/[-+*\/&?@^]|<(?:=>?|>)?|>=?|=>?|\.\.\.?/,punctuation:/[,;\[\](){}]/},t.languages.pq=t.languages.powerquery,t.languages.mscript=t.languages.powerquery}return FE}var zE,cP;function sSe(){if(cP)return zE;cP=1,zE=e,e.displayName="powershell",e.aliases=[];function e(t){(function(n){var r=n.languages.powershell={comment:[{pattern:/(^|[^`])<#[\s\S]*?#>/,lookbehind:!0},{pattern:/(^|[^`])#.*/,lookbehind:!0}],string:[{pattern:/"(?:`[\s\S]|[^`"])*"/,greedy:!0,inside:null},{pattern:/'(?:[^']|'')*'/,greedy:!0}],namespace:/\[[a-z](?:\[(?:\[[^\]]*\]|[^\[\]])*\]|[^\[\]])*\]/i,boolean:/\$(?:false|true)\b/i,variable:/\$\w+\b/,function:[/\b(?:Add|Approve|Assert|Backup|Block|Checkpoint|Clear|Close|Compare|Complete|Compress|Confirm|Connect|Convert|ConvertFrom|ConvertTo|Copy|Debug|Deny|Disable|Disconnect|Dismount|Edit|Enable|Enter|Exit|Expand|Export|Find|ForEach|Format|Get|Grant|Group|Hide|Import|Initialize|Install|Invoke|Join|Limit|Lock|Measure|Merge|Move|New|Open|Optimize|Out|Ping|Pop|Protect|Publish|Push|Read|Receive|Redo|Register|Remove|Rename|Repair|Request|Reset|Resize|Resolve|Restart|Restore|Resume|Revoke|Save|Search|Select|Send|Set|Show|Skip|Sort|Split|Start|Step|Stop|Submit|Suspend|Switch|Sync|Tee|Test|Trace|Unblock|Undo|Uninstall|Unlock|Unprotect|Unpublish|Unregister|Update|Use|Wait|Watch|Where|Write)-[a-z]+\b/i,/\b(?:ac|cat|chdir|clc|cli|clp|clv|compare|copy|cp|cpi|cpp|cvpa|dbp|del|diff|dir|ebp|echo|epal|epcsv|epsn|erase|fc|fl|ft|fw|gal|gbp|gc|gci|gcs|gdr|gi|gl|gm|gp|gps|group|gsv|gu|gv|gwmi|iex|ii|ipal|ipcsv|ipsn|irm|iwmi|iwr|kill|lp|ls|measure|mi|mount|move|mp|mv|nal|ndr|ni|nv|ogv|popd|ps|pushd|pwd|rbp|rd|rdr|ren|ri|rm|rmdir|rni|rnp|rp|rv|rvpa|rwmi|sal|saps|sasv|sbp|sc|select|set|shcm|si|sl|sleep|sls|sort|sp|spps|spsv|start|sv|swmi|tee|trcm|type|write)\b/i],keyword:/\b(?:Begin|Break|Catch|Class|Continue|Data|Define|Do|DynamicParam|Else|ElseIf|End|Exit|Filter|Finally|For|ForEach|From|Function|If|InlineScript|Parallel|Param|Process|Return|Sequence|Switch|Throw|Trap|Try|Until|Using|Var|While|Workflow)\b/i,operator:{pattern:/(^|\W)(?:!|-(?:b?(?:and|x?or)|as|(?:Not)?(?:Contains|In|Like|Match)|eq|ge|gt|is(?:Not)?|Join|le|lt|ne|not|Replace|sh[lr])\b|-[-=]?|\+[+=]?|[*\/%]=?)/i,lookbehind:!0},punctuation:/[|{}[\];(),.]/};r.string[0].inside={function:{pattern:/(^|[^`])\$\((?:\$\([^\r\n()]*\)|(?!\$\()[^\r\n)])*\)/,lookbehind:!0,inside:r},boolean:r.boolean,variable:r.variable}})(t)}return zE}var BE,uP;function lSe(){if(uP)return BE;uP=1,BE=e,e.displayName="processing",e.aliases=[];function e(t){t.languages.processing=t.languages.extend("clike",{keyword:/\b(?:break|case|catch|class|continue|default|else|extends|final|for|if|implements|import|new|null|private|public|return|static|super|switch|this|try|void|while)\b/,function:/\b\w+(?=\s*\()/,operator:/<[<=]?|>[>=]?|&&?|\|\|?|[%?]|[!=+\-*\/]=?/}),t.languages.insertBefore("processing","number",{constant:/\b(?!XML\b)[A-Z][A-Z\d_]+\b/,type:{pattern:/\b(?:boolean|byte|char|color|double|float|int|[A-Z]\w*)\b/,alias:"class-name"}})}return BE}var jE,dP;function cSe(){if(dP)return jE;dP=1,jE=e,e.displayName="prolog",e.aliases=[];function e(t){t.languages.prolog={comment:{pattern:/\/\*[\s\S]*?\*\/|%.*/,greedy:!0},string:{pattern:/(["'])(?:\1\1|\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1(?!\1)/,greedy:!0},builtin:/\b(?:fx|fy|xf[xy]?|yfx?)\b/,function:/\b[a-z]\w*(?:(?=\()|\/\d+)/,number:/\b\d+(?:\.\d*)?/,operator:/[:\\=><\-?*@\/;+^|!$.]+|\b(?:is|mod|not|xor)\b/,punctuation:/[(){}\[\],]/}}return jE}var UE,fP;function uSe(){if(fP)return UE;fP=1,UE=e,e.displayName="promql",e.aliases=[];function e(t){(function(n){var r=["sum","min","max","avg","group","stddev","stdvar","count","count_values","bottomk","topk","quantile"],a=["on","ignoring","group_right","group_left","by","without"],o=["offset"],s=r.concat(a,o);n.languages.promql={comment:{pattern:/(^[ \t]*)#.*/m,lookbehind:!0},"vector-match":{pattern:new RegExp("((?:"+a.join("|")+")\\s*)\\([^)]*\\)"),lookbehind:!0,inside:{"label-key":{pattern:/\b[^,]+\b/,alias:"attr-name"},punctuation:/[(),]/}},"context-labels":{pattern:/\{[^{}]*\}/,inside:{"label-key":{pattern:/\b[a-z_]\w*(?=\s*(?:=|![=~]))/,alias:"attr-name"},"label-value":{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0,alias:"attr-value"},punctuation:/\{|\}|=~?|![=~]|,/}},"context-range":[{pattern:/\[[\w\s:]+\]/,inside:{punctuation:/\[|\]|:/,"range-duration":{pattern:/\b(?:\d+(?:[smhdwy]|ms))+\b/i,alias:"number"}}},{pattern:/(\boffset\s+)\w+/,lookbehind:!0,inside:{"range-duration":{pattern:/\b(?:\d+(?:[smhdwy]|ms))+\b/i,alias:"number"}}}],keyword:new RegExp("\\b(?:"+s.join("|")+")\\b","i"),function:/\b[a-z_]\w*(?=\s*\()/i,number:/[-+]?(?:(?:\b\d+(?:\.\d+)?|\B\.\d+)(?:e[-+]?\d+)?\b|\b(?:0x[0-9a-f]+|nan|inf)\b)/i,operator:/[\^*/%+-]|==|!=|<=|<|>=|>|\b(?:and|or|unless)\b/i,punctuation:/[{};()`,.[\]]/}})(t)}return UE}var GE,pP;function dSe(){if(pP)return GE;pP=1,GE=e,e.displayName="properties",e.aliases=[];function e(t){t.languages.properties={comment:/^[ \t]*[#!].*$/m,"attr-value":{pattern:/(^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?: *[=:] *(?! )| ))(?:\\(?:\r\n|[\s\S])|[^\\\r\n])+/m,lookbehind:!0},"attr-name":/^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?= *[=:]| )/m,punctuation:/[=:]/}}return GE}var HE,gP;function fSe(){if(gP)return HE;gP=1,HE=e,e.displayName="protobuf",e.aliases=[];function e(t){(function(n){var r=/\b(?:bool|bytes|double|s?fixed(?:32|64)|float|[su]?int(?:32|64)|string)\b/;n.languages.protobuf=n.languages.extend("clike",{"class-name":[{pattern:/(\b(?:enum|extend|message|service)\s+)[A-Za-z_]\w*(?=\s*\{)/,lookbehind:!0},{pattern:/(\b(?:rpc\s+\w+|returns)\s*\(\s*(?:stream\s+)?)\.?[A-Za-z_]\w*(?:\.[A-Za-z_]\w*)*(?=\s*\))/,lookbehind:!0}],keyword:/\b(?:enum|extend|extensions|import|message|oneof|option|optional|package|public|repeated|required|reserved|returns|rpc(?=\s+\w)|service|stream|syntax|to)\b(?!\s*=\s*\d)/,function:/\b[a-z_]\w*(?=\s*\()/i}),n.languages.insertBefore("protobuf","operator",{map:{pattern:/\bmap<\s*[\w.]+\s*,\s*[\w.]+\s*>(?=\s+[a-z_]\w*\s*[=;])/i,alias:"class-name",inside:{punctuation:/[<>.,]/,builtin:r}},builtin:r,"positional-class-name":{pattern:/(?:\b|\B\.)[a-z_]\w*(?:\.[a-z_]\w*)*(?=\s+[a-z_]\w*\s*[=;])/i,alias:"class-name",inside:{punctuation:/\./}},annotation:{pattern:/(\[\s*)[a-z_]\w*(?=\s*=)/i,lookbehind:!0}})})(t)}return HE}var $E,hP;function pSe(){if(hP)return $E;hP=1,$E=e,e.displayName="psl",e.aliases=[];function e(t){t.languages.psl={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/"(?:\\.|[^\\"])*"/,greedy:!0,inside:{symbol:/\\[ntrbA-Z"\\]/}},"heredoc-string":{pattern:/<<<([a-zA-Z_]\w*)[\r\n](?:.*[\r\n])*?\1\b/,alias:"string",greedy:!0},keyword:/\b(?:__multi|__single|case|default|do|else|elsif|exit|export|for|foreach|function|if|last|line|local|next|requires|return|switch|until|while|word)\b/,constant:/\b(?:ALARM|CHART_ADD_GRAPH|CHART_DELETE_GRAPH|CHART_DESTROY|CHART_LOAD|CHART_PRINT|EOF|OFFLINE|OK|PSL_PROF_LOG|R_CHECK_HORIZ|R_CHECK_VERT|R_CLICKER|R_COLUMN|R_FRAME|R_ICON|R_LABEL|R_LABEL_CENTER|R_LIST_MULTIPLE|R_LIST_MULTIPLE_ND|R_LIST_SINGLE|R_LIST_SINGLE_ND|R_MENU|R_POPUP|R_POPUP_SCROLLED|R_RADIO_HORIZ|R_RADIO_VERT|R_ROW|R_SCALE_HORIZ|R_SCALE_VERT|R_SEP_HORIZ|R_SEP_VERT|R_SPINNER|R_TEXT_FIELD|R_TEXT_FIELD_LABEL|R_TOGGLE|TRIM_LEADING|TRIM_LEADING_AND_TRAILING|TRIM_REDUNDANT|TRIM_TRAILING|VOID|WARN)\b/,boolean:/\b(?:FALSE|False|NO|No|TRUE|True|YES|Yes|false|no|true|yes)\b/,variable:/\b(?:PslDebug|errno|exit_status)\b/,builtin:{pattern:/\b(?:PslExecute|PslFunctionCall|PslFunctionExists|PslSetOptions|_snmp_debug|acos|add_diary|annotate|annotate_get|ascii_to_ebcdic|asctime|asin|atan|atexit|batch_set|blackout|cat|ceil|chan_exists|change_state|close|code_cvt|cond_signal|cond_wait|console_type|convert_base|convert_date|convert_locale_date|cos|cosh|create|date|dcget_text|destroy|destroy_lock|dget_text|difference|dump_hist|ebcdic_to_ascii|encrypt|event_archive|event_catalog_get|event_check|event_query|event_range_manage|event_range_query|event_report|event_schedule|event_trigger|event_trigger2|execute|exists|exp|fabs|file|floor|fmod|fopen|fseek|ftell|full_discovery|get|get_chan_info|get_ranges|get_text|get_vars|getenv|gethostinfo|getpid|getpname|grep|history|history_get_retention|in_transition|index|int|internal|intersection|is_var|isnumber|join|kill|length|lines|lock|lock_info|log|log10|loge|matchline|msg_check|msg_get_format|msg_get_severity|msg_printf|msg_sprintf|ntharg|nthargf|nthline|nthlinef|num_bytes|num_consoles|pconfig|popen|poplines|pow|print|printf|proc_exists|process|random|read|readln|refresh_parameters|remote_check|remote_close|remote_event_query|remote_event_trigger|remote_file_send|remote_open|remove|replace|rindex|sec_check_priv|sec_store_get|sec_store_set|set|set_alarm_ranges|set_locale|share|sin|sinh|sleep|snmp_agent_config|snmp_agent_start|snmp_agent_stop|snmp_close|snmp_config|snmp_get|snmp_get_next|snmp_h_get|snmp_h_get_next|snmp_h_set|snmp_open|snmp_set|snmp_trap_ignore|snmp_trap_listen|snmp_trap_raise_std_trap|snmp_trap_receive|snmp_trap_register_im|snmp_trap_send|snmp_walk|sopen|sort|splitline|sprintf|sqrt|srandom|str_repeat|strcasecmp|subset|substr|system|tail|tan|tanh|text_domain|time|tmpnam|tolower|toupper|trace_psl_process|trim|union|unique|unlock|unset|va_arg|va_start|write)\b/,alias:"builtin-function"},"foreach-variable":{pattern:/(\bforeach\s+(?:(?:\w+\b|"(?:\\.|[^\\"])*")\s+){0,2})[_a-zA-Z]\w*(?=\s*\()/,lookbehind:!0,greedy:!0},function:/\b[_a-z]\w*\b(?=\s*\()/i,number:/\b(?:0x[0-9a-f]+|\d+(?:\.\d+)?)\b/i,operator:/--|\+\+|&&=?|\|\|=?|<<=?|>>=?|[=!]~|[-+*/%&|^!=<>]=?|\.|[:?]/,punctuation:/[(){}\[\];,]/}}return $E}var qE,mP;function gSe(){if(mP)return qE;mP=1,qE=e,e.displayName="pug",e.aliases=[];function e(t){(function(n){n.languages.pug={comment:{pattern:/(^([\t ]*))\/\/.*(?:(?:\r?\n|\r)\2[\t ].+)*/m,lookbehind:!0},"multiline-script":{pattern:/(^([\t ]*)script\b.*\.[\t ]*)(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0,inside:n.languages.javascript},filter:{pattern:/(^([\t ]*)):.+(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"variable"},text:/\S[\s\S]*/}},"multiline-plain-text":{pattern:/(^([\t ]*)[\w\-#.]+\.[\t ]*)(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0},markup:{pattern:/(^[\t ]*)<.+/m,lookbehind:!0,inside:n.languages.markup},doctype:{pattern:/((?:^|\n)[\t ]*)doctype(?: .+)?/,lookbehind:!0},"flow-control":{pattern:/(^[\t ]*)(?:case|default|each|else|if|unless|when|while)\b(?: .+)?/m,lookbehind:!0,inside:{each:{pattern:/^each .+? in\b/,inside:{keyword:/\b(?:each|in)\b/,punctuation:/,/}},branch:{pattern:/^(?:case|default|else|if|unless|when|while)\b/,alias:"keyword"},rest:n.languages.javascript}},keyword:{pattern:/(^[\t ]*)(?:append|block|extends|include|prepend)\b.+/m,lookbehind:!0},mixin:[{pattern:/(^[\t ]*)mixin .+/m,lookbehind:!0,inside:{keyword:/^mixin/,function:/\w+(?=\s*\(|\s*$)/,punctuation:/[(),.]/}},{pattern:/(^[\t ]*)\+.+/m,lookbehind:!0,inside:{name:{pattern:/^\+\w+/,alias:"function"},rest:n.languages.javascript}}],script:{pattern:/(^[\t ]*script(?:(?:&[^(]+)?\([^)]+\))*[\t ]).+/m,lookbehind:!0,inside:n.languages.javascript},"plain-text":{pattern:/(^[\t ]*(?!-)[\w\-#.]*[\w\-](?:(?:&[^(]+)?\([^)]+\))*\/?[\t ]).+/m,lookbehind:!0},tag:{pattern:/(^[\t ]*)(?!-)[\w\-#.]*[\w\-](?:(?:&[^(]+)?\([^)]+\))*\/?:?/m,lookbehind:!0,inside:{attributes:[{pattern:/&[^(]+\([^)]+\)/,inside:n.languages.javascript},{pattern:/\([^)]+\)/,inside:{"attr-value":{pattern:/(=\s*(?!\s))(?:\{[^}]*\}|[^,)\r\n]+)/,lookbehind:!0,inside:n.languages.javascript},"attr-name":/[\w-]+(?=\s*!?=|\s*[,)])/,punctuation:/[!=(),]+/}}],punctuation:/:/,"attr-id":/#[\w\-]+/,"attr-class":/\.[\w\-]+/}},code:[{pattern:/(^[\t ]*(?:-|!?=)).+/m,lookbehind:!0,inside:n.languages.javascript}],punctuation:/[.\-!=|]+/};for(var r=/(^([\t ]*)):<filter_name>(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/.source,a=[{filter:"atpl",language:"twig"},{filter:"coffee",language:"coffeescript"},"ejs","handlebars","less","livescript","markdown",{filter:"sass",language:"scss"},"stylus"],o={},s=0,l=a.length;s<l;s++){var u=a[s];u=typeof u=="string"?{filter:u,language:u}:u,n.languages[u.language]&&(o["filter-"+u.filter]={pattern:RegExp(r.replace("<filter_name>",function(){return u.filter}),"m"),lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"variable"},text:{pattern:/\S[\s\S]*/,alias:[u.language,"language-"+u.language],inside:n.languages[u.language]}}})}n.languages.insertBefore("pug","filter",o)})(t)}return qE}var VE,bP;function hSe(){if(bP)return VE;bP=1,VE=e,e.displayName="puppet",e.aliases=[];function e(t){(function(n){n.languages.puppet={heredoc:[{pattern:/(@\("([^"\r\n\/):]+)"(?:\/[nrts$uL]*)?\).*(?:\r?\n|\r))(?:.*(?:\r?\n|\r(?!\n)))*?[ \t]*(?:\|[ \t]*)?(?:-[ \t]*)?\2/,lookbehind:!0,alias:"string",inside:{punctuation:/(?=\S).*\S(?= *$)/}},{pattern:/(@\(([^"\r\n\/):]+)(?:\/[nrts$uL]*)?\).*(?:\r?\n|\r))(?:.*(?:\r?\n|\r(?!\n)))*?[ \t]*(?:\|[ \t]*)?(?:-[ \t]*)?\2/,lookbehind:!0,greedy:!0,alias:"string",inside:{punctuation:/(?=\S).*\S(?= *$)/}},{pattern:/@\("?(?:[^"\r\n\/):]+)"?(?:\/[nrts$uL]*)?\)/,alias:"string",inside:{punctuation:{pattern:/(\().+?(?=\))/,lookbehind:!0}}}],"multiline-comment":{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0,greedy:!0,alias:"comment"},regex:{pattern:/((?:\bnode\s+|[~=\(\[\{,]\s*|[=+]>\s*|^\s*))\/(?:[^\/\\]|\\[\s\S])+\/(?:[imx]+\b|\B)/,lookbehind:!0,greedy:!0,inside:{"extended-regex":{pattern:/^\/(?:[^\/\\]|\\[\s\S])+\/[im]*x[im]*$/,inside:{comment:/#.*/}}}},comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0,greedy:!0},string:{pattern:/(["'])(?:\$\{(?:[^'"}]|(["'])(?:(?!\2)[^\\]|\\[\s\S])*\2)+\}|\$(?!\{)|(?!\1)[^\\$]|\\[\s\S])*\1/,greedy:!0,inside:{"double-quoted":{pattern:/^"[\s\S]*"$/,inside:{}}}},variable:{pattern:/\$(?:::)?\w+(?:::\w+)*/,inside:{punctuation:/::/}},"attr-name":/(?:\b\w+|\*)(?=\s*=>)/,function:[{pattern:/(\.)(?!\d)\w+/,lookbehind:!0},/\b(?:contain|debug|err|fail|include|info|notice|realize|require|tag|warning)\b|\b(?!\d)\w+(?=\()/],number:/\b(?:0x[a-f\d]+|\d+(?:\.\d+)?(?:e-?\d+)?)\b/i,boolean:/\b(?:false|true)\b/,keyword:/\b(?:application|attr|case|class|consumes|default|define|else|elsif|function|if|import|inherits|node|private|produces|type|undef|unless)\b/,datatype:{pattern:/\b(?:Any|Array|Boolean|Callable|Catalogentry|Class|Collection|Data|Default|Enum|Float|Hash|Integer|NotUndef|Numeric|Optional|Pattern|Regexp|Resource|Runtime|Scalar|String|Struct|Tuple|Type|Undef|Variant)\b/,alias:"symbol"},operator:/=[=~>]?|![=~]?|<(?:<\|?|[=~|-])?|>[>=]?|->?|~>|\|>?>?|[*\/%+?]|\b(?:and|in|or)\b/,punctuation:/[\[\]{}().,;]|:+/};var r=[{pattern:/(^|[^\\])\$\{(?:[^'"{}]|\{[^}]*\}|(["'])(?:(?!\2)[^\\]|\\[\s\S])*\2)+\}/,lookbehind:!0,inside:{"short-variable":{pattern:/(^\$\{)(?!\w+\()(?:::)?\w+(?:::\w+)*/,lookbehind:!0,alias:"variable",inside:{punctuation:/::/}},delimiter:{pattern:/^\$/,alias:"variable"},rest:n.languages.puppet}},{pattern:/(^|[^\\])\$(?:::)?\w+(?:::\w+)*/,lookbehind:!0,alias:"variable",inside:{punctuation:/::/}}];n.languages.puppet.heredoc[0].inside.interpolation=r,n.languages.puppet.string.inside["double-quoted"].inside.interpolation=r})(t)}return VE}var WE,yP;function mSe(){if(yP)return WE;yP=1,WE=e,e.displayName="pure",e.aliases=[];function e(t){(function(n){n.languages.pure={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0},/#!.+/],"inline-lang":{pattern:/%<[\s\S]+?%>/,greedy:!0,inside:{lang:{pattern:/(^%< *)-\*-.+?-\*-/,lookbehind:!0,alias:"comment"},delimiter:{pattern:/^%<.*|%>$/,alias:"punctuation"}}},string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},number:{pattern:/((?:\.\.)?)(?:\b(?:inf|nan)\b|\b0x[\da-f]+|(?:\b(?:0b)?\d+(?:\.\d+)?|\B\.\d+)(?:e[+-]?\d+)?L?)/i,lookbehind:!0},keyword:/\b(?:NULL|ans|break|bt|case|catch|cd|clear|const|def|del|dump|else|end|exit|extern|false|force|help|if|infix[lr]?|interface|let|ls|mem|namespace|nonfix|of|otherwise|outfix|override|postfix|prefix|private|public|pwd|quit|run|save|show|stats|then|throw|trace|true|type|underride|using|when|with)\b/,function:/\b(?:abs|add_(?:addr|constdef|(?:fundef|interface|macdef|typedef)(?:_at)?|vardef)|all|any|applp?|arity|bigintp?|blob(?:_crc|_size|p)?|boolp?|byte_c?string(?:_pointer)?|byte_(?:matrix|pointer)|calloc|cat|catmap|ceil|char[ps]?|check_ptrtag|chr|clear_sentry|clearsym|closurep?|cmatrixp?|cols?|colcat(?:map)?|colmap|colrev|colvector(?:p|seq)?|complex(?:_float_(?:matrix|pointer)|_matrix(?:_view)?|_pointer|p)?|conj|cookedp?|cst|cstring(?:_(?:dup|list|vector))?|curry3?|cyclen?|del_(?:constdef|fundef|interface|macdef|typedef|vardef)|delete|diag(?:mat)?|dim|dmatrixp?|do|double(?:_matrix(?:_view)?|_pointer|p)?|dowith3?|drop|dropwhile|eval(?:cmd)?|exactp|filter|fix|fixity|flip|float(?:_matrix|_pointer)|floor|fold[lr]1?|frac|free|funp?|functionp?|gcd|get(?:_(?:byte|constdef|double|float|fundef|int(?:64)?|interface(?:_typedef)?|long|macdef|pointer|ptrtag|sentry|short|string|typedef|vardef))?|globsym|hash|head|id|im|imatrixp?|index|inexactp|infp|init|insert|int(?:_matrix(?:_view)?|_pointer|p)?|int64_(?:matrix|pointer)|integerp?|iteraten?|iterwhile|join|keys?|lambdap?|last(?:err(?:pos)?)?|lcd|list[2p]?|listmap|make_ptrtag|malloc|map|matcat|matrixp?|max|member|min|nanp|nargs|nmatrixp?|null|numberp?|ord|pack(?:ed)?|pointer(?:_cast|_tag|_type|p)?|pow|pred|ptrtag|put(?:_(?:byte|double|float|int(?:64)?|long|pointer|short|string))?|rationalp?|re|realp?|realloc|recordp?|redim|reduce(?:_with)?|refp?|repeatn?|reverse|rlistp?|round|rows?|rowcat(?:map)?|rowmap|rowrev|rowvector(?:p|seq)?|same|scan[lr]1?|sentry|sgn|short_(?:matrix|pointer)|slice|smatrixp?|sort|split|str|strcat|stream|stride|string(?:_(?:dup|list|vector)|p)?|subdiag(?:mat)?|submat|subseq2?|substr|succ|supdiag(?:mat)?|symbolp?|tail|take|takewhile|thunkp?|transpose|trunc|tuplep?|typep|ubyte|uint(?:64)?|ulong|uncurry3?|unref|unzip3?|update|ushort|vals?|varp?|vector(?:p|seq)?|void|zip3?|zipwith3?)\b/,special:{pattern:/\b__[a-z]+__\b/i,alias:"builtin"},operator:/(?:[!"#$%&'*+,\-.\/:<=>?@\\^`|~\u00a1-\u00bf\u00d7-\u00f7\u20d0-\u2bff]|\b_+\b)+|\b(?:and|div|mod|not|or)\b/,punctuation:/[(){}\[\];,|]/};var r=["c",{lang:"c++",alias:"cpp"},"fortran"],a=/%< *-\*- *<lang>\d* *-\*-[\s\S]+?%>/.source;r.forEach(function(o){var s=o;if(typeof o!="string"&&(s=o.alias,o=o.lang),n.languages[s]){var l={};l["inline-lang-"+s]={pattern:RegExp(a.replace("<lang>",o.replace(/([.+*?\/\\(){}\[\]])/g,"\\$1")),"i"),inside:n.util.clone(n.languages.pure["inline-lang"].inside)},l["inline-lang-"+s].inside.rest=n.util.clone(n.languages[s]),n.languages.insertBefore("pure","inline-lang",l)}}),n.languages.c&&(n.languages.pure["inline-lang"].inside.rest=n.util.clone(n.languages.c))})(t)}return WE}var YE,vP;function bSe(){if(vP)return YE;vP=1,YE=e,e.displayName="purebasic",e.aliases=[];function e(t){t.languages.purebasic=t.languages.extend("clike",{comment:/;.*/,keyword:/\b(?:align|and|as|break|calldebugger|case|compilercase|compilerdefault|compilerelse|compilerelseif|compilerendif|compilerendselect|compilererror|compilerif|compilerselect|continue|data|datasection|debug|debuglevel|declare|declarec|declarecdll|declaredll|declaremodule|default|define|dim|disableasm|disabledebugger|disableexplicit|else|elseif|enableasm|enabledebugger|enableexplicit|end|enddatasection|enddeclaremodule|endenumeration|endif|endimport|endinterface|endmacro|endmodule|endprocedure|endselect|endstructure|endstructureunion|endwith|enumeration|extends|fakereturn|for|foreach|forever|global|gosub|goto|if|import|importc|includebinary|includefile|includepath|interface|macro|module|newlist|newmap|next|not|or|procedure|procedurec|procedurecdll|proceduredll|procedurereturn|protected|prototype|prototypec|read|redim|repeat|restore|return|runtime|select|shared|static|step|structure|structureunion|swap|threaded|to|until|wend|while|with|xincludefile|xor)\b/i,function:/\b\w+(?:\.\w+)?\s*(?=\()/,number:/(?:\$[\da-f]+|\b-?(?:\d+(?:\.\d+)?|\.\d+)(?:e[+-]?\d+)?)\b/i,operator:/(?:@\*?|\?|\*)\w+|-[>-]?|\+\+?|!=?|<<?=?|>>?=?|==?|&&?|\|?\||[~^%?*/@]/}),t.languages.insertBefore("purebasic","keyword",{tag:/#\w+\$?/,asm:{pattern:/(^[\t ]*)!.*/m,lookbehind:!0,alias:"tag",inside:{comment:/;.*/,string:{pattern:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},"label-reference-anonymous":{pattern:/(!\s*j[a-z]+\s+)@[fb]/i,lookbehind:!0,alias:"fasm-label"},"label-reference-addressed":{pattern:/(!\s*j[a-z]+\s+)[A-Z._?$@][\w.?$@~#]*/i,lookbehind:!0,alias:"fasm-label"},keyword:[/\b(?:extern|global)\b[^;\r\n]*/i,/\b(?:CPU|DEFAULT|FLOAT)\b.*/],function:{pattern:/^([\t ]*!\s*)[\da-z]+(?=\s|$)/im,lookbehind:!0},"function-inline":{pattern:/(:\s*)[\da-z]+(?=\s)/i,lookbehind:!0,alias:"function"},label:{pattern:/^([\t ]*!\s*)[A-Za-z._?$@][\w.?$@~#]*(?=:)/m,lookbehind:!0,alias:"fasm-label"},register:/\b(?:st\d|[xyz]mm\d\d?|[cdt]r\d|r\d\d?[bwd]?|[er]?[abcd]x|[abcd][hl]|[er]?(?:bp|di|si|sp)|[cdefgs]s|mm\d+)\b/i,number:/(?:\b|-|(?=\$))(?:0[hx](?:[\da-f]*\.)?[\da-f]+(?:p[+-]?\d+)?|\d[\da-f]+[hx]|\$\d[\da-f]*|0[oq][0-7]+|[0-7]+[oq]|0[by][01]+|[01]+[by]|0[dt]\d+|(?:\d+(?:\.\d+)?|\.\d+)(?:\.?e[+-]?\d+)?[dt]?)\b/i,operator:/[\[\]*+\-/%<>=&|$!,.:]/}}}),delete t.languages.purebasic["class-name"],delete t.languages.purebasic.boolean,t.languages.pbfasm=t.languages.purebasic}return YE}var KE,SP;function ySe(){if(SP)return KE;SP=1;var e=SA();KE=t,t.displayName="purescript",t.aliases=["purs"];function t(n){n.register(e),n.languages.purescript=n.languages.extend("haskell",{keyword:/\b(?:ado|case|class|data|derive|do|else|forall|if|in|infixl|infixr|instance|let|module|newtype|of|primitive|then|type|where)\b|∀/,"import-statement":{pattern:/(^[\t ]*)import\s+[A-Z][\w']*(?:\.[A-Z][\w']*)*(?:\s+as\s+[A-Z][\w']*(?:\.[A-Z][\w']*)*)?(?:\s+hiding\b)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|hiding|import)\b/,punctuation:/\./}},builtin:/\b(?:absurd|add|ap|append|apply|between|bind|bottom|clamp|compare|comparing|compose|conj|const|degree|discard|disj|div|eq|flap|flip|gcd|identity|ifM|join|lcm|liftA1|liftM1|map|max|mempty|min|mod|mul|negate|not|notEq|one|otherwise|recip|show|sub|top|unit|unless|unlessM|void|when|whenM|zero)\b/,operator:[n.languages.haskell.operator[0],n.languages.haskell.operator[2],/[\xa2-\xa6\xa8\xa9\xac\xae-\xb1\xb4\xb8\xd7\xf7\u02c2-\u02c5\u02d2-\u02df\u02e5-\u02eb\u02ed\u02ef-\u02ff\u0375\u0384\u0385\u03f6\u0482\u058d-\u058f\u0606-\u0608\u060b\u060e\u060f\u06de\u06e9\u06fd\u06fe\u07f6\u07fe\u07ff\u09f2\u09f3\u09fa\u09fb\u0af1\u0b70\u0bf3-\u0bfa\u0c7f\u0d4f\u0d79\u0e3f\u0f01-\u0f03\u0f13\u0f15-\u0f17\u0f1a-\u0f1f\u0f34\u0f36\u0f38\u0fbe-\u0fc5\u0fc7-\u0fcc\u0fce\u0fcf\u0fd5-\u0fd8\u109e\u109f\u1390-\u1399\u166d\u17db\u1940\u19de-\u19ff\u1b61-\u1b6a\u1b74-\u1b7c\u1fbd\u1fbf-\u1fc1\u1fcd-\u1fcf\u1fdd-\u1fdf\u1fed-\u1fef\u1ffd\u1ffe\u2044\u2052\u207a-\u207c\u208a-\u208c\u20a0-\u20bf\u2100\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211e-\u2123\u2125\u2127\u2129\u212e\u213a\u213b\u2140-\u2144\u214a-\u214d\u214f\u218a\u218b\u2190-\u2307\u230c-\u2328\u232b-\u2426\u2440-\u244a\u249c-\u24e9\u2500-\u2767\u2794-\u27c4\u27c7-\u27e5\u27f0-\u2982\u2999-\u29d7\u29dc-\u29fb\u29fe-\u2b73\u2b76-\u2b95\u2b97-\u2bff\u2ce5-\u2cea\u2e50\u2e51\u2e80-\u2e99\u2e9b-\u2ef3\u2f00-\u2fd5\u2ff0-\u2ffb\u3004\u3012\u3013\u3020\u3036\u3037\u303e\u303f\u309b\u309c\u3190\u3191\u3196-\u319f\u31c0-\u31e3\u3200-\u321e\u322a-\u3247\u3250\u3260-\u327f\u328a-\u32b0\u32c0-\u33ff\u4dc0-\u4dff\ua490-\ua4c6\ua700-\ua716\ua720\ua721\ua789\ua78a\ua828-\ua82b\ua836-\ua839\uaa77-\uaa79\uab5b\uab6a\uab6b\ufb29\ufbb2-\ufbc1\ufdfc\ufdfd\ufe62\ufe64-\ufe66\ufe69\uff04\uff0b\uff1c-\uff1e\uff3e\uff40\uff5c\uff5e\uffe0-\uffe6\uffe8-\uffee\ufffc\ufffd]/]}),n.languages.purs=n.languages.purescript}return KE}var XE,EP;function vSe(){if(EP)return XE;EP=1,XE=e,e.displayName="python",e.aliases=["py"];function e(t){t.languages.python={comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0,greedy:!0},"string-interpolation":{pattern:/(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,lookbehind:!0,inside:{"format-spec":{pattern:/(:)[^:(){}]+(?=\}$)/,lookbehind:!0},"conversion-option":{pattern:/![sra](?=[:}]$)/,alias:"punctuation"},rest:null}},string:/[\s\S]+/}},"triple-quoted-string":{pattern:/(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,greedy:!0,alias:"string"},string:{pattern:/(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,greedy:!0},function:{pattern:/((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,lookbehind:!0},"class-name":{pattern:/(\bclass\s+)\w+/i,lookbehind:!0},decorator:{pattern:/(^[\t ]*)@\w+(?:\.\w+)*/m,lookbehind:!0,alias:["annotation","punctuation"],inside:{punctuation:/\./}},keyword:/\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,builtin:/\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,boolean:/\b(?:False|None|True)\b/,number:/\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,operator:/[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,punctuation:/[{}[\];(),.:]/},t.languages.python["string-interpolation"].inside.interpolation.inside.rest=t.languages.python,t.languages.py=t.languages.python}return XE}var ZE,wP;function SSe(){if(wP)return ZE;wP=1,ZE=e,e.displayName="q",e.aliases=[];function e(t){t.languages.q={string:/"(?:\\.|[^"\\\r\n])*"/,comment:[{pattern:/([\t )\]}])\/.*/,lookbehind:!0,greedy:!0},{pattern:/(^|\r?\n|\r)\/[\t ]*(?:(?:\r?\n|\r)(?:.*(?:\r?\n|\r(?!\n)))*?(?:\\(?=[\t ]*(?:\r?\n|\r))|$)|\S.*)/,lookbehind:!0,greedy:!0},{pattern:/^\\[\t ]*(?:\r?\n|\r)[\s\S]+/m,greedy:!0},{pattern:/^#!.+/m,greedy:!0}],symbol:/`(?::\S+|[\w.]*)/,datetime:{pattern:/0N[mdzuvt]|0W[dtz]|\d{4}\.\d\d(?:m|\.\d\d(?:T(?:\d\d(?::\d\d(?::\d\d(?:[.:]\d\d\d)?)?)?)?)?[dz]?)|\d\d:\d\d(?::\d\d(?:[.:]\d\d\d)?)?[uvt]?/,alias:"number"},number:/\b(?![01]:)(?:0N[hje]?|0W[hj]?|0[wn]|0x[\da-fA-F]+|\d+(?:\.\d*)?(?:e[+-]?\d+)?[hjfeb]?)/,keyword:/\\\w+\b|\b(?:abs|acos|aj0?|all|and|any|asc|asin|asof|atan|attr|avgs?|binr?|by|ceiling|cols|cor|cos|count|cov|cross|csv|cut|delete|deltas|desc|dev|differ|distinct|div|do|dsave|ej|enlist|eval|except|exec|exit|exp|fby|fills|first|fkeys|flip|floor|from|get|getenv|group|gtime|hclose|hcount|hdel|hopen|hsym|iasc|identity|idesc|if|ij|in|insert|inter|inv|keys?|last|like|list|ljf?|load|log|lower|lsq|ltime|ltrim|mavg|maxs?|mcount|md5|mdev|med|meta|mins?|mmax|mmin|mmu|mod|msum|neg|next|not|null|or|over|parse|peach|pj|plist|prds?|prev|prior|rand|rank|ratios|raze|read0|read1|reciprocal|reval|reverse|rload|rotate|rsave|rtrim|save|scan|scov|sdev|select|set|setenv|show|signum|sin|sqrt|ssr?|string|sublist|sums?|sv|svar|system|tables|tan|til|trim|txf|type|uj|ungroup|union|update|upper|upsert|value|var|views?|vs|wavg|where|while|within|wj1?|wsum|ww|xasc|xbar|xcols?|xdesc|xexp|xgroup|xkey|xlog|xprev|xrank)\b/,adverb:{pattern:/['\/\\]:?|\beach\b/,alias:"function"},verb:{pattern:/(?:\B\.\B|\b[01]:|<[=>]?|>=?|[:+\-*%,!?~=|$&#@^]):?|\b_\b:?/,alias:"operator"},punctuation:/[(){}\[\];.]/}}return ZE}var QE,xP;function ESe(){if(xP)return QE;xP=1,QE=e,e.displayName="qml",e.aliases=[];function e(t){(function(n){for(var r=/"(?:\\.|[^\\"\r\n])*"|'(?:\\.|[^\\'\r\n])*'/.source,a=/\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))*\*\//.source,o=/(?:[^\\()[\]{}"'/]|<string>|\/(?![*/])|<comment>|\(<expr>*\)|\[<expr>*\]|\{<expr>*\}|\\[\s\S])/.source.replace(/<string>/g,function(){return r}).replace(/<comment>/g,function(){return a}),s=0;s<2;s++)o=o.replace(/<expr>/g,function(){return o});o=o.replace(/<expr>/g,"[^\\s\\S]"),n.languages.qml={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},"javascript-function":{pattern:RegExp(/((?:^|;)[ \t]*)function\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*\(<js>*\)\s*\{<js>*\}/.source.replace(/<js>/g,function(){return o}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:n.languages.javascript},"class-name":{pattern:/((?:^|[:;])[ \t]*)(?!\d)\w+(?=[ \t]*\{|[ \t]+on\b)/m,lookbehind:!0},property:[{pattern:/((?:^|[;{])[ \t]*)(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0},{pattern:/((?:^|[;{])[ \t]*)property[ \t]+(?!\d)\w+(?:\.\w+)*[ \t]+(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0,inside:{keyword:/^property/,property:/\w+(?:\.\w+)*/}}],"javascript-expression":{pattern:RegExp(/(:[ \t]*)(?![\s;}[])(?:(?!$|[;}])<js>)+/.source.replace(/<js>/g,function(){return o}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:n.languages.javascript},string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},keyword:/\b(?:as|import|on)\b/,punctuation:/[{}[\]:;,]/}})(t)}return QE}var JE,kP;function wSe(){if(kP)return JE;kP=1,JE=e,e.displayName="qore",e.aliases=[];function e(t){t.languages.qore=t.languages.extend("clike",{comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:\/\/|#).*)/,lookbehind:!0},string:{pattern:/("|')(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},keyword:/\b(?:abstract|any|assert|binary|bool|boolean|break|byte|case|catch|char|class|code|const|continue|data|default|do|double|else|enum|extends|final|finally|float|for|goto|hash|if|implements|import|inherits|instanceof|int|interface|long|my|native|new|nothing|null|object|our|own|private|reference|rethrow|return|short|soft(?:bool|date|float|int|list|number|string)|static|strictfp|string|sub|super|switch|synchronized|this|throw|throws|transient|try|void|volatile|while)\b/,boolean:/\b(?:false|true)\b/i,function:/\$?\b(?!\d)\w+(?=\()/,number:/\b(?:0b[01]+|0x(?:[\da-f]*\.)?[\da-fp\-]+|(?:\d+(?:\.\d+)?|\.\d+)(?:e\d+)?[df]|(?:\d+(?:\.\d+)?|\.\d+))\b/i,operator:{pattern:/(^|[^.])(?:\+[+=]?|-[-=]?|[!=](?:==?|~)?|>>?=?|<(?:=>?|<=?)?|&[&=]?|\|[|=]?|[*\/%^]=?|[~?])/,lookbehind:!0},variable:/\$(?!\d)\w+\b/})}return JE}var ew,TP;function xSe(){if(TP)return ew;TP=1,ew=e,e.displayName="qsharp",e.aliases=["qs"];function e(t){(function(n){function r(v,y){return v.replace(/<<(\d+)>>/g,function(k,A){return"(?:"+y[+A]+")"})}function a(v,y,k){return RegExp(r(v,y),"")}function o(v,y){for(var k=0;k<y;k++)v=v.replace(/<<self>>/g,function(){return"(?:"+v+")"});return v.replace(/<<self>>/g,"[^\\s\\S]")}var s={type:"Adj BigInt Bool Ctl Double false Int One Pauli PauliI PauliX PauliY PauliZ Qubit Range Result String true Unit Zero",other:"Adjoint adjoint apply as auto body borrow borrowing Controlled controlled distribute elif else fail fixup for function if in internal intrinsic invert is let mutable namespace new newtype open operation repeat return self set until use using while within"};function l(v){return"\\b(?:"+v.trim().replace(/ /g,"|")+")\\b"}var u=RegExp(l(s.type+" "+s.other)),d=/\b[A-Za-z_]\w*\b/.source,p=r(/<<0>>(?:\s*\.\s*<<0>>)*/.source,[d]),g={keyword:u,punctuation:/[<>()?,.:[\]]/},m=/"(?:\\.|[^\\"])*"/.source;n.languages.qsharp=n.languages.extend("clike",{comment:/\/\/.*/,string:[{pattern:a(/(^|[^$\\])<<0>>/.source,[m]),lookbehind:!0,greedy:!0}],"class-name":[{pattern:a(/(\b(?:as|open)\s+)<<0>>(?=\s*(?:;|as\b))/.source,[p]),lookbehind:!0,inside:g},{pattern:a(/(\bnamespace\s+)<<0>>(?=\s*\{)/.source,[p]),lookbehind:!0,inside:g}],keyword:u,number:/(?:\b0(?:x[\da-f]+|b[01]+|o[0-7]+)|(?:\B\.\d+|\b\d+(?:\.\d*)?)(?:e[-+]?\d+)?)l?\b/i,operator:/\band=|\bor=|\band\b|\bnot\b|\bor\b|<[-=]|[-=]>|>>>=?|<<<=?|\^\^\^=?|\|\|\|=?|&&&=?|w\/=?|~~~|[*\/+\-^=!%]=?/,punctuation:/::|[{}[\];(),.:]/}),n.languages.insertBefore("qsharp","number",{range:{pattern:/\.\./,alias:"operator"}});var b=o(r(/\{(?:[^"{}]|<<0>>|<<self>>)*\}/.source,[m]),2);n.languages.insertBefore("qsharp","string",{"interpolation-string":{pattern:a(/\$"(?:\\.|<<0>>|[^\\"{])*"/.source,[b]),greedy:!0,inside:{interpolation:{pattern:a(/((?:^|[^\\])(?:\\\\)*)<<0>>/.source,[b]),lookbehind:!0,inside:{punctuation:/^\{|\}$/,expression:{pattern:/[\s\S]+/,alias:"language-qsharp",inside:n.languages.qsharp}}},string:/[\s\S]+/}}})})(t),t.languages.qs=t.languages.qsharp}return ew}var tw,AP;function kSe(){if(AP)return tw;AP=1,tw=e,e.displayName="r",e.aliases=[];function e(t){t.languages.r={comment:/#.*/,string:{pattern:/(['"])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},"percent-operator":{pattern:/%[^%\s]*%/,alias:"operator"},boolean:/\b(?:FALSE|TRUE)\b/,ellipsis:/\.\.(?:\.|\d+)/,number:[/\b(?:Inf|NaN)\b/,/(?:\b0x[\dA-Fa-f]+(?:\.\d*)?|\b\d+(?:\.\d*)?|\B\.\d+)(?:[EePp][+-]?\d+)?[iL]?/],keyword:/\b(?:NA|NA_character_|NA_complex_|NA_integer_|NA_real_|NULL|break|else|for|function|if|in|next|repeat|while)\b/,operator:/->?>?|<(?:=|<?-)?|[>=!]=?|::?|&&?|\|\|?|[+*\/^$@~]/,punctuation:/[(){}\[\],;]/}}return tw}var nw,RP;function TSe(){if(RP)return nw;RP=1;var e=kA();nw=t,t.displayName="racket",t.aliases=["rkt"];function t(n){n.register(e),n.languages.racket=n.languages.extend("scheme",{"lambda-parameter":{pattern:/([(\[]lambda\s+[(\[])[^()\[\]'\s]+/,lookbehind:!0}}),n.languages.insertBefore("racket","string",{lang:{pattern:/^#lang.+/m,greedy:!0,alias:"keyword"}}),n.languages.rkt=n.languages.racket}return nw}var rw,CP;function ASe(){if(CP)return rw;CP=1,rw=e,e.displayName="reason",e.aliases=[];function e(t){t.languages.reason=t.languages.extend("clike",{string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^\\\r\n"])*"/,greedy:!0},"class-name":/\b[A-Z]\w*/,keyword:/\b(?:and|as|assert|begin|class|constraint|do|done|downto|else|end|exception|external|for|fun|function|functor|if|in|include|inherit|initializer|lazy|let|method|module|mutable|new|nonrec|object|of|open|or|private|rec|sig|struct|switch|then|to|try|type|val|virtual|when|while|with)\b/,operator:/\.{3}|:[:=]|\|>|->|=(?:==?|>)?|<=?|>=?|[|^?'#!~`]|[+\-*\/]\.?|\b(?:asr|land|lor|lsl|lsr|lxor|mod)\b/}),t.languages.insertBefore("reason","class-name",{char:{pattern:/'(?:\\x[\da-f]{2}|\\o[0-3][0-7][0-7]|\\\d{3}|\\.|[^'\\\r\n])'/,greedy:!0},constructor:/\b[A-Z]\w*\b(?!\s*\.)/,label:{pattern:/\b[a-z]\w*(?=::)/,alias:"symbol"}}),delete t.languages.reason.function}return rw}var aw,_P;function RSe(){if(_P)return aw;_P=1,aw=e,e.displayName="regex",e.aliases=[];function e(t){(function(n){var r={pattern:/\\[\\(){}[\]^$+*?|.]/,alias:"escape"},a=/\\(?:x[\da-fA-F]{2}|u[\da-fA-F]{4}|u\{[\da-fA-F]+\}|0[0-7]{0,2}|[123][0-7]{2}|c[a-zA-Z]|.)/,o={pattern:/\.|\\[wsd]|\\p\{[^{}]+\}/i,alias:"class-name"},s={pattern:/\\[wsd]|\\p\{[^{}]+\}/i,alias:"class-name"},l="(?:[^\\\\-]|"+a.source+")",u=RegExp(l+"-"+l),d={pattern:/(<|')[^<>']+(?=[>']$)/,lookbehind:!0,alias:"variable"};n.languages.regex={"char-class":{pattern:/((?:^|[^\\])(?:\\\\)*)\[(?:[^\\\]]|\\[\s\S])*\]/,lookbehind:!0,inside:{"char-class-negation":{pattern:/(^\[)\^/,lookbehind:!0,alias:"operator"},"char-class-punctuation":{pattern:/^\[|\]$/,alias:"punctuation"},range:{pattern:u,inside:{escape:a,"range-punctuation":{pattern:/-/,alias:"operator"}}},"special-escape":r,"char-set":s,escape:a}},"special-escape":r,"char-set":o,backreference:[{pattern:/\\(?![123][0-7]{2})[1-9]/,alias:"keyword"},{pattern:/\\k<[^<>']+>/,alias:"keyword",inside:{"group-name":d}}],anchor:{pattern:/[$^]|\\[ABbGZz]/,alias:"function"},escape:a,group:[{pattern:/\((?:\?(?:<[^<>']+>|'[^<>']+'|[>:]|<?[=!]|[idmnsuxU]+(?:-[idmnsuxU]+)?:?))?/,alias:"punctuation",inside:{"group-name":d}},{pattern:/\)/,alias:"punctuation"}],quantifier:{pattern:/(?:[+*?]|\{\d+(?:,\d*)?\})[?+]?/,alias:"number"},alternation:{pattern:/\|/,alias:"keyword"}}})(t)}return aw}var ow,NP;function CSe(){if(NP)return ow;NP=1,ow=e,e.displayName="rego",e.aliases=[];function e(t){t.languages.rego={comment:/#.*/,property:{pattern:/(^|[^\\.])(?:"(?:\\.|[^\\"\r\n])*"|`[^`]*`|\b[a-z_]\w*\b)(?=\s*:(?!=))/i,lookbehind:!0,greedy:!0},string:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"|`[^`]*`/,lookbehind:!0,greedy:!0},keyword:/\b(?:as|default|else|import|not|null|package|set(?=\s*\()|some|with)\b/,boolean:/\b(?:false|true)\b/,function:{pattern:/\b[a-z_]\w*\b(?:\s*\.\s*\b[a-z_]\w*\b)*(?=\s*\()/i,inside:{namespace:/\b\w+\b(?=\s*\.)/,punctuation:/\./}},number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,operator:/[-+*/%|&]|[<>:=]=?|!=|\b_\b/,punctuation:/[,;.\[\]{}()]/}}return ow}var iw,OP;function _Se(){if(OP)return iw;OP=1,iw=e,e.displayName="renpy",e.aliases=["rpy"];function e(t){t.languages.renpy={comment:{pattern:/(^|[^\\])#.+/,lookbehind:!0},string:{pattern:/("""|''')[\s\S]+?\1|("|')(?:\\.|(?!\2)[^\\])*\2|(?:^#?(?:(?:[0-9a-fA-F]){3}|[0-9a-fA-F]{6})$)/m,greedy:!0},function:/\b[a-z_]\w*(?=\()/i,property:/\b(?:Update|UpdateVersion|action|activate_sound|adv_nvl_transition|after_load_transition|align|alpha|alt|anchor|antialias|area|auto|background|bar_invert|bar_resizing|bar_vertical|black_color|bold|bottom_bar|bottom_gutter|bottom_margin|bottom_padding|box_reverse|box_wrap|can_update|caret|child|color|crop|default_afm_enable|default_afm_time|default_fullscreen|default_text_cps|developer|directory_name|drag_handle|drag_joined|drag_name|drag_raise|draggable|dragged|drop_shadow|drop_shadow_color|droppable|dropped|easein|easeout|edgescroll|end_game_transition|end_splash_transition|enter_replay_transition|enter_sound|enter_transition|enter_yesno_transition|executable_name|exit_replay_transition|exit_sound|exit_transition|exit_yesno_transition|fadein|fadeout|first_indent|first_spacing|fit_first|focus|focus_mask|font|foreground|game_main_transition|get_installed_packages|google_play_key|google_play_salt|ground|has_music|has_sound|has_voice|height|help|hinting|hover|hover_background|hover_color|hover_sound|hovered|hyperlink_functions|idle|idle_color|image_style|include_update|insensitive|insensitive_background|insensitive_color|inside|intra_transition|italic|justify|kerning|keyboard_focus|language|layer_clipping|layers|layout|left_bar|left_gutter|left_margin|left_padding|length|line_leading|line_overlap_split|line_spacing|linear|main_game_transition|main_menu_music|maximum|min_width|minimum|minwidth|modal|mouse|mousewheel|name|narrator_menu|newline_indent|nvl_adv_transition|offset|order_reverse|outlines|overlay_functions|pos|position|prefix|radius|range|rest_indent|right_bar|right_gutter|right_margin|right_padding|rotate|rotate_pad|ruby_style|sample_sound|save_directory|say_attribute_transition|screen_height|screen_width|scrollbars|selected_hover|selected_hover_color|selected_idle|selected_idle_color|selected_insensitive|show_side_image|show_two_window|side_spacing|side_xpos|side_ypos|size|size_group|slow_cps|slow_cps_multiplier|spacing|strikethrough|subpixel|text_align|text_style|text_xpos|text_y_fudge|text_ypos|thumb|thumb_offset|thumb_shadow|thumbnail_height|thumbnail_width|time|top_bar|top_gutter|top_margin|top_padding|translations|underline|unscrollable|update|value|version|version_name|version_tuple|vertical|width|window_hide_transition|window_icon|window_left_padding|window_show_transition|window_title|windows_icon|xadjustment|xalign|xanchor|xanchoraround|xaround|xcenter|xfill|xinitial|xmargin|xmaximum|xminimum|xoffset|xofsset|xpadding|xpos|xsize|xzoom|yadjustment|yalign|yanchor|yanchoraround|yaround|ycenter|yfill|yinitial|ymargin|ymaximum|yminimum|yoffset|ypadding|ypos|ysize|ysizexysize|yzoom|zoom|zorder)\b/,tag:/\b(?:bar|block|button|buttoscreenn|drag|draggroup|fixed|frame|grid|[hv]box|hotbar|hotspot|image|imagebutton|imagemap|input|key|label|menu|mm_menu_frame|mousearea|nvl|parallel|screen|self|side|tag|text|textbutton|timer|vbar|viewport|window)\b|\$/,keyword:/\b(?:None|add|adjustment|alignaround|allow|angle|animation|around|as|assert|behind|box_layout|break|build|cache|call|center|changed|child_size|choice|circles|class|clear|clicked|clipping|clockwise|config|contains|continue|corner1|corner2|counterclockwise|def|default|define|del|delay|disabled|disabled_text|dissolve|elif|else|event|except|exclude|exec|expression|fade|finally|for|from|function|global|gm_root|has|hide|id|if|import|in|init|is|jump|knot|lambda|left|less_rounded|mm_root|movie|music|null|on|onlayer|pass|pause|persistent|play|print|python|queue|raise|random|renpy|repeat|return|right|rounded_window|scene|scope|set|show|slow|slow_abortable|slow_done|sound|stop|store|style|style_group|substitute|suffix|theme|transform|transform_anchor|transpose|try|ui|unhovered|updater|use|voice|while|widget|widget_hover|widget_selected|widget_text|yield)\b/,boolean:/\b(?:[Ff]alse|[Tt]rue)\b/,number:/(?:\b(?:0[bo])?(?:(?:\d|0x[\da-f])[\da-f]*(?:\.\d*)?)|\B\.\d+)(?:e[+-]?\d+)?j?/i,operator:/[-+%=]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]|\b(?:and|at|not|or|with)\b/,punctuation:/[{}[\];(),.:]/},t.languages.rpy=t.languages.renpy}return iw}var sw,IP;function NSe(){if(IP)return sw;IP=1,sw=e,e.displayName="rest",e.aliases=[];function e(t){t.languages.rest={table:[{pattern:/(^[\t ]*)(?:\+[=-]+)+\+(?:\r?\n|\r)(?:\1[+|].+[+|](?:\r?\n|\r))+\1(?:\+[=-]+)+\+/m,lookbehind:!0,inside:{punctuation:/\||(?:\+[=-]+)+\+/}},{pattern:/(^[\t ]*)=+ [ =]*=(?:(?:\r?\n|\r)\1.+)+(?:\r?\n|\r)\1=+ [ =]*=(?=(?:\r?\n|\r){2}|\s*$)/m,lookbehind:!0,inside:{punctuation:/[=-]+/}}],"substitution-def":{pattern:/(^[\t ]*\.\. )\|(?:[^|\s](?:[^|]*[^|\s])?)\| [^:]+::/m,lookbehind:!0,inside:{substitution:{pattern:/^\|(?:[^|\s]|[^|\s][^|]*[^|\s])\|/,alias:"attr-value",inside:{punctuation:/^\||\|$/}},directive:{pattern:/( )(?! )[^:]+::/,lookbehind:!0,alias:"function",inside:{punctuation:/::$/}}}},"link-target":[{pattern:/(^[\t ]*\.\. )\[[^\]]+\]/m,lookbehind:!0,alias:"string",inside:{punctuation:/^\[|\]$/}},{pattern:/(^[\t ]*\.\. )_(?:`[^`]+`|(?:[^:\\]|\\.)+):/m,lookbehind:!0,alias:"string",inside:{punctuation:/^_|:$/}}],directive:{pattern:/(^[\t ]*\.\. )[^:]+::/m,lookbehind:!0,alias:"function",inside:{punctuation:/::$/}},comment:{pattern:/(^[\t ]*\.\.)(?:(?: .+)?(?:(?:\r?\n|\r).+)+| .+)(?=(?:\r?\n|\r){2}|$)/m,lookbehind:!0},title:[{pattern:/^(([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2+)(?:\r?\n|\r).+(?:\r?\n|\r)\1$/m,inside:{punctuation:/^[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+|[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+$/,important:/.+/}},{pattern:/(^|(?:\r?\n|\r){2}).+(?:\r?\n|\r)([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2+(?=\r?\n|\r|$)/,lookbehind:!0,inside:{punctuation:/[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+$/,important:/.+/}}],hr:{pattern:/((?:\r?\n|\r){2})([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2{3,}(?=(?:\r?\n|\r){2})/,lookbehind:!0,alias:"punctuation"},field:{pattern:/(^[\t ]*):[^:\r\n]+:(?= )/m,lookbehind:!0,alias:"attr-name"},"command-line-option":{pattern:/(^[\t ]*)(?:[+-][a-z\d]|(?:--|\/)[a-z\d-]+)(?:[ =](?:[a-z][\w-]*|<[^<>]+>))?(?:, (?:[+-][a-z\d]|(?:--|\/)[a-z\d-]+)(?:[ =](?:[a-z][\w-]*|<[^<>]+>))?)*(?=(?:\r?\n|\r)? {2,}\S)/im,lookbehind:!0,alias:"symbol"},"literal-block":{pattern:/::(?:\r?\n|\r){2}([ \t]+)(?![ \t]).+(?:(?:\r?\n|\r)\1.+)*/,inside:{"literal-block-punctuation":{pattern:/^::/,alias:"punctuation"}}},"quoted-literal-block":{pattern:/::(?:\r?\n|\r){2}([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]).*(?:(?:\r?\n|\r)\1.*)*/,inside:{"literal-block-punctuation":{pattern:/^(?:::|([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\1*)/m,alias:"punctuation"}}},"list-bullet":{pattern:/(^[\t ]*)(?:[*+\-•‣⁃]|\(?(?:\d+|[a-z]|[ivxdclm]+)\)|(?:\d+|[a-z]|[ivxdclm]+)\.)(?= )/im,lookbehind:!0,alias:"punctuation"},"doctest-block":{pattern:/(^[\t ]*)>>> .+(?:(?:\r?\n|\r).+)*/m,lookbehind:!0,inside:{punctuation:/^>>>/}},inline:[{pattern:/(^|[\s\-:\/'"<(\[{])(?::[^:]+:`.*?`|`.*?`:[^:]+:|(\*\*?|``?|\|)(?!\s)(?:(?!\2).)*\S\2(?=[\s\-.,:;!?\\\/'")\]}]|$))/m,lookbehind:!0,inside:{bold:{pattern:/(^\*\*).+(?=\*\*$)/,lookbehind:!0},italic:{pattern:/(^\*).+(?=\*$)/,lookbehind:!0},"inline-literal":{pattern:/(^``).+(?=``$)/,lookbehind:!0,alias:"symbol"},role:{pattern:/^:[^:]+:|:[^:]+:$/,alias:"function",inside:{punctuation:/^:|:$/}},"interpreted-text":{pattern:/(^`).+(?=`$)/,lookbehind:!0,alias:"attr-value"},substitution:{pattern:/(^\|).+(?=\|$)/,lookbehind:!0,alias:"attr-value"},punctuation:/\*\*?|``?|\|/}}],link:[{pattern:/\[[^\[\]]+\]_(?=[\s\-.,:;!?\\\/'")\]}]|$)/,alias:"string",inside:{punctuation:/^\[|\]_$/}},{pattern:/(?:\b[a-z\d]+(?:[_.:+][a-z\d]+)*_?_|`[^`]+`_?_|_`[^`]+`)(?=[\s\-.,:;!?\\\/'")\]}]|$)/i,alias:"string",inside:{punctuation:/^_?`|`$|`?_?_$/}}],punctuation:{pattern:/(^[\t ]*)(?:\|(?= |$)|(?:---?|—|\.\.|__)(?= )|\.\.$)/m,lookbehind:!0}}}return sw}var lw,DP;function OSe(){if(DP)return lw;DP=1,lw=e,e.displayName="rip",e.aliases=[];function e(t){t.languages.rip={comment:{pattern:/#.*/,greedy:!0},char:{pattern:/\B`[^\s`'",.:;#\/\\()<>\[\]{}]\b/,greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},regex:{pattern:/(^|[^/])\/(?!\/)(?:\[[^\n\r\]]*\]|\\.|[^/\\\r\n\[])+\/(?=\s*(?:$|[\r\n,.;})]))/,lookbehind:!0,greedy:!0},keyword:/(?:=>|->)|\b(?:case|catch|class|else|exit|finally|if|raise|return|switch|try)\b/,builtin:/@|\bSystem\b/,boolean:/\b(?:false|true)\b/,date:/\b\d{4}-\d{2}-\d{2}\b/,time:/\b\d{2}:\d{2}:\d{2}\b/,datetime:/\b\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\b/,symbol:/:[^\d\s`'",.:;#\/\\()<>\[\]{}][^\s`'",.:;#\/\\()<>\[\]{}]*/,number:/[+-]?\b(?:\d+\.\d+|\d+)\b/,punctuation:/(?:\.{2,3})|[`,.:;=\/\\()<>\[\]{}]/,reference:/[^\d\s`'",.:;#\/\\()<>\[\]{}][^\s`'",.:;#\/\\()<>\[\]{}]*/}}return lw}var cw,LP;function ISe(){if(LP)return cw;LP=1,cw=e,e.displayName="roboconf",e.aliases=[];function e(t){t.languages.roboconf={comment:/#.*/,keyword:{pattern:/(^|\s)(?:(?:external|import)\b|(?:facet|instance of)(?=[ \t]+[\w-]+[ \t]*\{))/,lookbehind:!0},component:{pattern:/[\w-]+(?=[ \t]*\{)/,alias:"variable"},property:/[\w.-]+(?=[ \t]*:)/,value:{pattern:/(=[ \t]*(?![ \t]))[^,;]+/,lookbehind:!0,alias:"attr-value"},optional:{pattern:/\(optional\)/,alias:"builtin"},wildcard:{pattern:/(\.)\*/,lookbehind:!0,alias:"operator"},punctuation:/[{},.;:=]/}}return cw}var uw,MP;function DSe(){if(MP)return uw;MP=1,uw=e,e.displayName="robotframework",e.aliases=[];function e(t){(function(n){var r={pattern:/(^[ \t]*| {2}|\t)#.*/m,lookbehind:!0,greedy:!0},a={pattern:/((?:^|[^\\])(?:\\{2})*)[$@&%]\{(?:[^{}\r\n]|\{[^{}\r\n]*\})*\}/,lookbehind:!0,inside:{punctuation:/^[$@&%]\{|\}$/}};function o(d,p){var g={};g["section-header"]={pattern:/^ ?\*{3}.+?\*{3}/,alias:"keyword"};for(var m in p)g[m]=p[m];return g.tag={pattern:/([\r\n](?: {2}|\t)[ \t]*)\[[-\w]+\]/,lookbehind:!0,inside:{punctuation:/\[|\]/}},g.variable=a,g.comment=r,{pattern:RegExp(/^ ?\*{3}[ \t]*<name>[ \t]*\*{3}(?:.|[\r\n](?!\*{3}))*/.source.replace(/<name>/g,function(){return d}),"im"),alias:"section",inside:g}}var s={pattern:/(\[Documentation\](?: {2}|\t)[ \t]*)(?![ \t]|#)(?:.|(?:\r\n?|\n)[ \t]*\.{3})+/,lookbehind:!0,alias:"string"},l={pattern:/([\r\n] ?)(?!#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0,alias:"function",inside:{variable:a}},u={pattern:/([\r\n](?: {2}|\t)[ \t]*)(?!\[|\.{3}|#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0,inside:{variable:a}};n.languages.robotframework={settings:o("Settings",{documentation:{pattern:/([\r\n] ?Documentation(?: {2}|\t)[ \t]*)(?![ \t]|#)(?:.|(?:\r\n?|\n)[ \t]*\.{3})+/,lookbehind:!0,alias:"string"},property:{pattern:/([\r\n] ?)(?!\.{3}|#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0}}),variables:o("Variables"),"test-cases":o("Test Cases",{"test-name":l,documentation:s,property:u}),keywords:o("Keywords",{"keyword-name":l,documentation:s,property:u}),tasks:o("Tasks",{"task-name":l,documentation:s,property:u}),comment:r},n.languages.robot=n.languages.robotframework})(t)}return uw}var dw,PP;function LSe(){if(PP)return dw;PP=1,dw=e,e.displayName="rust",e.aliases=[];function e(t){(function(n){for(var r=/\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|<self>)*\*\//.source,a=0;a<2;a++)r=r.replace(/<self>/g,function(){return r});r=r.replace(/<self>/g,function(){return/[^\s\S]/.source}),n.languages.rust={comment:[{pattern:RegExp(/(^|[^\\])/.source+r),lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/b?"(?:\\[\s\S]|[^\\"])*"|b?r(#*)"(?:[^"]|"(?!\1))*"\1/,greedy:!0},char:{pattern:/b?'(?:\\(?:x[0-7][\da-fA-F]|u\{(?:[\da-fA-F]_*){1,6}\}|.)|[^\\\r\n\t'])'/,greedy:!0},attribute:{pattern:/#!?\[(?:[^\[\]"]|"(?:\\[\s\S]|[^\\"])*")*\]/,greedy:!0,alias:"attr-name",inside:{string:null}},"closure-params":{pattern:/([=(,:]\s*|\bmove\s*)\|[^|]*\||\|[^|]*\|(?=\s*(?:\{|->))/,lookbehind:!0,greedy:!0,inside:{"closure-punctuation":{pattern:/^\||\|$/,alias:"punctuation"},rest:null}},"lifetime-annotation":{pattern:/'\w+/,alias:"symbol"},"fragment-specifier":{pattern:/(\$\w+:)[a-z]+/,lookbehind:!0,alias:"punctuation"},variable:/\$\w+/,"function-definition":{pattern:/(\bfn\s+)\w+/,lookbehind:!0,alias:"function"},"type-definition":{pattern:/(\b(?:enum|struct|trait|type|union)\s+)\w+/,lookbehind:!0,alias:"class-name"},"module-declaration":[{pattern:/(\b(?:crate|mod)\s+)[a-z][a-z_\d]*/,lookbehind:!0,alias:"namespace"},{pattern:/(\b(?:crate|self|super)\s*)::\s*[a-z][a-z_\d]*\b(?:\s*::(?:\s*[a-z][a-z_\d]*\s*::)*)?/,lookbehind:!0,alias:"namespace",inside:{punctuation:/::/}}],keyword:[/\b(?:Self|abstract|as|async|await|become|box|break|const|continue|crate|do|dyn|else|enum|extern|final|fn|for|if|impl|in|let|loop|macro|match|mod|move|mut|override|priv|pub|ref|return|self|static|struct|super|trait|try|type|typeof|union|unsafe|unsized|use|virtual|where|while|yield)\b/,/\b(?:bool|char|f(?:32|64)|[ui](?:8|16|32|64|128|size)|str)\b/],function:/\b[a-z_]\w*(?=\s*(?:::\s*<|\())/,macro:{pattern:/\b\w+!/,alias:"property"},constant:/\b[A-Z_][A-Z_\d]+\b/,"class-name":/\b[A-Z]\w*\b/,namespace:{pattern:/(?:\b[a-z][a-z_\d]*\s*::\s*)*\b[a-z][a-z_\d]*\s*::(?!\s*<)/,inside:{punctuation:/::/}},number:/\b(?:0x[\dA-Fa-f](?:_?[\dA-Fa-f])*|0o[0-7](?:_?[0-7])*|0b[01](?:_?[01])*|(?:(?:\d(?:_?\d)*)?\.)?\d(?:_?\d)*(?:[Ee][+-]?\d+)?)(?:_?(?:f32|f64|[iu](?:8|16|32|64|size)?))?\b/,boolean:/\b(?:false|true)\b/,punctuation:/->|\.\.=|\.{1,3}|::|[{}[\];(),:]/,operator:/[-+*\/%!^]=?|=[=>]?|&[&=]?|\|[|=]?|<<?=?|>>?=?|[@?]/},n.languages.rust["closure-params"].inside.rest=n.languages.rust,n.languages.rust.attribute.inside.string=n.languages.rust.string})(t)}return dw}var fw,FP;function MSe(){if(FP)return fw;FP=1,fw=e,e.displayName="sas",e.aliases=[];function e(t){(function(n){var r=/(?:"(?:""|[^"])*"(?!")|'(?:''|[^'])*'(?!'))/.source,a=/\b(?:\d[\da-f]*x|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,o={pattern:RegExp(r+"[bx]"),alias:"number"},s={pattern:/&[a-z_]\w*/i},l={pattern:/((?:^|\s|=|\())%(?:ABORT|BY|CMS|COPY|DISPLAY|DO|ELSE|END|EVAL|GLOBAL|GO|GOTO|IF|INC|INCLUDE|INDEX|INPUT|KTRIM|LENGTH|LET|LIST|LOCAL|PUT|QKTRIM|QSCAN|QSUBSTR|QSYSFUNC|QUPCASE|RETURN|RUN|SCAN|SUBSTR|SUPERQ|SYMDEL|SYMEXIST|SYMGLOBL|SYMLOCAL|SYSCALL|SYSEVALF|SYSEXEC|SYSFUNC|SYSGET|SYSRPUT|THEN|TO|TSO|UNQUOTE|UNTIL|UPCASE|WHILE|WINDOW)\b/i,lookbehind:!0,alias:"keyword"},u={pattern:/(^|\s)(?:proc\s+\w+|data(?!=)|quit|run)\b/i,alias:"keyword",lookbehind:!0},d=[/\/\*[\s\S]*?\*\//,{pattern:/(^[ \t]*|;\s*)\*[^;]*;/m,lookbehind:!0}],p={pattern:RegExp(r),greedy:!0},g=/[$%@.(){}\[\];,\\]/,m={pattern:/%?\b\w+(?=\()/,alias:"keyword"},b={function:m,"arg-value":{pattern:/(=\s*)[A-Z\.]+/i,lookbehind:!0},operator:/=/,"macro-variable":s,arg:{pattern:/[A-Z]+/i,alias:"keyword"},number:a,"numeric-constant":o,punctuation:g,string:p},v={pattern:/\b(?:format|put)\b=?[\w'$.]+/i,inside:{keyword:/^(?:format|put)(?==)/i,equals:/=/,format:{pattern:/(?:\w|\$\d)+\.\d?/,alias:"number"}}},y={pattern:/\b(?:format|put)\s+[\w']+(?:\s+[$.\w]+)+(?=;)/i,inside:{keyword:/^(?:format|put)/i,format:{pattern:/[\w$]+\.\d?/,alias:"number"}}},k={pattern:/((?:^|\s)=?)(?:catname|checkpoint execute_always|dm|endsas|filename|footnote|%include|libname|%list|lock|missing|options|page|resetline|%run|sasfile|skip|sysecho|title\d?)\b/i,lookbehind:!0,alias:"keyword"},A={pattern:/(^|\s)(?:submit(?:\s+(?:load|norun|parseonly))?|endsubmit)\b/i,lookbehind:!0,alias:"keyword"},x=/aStore|accessControl|aggregation|audio|autotune|bayesianNetClassifier|bioMedImage|boolRule|builtins|cardinality|cdm|clustering|conditionalRandomFields|configuration|copula|countreg|dataDiscovery|dataPreprocess|dataSciencePilot|dataStep|decisionTree|deduplication|deepLearn|deepNeural|deepRnn|ds2|ecm|entityRes|espCluster|explainModel|factmac|fastKnn|fcmpact|fedSql|freqTab|gVarCluster|gam|gleam|graphSemiSupLearn|hiddenMarkovModel|hyperGroup|ica|image|iml|kernalPca|langModel|ldaTopic|loadStreams|mbc|mixed|mlTools|modelPublishing|network|neuralNet|nmf|nonParametricBayes|nonlinear|optNetwork|optimization|panel|pca|percentile|phreg|pls|qkb|qlim|quantreg|recommend|regression|reinforcementLearn|robustPca|ruleMining|sampling|sandwich|sccasl|search(?:Analytics)?|sentimentAnalysis|sequence|session(?:Prop)?|severity|simSystem|simple|smartData|sparkEmbeddedProcess|sparseML|spatialreg|spc|stabilityMonitoring|svDataDescription|svm|table|text(?:Filters|Frequency|Mining|Parse|Rule(?:Develop|Score)|Topic|Util)|timeData|transpose|tsInfo|tsReconcile|uniTimeSeries|varReduce/.source,R={pattern:RegExp(/(^|\s)(?:action\s+)?(?:<act>)\.[a-z]+\b[^;]+/.source.replace(/<act>/g,function(){return x}),"i"),lookbehind:!0,inside:{keyword:RegExp(/(?:<act>)\.[a-z]+\b/.source.replace(/<act>/g,function(){return x}),"i"),action:{pattern:/(?:action)/i,alias:"keyword"},comment:d,function:m,"arg-value":b["arg-value"],operator:b.operator,argument:b.arg,number:a,"numeric-constant":o,punctuation:g,string:p}},O={pattern:/((?:^|\s)=?)(?:after|analysis|and|array|barchart|barwidth|begingraph|by|call|cas|cbarline|cfill|class(?:lev)?|close|column|computed?|contains|continue|data(?==)|define|delete|describe|document|do\s+over|do|dol|drop|dul|else|end(?:comp|source)?|entryTitle|eval(?:uate)?|exec(?:ute)?|exit|file(?:name)?|fill(?:attrs)?|flist|fnc|function(?:list)?|global|goto|group(?:by)?|headline|headskip|histogram|if|infile|keep|keylabel|keyword|label|layout|leave|legendlabel|length|libname|loadactionset|merge|midpoints|_?null_|name|noobs|nowd|ods|options|or|otherwise|out(?:put)?|over(?:lay)?|plot|print|put|raise|ranexp|rannor|rbreak|retain|return|select|session|sessref|set|source|statgraph|sum|summarize|table|temp|terminate|then\s+do|then|title\d?|to|var|when|where|xaxisopts|y2axisopts|yaxisopts)\b/i,lookbehind:!0};n.languages.sas={datalines:{pattern:/^([ \t]*)(?:cards|(?:data)?lines);[\s\S]+?^[ \t]*;/im,lookbehind:!0,alias:"string",inside:{keyword:{pattern:/^(?:cards|(?:data)?lines)/i},punctuation:/;/}},"proc-sql":{pattern:/(^proc\s+(?:fed)?sql(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{sql:{pattern:RegExp(/^[ \t]*(?:select|alter\s+table|(?:create|describe|drop)\s+(?:index|table(?:\s+constraints)?|view)|create\s+unique\s+index|insert\s+into|update)(?:<str>|[^;"'])+;/.source.replace(/<str>/g,function(){return r}),"im"),alias:"language-sql",inside:n.languages.sql},"global-statements":k,"sql-statements":{pattern:/(^|\s)(?:disconnect\s+from|begin|commit|exec(?:ute)?|reset|rollback|validate)\b/i,lookbehind:!0,alias:"keyword"},number:a,"numeric-constant":o,punctuation:g,string:p}},"proc-groovy":{pattern:/(^proc\s+groovy(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:d,groovy:{pattern:RegExp(/(^[ \t]*submit(?:\s+(?:load|norun|parseonly))?)(?:<str>|[^"'])+?(?=endsubmit;)/.source.replace(/<str>/g,function(){return r}),"im"),lookbehind:!0,alias:"language-groovy",inside:n.languages.groovy},keyword:O,"submit-statement":A,"global-statements":k,number:a,"numeric-constant":o,punctuation:g,string:p}},"proc-lua":{pattern:/(^proc\s+lua(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:d,lua:{pattern:RegExp(/(^[ \t]*submit(?:\s+(?:load|norun|parseonly))?)(?:<str>|[^"'])+?(?=endsubmit;)/.source.replace(/<str>/g,function(){return r}),"im"),lookbehind:!0,alias:"language-lua",inside:n.languages.lua},keyword:O,"submit-statement":A,"global-statements":k,number:a,"numeric-constant":o,punctuation:g,string:p}},"proc-cas":{pattern:/(^proc\s+cas(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|quit|data);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:d,"statement-var":{pattern:/((?:^|\s)=?)saveresult\s[^;]+/im,lookbehind:!0,inside:{statement:{pattern:/^saveresult\s+\S+/i,inside:{keyword:/^(?:saveresult)/i}},rest:b}},"cas-actions":R,statement:{pattern:/((?:^|\s)=?)(?:default|(?:un)?set|on|output|upload)[^;]+/im,lookbehind:!0,inside:b},step:u,keyword:O,function:m,format:v,altformat:y,"global-statements":k,number:a,"numeric-constant":o,punctuation:g,string:p}},"proc-args":{pattern:RegExp(/(^proc\s+\w+\s+)(?!\s)(?:[^;"']|<str>)+;/.source.replace(/<str>/g,function(){return r}),"im"),lookbehind:!0,inside:b},"macro-keyword":l,"macro-variable":s,"macro-string-functions":{pattern:/((?:^|\s|=))%(?:BQUOTE|NRBQUOTE|NRQUOTE|NRSTR|QUOTE|STR)\(.*?(?:[^%]\))/i,lookbehind:!0,inside:{function:{pattern:/%(?:BQUOTE|NRBQUOTE|NRQUOTE|NRSTR|QUOTE|STR)/i,alias:"keyword"},"macro-keyword":l,"macro-variable":s,"escaped-char":{pattern:/%['"()<>=¬^~;,#]/},punctuation:g}},"macro-declaration":{pattern:/^%macro[^;]+(?=;)/im,inside:{keyword:/%macro/i}},"macro-end":{pattern:/^%mend[^;]+(?=;)/im,inside:{keyword:/%mend/i}},macro:{pattern:/%_\w+(?=\()/,alias:"keyword"},input:{pattern:/\binput\s[-\w\s/*.$&]+;/i,inside:{input:{alias:"keyword",pattern:/^input/i},comment:d,number:a,"numeric-constant":o}},"options-args":{pattern:/(^options)[-'"|/\\<>*+=:()\w\s]*(?=;)/im,lookbehind:!0,inside:b},"cas-actions":R,comment:d,function:m,format:v,altformat:y,"numeric-constant":o,datetime:{pattern:RegExp(r+"(?:dt?|t)"),alias:"number"},string:p,step:u,keyword:O,"operator-keyword":{pattern:/\b(?:eq|ge|gt|in|le|lt|ne|not)\b/i,alias:"operator"},number:a,operator:/\*\*?|\|\|?|!!?|¦¦?|<[>=]?|>[<=]?|[-+\/=&]|[~¬^]=?/,punctuation:g}})(t)}return fw}var pw,zP;function PSe(){if(zP)return pw;zP=1,pw=e,e.displayName="sass",e.aliases=[];function e(t){(function(n){n.languages.sass=n.languages.extend("css",{comment:{pattern:/^([ \t]*)\/[\/*].*(?:(?:\r?\n|\r)\1[ \t].+)*/m,lookbehind:!0,greedy:!0}}),n.languages.insertBefore("sass","atrule",{"atrule-line":{pattern:/^(?:[ \t]*)[@+=].+/m,greedy:!0,inside:{atrule:/(?:@[\w-]+|[+=])/}}}),delete n.languages.sass.atrule;var r=/\$[-\w]+|#\{\$[-\w]+\}/,a=[/[+*\/%]|[=!]=|<=?|>=?|\b(?:and|not|or)\b/,{pattern:/(\s)-(?=\s)/,lookbehind:!0}];n.languages.insertBefore("sass","property",{"variable-line":{pattern:/^[ \t]*\$.+/m,greedy:!0,inside:{punctuation:/:/,variable:r,operator:a}},"property-line":{pattern:/^[ \t]*(?:[^:\s]+ *:.*|:[^:\s].*)/m,greedy:!0,inside:{property:[/[^:\s]+(?=\s*:)/,{pattern:/(:)[^:\s]+/,lookbehind:!0}],punctuation:/:/,variable:r,operator:a,important:n.languages.sass.important}}}),delete n.languages.sass.property,delete n.languages.sass.important,n.languages.insertBefore("sass","punctuation",{selector:{pattern:/^([ \t]*)\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*(?:,(?:\r?\n|\r)\1[ \t]+\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*)*/m,lookbehind:!0,greedy:!0}})})(t)}return pw}var gw,BP;function FSe(){if(BP)return gw;BP=1;var e=EA();gw=t,t.displayName="scala",t.aliases=[];function t(n){n.register(e),n.languages.scala=n.languages.extend("java",{"triple-quoted-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/<-|=>|\b(?:abstract|case|catch|class|def|do|else|extends|final|finally|for|forSome|if|implicit|import|lazy|match|new|null|object|override|package|private|protected|return|sealed|self|super|this|throw|trait|try|type|val|var|while|with|yield)\b/,number:/\b0x(?:[\da-f]*\.)?[\da-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e\d+)?[dfl]?/i,builtin:/\b(?:Any|AnyRef|AnyVal|Boolean|Byte|Char|Double|Float|Int|Long|Nothing|Short|String|Unit)\b/,symbol:/'[^\d\s\\]\w*/}),n.languages.insertBefore("scala","triple-quoted-string",{"string-interpolation":{pattern:/\b[a-z]\w*(?:"""(?:[^$]|\$(?:[^{]|\{(?:[^{}]|\{[^{}]*\})*\}))*?"""|"(?:[^$"\r\n]|\$(?:[^{]|\{(?:[^{}]|\{[^{}]*\})*\}))*")/i,greedy:!0,inside:{id:{pattern:/^\w+/,greedy:!0,alias:"function"},escape:{pattern:/\\\$"|\$[$"]/,greedy:!0,alias:"symbol"},interpolation:{pattern:/\$(?:\w+|\{(?:[^{}]|\{[^{}]*\})*\})/,greedy:!0,inside:{punctuation:/^\$\{?|\}$/,expression:{pattern:/[\s\S]+/,inside:n.languages.scala}}},string:/[\s\S]+/}}}),delete n.languages.scala["class-name"],delete n.languages.scala.function}return gw}var hw,jP;function zSe(){if(jP)return hw;jP=1,hw=e,e.displayName="scss",e.aliases=[];function e(t){t.languages.scss=t.languages.extend("css",{comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0},atrule:{pattern:/@[\w-](?:\([^()]+\)|[^()\s]|\s+(?!\s))*?(?=\s+[{;])/,inside:{rule:/@[\w-]+/}},url:/(?:[-a-z]+-)?url(?=\()/i,selector:{pattern:/(?=\S)[^@;{}()]?(?:[^@;{}()\s]|\s+(?!\s)|#\{\$[-\w]+\})+(?=\s*\{(?:\}|\s|[^}][^:{}]*[:{][^}]))/,inside:{parent:{pattern:/&/,alias:"important"},placeholder:/%[-\w]+/,variable:/\$[-\w]+|#\{\$[-\w]+\}/}},property:{pattern:/(?:[-\w]|\$[-\w]|#\{\$[-\w]+\})+(?=\s*:)/,inside:{variable:/\$[-\w]+|#\{\$[-\w]+\}/}}}),t.languages.insertBefore("scss","atrule",{keyword:[/@(?:content|debug|each|else(?: if)?|extend|for|forward|function|if|import|include|mixin|return|use|warn|while)\b/i,{pattern:/( )(?:from|through)(?= )/,lookbehind:!0}]}),t.languages.insertBefore("scss","important",{variable:/\$[-\w]+|#\{\$[-\w]+\}/}),t.languages.insertBefore("scss","function",{"module-modifier":{pattern:/\b(?:as|hide|show|with)\b/i,alias:"keyword"},placeholder:{pattern:/%[-\w]+/,alias:"selector"},statement:{pattern:/\B!(?:default|optional)\b/i,alias:"keyword"},boolean:/\b(?:false|true)\b/,null:{pattern:/\bnull\b/,alias:"keyword"},operator:{pattern:/(\s)(?:[-+*\/%]|[=!]=|<=?|>=?|and|not|or)(?=\s)/,lookbehind:!0}}),t.languages.scss.atrule.inside.rest=t.languages.scss}return hw}var mw,UP;function BSe(){if(UP)return mw;UP=1;var e=jH();mw=t,t.displayName="shellSession",t.aliases=[];function t(n){n.register(e),function(r){var a=[/"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/.source,/'[^']*'/.source,/\$'(?:[^'\\]|\\[\s\S])*'/.source,/<<-?\s*(["']?)(\w+)\1\s[\s\S]*?[\r\n]\2/.source].join("|");r.languages["shell-session"]={command:{pattern:RegExp(/^/.source+"(?:"+(/[^\s@:$#%*!/\\]+@[^\r\n@:$#%*!/\\]+(?::[^\0-\x1F$#%*?"<>:;|]+)?/.source+"|"+/[/~.][^\0-\x1F$#%*?"<>@:;|]*/.source)+")?"+/[$#%](?=\s)/.source+/(?:[^\\\r\n \t'"<$]|[ \t](?:(?!#)|#.*$)|\\(?:[^\r]|\r\n?)|\$(?!')|<(?!<)|<<str>>)+/.source.replace(/<<str>>/g,function(){return a}),"m"),greedy:!0,inside:{info:{pattern:/^[^#$%]+/,alias:"punctuation",inside:{user:/^[^\s@:$#%*!/\\]+@[^\r\n@:$#%*!/\\]+/,punctuation:/:/,path:/[\s\S]+/}},bash:{pattern:/(^[$#%]\s*)\S[\s\S]*/,lookbehind:!0,alias:"language-bash",inside:r.languages.bash},"shell-symbol":{pattern:/^[$#%]/,alias:"important"}}},output:/.(?:.*(?:[\r\n]|.$))*/},r.languages["sh-session"]=r.languages.shellsession=r.languages["shell-session"]}(n)}return mw}var bw,GP;function jSe(){if(GP)return bw;GP=1,bw=e,e.displayName="smali",e.aliases=[];function e(t){t.languages.smali={comment:/#.*/,string:{pattern:/"(?:[^\r\n\\"]|\\.)*"|'(?:[^\r\n\\']|\\(?:.|u[\da-fA-F]{4}))'/,greedy:!0},"class-name":{pattern:/(^|[^L])L(?:(?:\w+|`[^`\r\n]*`)\/)*(?:[\w$]+|`[^`\r\n]*`)(?=\s*;)/,lookbehind:!0,inside:{"class-name":{pattern:/(^L|\/)(?:[\w$]+|`[^`\r\n]*`)$/,lookbehind:!0},namespace:{pattern:/^(L)(?:(?:\w+|`[^`\r\n]*`)\/)+/,lookbehind:!0,inside:{punctuation:/\//}},builtin:/^L/}},builtin:[{pattern:/([();\[])[BCDFIJSVZ]+/,lookbehind:!0},{pattern:/([\w$>]:)[BCDFIJSVZ]/,lookbehind:!0}],keyword:[{pattern:/(\.end\s+)[\w-]+/,lookbehind:!0},{pattern:/(^|[^\w.-])\.(?!\d)[\w-]+/,lookbehind:!0},{pattern:/(^|[^\w.-])(?:abstract|annotation|bridge|constructor|enum|final|interface|private|protected|public|runtime|static|synthetic|system|transient)(?![\w.-])/,lookbehind:!0}],function:{pattern:/(^|[^\w.-])(?:\w+|<[\w$-]+>)(?=\()/,lookbehind:!0},field:{pattern:/[\w$]+(?=:)/,alias:"variable"},register:{pattern:/(^|[^\w.-])[vp]\d(?![\w.-])/,lookbehind:!0,alias:"variable"},boolean:{pattern:/(^|[^\w.-])(?:false|true)(?![\w.-])/,lookbehind:!0},number:{pattern:/(^|[^/\w.-])-?(?:NAN|INFINITY|0x(?:[\dA-F]+(?:\.[\dA-F]*)?|\.[\dA-F]+)(?:p[+-]?[\dA-F]+)?|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?)[dflst]?(?![\w.-])/i,lookbehind:!0},label:{pattern:/(:)\w+/,lookbehind:!0,alias:"property"},operator:/->|\.\.|[\[=]/,punctuation:/[{}(),;:]/}}return bw}var yw,HP;function USe(){if(HP)return yw;HP=1,yw=e,e.displayName="smalltalk",e.aliases=[];function e(t){t.languages.smalltalk={comment:{pattern:/"(?:""|[^"])*"/,greedy:!0},char:{pattern:/\$./,greedy:!0},string:{pattern:/'(?:''|[^'])*'/,greedy:!0},symbol:/#[\da-z]+|#(?:-|([+\/\\*~<>=@%|&?!])\1?)|#(?=\()/i,"block-arguments":{pattern:/(\[\s*):[^\[|]*\|/,lookbehind:!0,inside:{variable:/:[\da-z]+/i,punctuation:/\|/}},"temporary-variables":{pattern:/\|[^|]+\|/,inside:{variable:/[\da-z]+/i,punctuation:/\|/}},keyword:/\b(?:new|nil|self|super)\b/,boolean:/\b(?:false|true)\b/,number:[/\d+r-?[\dA-Z]+(?:\.[\dA-Z]+)?(?:e-?\d+)?/,/\b\d+(?:\.\d+)?(?:e-?\d+)?/],operator:/[<=]=?|:=|~[~=]|\/\/?|\\\\|>[>=]?|[!^+\-*&|,@]/,punctuation:/[.;:?\[\](){}]/}}return yw}var vw,$P;function GSe(){if($P)return vw;$P=1;var e=Wn();vw=t,t.displayName="smarty",t.aliases=[];function t(n){n.register(e),function(r){r.languages.smarty={comment:{pattern:/^\{\*[\s\S]*?\*\}/,greedy:!0},"embedded-php":{pattern:/^\{php\}[\s\S]*?\{\/php\}/,greedy:!0,inside:{smarty:{pattern:/^\{php\}|\{\/php\}$/,inside:null},php:{pattern:/[\s\S]+/,alias:"language-php",inside:r.languages.php}}},string:[{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0,inside:{interpolation:{pattern:/\{[^{}]*\}|`[^`]*`/,inside:{"interpolation-punctuation":{pattern:/^[{`]|[`}]$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}},variable:/\$\w+/}},{pattern:/'(?:\\.|[^'\\\r\n])*'/,greedy:!0}],keyword:{pattern:/(^\{\/?)[a-z_]\w*\b(?!\()/i,lookbehind:!0,greedy:!0},delimiter:{pattern:/^\{\/?|\}$/,greedy:!0,alias:"punctuation"},number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,variable:[/\$(?!\d)\w+/,/#(?!\d)\w+#/,{pattern:/(\.|->|\w\s*=)(?!\d)\w+\b(?!\()/,lookbehind:!0},{pattern:/(\[)(?!\d)\w+(?=\])/,lookbehind:!0}],function:{pattern:/(\|\s*)@?[a-z_]\w*|\b[a-z_]\w*(?=\()/i,lookbehind:!0},"attr-name":/\b[a-z_]\w*(?=\s*=)/i,boolean:/\b(?:false|no|off|on|true|yes)\b/,punctuation:/[\[\](){}.,:`]|->/,operator:[/[+\-*\/%]|==?=?|[!<>]=?|&&|\|\|?/,/\bis\s+(?:not\s+)?(?:div|even|odd)(?:\s+by)?\b/,/\b(?:and|eq|gt?e|gt|lt?e|lt|mod|neq?|not|or)\b/]},r.languages.smarty["embedded-php"].inside.smarty.inside=r.languages.smarty,r.languages.smarty.string[0].inside.interpolation.inside.expression.inside=r.languages.smarty;var a=/"(?:\\.|[^"\\\r\n])*"|'(?:\\.|[^'\\\r\n])*'/,o=RegExp(/\{\*[\s\S]*?\*\}/.source+"|"+/\{php\}[\s\S]*?\{\/php\}/.source+"|"+/\{(?:[^{}"']|<str>|\{(?:[^{}"']|<str>|\{(?:[^{}"']|<str>)*\})*\})*\}/.source.replace(/<str>/g,function(){return a.source}),"g");r.hooks.add("before-tokenize",function(s){var l="{literal}",u="{/literal}",d=!1;r.languages["markup-templating"].buildPlaceholders(s,"smarty",o,function(p){return p===u&&(d=!1),d?!1:(p===l&&(d=!0),!0)})}),r.hooks.add("after-tokenize",function(s){r.languages["markup-templating"].tokenizePlaceholders(s,"smarty")})}(n)}return vw}var Sw,qP;function HSe(){if(qP)return Sw;qP=1,Sw=e,e.displayName="sml",e.aliases=["smlnj"];function e(t){(function(n){var r=/\b(?:abstype|and|andalso|as|case|datatype|do|else|end|eqtype|exception|fn|fun|functor|handle|if|in|include|infix|infixr|let|local|nonfix|of|op|open|orelse|raise|rec|sharing|sig|signature|struct|structure|then|type|val|where|while|with|withtype)\b/i;n.languages.sml={comment:/\(\*(?:[^*(]|\*(?!\))|\((?!\*)|\(\*(?:[^*(]|\*(?!\))|\((?!\*))*\*\))*\*\)/,string:{pattern:/#?"(?:[^"\\]|\\.)*"/,greedy:!0},"class-name":[{pattern:RegExp(/((?:^|[^:]):\s*)<TERMINAL>(?:\s*(?:(?:\*|->)\s*<TERMINAL>|,\s*<TERMINAL>(?:(?=<NOT-LAST>)|(?!<NOT-LAST>)\s+<LONG-ID>)))*/.source.replace(/<NOT-LAST>/g,function(){return/\s*(?:[*,]|->)/.source}).replace(/<TERMINAL>/g,function(){return/(?:'[\w']*|<LONG-ID>|\((?:[^()]|\([^()]*\))*\)|\{(?:[^{}]|\{[^{}]*\})*\})(?:\s+<LONG-ID>)*/.source}).replace(/<LONG-ID>/g,function(){return/(?!<KEYWORD>)[a-z\d_][\w'.]*/.source}).replace(/<KEYWORD>/g,function(){return r.source}),"i"),lookbehind:!0,greedy:!0,inside:null},{pattern:/((?:^|[^\w'])(?:datatype|exception|functor|signature|structure|type)\s+)[a-z_][\w'.]*/i,lookbehind:!0}],function:{pattern:/((?:^|[^\w'])fun\s+)[a-z_][\w'.]*/i,lookbehind:!0},keyword:r,variable:{pattern:/(^|[^\w'])'[\w']*/,lookbehind:!0},number:/~?\b(?:\d+(?:\.\d+)?(?:e~?\d+)?|0x[\da-f]+)\b/i,word:{pattern:/\b0w(?:\d+|x[\da-f]+)\b/i,alias:"constant"},boolean:/\b(?:false|true)\b/i,operator:/\.\.\.|:[>=:]|=>?|->|[<>]=?|[!+\-*/^#|@~]/,punctuation:/[(){}\[\].:,;]/},n.languages.sml["class-name"][0].inside=n.languages.sml,n.languages.smlnj=n.languages.sml})(t)}return Sw}var Ew,VP;function $Se(){if(VP)return Ew;VP=1,Ew=e,e.displayName="solidity",e.aliases=["sol"];function e(t){t.languages.solidity=t.languages.extend("clike",{"class-name":{pattern:/(\b(?:contract|enum|interface|library|new|struct|using)\s+)(?!\d)[\w$]+/,lookbehind:!0},keyword:/\b(?:_|anonymous|as|assembly|assert|break|calldata|case|constant|constructor|continue|contract|default|delete|do|else|emit|enum|event|external|for|from|function|if|import|indexed|inherited|interface|internal|is|let|library|mapping|memory|modifier|new|payable|pragma|private|public|pure|require|returns?|revert|selfdestruct|solidity|storage|struct|suicide|switch|this|throw|using|var|view|while)\b/,operator:/=>|->|:=|=:|\*\*|\+\+|--|\|\||&&|<<=?|>>=?|[-+*/%^&|<>!=]=?|[~?]/}),t.languages.insertBefore("solidity","keyword",{builtin:/\b(?:address|bool|byte|u?int(?:8|16|24|32|40|48|56|64|72|80|88|96|104|112|120|128|136|144|152|160|168|176|184|192|200|208|216|224|232|240|248|256)?|string|bytes(?:[1-9]|[12]\d|3[0-2])?)\b/}),t.languages.insertBefore("solidity","number",{version:{pattern:/([<>]=?|\^)\d+\.\d+\.\d+\b/,lookbehind:!0,alias:"number"}}),t.languages.sol=t.languages.solidity}return Ew}var ww,WP;function qSe(){if(WP)return ww;WP=1,ww=e,e.displayName="solutionFile",e.aliases=[];function e(t){(function(n){var r={pattern:/\{[\da-f]{8}-[\da-f]{4}-[\da-f]{4}-[\da-f]{4}-[\da-f]{12}\}/i,alias:"constant",inside:{punctuation:/[{}]/}};n.languages["solution-file"]={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0,inside:{guid:r}},object:{pattern:/^([ \t]*)(?:([A-Z]\w*)\b(?=.*(?:\r\n?|\n)(?:\1[ \t].*(?:\r\n?|\n))*\1End\2(?=[ \t]*$))|End[A-Z]\w*(?=[ \t]*$))/m,lookbehind:!0,greedy:!0,alias:"keyword"},property:{pattern:/^([ \t]*)(?!\s)[^\r\n"#=()]*[^\s"#=()](?=\s*=)/m,lookbehind:!0,inside:{guid:r}},guid:r,number:/\b\d+(?:\.\d+)*\b/,boolean:/\b(?:FALSE|TRUE)\b/,operator:/=/,punctuation:/[(),]/},n.languages.sln=n.languages["solution-file"]})(t)}return ww}var xw,YP;function VSe(){if(YP)return xw;YP=1;var e=Wn();xw=t,t.displayName="soy",t.aliases=[];function t(n){n.register(e),function(r){var a=/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,o=/\b\d+(?:\.\d+)?(?:[eE][+-]?\d+)?\b|\b0x[\dA-F]+\b/;r.languages.soy={comment:[/\/\*[\s\S]*?\*\//,{pattern:/(\s)\/\/.*/,lookbehind:!0,greedy:!0}],"command-arg":{pattern:/(\{+\/?\s*(?:alias|call|delcall|delpackage|deltemplate|namespace|template)\s+)\.?[\w.]+/,lookbehind:!0,alias:"string",inside:{punctuation:/\./}},parameter:{pattern:/(\{+\/?\s*@?param\??\s+)\.?[\w.]+/,lookbehind:!0,alias:"variable"},keyword:[{pattern:/(\{+\/?[^\S\r\n]*)(?:\\[nrt]|alias|call|case|css|default|delcall|delpackage|deltemplate|else(?:if)?|fallbackmsg|for(?:each)?|if(?:empty)?|lb|let|literal|msg|namespace|nil|@?param\??|rb|sp|switch|template|xid)/,lookbehind:!0},/\b(?:any|as|attributes|bool|css|float|html|in|int|js|list|map|null|number|string|uri)\b/],delimiter:{pattern:/^\{+\/?|\/?\}+$/,alias:"punctuation"},property:/\w+(?==)/,variable:{pattern:/\$[^\W\d]\w*(?:\??(?:\.\w+|\[[^\]]+\]))*/,inside:{string:{pattern:a,greedy:!0},number:o,punctuation:/[\[\].?]/}},string:{pattern:a,greedy:!0},function:[/\w+(?=\()/,{pattern:/(\|[^\S\r\n]*)\w+/,lookbehind:!0}],boolean:/\b(?:false|true)\b/,number:o,operator:/\?:?|<=?|>=?|==?|!=|[+*/%-]|\b(?:and|not|or)\b/,punctuation:/[{}()\[\]|.,:]/},r.hooks.add("before-tokenize",function(s){var l=/\{\{.+?\}\}|\{.+?\}|\s\/\/.*|\/\*[\s\S]*?\*\//g,u="{literal}",d="{/literal}",p=!1;r.languages["markup-templating"].buildPlaceholders(s,"soy",l,function(g){return g===d&&(p=!1),p?!1:(g===u&&(p=!0),!0)})}),r.hooks.add("after-tokenize",function(s){r.languages["markup-templating"].tokenizePlaceholders(s,"soy")})}(n)}return xw}var kw,KP;function $H(){if(KP)return kw;KP=1,kw=e,e.displayName="turtle",e.aliases=[];function e(t){t.languages.turtle={comment:{pattern:/#.*/,greedy:!0},"multiline-string":{pattern:/"""(?:(?:""?)?(?:[^"\\]|\\.))*"""|'''(?:(?:''?)?(?:[^'\\]|\\.))*'''/,greedy:!0,alias:"string",inside:{comment:/#.*/}},string:{pattern:/"(?:[^\\"\r\n]|\\.)*"|'(?:[^\\'\r\n]|\\.)*'/,greedy:!0},url:{pattern:/<(?:[^\x00-\x20<>"{}|^`\\]|\\(?:u[\da-fA-F]{4}|U[\da-fA-F]{8}))*>/,greedy:!0,inside:{punctuation:/[<>]/}},function:{pattern:/(?:(?![-.\d\xB7])[-.\w\xB7\xC0-\uFFFD]+)?:(?:(?![-.])(?:[-.:\w\xC0-\uFFFD]|%[\da-f]{2}|\\.)+)?/i,inside:{"local-name":{pattern:/([^:]*:)[\s\S]+/,lookbehind:!0},prefix:{pattern:/[\s\S]+/,inside:{punctuation:/:/}}}},number:/[+-]?\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,punctuation:/[{}.,;()[\]]|\^\^/,boolean:/\b(?:false|true)\b/,keyword:[/(?:\ba|@prefix|@base)\b|=/,/\b(?:base|graph|prefix)\b/i],tag:{pattern:/@[a-z]+(?:-[a-z\d]+)*/i,inside:{punctuation:/@/}}},t.languages.trig=t.languages.turtle}return kw}var Tw,XP;function WSe(){if(XP)return Tw;XP=1;var e=$H();Tw=t,t.displayName="sparql",t.aliases=["rq"];function t(n){n.register(e),n.languages.sparql=n.languages.extend("turtle",{boolean:/\b(?:false|true)\b/i,variable:{pattern:/[?$]\w+/,greedy:!0}}),n.languages.insertBefore("sparql","punctuation",{keyword:[/\b(?:A|ADD|ALL|AS|ASC|ASK|BNODE|BY|CLEAR|CONSTRUCT|COPY|CREATE|DATA|DEFAULT|DELETE|DESC|DESCRIBE|DISTINCT|DROP|EXISTS|FILTER|FROM|GROUP|HAVING|INSERT|INTO|LIMIT|LOAD|MINUS|MOVE|NAMED|NOT|NOW|OFFSET|OPTIONAL|ORDER|RAND|REDUCED|SELECT|SEPARATOR|SERVICE|SILENT|STRUUID|UNION|USING|UUID|VALUES|WHERE)\b/i,/\b(?:ABS|AVG|BIND|BOUND|CEIL|COALESCE|CONCAT|CONTAINS|COUNT|DATATYPE|DAY|ENCODE_FOR_URI|FLOOR|GROUP_CONCAT|HOURS|IF|IRI|isBLANK|isIRI|isLITERAL|isNUMERIC|isURI|LANG|LANGMATCHES|LCASE|MAX|MD5|MIN|MINUTES|MONTH|REGEX|REPLACE|ROUND|sameTerm|SAMPLE|SECONDS|SHA1|SHA256|SHA384|SHA512|STR|STRAFTER|STRBEFORE|STRDT|STRENDS|STRLANG|STRLEN|STRSTARTS|SUBSTR|SUM|TIMEZONE|TZ|UCASE|URI|YEAR)\b(?=\s*\()/i,/\b(?:BASE|GRAPH|PREFIX)\b/i]}),n.languages.rq=n.languages.sparql}return Tw}var Aw,ZP;function YSe(){if(ZP)return Aw;ZP=1,Aw=e,e.displayName="splunkSpl",e.aliases=[];function e(t){t.languages["splunk-spl"]={comment:/`comment\("(?:\\.|[^\\"])*"\)`/,string:{pattern:/"(?:\\.|[^\\"])*"/,greedy:!0},keyword:/\b(?:abstract|accum|addcoltotals|addinfo|addtotals|analyzefields|anomalies|anomalousvalue|anomalydetection|append|appendcols|appendcsv|appendlookup|appendpipe|arules|associate|audit|autoregress|bin|bucket|bucketdir|chart|cluster|cofilter|collect|concurrency|contingency|convert|correlate|datamodel|dbinspect|dedup|delete|delta|diff|erex|eval|eventcount|eventstats|extract|fieldformat|fields|fieldsummary|filldown|fillnull|findtypes|folderize|foreach|format|from|gauge|gentimes|geom|geomfilter|geostats|head|highlight|history|iconify|input|inputcsv|inputlookup|iplocation|join|kmeans|kv|kvform|loadjob|localize|localop|lookup|makecontinuous|makemv|makeresults|map|mcollect|metadata|metasearch|meventcollect|mstats|multikv|multisearch|mvcombine|mvexpand|nomv|outlier|outputcsv|outputlookup|outputtext|overlap|pivot|predict|rangemap|rare|regex|relevancy|reltime|rename|replace|rest|return|reverse|rex|rtorder|run|savedsearch|script|scrub|search|searchtxn|selfjoin|sendemail|set|setfields|sichart|sirare|sistats|sitimechart|sitop|sort|spath|stats|strcat|streamstats|table|tags|tail|timechart|timewrap|top|transaction|transpose|trendline|tscollect|tstats|typeahead|typelearner|typer|union|uniq|untable|where|x11|xmlkv|xmlunescape|xpath|xyseries)\b/i,"operator-word":{pattern:/\b(?:and|as|by|not|or|xor)\b/i,alias:"operator"},function:/\b\w+(?=\s*\()/,property:/\b\w+(?=\s*=(?!=))/,date:{pattern:/\b\d{1,2}\/\d{1,2}\/\d{1,4}(?:(?::\d{1,2}){3})?\b/,alias:"number"},number:/\b\d+(?:\.\d+)?\b/,boolean:/\b(?:f|false|t|true)\b/i,operator:/[<>=]=?|[-+*/%|]/,punctuation:/[()[\],]/}}return Aw}var Rw,QP;function KSe(){if(QP)return Rw;QP=1,Rw=e,e.displayName="sqf",e.aliases=[];function e(t){t.languages.sqf=t.languages.extend("clike",{string:{pattern:/"(?:(?:"")?[^"])*"(?!")|'(?:[^'])*'/,greedy:!0},keyword:/\b(?:breakOut|breakTo|call|case|catch|default|do|echo|else|execFSM|execVM|exitWith|for|forEach|forEachMember|forEachMemberAgent|forEachMemberTeam|from|goto|if|nil|preprocessFile|preprocessFileLineNumbers|private|scopeName|spawn|step|switch|then|throw|to|try|while|with)\b/i,boolean:/\b(?:false|true)\b/i,function:/\b(?:abs|accTime|acos|action|actionIDs|actionKeys|actionKeysImages|actionKeysNames|actionKeysNamesArray|actionName|actionParams|activateAddons|activatedAddons|activateKey|add3DENConnection|add3DENEventHandler|add3DENLayer|addAction|addBackpack|addBackpackCargo|addBackpackCargoGlobal|addBackpackGlobal|addCamShake|addCuratorAddons|addCuratorCameraArea|addCuratorEditableObjects|addCuratorEditingArea|addCuratorPoints|addEditorObject|addEventHandler|addForce|addForceGeneratorRTD|addGoggles|addGroupIcon|addHandgunItem|addHeadgear|addItem|addItemCargo|addItemCargoGlobal|addItemPool|addItemToBackpack|addItemToUniform|addItemToVest|addLiveStats|addMagazine|addMagazineAmmoCargo|addMagazineCargo|addMagazineCargoGlobal|addMagazineGlobal|addMagazinePool|addMagazines|addMagazineTurret|addMenu|addMenuItem|addMissionEventHandler|addMPEventHandler|addMusicEventHandler|addOwnedMine|addPlayerScores|addPrimaryWeaponItem|addPublicVariableEventHandler|addRating|addResources|addScore|addScoreSide|addSecondaryWeaponItem|addSwitchableUnit|addTeamMember|addToRemainsCollector|addTorque|addUniform|addVehicle|addVest|addWaypoint|addWeapon|addWeaponCargo|addWeaponCargoGlobal|addWeaponGlobal|addWeaponItem|addWeaponPool|addWeaponTurret|admin|agent|agents|AGLToASL|aimedAtTarget|aimPos|airDensityCurveRTD|airDensityRTD|airplaneThrottle|airportSide|AISFinishHeal|alive|all3DENEntities|allAirports|allControls|allCurators|allCutLayers|allDead|allDeadMen|allDisplays|allGroups|allMapMarkers|allMines|allMissionObjects|allow3DMode|allowCrewInImmobile|allowCuratorLogicIgnoreAreas|allowDamage|allowDammage|allowFileOperations|allowFleeing|allowGetIn|allowSprint|allPlayers|allSimpleObjects|allSites|allTurrets|allUnits|allUnitsUAV|allVariables|ammo|ammoOnPylon|animate|animateBay|animateDoor|animatePylon|animateSource|animationNames|animationPhase|animationSourcePhase|animationState|append|apply|armoryPoints|arrayIntersect|asin|ASLToAGL|ASLToATL|assert|assignAsCargo|assignAsCargoIndex|assignAsCommander|assignAsDriver|assignAsGunner|assignAsTurret|assignCurator|assignedCargo|assignedCommander|assignedDriver|assignedGunner|assignedItems|assignedTarget|assignedTeam|assignedVehicle|assignedVehicleRole|assignItem|assignTeam|assignToAirport|atan|atan2|atg|ATLToASL|attachedObject|attachedObjects|attachedTo|attachObject|attachTo|attackEnabled|backpack|backpackCargo|backpackContainer|backpackItems|backpackMagazines|backpackSpaceFor|behaviour|benchmark|binocular|blufor|boundingBox|boundingBoxReal|boundingCenter|briefingName|buildingExit|buildingPos|buldozer_EnableRoadDiag|buldozer_IsEnabledRoadDiag|buldozer_LoadNewRoads|buldozer_reloadOperMap|buttonAction|buttonSetAction|cadetMode|callExtension|camCommand|camCommit|camCommitPrepared|camCommitted|camConstuctionSetParams|camCreate|camDestroy|cameraEffect|cameraEffectEnableHUD|cameraInterest|cameraOn|cameraView|campaignConfigFile|camPreload|camPreloaded|camPrepareBank|camPrepareDir|camPrepareDive|camPrepareFocus|camPrepareFov|camPrepareFovRange|camPreparePos|camPrepareRelPos|camPrepareTarget|camSetBank|camSetDir|camSetDive|camSetFocus|camSetFov|camSetFovRange|camSetPos|camSetRelPos|camSetTarget|camTarget|camUseNVG|canAdd|canAddItemToBackpack|canAddItemToUniform|canAddItemToVest|cancelSimpleTaskDestination|canFire|canMove|canSlingLoad|canStand|canSuspend|canTriggerDynamicSimulation|canUnloadInCombat|canVehicleCargo|captive|captiveNum|cbChecked|cbSetChecked|ceil|channelEnabled|cheatsEnabled|checkAIFeature|checkVisibility|civilian|className|clear3DENAttribute|clear3DENInventory|clearAllItemsFromBackpack|clearBackpackCargo|clearBackpackCargoGlobal|clearForcesRTD|clearGroupIcons|clearItemCargo|clearItemCargoGlobal|clearItemPool|clearMagazineCargo|clearMagazineCargoGlobal|clearMagazinePool|clearOverlay|clearRadio|clearVehicleInit|clearWeaponCargo|clearWeaponCargoGlobal|clearWeaponPool|clientOwner|closeDialog|closeDisplay|closeOverlay|collapseObjectTree|collect3DENHistory|collectiveRTD|combatMode|commandArtilleryFire|commandChat|commander|commandFire|commandFollow|commandFSM|commandGetOut|commandingMenu|commandMove|commandRadio|commandStop|commandSuppressiveFire|commandTarget|commandWatch|comment|commitOverlay|compile|compileFinal|completedFSM|composeText|configClasses|configFile|configHierarchy|configName|configNull|configProperties|configSourceAddonList|configSourceMod|configSourceModList|confirmSensorTarget|connectTerminalToUAV|controlNull|controlsGroupCtrl|copyFromClipboard|copyToClipboard|copyWaypoints|cos|count|countEnemy|countFriendly|countSide|countType|countUnknown|create3DENComposition|create3DENEntity|createAgent|createCenter|createDialog|createDiaryLink|createDiaryRecord|createDiarySubject|createDisplay|createGearDialog|createGroup|createGuardedPoint|createLocation|createMarker|createMarkerLocal|createMenu|createMine|createMissionDisplay|createMPCampaignDisplay|createSimpleObject|createSimpleTask|createSite|createSoundSource|createTask|createTeam|createTrigger|createUnit|createVehicle|createVehicleCrew|createVehicleLocal|crew|ctAddHeader|ctAddRow|ctClear|ctCurSel|ctData|ctFindHeaderRows|ctFindRowHeader|ctHeaderControls|ctHeaderCount|ctRemoveHeaders|ctRemoveRows|ctrlActivate|ctrlAddEventHandler|ctrlAngle|ctrlAutoScrollDelay|ctrlAutoScrollRewind|ctrlAutoScrollSpeed|ctrlChecked|ctrlClassName|ctrlCommit|ctrlCommitted|ctrlCreate|ctrlDelete|ctrlEnable|ctrlEnabled|ctrlFade|ctrlHTMLLoaded|ctrlIDC|ctrlIDD|ctrlMapAnimAdd|ctrlMapAnimClear|ctrlMapAnimCommit|ctrlMapAnimDone|ctrlMapCursor|ctrlMapMouseOver|ctrlMapScale|ctrlMapScreenToWorld|ctrlMapWorldToScreen|ctrlModel|ctrlModelDirAndUp|ctrlModelScale|ctrlParent|ctrlParentControlsGroup|ctrlPosition|ctrlRemoveAllEventHandlers|ctrlRemoveEventHandler|ctrlScale|ctrlSetActiveColor|ctrlSetAngle|ctrlSetAutoScrollDelay|ctrlSetAutoScrollRewind|ctrlSetAutoScrollSpeed|ctrlSetBackgroundColor|ctrlSetChecked|ctrlSetDisabledColor|ctrlSetEventHandler|ctrlSetFade|ctrlSetFocus|ctrlSetFont|ctrlSetFontH1|ctrlSetFontH1B|ctrlSetFontH2|ctrlSetFontH2B|ctrlSetFontH3|ctrlSetFontH3B|ctrlSetFontH4|ctrlSetFontH4B|ctrlSetFontH5|ctrlSetFontH5B|ctrlSetFontH6|ctrlSetFontH6B|ctrlSetFontHeight|ctrlSetFontHeightH1|ctrlSetFontHeightH2|ctrlSetFontHeightH3|ctrlSetFontHeightH4|ctrlSetFontHeightH5|ctrlSetFontHeightH6|ctrlSetFontHeightSecondary|ctrlSetFontP|ctrlSetFontPB|ctrlSetFontSecondary|ctrlSetForegroundColor|ctrlSetModel|ctrlSetModelDirAndUp|ctrlSetModelScale|ctrlSetPixelPrecision|ctrlSetPosition|ctrlSetScale|ctrlSetStructuredText|ctrlSetText|ctrlSetTextColor|ctrlSetTextColorSecondary|ctrlSetTextSecondary|ctrlSetTooltip|ctrlSetTooltipColorBox|ctrlSetTooltipColorShade|ctrlSetTooltipColorText|ctrlShow|ctrlShown|ctrlText|ctrlTextHeight|ctrlTextSecondary|ctrlTextWidth|ctrlType|ctrlVisible|ctRowControls|ctRowCount|ctSetCurSel|ctSetData|ctSetHeaderTemplate|ctSetRowTemplate|ctSetValue|ctValue|curatorAddons|curatorCamera|curatorCameraArea|curatorCameraAreaCeiling|curatorCoef|curatorEditableObjects|curatorEditingArea|curatorEditingAreaType|curatorMouseOver|curatorPoints|curatorRegisteredObjects|curatorSelected|curatorWaypointCost|current3DENOperation|currentChannel|currentCommand|currentMagazine|currentMagazineDetail|currentMagazineDetailTurret|currentMagazineTurret|currentMuzzle|currentNamespace|currentTask|currentTasks|currentThrowable|currentVisionMode|currentWaypoint|currentWeapon|currentWeaponMode|currentWeaponTurret|currentZeroing|cursorObject|cursorTarget|customChat|customRadio|cutFadeOut|cutObj|cutRsc|cutText|damage|date|dateToNumber|daytime|deActivateKey|debriefingText|debugFSM|debugLog|deg|delete3DENEntities|deleteAt|deleteCenter|deleteCollection|deleteEditorObject|deleteGroup|deleteGroupWhenEmpty|deleteIdentity|deleteLocation|deleteMarker|deleteMarkerLocal|deleteRange|deleteResources|deleteSite|deleteStatus|deleteTeam|deleteVehicle|deleteVehicleCrew|deleteWaypoint|detach|detectedMines|diag_activeMissionFSMs|diag_activeScripts|diag_activeSQFScripts|diag_activeSQSScripts|diag_captureFrame|diag_captureFrameToFile|diag_captureSlowFrame|diag_codePerformance|diag_drawMode|diag_dynamicSimulationEnd|diag_enable|diag_enabled|diag_fps|diag_fpsMin|diag_frameNo|diag_lightNewLoad|diag_list|diag_log|diag_logSlowFrame|diag_mergeConfigFile|diag_recordTurretLimits|diag_setLightNew|diag_tickTime|diag_toggle|dialog|diarySubjectExists|didJIP|didJIPOwner|difficulty|difficultyEnabled|difficultyEnabledRTD|difficultyOption|direction|directSay|disableAI|disableCollisionWith|disableConversation|disableDebriefingStats|disableMapIndicators|disableNVGEquipment|disableRemoteSensors|disableSerialization|disableTIEquipment|disableUAVConnectability|disableUserInput|displayAddEventHandler|displayCtrl|displayNull|displayParent|displayRemoveAllEventHandlers|displayRemoveEventHandler|displaySetEventHandler|dissolveTeam|distance|distance2D|distanceSqr|distributionRegion|do3DENAction|doArtilleryFire|doFire|doFollow|doFSM|doGetOut|doMove|doorPhase|doStop|doSuppressiveFire|doTarget|doWatch|drawArrow|drawEllipse|drawIcon|drawIcon3D|drawLine|drawLine3D|drawLink|drawLocation|drawPolygon|drawRectangle|drawTriangle|driver|drop|dynamicSimulationDistance|dynamicSimulationDistanceCoef|dynamicSimulationEnabled|dynamicSimulationSystemEnabled|east|edit3DENMissionAttributes|editObject|editorSetEventHandler|effectiveCommander|emptyPositions|enableAI|enableAIFeature|enableAimPrecision|enableAttack|enableAudioFeature|enableAutoStartUpRTD|enableAutoTrimRTD|enableCamShake|enableCaustics|enableChannel|enableCollisionWith|enableCopilot|enableDebriefingStats|enableDiagLegend|enableDynamicSimulation|enableDynamicSimulationSystem|enableEndDialog|enableEngineArtillery|enableEnvironment|enableFatigue|enableGunLights|enableInfoPanelComponent|enableIRLasers|enableMimics|enablePersonTurret|enableRadio|enableReload|enableRopeAttach|enableSatNormalOnDetail|enableSaving|enableSentences|enableSimulation|enableSimulationGlobal|enableStamina|enableStressDamage|enableTeamSwitch|enableTraffic|enableUAVConnectability|enableUAVWaypoints|enableVehicleCargo|enableVehicleSensor|enableWeaponDisassembly|endl|endLoadingScreen|endMission|engineOn|enginesIsOnRTD|enginesPowerRTD|enginesRpmRTD|enginesTorqueRTD|entities|environmentEnabled|estimatedEndServerTime|estimatedTimeLeft|evalObjectArgument|everyBackpack|everyContainer|exec|execEditorScript|exp|expectedDestination|exportJIPMessages|eyeDirection|eyePos|face|faction|fadeMusic|fadeRadio|fadeSound|fadeSpeech|failMission|fillWeaponsFromPool|find|findCover|findDisplay|findEditorObject|findEmptyPosition|findEmptyPositionReady|findIf|findNearestEnemy|finishMissionInit|finite|fire|fireAtTarget|firstBackpack|flag|flagAnimationPhase|flagOwner|flagSide|flagTexture|fleeing|floor|flyInHeight|flyInHeightASL|fog|fogForecast|fogParams|forceAddUniform|forceAtPositionRTD|forcedMap|forceEnd|forceFlagTexture|forceFollowRoad|forceGeneratorRTD|forceMap|forceRespawn|forceSpeed|forceWalk|forceWeaponFire|forceWeatherChange|forgetTarget|format|formation|formationDirection|formationLeader|formationMembers|formationPosition|formationTask|formatText|formLeader|freeLook|fromEditor|fuel|fullCrew|gearIDCAmmoCount|gearSlotAmmoCount|gearSlotData|get3DENActionState|get3DENAttribute|get3DENCamera|get3DENConnections|get3DENEntity|get3DENEntityID|get3DENGrid|get3DENIconsVisible|get3DENLayerEntities|get3DENLinesVisible|get3DENMissionAttribute|get3DENMouseOver|get3DENSelected|getAimingCoef|getAllEnvSoundControllers|getAllHitPointsDamage|getAllOwnedMines|getAllSoundControllers|getAmmoCargo|getAnimAimPrecision|getAnimSpeedCoef|getArray|getArtilleryAmmo|getArtilleryComputerSettings|getArtilleryETA|getAssignedCuratorLogic|getAssignedCuratorUnit|getBackpackCargo|getBleedingRemaining|getBurningValue|getCameraViewDirection|getCargoIndex|getCenterOfMass|getClientState|getClientStateNumber|getCompatiblePylonMagazines|getConnectedUAV|getContainerMaxLoad|getCursorObjectParams|getCustomAimCoef|getDammage|getDescription|getDir|getDirVisual|getDLCAssetsUsage|getDLCAssetsUsageByName|getDLCs|getDLCUsageTime|getEditorCamera|getEditorMode|getEditorObjectScope|getElevationOffset|getEngineTargetRpmRTD|getEnvSoundController|getFatigue|getFieldManualStartPage|getForcedFlagTexture|getFriend|getFSMVariable|getFuelCargo|getGroupIcon|getGroupIconParams|getGroupIcons|getHideFrom|getHit|getHitIndex|getHitPointDamage|getItemCargo|getMagazineCargo|getMarkerColor|getMarkerPos|getMarkerSize|getMarkerType|getMass|getMissionConfig|getMissionConfigValue|getMissionDLCs|getMissionLayerEntities|getMissionLayers|getModelInfo|getMousePosition|getMusicPlayedTime|getNumber|getObjectArgument|getObjectChildren|getObjectDLC|getObjectMaterials|getObjectProxy|getObjectTextures|getObjectType|getObjectViewDistance|getOxygenRemaining|getPersonUsedDLCs|getPilotCameraDirection|getPilotCameraPosition|getPilotCameraRotation|getPilotCameraTarget|getPlateNumber|getPlayerChannel|getPlayerScores|getPlayerUID|getPlayerUIDOld|getPos|getPosASL|getPosASLVisual|getPosASLW|getPosATL|getPosATLVisual|getPosVisual|getPosWorld|getPylonMagazines|getRelDir|getRelPos|getRemoteSensorsDisabled|getRepairCargo|getResolution|getRotorBrakeRTD|getShadowDistance|getShotParents|getSlingLoad|getSoundController|getSoundControllerResult|getSpeed|getStamina|getStatValue|getSuppression|getTerrainGrid|getTerrainHeightASL|getText|getTotalDLCUsageTime|getTrimOffsetRTD|getUnitLoadout|getUnitTrait|getUserMFDText|getUserMFDValue|getVariable|getVehicleCargo|getWeaponCargo|getWeaponSway|getWingsOrientationRTD|getWingsPositionRTD|getWPPos|glanceAt|globalChat|globalRadio|goggles|group|groupChat|groupFromNetId|groupIconSelectable|groupIconsVisible|groupId|groupOwner|groupRadio|groupSelectedUnits|groupSelectUnit|grpNull|gunner|gusts|halt|handgunItems|handgunMagazine|handgunWeapon|handsHit|hasInterface|hasPilotCamera|hasWeapon|hcAllGroups|hcGroupParams|hcLeader|hcRemoveAllGroups|hcRemoveGroup|hcSelected|hcSelectGroup|hcSetGroup|hcShowBar|hcShownBar|headgear|hideBody|hideObject|hideObjectGlobal|hideSelection|hint|hintC|hintCadet|hintSilent|hmd|hostMission|htmlLoad|HUDMovementLevels|humidity|image|importAllGroups|importance|in|inArea|inAreaArray|incapacitatedState|independent|inflame|inflamed|infoPanel|infoPanelComponentEnabled|infoPanelComponents|infoPanels|inGameUISetEventHandler|inheritsFrom|initAmbientLife|inPolygon|inputAction|inRangeOfArtillery|insertEditorObject|intersect|is3DEN|is3DENMultiplayer|isAbleToBreathe|isAgent|isAimPrecisionEnabled|isArray|isAutoHoverOn|isAutonomous|isAutoStartUpEnabledRTD|isAutotest|isAutoTrimOnRTD|isBleeding|isBurning|isClass|isCollisionLightOn|isCopilotEnabled|isDamageAllowed|isDedicated|isDLCAvailable|isEngineOn|isEqualTo|isEqualType|isEqualTypeAll|isEqualTypeAny|isEqualTypeArray|isEqualTypeParams|isFilePatchingEnabled|isFlashlightOn|isFlatEmpty|isForcedWalk|isFormationLeader|isGroupDeletedWhenEmpty|isHidden|isInRemainsCollector|isInstructorFigureEnabled|isIRLaserOn|isKeyActive|isKindOf|isLaserOn|isLightOn|isLocalized|isManualFire|isMarkedForCollection|isMultiplayer|isMultiplayerSolo|isNil|isNull|isNumber|isObjectHidden|isObjectRTD|isOnRoad|isPipEnabled|isPlayer|isRealTime|isRemoteExecuted|isRemoteExecutedJIP|isServer|isShowing3DIcons|isSimpleObject|isSprintAllowed|isStaminaEnabled|isSteamMission|isStreamFriendlyUIEnabled|isStressDamageEnabled|isText|isTouchingGround|isTurnedOut|isTutHintsEnabled|isUAVConnectable|isUAVConnected|isUIContext|isUniformAllowed|isVehicleCargo|isVehicleRadarOn|isVehicleSensorEnabled|isWalking|isWeaponDeployed|isWeaponRested|itemCargo|items|itemsWithMagazines|join|joinAs|joinAsSilent|joinSilent|joinString|kbAddDatabase|kbAddDatabaseTargets|kbAddTopic|kbHasTopic|kbReact|kbRemoveTopic|kbTell|kbWasSaid|keyImage|keyName|knowsAbout|land|landAt|landResult|language|laserTarget|lbAdd|lbClear|lbColor|lbColorRight|lbCurSel|lbData|lbDelete|lbIsSelected|lbPicture|lbPictureRight|lbSelection|lbSetColor|lbSetColorRight|lbSetCurSel|lbSetData|lbSetPicture|lbSetPictureColor|lbSetPictureColorDisabled|lbSetPictureColorSelected|lbSetPictureRight|lbSetPictureRightColor|lbSetPictureRightColorDisabled|lbSetPictureRightColorSelected|lbSetSelectColor|lbSetSelectColorRight|lbSetSelected|lbSetText|lbSetTextRight|lbSetTooltip|lbSetValue|lbSize|lbSort|lbSortByValue|lbText|lbTextRight|lbValue|leader|leaderboardDeInit|leaderboardGetRows|leaderboardInit|leaderboardRequestRowsFriends|leaderboardRequestRowsGlobal|leaderboardRequestRowsGlobalAroundUser|leaderboardsRequestUploadScore|leaderboardsRequestUploadScoreKeepBest|leaderboardState|leaveVehicle|libraryCredits|libraryDisclaimers|lifeState|lightAttachObject|lightDetachObject|lightIsOn|lightnings|limitSpeed|linearConversion|lineBreak|lineIntersects|lineIntersectsObjs|lineIntersectsSurfaces|lineIntersectsWith|linkItem|list|listObjects|listRemoteTargets|listVehicleSensors|ln|lnbAddArray|lnbAddColumn|lnbAddRow|lnbClear|lnbColor|lnbColorRight|lnbCurSelRow|lnbData|lnbDeleteColumn|lnbDeleteRow|lnbGetColumnsPosition|lnbPicture|lnbPictureRight|lnbSetColor|lnbSetColorRight|lnbSetColumnsPos|lnbSetCurSelRow|lnbSetData|lnbSetPicture|lnbSetPictureColor|lnbSetPictureColorRight|lnbSetPictureColorSelected|lnbSetPictureColorSelectedRight|lnbSetPictureRight|lnbSetText|lnbSetTextRight|lnbSetValue|lnbSize|lnbSort|lnbSortByValue|lnbText|lnbTextRight|lnbValue|load|loadAbs|loadBackpack|loadFile|loadGame|loadIdentity|loadMagazine|loadOverlay|loadStatus|loadUniform|loadVest|local|localize|locationNull|locationPosition|lock|lockCameraTo|lockCargo|lockDriver|locked|lockedCargo|lockedDriver|lockedTurret|lockIdentity|lockTurret|lockWP|log|logEntities|logNetwork|logNetworkTerminate|lookAt|lookAtPos|magazineCargo|magazines|magazinesAllTurrets|magazinesAmmo|magazinesAmmoCargo|magazinesAmmoFull|magazinesDetail|magazinesDetailBackpack|magazinesDetailUniform|magazinesDetailVest|magazinesTurret|magazineTurretAmmo|mapAnimAdd|mapAnimClear|mapAnimCommit|mapAnimDone|mapCenterOnCamera|mapGridPosition|markAsFinishedOnSteam|markerAlpha|markerBrush|markerColor|markerDir|markerPos|markerShape|markerSize|markerText|markerType|max|members|menuAction|menuAdd|menuChecked|menuClear|menuCollapse|menuData|menuDelete|menuEnable|menuEnabled|menuExpand|menuHover|menuPicture|menuSetAction|menuSetCheck|menuSetData|menuSetPicture|menuSetValue|menuShortcut|menuShortcutText|menuSize|menuSort|menuText|menuURL|menuValue|min|mineActive|mineDetectedBy|missionConfigFile|missionDifficulty|missionName|missionNamespace|missionStart|missionVersion|modelToWorld|modelToWorldVisual|modelToWorldVisualWorld|modelToWorldWorld|modParams|moonIntensity|moonPhase|morale|move|move3DENCamera|moveInAny|moveInCargo|moveInCommander|moveInDriver|moveInGunner|moveInTurret|moveObjectToEnd|moveOut|moveTime|moveTo|moveToCompleted|moveToFailed|musicVolume|name|nameSound|nearEntities|nearestBuilding|nearestLocation|nearestLocations|nearestLocationWithDubbing|nearestObject|nearestObjects|nearestTerrainObjects|nearObjects|nearObjectsReady|nearRoads|nearSupplies|nearTargets|needReload|netId|netObjNull|newOverlay|nextMenuItemIndex|nextWeatherChange|nMenuItems|numberOfEnginesRTD|numberToDate|objectCurators|objectFromNetId|objectParent|objNull|objStatus|onBriefingGear|onBriefingGroup|onBriefingNotes|onBriefingPlan|onBriefingTeamSwitch|onCommandModeChanged|onDoubleClick|onEachFrame|onGroupIconClick|onGroupIconOverEnter|onGroupIconOverLeave|onHCGroupSelectionChanged|onMapSingleClick|onPlayerConnected|onPlayerDisconnected|onPreloadFinished|onPreloadStarted|onShowNewObject|onTeamSwitch|openCuratorInterface|openDLCPage|openDSInterface|openMap|openSteamApp|openYoutubeVideo|opfor|orderGetIn|overcast|overcastForecast|owner|param|params|parseNumber|parseSimpleArray|parseText|parsingNamespace|particlesQuality|pi|pickWeaponPool|pitch|pixelGrid|pixelGridBase|pixelGridNoUIScale|pixelH|pixelW|playableSlotsNumber|playableUnits|playAction|playActionNow|player|playerRespawnTime|playerSide|playersNumber|playGesture|playMission|playMove|playMoveNow|playMusic|playScriptedMission|playSound|playSound3D|position|positionCameraToWorld|posScreenToWorld|posWorldToScreen|ppEffectAdjust|ppEffectCommit|ppEffectCommitted|ppEffectCreate|ppEffectDestroy|ppEffectEnable|ppEffectEnabled|ppEffectForceInNVG|precision|preloadCamera|preloadObject|preloadSound|preloadTitleObj|preloadTitleRsc|primaryWeapon|primaryWeaponItems|primaryWeaponMagazine|priority|processDiaryLink|processInitCommands|productVersion|profileName|profileNamespace|profileNameSteam|progressLoadingScreen|progressPosition|progressSetPosition|publicVariable|publicVariableClient|publicVariableServer|pushBack|pushBackUnique|putWeaponPool|queryItemsPool|queryMagazinePool|queryWeaponPool|rad|radioChannelAdd|radioChannelCreate|radioChannelRemove|radioChannelSetCallSign|radioChannelSetLabel|radioVolume|rain|rainbow|random|rank|rankId|rating|rectangular|registeredTasks|registerTask|reload|reloadEnabled|remoteControl|remoteExec|remoteExecCall|remoteExecutedOwner|remove3DENConnection|remove3DENEventHandler|remove3DENLayer|removeAction|removeAll3DENEventHandlers|removeAllActions|removeAllAssignedItems|removeAllContainers|removeAllCuratorAddons|removeAllCuratorCameraAreas|removeAllCuratorEditingAreas|removeAllEventHandlers|removeAllHandgunItems|removeAllItems|removeAllItemsWithMagazines|removeAllMissionEventHandlers|removeAllMPEventHandlers|removeAllMusicEventHandlers|removeAllOwnedMines|removeAllPrimaryWeaponItems|removeAllWeapons|removeBackpack|removeBackpackGlobal|removeCuratorAddons|removeCuratorCameraArea|removeCuratorEditableObjects|removeCuratorEditingArea|removeDrawIcon|removeDrawLinks|removeEventHandler|removeFromRemainsCollector|removeGoggles|removeGroupIcon|removeHandgunItem|removeHeadgear|removeItem|removeItemFromBackpack|removeItemFromUniform|removeItemFromVest|removeItems|removeMagazine|removeMagazineGlobal|removeMagazines|removeMagazinesTurret|removeMagazineTurret|removeMenuItem|removeMissionEventHandler|removeMPEventHandler|removeMusicEventHandler|removeOwnedMine|removePrimaryWeaponItem|removeSecondaryWeaponItem|removeSimpleTask|removeSwitchableUnit|removeTeamMember|removeUniform|removeVest|removeWeapon|removeWeaponAttachmentCargo|removeWeaponCargo|removeWeaponGlobal|removeWeaponTurret|reportRemoteTarget|requiredVersion|resetCamShake|resetSubgroupDirection|resistance|resize|resources|respawnVehicle|restartEditorCamera|reveal|revealMine|reverse|reversedMouseY|roadAt|roadsConnectedTo|roleDescription|ropeAttachedObjects|ropeAttachedTo|ropeAttachEnabled|ropeAttachTo|ropeCreate|ropeCut|ropeDestroy|ropeDetach|ropeEndPosition|ropeLength|ropes|ropeUnwind|ropeUnwound|rotorsForcesRTD|rotorsRpmRTD|round|runInitScript|safeZoneH|safeZoneW|safeZoneWAbs|safeZoneX|safeZoneXAbs|safeZoneY|save3DENInventory|saveGame|saveIdentity|saveJoysticks|saveOverlay|saveProfileNamespace|saveStatus|saveVar|savingEnabled|say|say2D|say3D|score|scoreSide|screenshot|screenToWorld|scriptDone|scriptName|scriptNull|scudState|secondaryWeapon|secondaryWeaponItems|secondaryWeaponMagazine|select|selectBestPlaces|selectDiarySubject|selectedEditorObjects|selectEditorObject|selectionNames|selectionPosition|selectLeader|selectMax|selectMin|selectNoPlayer|selectPlayer|selectRandom|selectRandomWeighted|selectWeapon|selectWeaponTurret|sendAUMessage|sendSimpleCommand|sendTask|sendTaskResult|sendUDPMessage|serverCommand|serverCommandAvailable|serverCommandExecutable|serverName|serverTime|set|set3DENAttribute|set3DENAttributes|set3DENGrid|set3DENIconsVisible|set3DENLayer|set3DENLinesVisible|set3DENLogicType|set3DENMissionAttribute|set3DENMissionAttributes|set3DENModelsVisible|set3DENObjectType|set3DENSelected|setAccTime|setActualCollectiveRTD|setAirplaneThrottle|setAirportSide|setAmmo|setAmmoCargo|setAmmoOnPylon|setAnimSpeedCoef|setAperture|setApertureNew|setArmoryPoints|setAttributes|setAutonomous|setBehaviour|setBleedingRemaining|setBrakesRTD|setCameraInterest|setCamShakeDefParams|setCamShakeParams|setCamUseTI|setCaptive|setCenterOfMass|setCollisionLight|setCombatMode|setCompassOscillation|setConvoySeparation|setCuratorCameraAreaCeiling|setCuratorCoef|setCuratorEditingAreaType|setCuratorWaypointCost|setCurrentChannel|setCurrentTask|setCurrentWaypoint|setCustomAimCoef|setCustomWeightRTD|setDamage|setDammage|setDate|setDebriefingText|setDefaultCamera|setDestination|setDetailMapBlendPars|setDir|setDirection|setDrawIcon|setDriveOnPath|setDropInterval|setDynamicSimulationDistance|setDynamicSimulationDistanceCoef|setEditorMode|setEditorObjectScope|setEffectCondition|setEngineRpmRTD|setFace|setFaceAnimation|setFatigue|setFeatureType|setFlagAnimationPhase|setFlagOwner|setFlagSide|setFlagTexture|setFog|setForceGeneratorRTD|setFormation|setFormationTask|setFormDir|setFriend|setFromEditor|setFSMVariable|setFuel|setFuelCargo|setGroupIcon|setGroupIconParams|setGroupIconsSelectable|setGroupIconsVisible|setGroupId|setGroupIdGlobal|setGroupOwner|setGusts|setHideBehind|setHit|setHitIndex|setHitPointDamage|setHorizonParallaxCoef|setHUDMovementLevels|setIdentity|setImportance|setInfoPanel|setLeader|setLightAmbient|setLightAttenuation|setLightBrightness|setLightColor|setLightDayLight|setLightFlareMaxDistance|setLightFlareSize|setLightIntensity|setLightnings|setLightUseFlare|setLocalWindParams|setMagazineTurretAmmo|setMarkerAlpha|setMarkerAlphaLocal|setMarkerBrush|setMarkerBrushLocal|setMarkerColor|setMarkerColorLocal|setMarkerDir|setMarkerDirLocal|setMarkerPos|setMarkerPosLocal|setMarkerShape|setMarkerShapeLocal|setMarkerSize|setMarkerSizeLocal|setMarkerText|setMarkerTextLocal|setMarkerType|setMarkerTypeLocal|setMass|setMimic|setMousePosition|setMusicEffect|setMusicEventHandler|setName|setNameSound|setObjectArguments|setObjectMaterial|setObjectMaterialGlobal|setObjectProxy|setObjectTexture|setObjectTextureGlobal|setObjectViewDistance|setOvercast|setOwner|setOxygenRemaining|setParticleCircle|setParticleClass|setParticleFire|setParticleParams|setParticleRandom|setPilotCameraDirection|setPilotCameraRotation|setPilotCameraTarget|setPilotLight|setPiPEffect|setPitch|setPlateNumber|setPlayable|setPlayerRespawnTime|setPos|setPosASL|setPosASL2|setPosASLW|setPosATL|setPosition|setPosWorld|setPylonLoadOut|setPylonsPriority|setRadioMsg|setRain|setRainbow|setRandomLip|setRank|setRectangular|setRepairCargo|setRotorBrakeRTD|setShadowDistance|setShotParents|setSide|setSimpleTaskAlwaysVisible|setSimpleTaskCustomData|setSimpleTaskDescription|setSimpleTaskDestination|setSimpleTaskTarget|setSimpleTaskType|setSimulWeatherLayers|setSize|setSkill|setSlingLoad|setSoundEffect|setSpeaker|setSpeech|setSpeedMode|setStamina|setStaminaScheme|setStatValue|setSuppression|setSystemOfUnits|setTargetAge|setTaskMarkerOffset|setTaskResult|setTaskState|setTerrainGrid|setText|setTimeMultiplier|setTitleEffect|setToneMapping|setToneMappingParams|setTrafficDensity|setTrafficDistance|setTrafficGap|setTrafficSpeed|setTriggerActivation|setTriggerArea|setTriggerStatements|setTriggerText|setTriggerTimeout|setTriggerType|setType|setUnconscious|setUnitAbility|setUnitLoadout|setUnitPos|setUnitPosWeak|setUnitRank|setUnitRecoilCoefficient|setUnitTrait|setUnloadInCombat|setUserActionText|setUserMFDText|setUserMFDValue|setVariable|setVectorDir|setVectorDirAndUp|setVectorUp|setVehicleAmmo|setVehicleAmmoDef|setVehicleArmor|setVehicleCargo|setVehicleId|setVehicleInit|setVehicleLock|setVehiclePosition|setVehicleRadar|setVehicleReceiveRemoteTargets|setVehicleReportOwnPosition|setVehicleReportRemoteTargets|setVehicleTIPars|setVehicleVarName|setVelocity|setVelocityModelSpace|setVelocityTransformation|setViewDistance|setVisibleIfTreeCollapsed|setWantedRpmRTD|setWaves|setWaypointBehaviour|setWaypointCombatMode|setWaypointCompletionRadius|setWaypointDescription|setWaypointForceBehaviour|setWaypointFormation|setWaypointHousePosition|setWaypointLoiterRadius|setWaypointLoiterType|setWaypointName|setWaypointPosition|setWaypointScript|setWaypointSpeed|setWaypointStatements|setWaypointTimeout|setWaypointType|setWaypointVisible|setWeaponReloadingTime|setWind|setWindDir|setWindForce|setWindStr|setWingForceScaleRTD|setWPPos|show3DIcons|showChat|showCinemaBorder|showCommandingMenu|showCompass|showCuratorCompass|showGPS|showHUD|showLegend|showMap|shownArtilleryComputer|shownChat|shownCompass|shownCuratorCompass|showNewEditorObject|shownGPS|shownHUD|shownMap|shownPad|shownRadio|shownScoretable|shownUAVFeed|shownWarrant|shownWatch|showPad|showRadio|showScoretable|showSubtitles|showUAVFeed|showWarrant|showWatch|showWaypoint|showWaypoints|side|sideAmbientLife|sideChat|sideEmpty|sideEnemy|sideFriendly|sideLogic|sideRadio|sideUnknown|simpleTasks|simulationEnabled|simulCloudDensity|simulCloudOcclusion|simulInClouds|simulWeatherSync|sin|size|sizeOf|skill|skillFinal|skipTime|sleep|sliderPosition|sliderRange|sliderSetPosition|sliderSetRange|sliderSetSpeed|sliderSpeed|slingLoadAssistantShown|soldierMagazines|someAmmo|sort|soundVolume|speaker|speed|speedMode|splitString|sqrt|squadParams|stance|startLoadingScreen|stop|stopEngineRTD|stopped|str|sunOrMoon|supportInfo|suppressFor|surfaceIsWater|surfaceNormal|surfaceType|swimInDepth|switchableUnits|switchAction|switchCamera|switchGesture|switchLight|switchMove|synchronizedObjects|synchronizedTriggers|synchronizedWaypoints|synchronizeObjectsAdd|synchronizeObjectsRemove|synchronizeTrigger|synchronizeWaypoint|systemChat|systemOfUnits|tan|targetKnowledge|targets|targetsAggregate|targetsQuery|taskAlwaysVisible|taskChildren|taskCompleted|taskCustomData|taskDescription|taskDestination|taskHint|taskMarkerOffset|taskNull|taskParent|taskResult|taskState|taskType|teamMember|teamMemberNull|teamName|teams|teamSwitch|teamSwitchEnabled|teamType|terminate|terrainIntersect|terrainIntersectASL|terrainIntersectAtASL|text|textLog|textLogFormat|tg|time|timeMultiplier|titleCut|titleFadeOut|titleObj|titleRsc|titleText|toArray|toFixed|toLower|toString|toUpper|triggerActivated|triggerActivation|triggerArea|triggerAttachedVehicle|triggerAttachObject|triggerAttachVehicle|triggerDynamicSimulation|triggerStatements|triggerText|triggerTimeout|triggerTimeoutCurrent|triggerType|turretLocal|turretOwner|turretUnit|tvAdd|tvClear|tvCollapse|tvCollapseAll|tvCount|tvCurSel|tvData|tvDelete|tvExpand|tvExpandAll|tvPicture|tvPictureRight|tvSetColor|tvSetCurSel|tvSetData|tvSetPicture|tvSetPictureColor|tvSetPictureColorDisabled|tvSetPictureColorSelected|tvSetPictureRight|tvSetPictureRightColor|tvSetPictureRightColorDisabled|tvSetPictureRightColorSelected|tvSetSelectColor|tvSetText|tvSetTooltip|tvSetValue|tvSort|tvSortByValue|tvText|tvTooltip|tvValue|type|typeName|typeOf|UAVControl|uiNamespace|uiSleep|unassignCurator|unassignItem|unassignTeam|unassignVehicle|underwater|uniform|uniformContainer|uniformItems|uniformMagazines|unitAddons|unitAimPosition|unitAimPositionVisual|unitBackpack|unitIsUAV|unitPos|unitReady|unitRecoilCoefficient|units|unitsBelowHeight|unlinkItem|unlockAchievement|unregisterTask|updateDrawIcon|updateMenuItem|updateObjectTree|useAIOperMapObstructionTest|useAISteeringComponent|useAudioTimeForMoves|userInputDisabled|vectorAdd|vectorCos|vectorCrossProduct|vectorDiff|vectorDir|vectorDirVisual|vectorDistance|vectorDistanceSqr|vectorDotProduct|vectorFromTo|vectorMagnitude|vectorMagnitudeSqr|vectorModelToWorld|vectorModelToWorldVisual|vectorMultiply|vectorNormalized|vectorUp|vectorUpVisual|vectorWorldToModel|vectorWorldToModelVisual|vehicle|vehicleCargoEnabled|vehicleChat|vehicleRadio|vehicleReceiveRemoteTargets|vehicleReportOwnPosition|vehicleReportRemoteTargets|vehicles|vehicleVarName|velocity|velocityModelSpace|verifySignature|vest|vestContainer|vestItems|vestMagazines|viewDistance|visibleCompass|visibleGPS|visibleMap|visiblePosition|visiblePositionASL|visibleScoretable|visibleWatch|waitUntil|waves|waypointAttachedObject|waypointAttachedVehicle|waypointAttachObject|waypointAttachVehicle|waypointBehaviour|waypointCombatMode|waypointCompletionRadius|waypointDescription|waypointForceBehaviour|waypointFormation|waypointHousePosition|waypointLoiterRadius|waypointLoiterType|waypointName|waypointPosition|waypoints|waypointScript|waypointsEnabledUAV|waypointShow|waypointSpeed|waypointStatements|waypointTimeout|waypointTimeoutCurrent|waypointType|waypointVisible|weaponAccessories|weaponAccessoriesCargo|weaponCargo|weaponDirection|weaponInertia|weaponLowered|weapons|weaponsItems|weaponsItemsCargo|weaponState|weaponsTurret|weightRTD|west|WFSideText|wind|windDir|windRTD|windStr|wingsForcesRTD|worldName|worldSize|worldToModel|worldToModelVisual|worldToScreen)\b/i,number:/(?:\$|\b0x)[\da-f]+\b|(?:\B\.\d+|\b\d+(?:\.\d+)?)(?:e[+-]?\d+)?\b/i,operator:/##|>>|&&|\|\||[!=<>]=?|[-+*/%#^]|\b(?:and|mod|not|or)\b/i,"magic-variable":{pattern:/\b(?:this|thisList|thisTrigger|_exception|_fnc_scriptName|_fnc_scriptNameParent|_forEachIndex|_this|_thisEventHandler|_thisFSM|_thisScript|_x)\b/i,alias:"keyword"},constant:/\bDIK(?:_[a-z\d]+)+\b/i}),t.languages.insertBefore("sqf","string",{macro:{pattern:/(^[ \t]*)#[a-z](?:[^\r\n\\]|\\(?:\r\n|[\s\S]))*/im,lookbehind:!0,greedy:!0,alias:"property",inside:{directive:{pattern:/#[a-z]+\b/i,alias:"keyword"},comment:t.languages.sqf.comment}}}),delete t.languages.sqf["class-name"]}return Rw}var Cw,JP;function XSe(){if(JP)return Cw;JP=1,Cw=e,e.displayName="squirrel",e.aliases=[];function e(t){t.languages.squirrel=t.languages.extend("clike",{comment:[t.languages.clike.comment[0],{pattern:/(^|[^\\:])(?:\/\/|#).*/,lookbehind:!0,greedy:!0}],string:{pattern:/(^|[^\\"'@])(?:@"(?:[^"]|"")*"(?!")|"(?:[^\\\r\n"]|\\.)*")/,lookbehind:!0,greedy:!0},"class-name":{pattern:/(\b(?:class|enum|extends|instanceof)\s+)\w+(?:\.\w+)*/,lookbehind:!0,inside:{punctuation:/\./}},keyword:/\b(?:__FILE__|__LINE__|base|break|case|catch|class|clone|const|constructor|continue|default|delete|else|enum|extends|for|foreach|function|if|in|instanceof|local|null|resume|return|static|switch|this|throw|try|typeof|while|yield)\b/,number:/\b(?:0x[0-9a-fA-F]+|\d+(?:\.(?:\d+|[eE][+-]?\d+))?)\b/,operator:/\+\+|--|<=>|<[-<]|>>>?|&&?|\|\|?|[-+*/%!=<>]=?|[~^]|::?/,punctuation:/[(){}\[\],;.]/}),t.languages.insertBefore("squirrel","string",{char:{pattern:/(^|[^\\"'])'(?:[^\\']|\\(?:[xuU][0-9a-fA-F]{0,8}|[\s\S]))'/,lookbehind:!0,greedy:!0}}),t.languages.insertBefore("squirrel","operator",{"attribute-punctuation":{pattern:/<\/|\/>/,alias:"important"},lambda:{pattern:/@(?=\()/,alias:"operator"}})}return Cw}var _w,eF;function ZSe(){if(eF)return _w;eF=1,_w=e,e.displayName="stan",e.aliases=[];function e(t){(function(n){var r=/\b(?:algebra_solver|algebra_solver_newton|integrate_1d|integrate_ode|integrate_ode_bdf|integrate_ode_rk45|map_rect|ode_(?:adams|bdf|ckrk|rk45)(?:_tol)?|ode_adjoint_tol_ctl|reduce_sum|reduce_sum_static)\b/;n.languages.stan={comment:/\/\/.*|\/\*[\s\S]*?\*\/|#(?!include).*/,string:{pattern:/"[\x20\x21\x23-\x5B\x5D-\x7E]*"/,greedy:!0},directive:{pattern:/^([ \t]*)#include\b.*/m,lookbehind:!0,alias:"property"},"function-arg":{pattern:RegExp("("+r.source+/\s*\(\s*/.source+")"+/[a-zA-Z]\w*/.source),lookbehind:!0,alias:"function"},constraint:{pattern:/(\b(?:int|matrix|real|row_vector|vector)\s*)<[^<>]*>/,lookbehind:!0,inside:{expression:{pattern:/(=\s*)\S(?:\S|\s+(?!\s))*?(?=\s*(?:>$|,\s*\w+\s*=))/,lookbehind:!0,inside:null},property:/\b[a-z]\w*(?=\s*=)/i,operator:/=/,punctuation:/^<|>$|,/}},keyword:[{pattern:/\bdata(?=\s*\{)|\b(?:functions|generated|model|parameters|quantities|transformed)\b/,alias:"program-block"},/\b(?:array|break|cholesky_factor_corr|cholesky_factor_cov|complex|continue|corr_matrix|cov_matrix|data|else|for|if|in|increment_log_prob|int|matrix|ordered|positive_ordered|print|real|reject|return|row_vector|simplex|target|unit_vector|vector|void|while)\b/,r],function:/\b[a-z]\w*(?=\s*\()/i,number:/(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:E[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,boolean:/\b(?:false|true)\b/,operator:/<-|\.[*/]=?|\|\|?|&&|[!=<>+\-*/]=?|['^%~?:]/,punctuation:/[()\[\]{},;]/},n.languages.stan.constraint.inside.expression.inside=n.languages.stan})(t)}return _w}var Nw,tF;function QSe(){if(tF)return Nw;tF=1,Nw=e,e.displayName="stylus",e.aliases=[];function e(t){(function(n){var r={pattern:/(\b\d+)(?:%|[a-z]+)/,lookbehind:!0},a={pattern:/(^|[^\w.-])-?(?:\d+(?:\.\d+)?|\.\d+)/,lookbehind:!0},o={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0},url:{pattern:/\burl\((["']?).*?\1\)/i,greedy:!0},string:{pattern:/("|')(?:(?!\1)[^\\\r\n]|\\(?:\r\n|[\s\S]))*\1/,greedy:!0},interpolation:null,func:null,important:/\B!(?:important|optional)\b/i,keyword:{pattern:/(^|\s+)(?:(?:else|for|if|return|unless)(?=\s|$)|@[\w-]+)/,lookbehind:!0},hexcode:/#[\da-f]{3,6}/i,color:[/\b(?:AliceBlue|AntiqueWhite|Aqua|Aquamarine|Azure|Beige|Bisque|Black|BlanchedAlmond|Blue|BlueViolet|Brown|BurlyWood|CadetBlue|Chartreuse|Chocolate|Coral|CornflowerBlue|Cornsilk|Crimson|Cyan|DarkBlue|DarkCyan|DarkGoldenRod|DarkGr[ae]y|DarkGreen|DarkKhaki|DarkMagenta|DarkOliveGreen|DarkOrange|DarkOrchid|DarkRed|DarkSalmon|DarkSeaGreen|DarkSlateBlue|DarkSlateGr[ae]y|DarkTurquoise|DarkViolet|DeepPink|DeepSkyBlue|DimGr[ae]y|DodgerBlue|FireBrick|FloralWhite|ForestGreen|Fuchsia|Gainsboro|GhostWhite|Gold|GoldenRod|Gr[ae]y|Green|GreenYellow|HoneyDew|HotPink|IndianRed|Indigo|Ivory|Khaki|Lavender|LavenderBlush|LawnGreen|LemonChiffon|LightBlue|LightCoral|LightCyan|LightGoldenRodYellow|LightGr[ae]y|LightGreen|LightPink|LightSalmon|LightSeaGreen|LightSkyBlue|LightSlateGr[ae]y|LightSteelBlue|LightYellow|Lime|LimeGreen|Linen|Magenta|Maroon|MediumAquaMarine|MediumBlue|MediumOrchid|MediumPurple|MediumSeaGreen|MediumSlateBlue|MediumSpringGreen|MediumTurquoise|MediumVioletRed|MidnightBlue|MintCream|MistyRose|Moccasin|NavajoWhite|Navy|OldLace|Olive|OliveDrab|Orange|OrangeRed|Orchid|PaleGoldenRod|PaleGreen|PaleTurquoise|PaleVioletRed|PapayaWhip|PeachPuff|Peru|Pink|Plum|PowderBlue|Purple|Red|RosyBrown|RoyalBlue|SaddleBrown|Salmon|SandyBrown|SeaGreen|SeaShell|Sienna|Silver|SkyBlue|SlateBlue|SlateGr[ae]y|Snow|SpringGreen|SteelBlue|Tan|Teal|Thistle|Tomato|Transparent|Turquoise|Violet|Wheat|White|WhiteSmoke|Yellow|YellowGreen)\b/i,{pattern:/\b(?:hsl|rgb)\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*\)\B|\b(?:hsl|rgb)a\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*,\s*(?:0|0?\.\d+|1)\s*\)\B/i,inside:{unit:r,number:a,function:/[\w-]+(?=\()/,punctuation:/[(),]/}}],entity:/\\[\da-f]{1,8}/i,unit:r,boolean:/\b(?:false|true)\b/,operator:[/~|[+!\/%<>?=]=?|[-:]=|\*[*=]?|\.{2,3}|&&|\|\||\B-\B|\b(?:and|in|is(?: a| defined| not|nt)?|not|or)\b/],number:a,punctuation:/[{}()\[\];:,]/};o.interpolation={pattern:/\{[^\r\n}:]+\}/,alias:"variable",inside:{delimiter:{pattern:/^\{|\}$/,alias:"punctuation"},rest:o}},o.func={pattern:/[\w-]+\([^)]*\).*/,inside:{function:/^[^(]+/,rest:o}},n.languages.stylus={"atrule-declaration":{pattern:/(^[ \t]*)@.+/m,lookbehind:!0,inside:{atrule:/^@[\w-]+/,rest:o}},"variable-declaration":{pattern:/(^[ \t]*)[\w$-]+\s*.?=[ \t]*(?:\{[^{}]*\}|\S.*|$)/m,lookbehind:!0,inside:{variable:/^\S+/,rest:o}},statement:{pattern:/(^[ \t]*)(?:else|for|if|return|unless)[ \t].+/m,lookbehind:!0,inside:{keyword:/^\S+/,rest:o}},"property-declaration":{pattern:/((?:^|\{)([ \t]*))(?:[\w-]|\{[^}\r\n]+\})+(?:\s*:\s*|[ \t]+)(?!\s)[^{\r\n]*(?:;|[^{\r\n,]$(?!(?:\r?\n|\r)(?:\{|\2[ \t])))/m,lookbehind:!0,inside:{property:{pattern:/^[^\s:]+/,inside:{interpolation:o.interpolation}},rest:o}},selector:{pattern:/(^[ \t]*)(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)(?:(?:\r?\n|\r)(?:\1(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)))*(?:,$|\{|(?=(?:\r?\n|\r)(?:\{|\1[ \t])))/m,lookbehind:!0,inside:{interpolation:o.interpolation,comment:o.comment,punctuation:/[{},]/}},func:o.func,string:o.string,comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0,greedy:!0},interpolation:o.interpolation,punctuation:/[{}()\[\];:.]/}})(t)}return Nw}var Ow,nF;function JSe(){if(nF)return Ow;nF=1,Ow=e,e.displayName="swift",e.aliases=[];function e(t){t.languages.swift={comment:{pattern:/(^|[^\\:])(?:\/\/.*|\/\*(?:[^/*]|\/(?!\*)|\*(?!\/)|\/\*(?:[^*]|\*(?!\/))*\*\/)*\*\/)/,lookbehind:!0,greedy:!0},"string-literal":[{pattern:RegExp(/(^|[^"#])/.source+"(?:"+/"(?:\\(?:\((?:[^()]|\([^()]*\))*\)|\r\n|[^(])|[^\\\r\n"])*"/.source+"|"+/"""(?:\\(?:\((?:[^()]|\([^()]*\))*\)|[^(])|[^\\"]|"(?!""))*"""/.source+")"+/(?!["#])/.source),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\\($/,alias:"punctuation"},punctuation:/\\(?=[\r\n])/,string:/[\s\S]+/}},{pattern:RegExp(/(^|[^"#])(#+)/.source+"(?:"+/"(?:\\(?:#+\((?:[^()]|\([^()]*\))*\)|\r\n|[^#])|[^\\\r\n])*?"/.source+"|"+/"""(?:\\(?:#+\((?:[^()]|\([^()]*\))*\)|[^#])|[^\\])*?"""/.source+")\\2"),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\#+\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\#+\($/,alias:"punctuation"},string:/[\s\S]+/}}],directive:{pattern:RegExp(/#/.source+"(?:"+(/(?:elseif|if)\b/.source+"(?:[ 	]*"+/(?:![ \t]*)?(?:\b\w+\b(?:[ \t]*\((?:[^()]|\([^()]*\))*\))?|\((?:[^()]|\([^()]*\))*\))(?:[ \t]*(?:&&|\|\|))?/.source+")+")+"|"+/(?:else|endif)\b/.source+")"),alias:"property",inside:{"directive-name":/^#\w+/,boolean:/\b(?:false|true)\b/,number:/\b\d+(?:\.\d+)*\b/,operator:/!|&&|\|\||[<>]=?/,punctuation:/[(),]/}},literal:{pattern:/#(?:colorLiteral|column|dsohandle|file(?:ID|Literal|Path)?|function|imageLiteral|line)\b/,alias:"constant"},"other-directive":{pattern:/#\w+\b/,alias:"property"},attribute:{pattern:/@\w+/,alias:"atrule"},"function-definition":{pattern:/(\bfunc\s+)\w+/,lookbehind:!0,alias:"function"},label:{pattern:/\b(break|continue)\s+\w+|\b[a-zA-Z_]\w*(?=\s*:\s*(?:for|repeat|while)\b)/,lookbehind:!0,alias:"important"},keyword:/\b(?:Any|Protocol|Self|Type|actor|as|assignment|associatedtype|associativity|async|await|break|case|catch|class|continue|convenience|default|defer|deinit|didSet|do|dynamic|else|enum|extension|fallthrough|fileprivate|final|for|func|get|guard|higherThan|if|import|in|indirect|infix|init|inout|internal|is|isolated|lazy|left|let|lowerThan|mutating|none|nonisolated|nonmutating|open|operator|optional|override|postfix|precedencegroup|prefix|private|protocol|public|repeat|required|rethrows|return|right|safe|self|set|some|static|struct|subscript|super|switch|throw|throws|try|typealias|unowned|unsafe|var|weak|where|while|willSet)\b/,boolean:/\b(?:false|true)\b/,nil:{pattern:/\bnil\b/,alias:"constant"},"short-argument":/\$\d+\b/,omit:{pattern:/\b_\b/,alias:"keyword"},number:/\b(?:[\d_]+(?:\.[\de_]+)?|0x[a-f0-9_]+(?:\.[a-f0-9p_]+)?|0b[01_]+|0o[0-7_]+)\b/i,"class-name":/\b[A-Z](?:[A-Z_\d]*[a-z]\w*)?\b/,function:/\b[a-z_]\w*(?=\s*\()/i,constant:/\b(?:[A-Z_]{2,}|k[A-Z][A-Za-z_]+)\b/,operator:/[-+*/%=!<>&|^~?]+|\.[.\-+*/%=!<>&|^~?]+/,punctuation:/[{}[\]();,.:\\]/},t.languages.swift["string-literal"].forEach(function(n){n.inside.interpolation.inside=t.languages.swift})}return Ow}var Iw,rF;function eEe(){if(rF)return Iw;rF=1,Iw=e,e.displayName="systemd",e.aliases=[];function e(t){(function(n){var r={pattern:/^[;#].*/m,greedy:!0},a=/"(?:[^\r\n"\\]|\\(?:[^\r]|\r\n?))*"(?!\S)/.source;n.languages.systemd={comment:r,section:{pattern:/^\[[^\n\r\[\]]*\](?=[ \t]*$)/m,greedy:!0,inside:{punctuation:/^\[|\]$/,"section-name":{pattern:/[\s\S]+/,alias:"selector"}}},key:{pattern:/^[^\s=]+(?=[ \t]*=)/m,greedy:!0,alias:"attr-name"},value:{pattern:RegExp(/(=[ \t]*(?!\s))/.source+"(?:"+a+`|(?=[^"\r
]))(?:`+(/[^\s\\]/.source+'|[ 	]+(?:(?![ 	"])|'+a+")|"+/\\[\r\n]+(?:[#;].*[\r\n]+)*(?![#;])/.source)+")*"),lookbehind:!0,greedy:!0,alias:"attr-value",inside:{comment:r,quoted:{pattern:RegExp(/(^|\s)/.source+a),lookbehind:!0,greedy:!0},punctuation:/\\$/m,boolean:{pattern:/^(?:false|no|off|on|true|yes)$/,greedy:!0}}},punctuation:/=/}})(t)}return Iw}var Dw,aF;function TA(){if(aF)return Dw;aF=1,Dw=e,e.displayName="t4Templating",e.aliases=[];function e(t){(function(n){function r(o,s,l){return{pattern:RegExp("<#"+o+"[\\s\\S]*?#>"),alias:"block",inside:{delimiter:{pattern:RegExp("^<#"+o+"|#>$"),alias:"important"},content:{pattern:/[\s\S]+/,inside:s,alias:l}}}}function a(o){var s=n.languages[o],l="language-"+o;return{block:{pattern:/<#[\s\S]+?#>/,inside:{directive:r("@",{"attr-value":{pattern:/=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+)/,inside:{punctuation:/^=|^["']|["']$/}},keyword:/\b\w+(?=\s)/,"attr-name":/\b\w+/}),expression:r("=",s,l),"class-feature":r("\\+",s,l),standard:r("",s,l)}}}}n.languages["t4-templating"]=Object.defineProperty({},"createT4",{value:a})})(t)}return Dw}var Lw,oF;function tEe(){if(oF)return Lw;oF=1;var e=TA(),t=zp();Lw=n,n.displayName="t4Cs",n.aliases=[];function n(r){r.register(e),r.register(t),r.languages.t4=r.languages["t4-cs"]=r.languages["t4-templating"].createT4("csharp")}return Lw}var Mw,iF;function qH(){if(iF)return Mw;iF=1;var e=UH();Mw=t,t.displayName="vbnet",t.aliases=[];function t(n){n.register(e),n.languages.vbnet=n.languages.extend("basic",{comment:[{pattern:/(?:!|REM\b).+/i,inside:{keyword:/^REM/i}},{pattern:/(^|[^\\:])'.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(^|[^"])"(?:""|[^"])*"(?!")/,lookbehind:!0,greedy:!0},keyword:/(?:\b(?:ADDHANDLER|ADDRESSOF|ALIAS|AND|ANDALSO|AS|BEEP|BLOAD|BOOLEAN|BSAVE|BYREF|BYTE|BYVAL|CALL(?: ABSOLUTE)?|CASE|CATCH|CBOOL|CBYTE|CCHAR|CDATE|CDBL|CDEC|CHAIN|CHAR|CHDIR|CINT|CLASS|CLEAR|CLNG|CLOSE|CLS|COBJ|COM|COMMON|CONST|CONTINUE|CSBYTE|CSHORT|CSNG|CSTR|CTYPE|CUINT|CULNG|CUSHORT|DATA|DATE|DECIMAL|DECLARE|DEF(?: FN| SEG|DBL|INT|LNG|SNG|STR)|DEFAULT|DELEGATE|DIM|DIRECTCAST|DO|DOUBLE|ELSE|ELSEIF|END|ENUM|ENVIRON|ERASE|ERROR|EVENT|EXIT|FALSE|FIELD|FILES|FINALLY|FOR(?: EACH)?|FRIEND|FUNCTION|GET|GETTYPE|GETXMLNAMESPACE|GLOBAL|GOSUB|GOTO|HANDLES|IF|IMPLEMENTS|IMPORTS|IN|INHERITS|INPUT|INTEGER|INTERFACE|IOCTL|IS|ISNOT|KEY|KILL|LET|LIB|LIKE|LINE INPUT|LOCATE|LOCK|LONG|LOOP|LSET|ME|MKDIR|MOD|MODULE|MUSTINHERIT|MUSTOVERRIDE|MYBASE|MYCLASS|NAME|NAMESPACE|NARROWING|NEW|NEXT|NOT|NOTHING|NOTINHERITABLE|NOTOVERRIDABLE|OBJECT|OF|OFF|ON(?: COM| ERROR| KEY| TIMER)?|OPEN|OPERATOR|OPTION(?: BASE)?|OPTIONAL|OR|ORELSE|OUT|OVERLOADS|OVERRIDABLE|OVERRIDES|PARAMARRAY|PARTIAL|POKE|PRIVATE|PROPERTY|PROTECTED|PUBLIC|PUT|RAISEEVENT|READ|READONLY|REDIM|REM|REMOVEHANDLER|RESTORE|RESUME|RETURN|RMDIR|RSET|RUN|SBYTE|SELECT(?: CASE)?|SET|SHADOWS|SHARED|SHELL|SHORT|SINGLE|SLEEP|STATIC|STEP|STOP|STRING|STRUCTURE|SUB|SWAP|SYNCLOCK|SYSTEM|THEN|THROW|TIMER|TO|TROFF|TRON|TRUE|TRY|TRYCAST|TYPE|TYPEOF|UINTEGER|ULONG|UNLOCK|UNTIL|USHORT|USING|VIEW PRINT|WAIT|WEND|WHEN|WHILE|WIDENING|WITH|WITHEVENTS|WRITE|WRITEONLY|XOR)|\B(?:#CONST|#ELSE|#ELSEIF|#END|#IF))(?:\$|\b)/i,punctuation:/[,;:(){}]/})}return Mw}var Pw,sF;function nEe(){if(sF)return Pw;sF=1;var e=TA(),t=qH();Pw=n,n.displayName="t4Vb",n.aliases=[];function n(r){r.register(e),r.register(t),r.languages["t4-vb"]=r.languages["t4-templating"].createT4("vbnet")}return Pw}var Fw,lF;function VH(){if(lF)return Fw;lF=1,Fw=e,e.displayName="yaml",e.aliases=["yml"];function e(t){(function(n){var r=/[*&][^\s[\]{},]+/,a=/!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/,o="(?:"+a.source+"(?:[ 	]+"+r.source+")?|"+r.source+"(?:[ 	]+"+a.source+")?)",s=/(?:[^\s\x00-\x08\x0e-\x1f!"#%&'*,\-:>?@[\]`{|}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]|[?:-]<PLAIN>)(?:[ \t]*(?:(?![#:])<PLAIN>|:<PLAIN>))*/.source.replace(/<PLAIN>/g,function(){return/[^\s\x00-\x08\x0e-\x1f,[\]{}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]/.source}),l=/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/.source;function u(d,p){p=(p||"").replace(/m/g,"")+"m";var g=/([:\-,[{]\s*(?:\s<<prop>>[ \t]+)?)(?:<<value>>)(?=[ \t]*(?:$|,|\]|\}|(?:[\r\n]\s*)?#))/.source.replace(/<<prop>>/g,function(){return o}).replace(/<<value>>/g,function(){return d});return RegExp(g,p)}n.languages.yaml={scalar:{pattern:RegExp(/([\-:]\s*(?:\s<<prop>>[ \t]+)?[|>])[ \t]*(?:((?:\r?\n|\r)[ \t]+)\S[^\r\n]*(?:\2[^\r\n]+)*)/.source.replace(/<<prop>>/g,function(){return o})),lookbehind:!0,alias:"string"},comment:/#.*/,key:{pattern:RegExp(/((?:^|[:\-,[{\r\n?])[ \t]*(?:<<prop>>[ \t]+)?)<<key>>(?=\s*:\s)/.source.replace(/<<prop>>/g,function(){return o}).replace(/<<key>>/g,function(){return"(?:"+s+"|"+l+")"})),lookbehind:!0,greedy:!0,alias:"atrule"},directive:{pattern:/(^[ \t]*)%.+/m,lookbehind:!0,alias:"important"},datetime:{pattern:u(/\d{4}-\d\d?-\d\d?(?:[tT]|[ \t]+)\d\d?:\d{2}:\d{2}(?:\.\d*)?(?:[ \t]*(?:Z|[-+]\d\d?(?::\d{2})?))?|\d{4}-\d{2}-\d{2}|\d\d?:\d{2}(?::\d{2}(?:\.\d*)?)?/.source),lookbehind:!0,alias:"number"},boolean:{pattern:u(/false|true/.source,"i"),lookbehind:!0,alias:"important"},null:{pattern:u(/null|~/.source,"i"),lookbehind:!0,alias:"important"},string:{pattern:u(l),lookbehind:!0,greedy:!0},number:{pattern:u(/[+-]?(?:0x[\da-f]+|0o[0-7]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|\.inf|\.nan)/.source,"i"),lookbehind:!0},tag:a,important:r,punctuation:/---|[:[\]{}\-,|>?]|\.\.\./},n.languages.yml=n.languages.yaml})(t)}return Fw}var zw,cF;function rEe(){if(cF)return zw;cF=1;var e=VH();zw=t,t.displayName="tap",t.aliases=[];function t(n){n.register(e),n.languages.tap={fail:/not ok[^#{\n\r]*/,pass:/ok[^#{\n\r]*/,pragma:/pragma [+-][a-z]+/,bailout:/bail out!.*/i,version:/TAP version \d+/i,plan:/\b\d+\.\.\d+(?: +#.*)?/,subtest:{pattern:/# Subtest(?:: .*)?/,greedy:!0},punctuation:/[{}]/,directive:/#.*/,yamlish:{pattern:/(^[ \t]*)---[\s\S]*?[\r\n][ \t]*\.\.\.$/m,lookbehind:!0,inside:n.languages.yaml,alias:"language-yaml"}}}return zw}var Bw,uF;function aEe(){if(uF)return Bw;uF=1,Bw=e,e.displayName="tcl",e.aliases=[];function e(t){t.languages.tcl={comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0},string:{pattern:/"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*"/,greedy:!0},variable:[{pattern:/(\$)(?:::)?(?:[a-zA-Z0-9]+::)*\w+/,lookbehind:!0},{pattern:/(\$)\{[^}]+\}/,lookbehind:!0},{pattern:/(^[\t ]*set[ \t]+)(?:::)?(?:[a-zA-Z0-9]+::)*\w+/m,lookbehind:!0}],function:{pattern:/(^[\t ]*proc[ \t]+)\S+/m,lookbehind:!0},builtin:[{pattern:/(^[\t ]*)(?:break|class|continue|error|eval|exit|for|foreach|if|proc|return|switch|while)\b/m,lookbehind:!0},/\b(?:else|elseif)\b/],scope:{pattern:/(^[\t ]*)(?:global|upvar|variable)\b/m,lookbehind:!0,alias:"constant"},keyword:{pattern:/(^[\t ]*|\[)(?:Safe_Base|Tcl|after|append|apply|array|auto_(?:execok|import|load|mkindex|qualify|reset)|automkindex_old|bgerror|binary|catch|cd|chan|clock|close|concat|dde|dict|encoding|eof|exec|expr|fblocked|fconfigure|fcopy|file(?:event|name)?|flush|gets|glob|history|http|incr|info|interp|join|lappend|lassign|lindex|linsert|list|llength|load|lrange|lrepeat|lreplace|lreverse|lsearch|lset|lsort|math(?:func|op)|memory|msgcat|namespace|open|package|parray|pid|pkg_mkIndex|platform|puts|pwd|re_syntax|read|refchan|regexp|registry|regsub|rename|scan|seek|set|socket|source|split|string|subst|tcl(?:_endOfWord|_findLibrary|startOf(?:Next|Previous)Word|test|vars|wordBreak(?:After|Before))|tell|time|tm|trace|unknown|unload|unset|update|uplevel|vwait)\b/m,lookbehind:!0},operator:/!=?|\*\*?|==|&&?|\|\|?|<[=<]?|>[=>]?|[-+~\/%?^]|\b(?:eq|in|ne|ni)\b/,punctuation:/[{}()\[\]]/}}return Bw}var jw,dF;function oEe(){if(dF)return jw;dF=1,jw=e,e.displayName="textile",e.aliases=[];function e(t){(function(n){var r=/\([^|()\n]+\)|\[[^\]\n]+\]|\{[^}\n]+\}/.source,a=/\)|\((?![^|()\n]+\))/.source;function o(m,b){return RegExp(m.replace(/<MOD>/g,function(){return"(?:"+r+")"}).replace(/<PAR>/g,function(){return"(?:"+a+")"}),b||"")}var s={css:{pattern:/\{[^{}]+\}/,inside:{rest:n.languages.css}},"class-id":{pattern:/(\()[^()]+(?=\))/,lookbehind:!0,alias:"attr-value"},lang:{pattern:/(\[)[^\[\]]+(?=\])/,lookbehind:!0,alias:"attr-value"},punctuation:/[\\\/]\d+|\S/},l=n.languages.textile=n.languages.extend("markup",{phrase:{pattern:/(^|\r|\n)\S[\s\S]*?(?=$|\r?\n\r?\n|\r\r)/,lookbehind:!0,inside:{"block-tag":{pattern:o(/^[a-z]\w*(?:<MOD>|<PAR>|[<>=])*\./.source),inside:{modifier:{pattern:o(/(^[a-z]\w*)(?:<MOD>|<PAR>|[<>=])+(?=\.)/.source),lookbehind:!0,inside:s},tag:/^[a-z]\w*/,punctuation:/\.$/}},list:{pattern:o(/^[*#]+<MOD>*\s+\S.*/.source,"m"),inside:{modifier:{pattern:o(/(^[*#]+)<MOD>+/.source),lookbehind:!0,inside:s},punctuation:/^[*#]+/}},table:{pattern:o(/^(?:(?:<MOD>|<PAR>|[<>=^~])+\.\s*)?(?:\|(?:(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+\.|(?!(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+\.))[^|]*)+\|/.source,"m"),inside:{modifier:{pattern:o(/(^|\|(?:\r?\n|\r)?)(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+(?=\.)/.source),lookbehind:!0,inside:s},punctuation:/\||^\./}},inline:{pattern:o(/(^|[^a-zA-Z\d])(\*\*|__|\?\?|[*_%@+\-^~])<MOD>*.+?\2(?![a-zA-Z\d])/.source),lookbehind:!0,inside:{bold:{pattern:o(/(^(\*\*?)<MOD>*).+?(?=\2)/.source),lookbehind:!0},italic:{pattern:o(/(^(__?)<MOD>*).+?(?=\2)/.source),lookbehind:!0},cite:{pattern:o(/(^\?\?<MOD>*).+?(?=\?\?)/.source),lookbehind:!0,alias:"string"},code:{pattern:o(/(^@<MOD>*).+?(?=@)/.source),lookbehind:!0,alias:"keyword"},inserted:{pattern:o(/(^\+<MOD>*).+?(?=\+)/.source),lookbehind:!0},deleted:{pattern:o(/(^-<MOD>*).+?(?=-)/.source),lookbehind:!0},span:{pattern:o(/(^%<MOD>*).+?(?=%)/.source),lookbehind:!0},modifier:{pattern:o(/(^\*\*|__|\?\?|[*_%@+\-^~])<MOD>+/.source),lookbehind:!0,inside:s},punctuation:/[*_%?@+\-^~]+/}},"link-ref":{pattern:/^\[[^\]]+\]\S+$/m,inside:{string:{pattern:/(^\[)[^\]]+(?=\])/,lookbehind:!0},url:{pattern:/(^\])\S+$/,lookbehind:!0},punctuation:/[\[\]]/}},link:{pattern:o(/"<MOD>*[^"]+":.+?(?=[^\w/]?(?:\s|$))/.source),inside:{text:{pattern:o(/(^"<MOD>*)[^"]+(?=")/.source),lookbehind:!0},modifier:{pattern:o(/(^")<MOD>+/.source),lookbehind:!0,inside:s},url:{pattern:/(:).+/,lookbehind:!0},punctuation:/[":]/}},image:{pattern:o(/!(?:<MOD>|<PAR>|[<>=])*(?![<>=])[^!\s()]+(?:\([^)]+\))?!(?::.+?(?=[^\w/]?(?:\s|$)))?/.source),inside:{source:{pattern:o(/(^!(?:<MOD>|<PAR>|[<>=])*)(?![<>=])[^!\s()]+(?:\([^)]+\))?(?=!)/.source),lookbehind:!0,alias:"url"},modifier:{pattern:o(/(^!)(?:<MOD>|<PAR>|[<>=])+/.source),lookbehind:!0,inside:s},url:{pattern:/(:).+/,lookbehind:!0},punctuation:/[!:]/}},footnote:{pattern:/\b\[\d+\]/,alias:"comment",inside:{punctuation:/\[|\]/}},acronym:{pattern:/\b[A-Z\d]+\([^)]+\)/,inside:{comment:{pattern:/(\()[^()]+(?=\))/,lookbehind:!0},punctuation:/[()]/}},mark:{pattern:/\b\((?:C|R|TM)\)/,alias:"comment",inside:{punctuation:/[()]/}}}}}),u=l.phrase.inside,d={inline:u.inline,link:u.link,image:u.image,footnote:u.footnote,acronym:u.acronym,mark:u.mark};l.tag.pattern=/<\/?(?!\d)[a-z0-9]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/i;var p=u.inline.inside;p.bold.inside=d,p.italic.inside=d,p.inserted.inside=d,p.deleted.inside=d,p.span.inside=d;var g=u.table.inside;g.inline=d.inline,g.link=d.link,g.image=d.image,g.footnote=d.footnote,g.acronym=d.acronym,g.mark=d.mark})(t)}return jw}var Uw,fF;function iEe(){if(fF)return Uw;fF=1,Uw=e,e.displayName="toml",e.aliases=[];function e(t){(function(n){var r=/(?:[\w-]+|'[^'\n\r]*'|"(?:\\.|[^\\"\r\n])*")/.source;function a(o){return o.replace(/__/g,function(){return r})}n.languages.toml={comment:{pattern:/#.*/,greedy:!0},table:{pattern:RegExp(a(/(^[\t ]*\[\s*(?:\[\s*)?)__(?:\s*\.\s*__)*(?=\s*\])/.source),"m"),lookbehind:!0,greedy:!0,alias:"class-name"},key:{pattern:RegExp(a(/(^[\t ]*|[{,]\s*)__(?:\s*\.\s*__)*(?=\s*=)/.source),"m"),lookbehind:!0,greedy:!0,alias:"property"},string:{pattern:/"""(?:\\[\s\S]|[^\\])*?"""|'''[\s\S]*?'''|'[^'\n\r]*'|"(?:\\.|[^\\"\r\n])*"/,greedy:!0},date:[{pattern:/\b\d{4}-\d{2}-\d{2}(?:[T\s]\d{2}:\d{2}:\d{2}(?:\.\d+)?(?:Z|[+-]\d{2}:\d{2})?)?\b/i,alias:"number"},{pattern:/\b\d{2}:\d{2}:\d{2}(?:\.\d+)?\b/,alias:"number"}],number:/(?:\b0(?:x[\da-zA-Z]+(?:_[\da-zA-Z]+)*|o[0-7]+(?:_[0-7]+)*|b[10]+(?:_[10]+)*))\b|[-+]?\b\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?\b|[-+]?\b(?:inf|nan)\b/,boolean:/\b(?:false|true)\b/,punctuation:/[.,=[\]{}]/}})(t)}return Uw}var Gw,pF;function sEe(){if(pF)return Gw;pF=1,Gw=e,e.displayName="tremor",e.aliases=[];function e(t){(function(n){n.languages.tremor={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,lookbehind:!0},"interpolated-string":null,extractor:{pattern:/\b[a-z_]\w*\|(?:[^\r\n\\|]|\\(?:\r\n|[\s\S]))*\|/i,greedy:!0,inside:{regex:{pattern:/(^re)\|[\s\S]+/,lookbehind:!0},function:/^\w+/,value:/\|[\s\S]+/}},identifier:{pattern:/`[^`]*`/,greedy:!0},function:/\b[a-z_]\w*(?=\s*(?:::\s*<|\())\b/,keyword:/\b(?:args|as|by|case|config|connect|connector|const|copy|create|default|define|deploy|drop|each|emit|end|erase|event|flow|fn|for|from|group|having|insert|into|intrinsic|let|links|match|merge|mod|move|of|operator|patch|pipeline|recur|script|select|set|sliding|state|stream|to|tumbling|update|use|when|where|window|with)\b/,boolean:/\b(?:false|null|true)\b/i,number:/\b(?:0b[01_]*|0x[0-9a-fA-F_]*|\d[\d_]*(?:\.\d[\d_]*)?(?:[Ee][+-]?[\d_]+)?)\b/,"pattern-punctuation":{pattern:/%(?=[({[])/,alias:"punctuation"},operator:/[-+*\/%~!^]=?|=[=>]?|&[&=]?|\|[|=]?|<<?=?|>>?>?=?|(?:absent|and|not|or|present|xor)\b/,punctuation:/::|[;\[\]()\{\},.:]/};var r=/#\{(?:[^"{}]|\{[^{}]*\}|"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*")*\}/.source;n.languages.tremor["interpolated-string"]={pattern:RegExp(/(^|[^\\])/.source+'(?:"""(?:'+/[^"\\#]|\\[\s\S]|"(?!"")|#(?!\{)/.source+"|"+r+')*"""|"(?:'+/[^"\\\r\n#]|\\(?:\r\n|[\s\S])|#(?!\{)/.source+"|"+r+')*")'),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:RegExp(r),inside:{punctuation:/^#\{|\}$/,expression:{pattern:/[\s\S]+/,inside:n.languages.tremor}}},string:/[\s\S]+/}},n.languages.troy=n.languages.tremor,n.languages.trickle=n.languages.tremor})(t)}return Gw}var Hw,gF;function lEe(){if(gF)return Hw;gF=1;var e=HH(),t=wA();Hw=n,n.displayName="tsx",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var o=a.util.clone(a.languages.typescript);a.languages.tsx=a.languages.extend("jsx",o),delete a.languages.tsx.parameter,delete a.languages.tsx["literal-property"];var s=a.languages.tsx.tag;s.pattern=RegExp(/(^|[^\w$]|(?=<\/))/.source+"(?:"+s.pattern.source+")",s.pattern.flags),s.lookbehind=!0}(r)}return Hw}var $w,hF;function cEe(){if(hF)return $w;hF=1;var e=Wn();$w=t,t.displayName="tt2",t.aliases=[];function t(n){n.register(e),function(r){r.languages.tt2=r.languages.extend("clike",{comment:/#.*|\[%#[\s\S]*?%\]/,keyword:/\b(?:BLOCK|CALL|CASE|CATCH|CLEAR|DEBUG|DEFAULT|ELSE|ELSIF|END|FILTER|FINAL|FOREACH|GET|IF|IN|INCLUDE|INSERT|LAST|MACRO|META|NEXT|PERL|PROCESS|RAWPERL|RETURN|SET|STOP|SWITCH|TAGS|THROW|TRY|UNLESS|USE|WHILE|WRAPPER)\b/,punctuation:/[[\]{},()]/}),r.languages.insertBefore("tt2","number",{operator:/=[>=]?|!=?|<=?|>=?|&&|\|\|?|\b(?:and|not|or)\b/,variable:{pattern:/\b[a-z]\w*(?:\s*\.\s*(?:\d+|\$?[a-z]\w*))*\b/i}}),r.languages.insertBefore("tt2","keyword",{delimiter:{pattern:/^(?:\[%|%%)-?|-?%\]$/,alias:"punctuation"}}),r.languages.insertBefore("tt2","string",{"single-quoted-string":{pattern:/'[^\\']*(?:\\[\s\S][^\\']*)*'/,greedy:!0,alias:"string"},"double-quoted-string":{pattern:/"[^\\"]*(?:\\[\s\S][^\\"]*)*"/,greedy:!0,alias:"string",inside:{variable:{pattern:/\$(?:[a-z]\w*(?:\.(?:\d+|\$?[a-z]\w*))*)/i}}}}),delete r.languages.tt2.string,r.hooks.add("before-tokenize",function(a){var o=/\[%[\s\S]+?%\]/g;r.languages["markup-templating"].buildPlaceholders(a,"tt2",o)}),r.hooks.add("after-tokenize",function(a){r.languages["markup-templating"].tokenizePlaceholders(a,"tt2")})}(n)}return $w}var qw,mF;function uEe(){if(mF)return qw;mF=1;var e=Wn();qw=t,t.displayName="twig",t.aliases=[];function t(n){n.register(e),n.languages.twig={comment:/^\{#[\s\S]*?#\}$/,"tag-name":{pattern:/(^\{%-?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%]-?|-?[%}]\}$/,alias:"punctuation"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,inside:{punctuation:/^['"]|['"]$/}},keyword:/\b(?:even|if|odd)\b/,boolean:/\b(?:false|null|true)\b/,number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,operator:[{pattern:/(\s)(?:and|b-and|b-or|b-xor|ends with|in|is|matches|not|or|same as|starts with)(?=\s)/,lookbehind:!0},/[=<>]=?|!=|\*\*?|\/\/?|\?:?|[-+~%|]/],punctuation:/[()\[\]{}:.,]/},n.hooks.add("before-tokenize",function(r){if(r.language==="twig"){var a=/\{(?:#[\s\S]*?#|%[\s\S]*?%|\{[\s\S]*?\})\}/g;n.languages["markup-templating"].buildPlaceholders(r,"twig",a)}}),n.hooks.add("after-tokenize",function(r){n.languages["markup-templating"].tokenizePlaceholders(r,"twig")})}return qw}var Vw,bF;function dEe(){if(bF)return Vw;bF=1,Vw=e,e.displayName="typoscript",e.aliases=["tsconfig"];function e(t){(function(n){var r=/\b(?:ACT|ACTIFSUB|CARRAY|CASE|CLEARGIF|COA|COA_INT|CONSTANTS|CONTENT|CUR|EDITPANEL|EFFECT|EXT|FILE|FLUIDTEMPLATE|FORM|FRAME|FRAMESET|GIFBUILDER|GMENU|GMENU_FOLDOUT|GMENU_LAYERS|GP|HMENU|HRULER|HTML|IENV|IFSUB|IMAGE|IMGMENU|IMGMENUITEM|IMGTEXT|IMG_RESOURCE|INCLUDE_TYPOSCRIPT|JSMENU|JSMENUITEM|LLL|LOAD_REGISTER|NO|PAGE|RECORDS|RESTORE_REGISTER|TEMPLATE|TEXT|TMENU|TMENUITEM|TMENU_LAYERS|USER|USER_INT|_GIFBUILDER|global|globalString|globalVar)\b/;n.languages.typoscript={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0},{pattern:/(^|[^\\:= \t]|(?:^|[^= \t])[ \t]+)\/\/.*/,lookbehind:!0,greedy:!0},{pattern:/(^|[^"'])#.*/,lookbehind:!0,greedy:!0}],function:[{pattern:/<INCLUDE_TYPOSCRIPT:\s*source\s*=\s*(?:"[^"\r\n]*"|'[^'\r\n]*')\s*>/,inside:{string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,inside:{keyword:r}},keyword:{pattern:/INCLUDE_TYPOSCRIPT/}}},{pattern:/@import\s*(?:"[^"\r\n]*"|'[^'\r\n]*')/,inside:{string:/"[^"\r\n]*"|'[^'\r\n]*'/}}],string:{pattern:/^([^=]*=[< ]?)(?:(?!\]\n).)*/,lookbehind:!0,inside:{function:/\{\$.*\}/,keyword:r,number:/^\d+$/,punctuation:/[,|:]/}},keyword:r,number:{pattern:/\b\d+\s*[.{=]/,inside:{operator:/[.{=]/}},tag:{pattern:/\.?[-\w\\]+\.?/,inside:{punctuation:/\./}},punctuation:/[{}[\];(),.:|]/,operator:/[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/},n.languages.tsconfig=n.languages.typoscript})(t)}return Vw}var Ww,yF;function fEe(){if(yF)return Ww;yF=1,Ww=e,e.displayName="unrealscript",e.aliases=["uc","uscript"];function e(t){t.languages.unrealscript={comment:/\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},category:{pattern:/(\b(?:(?:autoexpand|hide|show)categories|var)\s*\()[^()]+(?=\))/,lookbehind:!0,greedy:!0,alias:"property"},metadata:{pattern:/(\w\s*)<\s*\w+\s*=[^<>|=\r\n]+(?:\|\s*\w+\s*=[^<>|=\r\n]+)*>/,lookbehind:!0,greedy:!0,inside:{property:/\b\w+(?=\s*=)/,operator:/=/,punctuation:/[<>|]/}},macro:{pattern:/`\w+/,alias:"property"},"class-name":{pattern:/(\b(?:class|enum|extends|interface|state(?:\(\))?|struct|within)\s+)\w+/,lookbehind:!0},keyword:/\b(?:abstract|actor|array|auto|autoexpandcategories|bool|break|byte|case|class|classgroup|client|coerce|collapsecategories|config|const|continue|default|defaultproperties|delegate|dependson|deprecated|do|dontcollapsecategories|editconst|editinlinenew|else|enum|event|exec|export|extends|final|float|for|forcescriptorder|foreach|function|goto|guid|hidecategories|hidedropdown|if|ignores|implements|inherits|input|int|interface|iterator|latent|local|material|name|native|nativereplication|noexport|nontransient|noteditinlinenew|notplaceable|operator|optional|out|pawn|perobjectconfig|perobjectlocalized|placeable|postoperator|preoperator|private|protected|reliable|replication|return|server|showcategories|simulated|singular|state|static|string|struct|structdefault|structdefaultproperties|switch|texture|transient|travel|unreliable|until|var|vector|while|within)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,operator:/>>|<<|--|\+\+|\*\*|[-+*/~!=<>$@]=?|&&?|\|\|?|\^\^?|[?:%]|\b(?:ClockwiseFrom|Cross|Dot)\b/,punctuation:/[()[\]{};,.]/},t.languages.uc=t.languages.uscript=t.languages.unrealscript}return Ww}var Yw,vF;function pEe(){if(vF)return Yw;vF=1,Yw=e,e.displayName="uorazor",e.aliases=[];function e(t){t.languages.uorazor={"comment-hash":{pattern:/#.*/,alias:"comment",greedy:!0},"comment-slash":{pattern:/\/\/.*/,alias:"comment",greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,inside:{punctuation:/^['"]|['"]$/},greedy:!0},"source-layers":{pattern:/\b(?:arms|backpack|blue|bracelet|cancel|clear|cloak|criminal|earrings|enemy|facialhair|friend|friendly|gloves|gray|grey|ground|hair|head|innerlegs|innertorso|innocent|lefthand|middletorso|murderer|neck|nonfriendly|onehandedsecondary|outerlegs|outertorso|pants|red|righthand|ring|self|shirt|shoes|talisman|waist)\b/i,alias:"function"},"source-commands":{pattern:/\b(?:alliance|attack|cast|clearall|clearignore|clearjournal|clearlist|clearsysmsg|createlist|createtimer|dclick|dclicktype|dclickvar|dress|dressconfig|drop|droprelloc|emote|getlabel|guild|gumpclose|gumpresponse|hotkey|ignore|lasttarget|lift|lifttype|menu|menuresponse|msg|org|organize|organizer|overhead|pause|poplist|potion|promptresponse|pushlist|removelist|removetimer|rename|restock|say|scav|scavenger|script|setability|setlasttarget|setskill|settimer|setvar|sysmsg|target|targetloc|targetrelloc|targettype|undress|unignore|unsetvar|useobject|useonce|useskill|usetype|virtue|wait|waitforgump|waitformenu|waitforprompt|waitforstat|waitforsysmsg|waitfortarget|walk|wfsysmsg|wft|whisper|yell)\b/,alias:"function"},"tag-name":{pattern:/(^\{%-?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%]-?|-?[%}]\}$/,alias:"punctuation"},function:/\b(?:atlist|close|closest|count|counter|counttype|dead|dex|diffhits|diffmana|diffstam|diffweight|find|findbuff|finddebuff|findlayer|findtype|findtypelist|followers|gumpexists|hidden|hits|hp|hue|human|humanoid|ingump|inlist|insysmessage|insysmsg|int|invul|lhandempty|list|listexists|mana|maxhits|maxhp|maxmana|maxstam|maxweight|monster|mounted|name|next|noto|paralyzed|poisoned|position|prev|previous|queued|rand|random|rhandempty|skill|stam|str|targetexists|timer|timerexists|varexist|warmode|weight)\b/,keyword:/\b(?:and|as|break|continue|else|elseif|endfor|endif|endwhile|for|if|loop|not|or|replay|stop|while)\b/,boolean:/\b(?:false|null|true)\b/,number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,operator:[{pattern:/(\s)(?:and|b-and|b-or|b-xor|ends with|in|is|matches|not|or|same as|starts with)(?=\s)/,lookbehind:!0},/[=<>]=?|!=|\*\*?|\/\/?|\?:?|[-+~%|]/],punctuation:/[()\[\]{}:.,]/}}return Yw}var Kw,SF;function gEe(){if(SF)return Kw;SF=1,Kw=e,e.displayName="uri",e.aliases=["url"];function e(t){t.languages.uri={scheme:{pattern:/^[a-z][a-z0-9+.-]*:/im,greedy:!0,inside:{"scheme-delimiter":/:$/}},fragment:{pattern:/#[\w\-.~!$&'()*+,;=%:@/?]*/,inside:{"fragment-delimiter":/^#/}},query:{pattern:/\?[\w\-.~!$&'()*+,;=%:@/?]*/,inside:{"query-delimiter":{pattern:/^\?/,greedy:!0},"pair-delimiter":/[&;]/,pair:{pattern:/^[^=][\s\S]*/,inside:{key:/^[^=]+/,value:{pattern:/(^=)[\s\S]+/,lookbehind:!0}}}}},authority:{pattern:RegExp(/^\/\//.source+/(?:[\w\-.~!$&'()*+,;=%:]*@)?/.source+("(?:"+/\[(?:[0-9a-fA-F:.]{2,48}|v[0-9a-fA-F]+\.[\w\-.~!$&'()*+,;=]+)\]/.source+"|"+/[\w\-.~!$&'()*+,;=%]*/.source+")")+/(?::\d*)?/.source,"m"),inside:{"authority-delimiter":/^\/\//,"user-info-segment":{pattern:/^[\w\-.~!$&'()*+,;=%:]*@/,inside:{"user-info-delimiter":/@$/,"user-info":/^[\w\-.~!$&'()*+,;=%:]+/}},"port-segment":{pattern:/:\d*$/,inside:{"port-delimiter":/^:/,port:/^\d+/}},host:{pattern:/[\s\S]+/,inside:{"ip-literal":{pattern:/^\[[\s\S]+\]$/,inside:{"ip-literal-delimiter":/^\[|\]$/,"ipv-future":/^v[\s\S]+/,"ipv6-address":/^[\s\S]+/}},"ipv4-address":/^(?:(?:[03-9]\d?|[12]\d{0,2})\.){3}(?:[03-9]\d?|[12]\d{0,2})$/}}}},path:{pattern:/^[\w\-.~!$&'()*+,;=%:@/]+/m,inside:{"path-separator":/\//}}},t.languages.url=t.languages.uri}return Kw}var Xw,EF;function hEe(){if(EF)return Xw;EF=1,Xw=e,e.displayName="v",e.aliases=[];function e(t){(function(n){var r={pattern:/[\s\S]+/,inside:null};n.languages.v=n.languages.extend("clike",{string:{pattern:/r?(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,alias:"quoted-string",greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\{[^{}]*\}|\w+(?:\.\w+(?:\([^\(\)]*\))?|\[[^\[\]]+\])*)/,lookbehind:!0,inside:{"interpolation-variable":{pattern:/^\$\w[\s\S]*$/,alias:"variable"},"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},"interpolation-expression":r}}}},"class-name":{pattern:/(\b(?:enum|interface|struct|type)\s+)(?:C\.)?\w+/,lookbehind:!0},keyword:/(?:\b(?:__global|as|asm|assert|atomic|break|chan|const|continue|defer|else|embed|enum|fn|for|go(?:to)?|if|import|in|interface|is|lock|match|module|mut|none|or|pub|return|rlock|select|shared|sizeof|static|struct|type(?:of)?|union|unsafe)|\$(?:else|for|if)|#(?:flag|include))\b/,number:/\b(?:0x[a-f\d]+(?:_[a-f\d]+)*|0b[01]+(?:_[01]+)*|0o[0-7]+(?:_[0-7]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?)\b/i,operator:/~|\?|[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\.?/,builtin:/\b(?:any(?:_float|_int)?|bool|byte(?:ptr)?|charptr|f(?:32|64)|i(?:8|16|64|128|nt)|rune|size_t|string|u(?:16|32|64|128)|voidptr)\b/}),r.inside=n.languages.v,n.languages.insertBefore("v","string",{char:{pattern:/`(?:\\`|\\?[^`]{1,2})`/,alias:"rune"}}),n.languages.insertBefore("v","operator",{attribute:{pattern:/(^[\t ]*)\[(?:deprecated|direct_array_access|flag|inline|live|ref_only|typedef|unsafe_fn|windows_stdcall)\]/m,lookbehind:!0,alias:"annotation",inside:{punctuation:/[\[\]]/,keyword:/\w+/}},generic:{pattern:/<\w+>(?=\s*[\)\{])/,inside:{punctuation:/[<>]/,"class-name":/\w+/}}}),n.languages.insertBefore("v","function",{"generic-function":{pattern:/\b\w+\s*<\w+>(?=\()/,inside:{function:/^\w+/,generic:{pattern:/<\w+>/,inside:n.languages.v.generic.inside}}}})})(t)}return Xw}var Zw,wF;function mEe(){if(wF)return Zw;wF=1,Zw=e,e.displayName="vala",e.aliases=[];function e(t){t.languages.vala=t.languages.extend("clike",{"class-name":[{pattern:/\b[A-Z]\w*(?:\.\w+)*\b(?=(?:\?\s+|\*?\s+\*?)\w)/,inside:{punctuation:/\./}},{pattern:/(\[)[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}},{pattern:/(\b(?:class|interface)\s+[A-Z]\w*(?:\.\w+)*\s*:\s*)[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}},{pattern:/((?:\b(?:class|enum|interface|new|struct)\s+)|(?:catch\s+\())[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}}],keyword:/\b(?:abstract|as|assert|async|base|bool|break|case|catch|char|class|const|construct|continue|default|delegate|delete|do|double|dynamic|else|ensures|enum|errordomain|extern|finally|float|for|foreach|get|if|in|inline|int|int16|int32|int64|int8|interface|internal|is|lock|long|namespace|new|null|out|override|owned|params|private|protected|public|ref|requires|return|set|short|signal|sizeof|size_t|ssize_t|static|string|struct|switch|this|throw|throws|try|typeof|uchar|uint|uint16|uint32|uint64|uint8|ulong|unichar|unowned|ushort|using|value|var|virtual|void|volatile|weak|while|yield)\b/i,function:/\b\w+(?=\s*\()/,number:/(?:\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)(?:f|u?l?)?/i,operator:/\+\+|--|&&|\|\||<<=?|>>=?|=>|->|~|[+\-*\/%&^|=!<>]=?|\?\??|\.\.\./,punctuation:/[{}[\];(),.:]/,constant:/\b[A-Z0-9_]+\b/}),t.languages.insertBefore("vala","string",{"raw-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},"template-string":{pattern:/@"[\s\S]*?"/,greedy:!0,inside:{interpolation:{pattern:/\$(?:\([^)]*\)|[a-zA-Z]\w*)/,inside:{delimiter:{pattern:/^\$\(?|\)$/,alias:"punctuation"},rest:t.languages.vala}},string:/[\s\S]+/}}}),t.languages.insertBefore("vala","keyword",{regex:{pattern:/\/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[imsx]{0,4}(?=\s*(?:$|[\r\n,.;})\]]))/,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:t.languages.regex},"regex-delimiter":/^\//,"regex-flags":/^[a-z]+$/}}})}return Zw}var Qw,xF;function bEe(){if(xF)return Qw;xF=1,Qw=e,e.displayName="velocity",e.aliases=[];function e(t){(function(n){n.languages.velocity=n.languages.extend("markup",{});var r={variable:{pattern:/(^|[^\\](?:\\\\)*)\$!?(?:[a-z][\w-]*(?:\([^)]*\))?(?:\.[a-z][\w-]*(?:\([^)]*\))?|\[[^\]]+\])*|\{[^}]+\})/i,lookbehind:!0,inside:{}},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},number:/\b\d+\b/,boolean:/\b(?:false|true)\b/,operator:/[=!<>]=?|[+*/%-]|&&|\|\||\.\.|\b(?:eq|g[et]|l[et]|n(?:e|ot))\b/,punctuation:/[(){}[\]:,.]/};r.variable.inside={string:r.string,function:{pattern:/([^\w-])[a-z][\w-]*(?=\()/,lookbehind:!0},number:r.number,boolean:r.boolean,punctuation:r.punctuation},n.languages.insertBefore("velocity","comment",{unparsed:{pattern:/(^|[^\\])#\[\[[\s\S]*?\]\]#/,lookbehind:!0,greedy:!0,inside:{punctuation:/^#\[\[|\]\]#$/}},"velocity-comment":[{pattern:/(^|[^\\])#\*[\s\S]*?\*#/,lookbehind:!0,greedy:!0,alias:"comment"},{pattern:/(^|[^\\])##.*/,lookbehind:!0,greedy:!0,alias:"comment"}],directive:{pattern:/(^|[^\\](?:\\\\)*)#@?(?:[a-z][\w-]*|\{[a-z][\w-]*\})(?:\s*\((?:[^()]|\([^()]*\))*\))?/i,lookbehind:!0,inside:{keyword:{pattern:/^#@?(?:[a-z][\w-]*|\{[a-z][\w-]*\})|\bin\b/,inside:{punctuation:/[{}]/}},rest:r}},variable:r.variable}),n.languages.velocity.tag.inside["attr-value"].inside.rest=n.languages.velocity})(t)}return Qw}var Jw,kF;function yEe(){if(kF)return Jw;kF=1,Jw=e,e.displayName="verilog",e.aliases=[];function e(t){t.languages.verilog={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},"kernel-function":{pattern:/\B\$\w+\b/,alias:"property"},constant:/\B`\w+\b/,function:/\b\w+(?=\()/,keyword:/\b(?:alias|and|assert|assign|assume|automatic|before|begin|bind|bins|binsof|bit|break|buf|bufif0|bufif1|byte|case|casex|casez|cell|chandle|class|clocking|cmos|config|const|constraint|context|continue|cover|covergroup|coverpoint|cross|deassign|default|defparam|design|disable|dist|do|edge|else|end|endcase|endclass|endclocking|endconfig|endfunction|endgenerate|endgroup|endinterface|endmodule|endpackage|endprimitive|endprogram|endproperty|endsequence|endspecify|endtable|endtask|enum|event|expect|export|extends|extern|final|first_match|for|force|foreach|forever|fork|forkjoin|function|generate|genvar|highz0|highz1|if|iff|ifnone|ignore_bins|illegal_bins|import|incdir|include|initial|inout|input|inside|instance|int|integer|interface|intersect|join|join_any|join_none|large|liblist|library|local|localparam|logic|longint|macromodule|matches|medium|modport|module|nand|negedge|new|nmos|nor|noshowcancelled|not|notif0|notif1|null|or|output|package|packed|parameter|pmos|posedge|primitive|priority|program|property|protected|pull0|pull1|pulldown|pullup|pulsestyle_ondetect|pulsestyle_onevent|pure|rand|randc|randcase|randsequence|rcmos|real|realtime|ref|reg|release|repeat|return|rnmos|rpmos|rtran|rtranif0|rtranif1|scalared|sequence|shortint|shortreal|showcancelled|signed|small|solve|specify|specparam|static|string|strong0|strong1|struct|super|supply0|supply1|table|tagged|task|this|throughout|time|timeprecision|timeunit|tran|tranif0|tranif1|tri|tri0|tri1|triand|trior|trireg|type|typedef|union|unique|unsigned|use|uwire|var|vectored|virtual|void|wait|wait_order|wand|weak0|weak1|while|wildcard|wire|with|within|wor|xnor|xor)\b/,important:/\b(?:always|always_comb|always_ff|always_latch)\b(?: *@)?/,number:/\B##?\d+|(?:\b\d+)?'[odbh] ?[\da-fzx_?]+|\b(?:\d*[._])?\d+(?:e[-+]?\d+)?/i,operator:/[-+{}^~%*\/?=!<>&|]+/,punctuation:/[[\];(),.:]/}}return Jw}var ex,TF;function vEe(){if(TF)return ex;TF=1,ex=e,e.displayName="vhdl",e.aliases=[];function e(t){t.languages.vhdl={comment:/--.+/,"vhdl-vectors":{pattern:/\b[oxb]"[\da-f_]+"|"[01uxzwlh-]+"/i,alias:"number"},"quoted-function":{pattern:/"\S+?"(?=\()/,alias:"function"},string:/"(?:[^\\"\r\n]|\\(?:\r\n|[\s\S]))*"/,constant:/\b(?:library|use)\b/i,keyword:/\b(?:'active|'ascending|'base|'delayed|'driving|'driving_value|'event|'high|'image|'instance_name|'last_active|'last_event|'last_value|'left|'leftof|'length|'low|'path_name|'pos|'pred|'quiet|'range|'reverse_range|'right|'rightof|'simple_name|'stable|'succ|'transaction|'val|'value|access|after|alias|all|architecture|array|assert|attribute|begin|block|body|buffer|bus|case|component|configuration|constant|disconnect|downto|else|elsif|end|entity|exit|file|for|function|generate|generic|group|guarded|if|impure|in|inertial|inout|is|label|library|linkage|literal|loop|map|new|next|null|of|on|open|others|out|package|port|postponed|procedure|process|pure|range|record|register|reject|report|return|select|severity|shared|signal|subtype|then|to|transport|type|unaffected|units|until|use|variable|wait|when|while|with)\b/i,boolean:/\b(?:false|true)\b/i,function:/\w+(?=\()/,number:/'[01uxzwlh-]'|\b(?:\d+#[\da-f_.]+#|\d[\d_.]*)(?:e[-+]?\d+)?/i,operator:/[<>]=?|:=|[-+*/&=]|\b(?:abs|and|mod|nand|nor|not|or|rem|rol|ror|sla|sll|sra|srl|xnor|xor)\b/i,punctuation:/[{}[\];(),.:]/}}return ex}var tx,AF;function SEe(){if(AF)return tx;AF=1,tx=e,e.displayName="vim",e.aliases=[];function e(t){t.languages.vim={string:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\r\n]|'')*'/,comment:/".*/,function:/\b\w+(?=\()/,keyword:/\b(?:N|Next|P|Print|X|XMLent|XMLns|ab|abbreviate|abc|abclear|abo|aboveleft|al|all|ar|arga|argadd|argd|argdelete|argdo|arge|argedit|argg|argglobal|argl|arglocal|args|argu|argument|as|ascii|b|bN|bNext|ba|bad|badd|ball|bd|bdelete|be|bel|belowright|bf|bfirst|bl|blast|bm|bmodified|bn|bnext|bo|botright|bp|bprevious|br|brea|break|breaka|breakadd|breakd|breakdel|breakl|breaklist|brewind|bro|browse|bufdo|buffer|buffers|bun|bunload|bw|bwipeout|c|cN|cNext|cNfcNfile|ca|cabbrev|cabc|cabclear|cad|caddb|caddbuffer|caddexpr|caddf|caddfile|cal|call|cat|catch|cb|cbuffer|cc|ccl|cclose|cd|ce|center|cex|cexpr|cf|cfile|cfir|cfirst|cg|cgetb|cgetbuffer|cgete|cgetexpr|cgetfile|change|changes|chd|chdir|che|checkpath|checkt|checktime|cl|cla|clast|clist|clo|close|cmapc|cmapclear|cn|cnew|cnewer|cnext|cnf|cnfile|cnorea|cnoreabbrev|co|col|colder|colo|colorscheme|comc|comclear|comp|compiler|con|conf|confirm|continue|cope|copen|copy|cp|cpf|cpfile|cprevious|cq|cquit|cr|crewind|cu|cuna|cunabbrev|cunmap|cw|cwindow|d|debugg|debuggreedy|delc|delcommand|delete|delf|delfunction|delm|delmarks|di|diffg|diffget|diffoff|diffpatch|diffpu|diffput|diffsplit|diffthis|diffu|diffupdate|dig|digraphs|display|dj|djump|dl|dlist|dr|drop|ds|dsearch|dsp|dsplit|e|earlier|echoe|echoerr|echom|echomsg|echon|edit|el|else|elsei|elseif|em|emenu|en|endf|endfo|endfor|endfun|endfunction|endif|endt|endtry|endw|endwhile|ene|enew|ex|exi|exit|exu|exusage|f|file|files|filetype|fin|fina|finally|find|fini|finish|fir|first|fix|fixdel|fo|fold|foldc|foldclose|foldd|folddoc|folddoclosed|folddoopen|foldo|foldopen|for|fu|fun|function|go|goto|gr|grep|grepa|grepadd|h|ha|hardcopy|help|helpf|helpfind|helpg|helpgrep|helpt|helptags|hid|hide|his|history|ia|iabbrev|iabc|iabclear|if|ij|ijump|il|ilist|imapc|imapclear|in|inorea|inoreabbrev|isearch|isp|isplit|iu|iuna|iunabbrev|iunmap|j|join|ju|jumps|k|kee|keepalt|keepj|keepjumps|keepmarks|l|lN|lNext|lNf|lNfile|la|lad|laddb|laddbuffer|laddexpr|laddf|laddfile|lan|language|last|later|lb|lbuffer|lc|lcd|lch|lchdir|lcl|lclose|left|lefta|leftabove|let|lex|lexpr|lf|lfile|lfir|lfirst|lg|lgetb|lgetbuffer|lgete|lgetexpr|lgetfile|lgr|lgrep|lgrepa|lgrepadd|lh|lhelpgrep|list|ll|lla|llast|lli|llist|lm|lmak|lmake|lmap|lmapc|lmapclear|ln|lne|lnew|lnewer|lnext|lnf|lnfile|lnoremap|lo|loadview|loc|lockmarks|lockv|lockvar|lol|lolder|lop|lopen|lp|lpf|lpfile|lprevious|lr|lrewind|ls|lt|ltag|lu|lunmap|lv|lvimgrep|lvimgrepa|lvimgrepadd|lw|lwindow|m|ma|mak|make|mark|marks|mat|match|menut|menutranslate|mk|mkexrc|mks|mksession|mksp|mkspell|mkv|mkvie|mkview|mkvimrc|mod|mode|move|mz|mzf|mzfile|mzscheme|n|nbkey|new|next|nmapc|nmapclear|noh|nohlsearch|norea|noreabbrev|nu|number|nun|nunmap|o|omapc|omapclear|on|only|open|opt|options|ou|ounmap|p|pc|pclose|pe|ped|pedit|perl|perld|perldo|po|pop|popu|popup|pp|ppop|pre|preserve|prev|previous|print|prof|profd|profdel|profile|promptf|promptfind|promptr|promptrepl|ps|psearch|ptN|ptNext|pta|ptag|ptf|ptfirst|ptj|ptjump|ptl|ptlast|ptn|ptnext|ptp|ptprevious|ptr|ptrewind|pts|ptselect|pu|put|pw|pwd|py|pyf|pyfile|python|q|qa|qall|quit|quita|quitall|r|read|rec|recover|red|redi|redir|redo|redr|redraw|redraws|redrawstatus|reg|registers|res|resize|ret|retab|retu|return|rew|rewind|ri|right|rightb|rightbelow|ru|rub|ruby|rubyd|rubydo|rubyf|rubyfile|runtime|rv|rviminfo|sN|sNext|sa|sal|sall|san|sandbox|sargument|sav|saveas|sb|sbN|sbNext|sba|sball|sbf|sbfirst|sbl|sblast|sbm|sbmodified|sbn|sbnext|sbp|sbprevious|sbr|sbrewind|sbuffer|scrip|scripte|scriptencoding|scriptnames|se|set|setf|setfiletype|setg|setglobal|setl|setlocal|sf|sfind|sfir|sfirst|sh|shell|sign|sil|silent|sim|simalt|sl|sla|slast|sleep|sm|smagic|smap|smapc|smapclear|sme|smenu|sn|snext|sni|sniff|sno|snomagic|snor|snoremap|snoreme|snoremenu|so|sor|sort|source|sp|spe|spelld|spelldump|spellgood|spelli|spellinfo|spellr|spellrepall|spellu|spellundo|spellw|spellwrong|split|spr|sprevious|sre|srewind|st|sta|stag|star|startg|startgreplace|startinsert|startr|startreplace|stj|stjump|stop|stopi|stopinsert|sts|stselect|sun|sunhide|sunm|sunmap|sus|suspend|sv|sview|syncbind|t|tN|tNext|ta|tab|tabN|tabNext|tabc|tabclose|tabd|tabdo|tabe|tabedit|tabf|tabfind|tabfir|tabfirst|tabl|tablast|tabm|tabmove|tabn|tabnew|tabnext|tabo|tabonly|tabp|tabprevious|tabr|tabrewind|tabs|tag|tags|tc|tcl|tcld|tcldo|tclf|tclfile|te|tearoff|tf|tfirst|th|throw|tj|tjump|tl|tlast|tm|tmenu|tn|tnext|to|topleft|tp|tprevious|tr|trewind|try|ts|tselect|tu|tunmenu|u|una|unabbreviate|undo|undoj|undojoin|undol|undolist|unh|unhide|unlet|unlo|unlockvar|unm|unmap|up|update|ve|verb|verbose|version|vert|vertical|vi|vie|view|vim|vimgrep|vimgrepa|vimgrepadd|visual|viu|viusage|vmapc|vmapclear|vne|vnew|vs|vsplit|vu|vunmap|w|wN|wNext|wa|wall|wh|while|win|winc|wincmd|windo|winp|winpos|winsize|wn|wnext|wp|wprevious|wq|wqa|wqall|write|ws|wsverb|wv|wviminfo|x|xa|xall|xit|xm|xmap|xmapc|xmapclear|xme|xmenu|xn|xnoremap|xnoreme|xnoremenu|xu|xunmap|y|yank)\b/,builtin:/\b(?:acd|ai|akm|aleph|allowrevins|altkeymap|ambiwidth|ambw|anti|antialias|arab|arabic|arabicshape|ari|arshape|autochdir|autocmd|autoindent|autoread|autowrite|autowriteall|aw|awa|background|backspace|backup|backupcopy|backupdir|backupext|backupskip|balloondelay|ballooneval|balloonexpr|bdir|bdlay|beval|bex|bexpr|bg|bh|bin|binary|biosk|bioskey|bk|bkc|bomb|breakat|brk|browsedir|bs|bsdir|bsk|bt|bufhidden|buflisted|buftype|casemap|ccv|cdpath|cedit|cfu|ch|charconvert|ci|cin|cindent|cink|cinkeys|cino|cinoptions|cinw|cinwords|clipboard|cmdheight|cmdwinheight|cmp|cms|columns|com|comments|commentstring|compatible|complete|completefunc|completeopt|consk|conskey|copyindent|cot|cpo|cpoptions|cpt|cscopepathcomp|cscopeprg|cscopequickfix|cscopetag|cscopetagorder|cscopeverbose|cspc|csprg|csqf|cst|csto|csverb|cuc|cul|cursorcolumn|cursorline|cwh|debug|deco|def|define|delcombine|dex|dg|dict|dictionary|diff|diffexpr|diffopt|digraph|dip|dir|directory|dy|ea|ead|eadirection|eb|ed|edcompatible|ef|efm|ei|ek|enc|encoding|endofline|eol|ep|equalalways|equalprg|errorbells|errorfile|errorformat|esckeys|et|eventignore|expandtab|exrc|fcl|fcs|fdc|fde|fdi|fdl|fdls|fdm|fdn|fdo|fdt|fen|fenc|fencs|fex|ff|ffs|fileencoding|fileencodings|fileformat|fileformats|fillchars|fk|fkmap|flp|fml|fmr|foldcolumn|foldenable|foldexpr|foldignore|foldlevel|foldlevelstart|foldmarker|foldmethod|foldminlines|foldnestmax|foldtext|formatexpr|formatlistpat|formatoptions|formatprg|fp|fs|fsync|ft|gcr|gd|gdefault|gfm|gfn|gfs|gfw|ghr|gp|grepformat|grepprg|gtl|gtt|guicursor|guifont|guifontset|guifontwide|guiheadroom|guioptions|guipty|guitablabel|guitabtooltip|helpfile|helpheight|helplang|hf|hh|hi|hidden|highlight|hk|hkmap|hkmapp|hkp|hl|hlg|hls|hlsearch|ic|icon|iconstring|ignorecase|im|imactivatekey|imak|imc|imcmdline|imd|imdisable|imi|iminsert|ims|imsearch|inc|include|includeexpr|incsearch|inde|indentexpr|indentkeys|indk|inex|inf|infercase|insertmode|invacd|invai|invakm|invallowrevins|invaltkeymap|invanti|invantialias|invar|invarab|invarabic|invarabicshape|invari|invarshape|invautochdir|invautoindent|invautoread|invautowrite|invautowriteall|invaw|invawa|invbackup|invballooneval|invbeval|invbin|invbinary|invbiosk|invbioskey|invbk|invbl|invbomb|invbuflisted|invcf|invci|invcin|invcindent|invcompatible|invconfirm|invconsk|invconskey|invcopyindent|invcp|invcscopetag|invcscopeverbose|invcst|invcsverb|invcuc|invcul|invcursorcolumn|invcursorline|invdeco|invdelcombine|invdg|invdiff|invdigraph|invdisable|invea|inveb|inved|invedcompatible|invek|invendofline|inveol|invequalalways|inverrorbells|invesckeys|invet|invex|invexpandtab|invexrc|invfen|invfk|invfkmap|invfoldenable|invgd|invgdefault|invguipty|invhid|invhidden|invhk|invhkmap|invhkmapp|invhkp|invhls|invhlsearch|invic|invicon|invignorecase|invim|invimc|invimcmdline|invimd|invincsearch|invinf|invinfercase|invinsertmode|invis|invjoinspaces|invjs|invlazyredraw|invlbr|invlinebreak|invlisp|invlist|invloadplugins|invlpl|invlz|invma|invmacatsui|invmagic|invmh|invml|invmod|invmodeline|invmodifiable|invmodified|invmore|invmousef|invmousefocus|invmousehide|invnu|invnumber|invodev|invopendevice|invpaste|invpi|invpreserveindent|invpreviewwindow|invprompt|invpvw|invreadonly|invremap|invrestorescreen|invrevins|invri|invrightleft|invrightleftcmd|invrl|invrlc|invro|invrs|invru|invruler|invsb|invsc|invscb|invscrollbind|invscs|invsecure|invsft|invshellslash|invshelltemp|invshiftround|invshortname|invshowcmd|invshowfulltag|invshowmatch|invshowmode|invsi|invsm|invsmartcase|invsmartindent|invsmarttab|invsmd|invsn|invsol|invspell|invsplitbelow|invsplitright|invspr|invsr|invssl|invsta|invstartofline|invstmp|invswapfile|invswf|invta|invtagbsearch|invtagrelative|invtagstack|invtbi|invtbidi|invtbs|invtermbidi|invterse|invtextauto|invtextmode|invtf|invtgst|invtildeop|invtimeout|invtitle|invto|invtop|invtr|invttimeout|invttybuiltin|invttyfast|invtx|invvb|invvisualbell|invwa|invwarn|invwb|invweirdinvert|invwfh|invwfw|invwildmenu|invwinfixheight|invwinfixwidth|invwiv|invwmnu|invwrap|invwrapscan|invwrite|invwriteany|invwritebackup|invws|isf|isfname|isi|isident|isk|iskeyword|isprint|joinspaces|js|key|keymap|keymodel|keywordprg|km|kmp|kp|langmap|langmenu|laststatus|lazyredraw|lbr|lcs|linebreak|lines|linespace|lisp|lispwords|listchars|loadplugins|lpl|lsp|lz|macatsui|magic|makeef|makeprg|matchpairs|matchtime|maxcombine|maxfuncdepth|maxmapdepth|maxmem|maxmempattern|maxmemtot|mco|mef|menuitems|mfd|mh|mis|mkspellmem|ml|mls|mm|mmd|mmp|mmt|modeline|modelines|modifiable|modified|more|mouse|mousef|mousefocus|mousehide|mousem|mousemodel|mouses|mouseshape|mouset|mousetime|mp|mps|msm|mzq|mzquantum|nf|noacd|noai|noakm|noallowrevins|noaltkeymap|noanti|noantialias|noar|noarab|noarabic|noarabicshape|noari|noarshape|noautochdir|noautoindent|noautoread|noautowrite|noautowriteall|noaw|noawa|nobackup|noballooneval|nobeval|nobin|nobinary|nobiosk|nobioskey|nobk|nobl|nobomb|nobuflisted|nocf|noci|nocin|nocindent|nocompatible|noconfirm|noconsk|noconskey|nocopyindent|nocp|nocscopetag|nocscopeverbose|nocst|nocsverb|nocuc|nocul|nocursorcolumn|nocursorline|nodeco|nodelcombine|nodg|nodiff|nodigraph|nodisable|noea|noeb|noed|noedcompatible|noek|noendofline|noeol|noequalalways|noerrorbells|noesckeys|noet|noex|noexpandtab|noexrc|nofen|nofk|nofkmap|nofoldenable|nogd|nogdefault|noguipty|nohid|nohidden|nohk|nohkmap|nohkmapp|nohkp|nohls|noic|noicon|noignorecase|noim|noimc|noimcmdline|noimd|noincsearch|noinf|noinfercase|noinsertmode|nois|nojoinspaces|nojs|nolazyredraw|nolbr|nolinebreak|nolisp|nolist|noloadplugins|nolpl|nolz|noma|nomacatsui|nomagic|nomh|noml|nomod|nomodeline|nomodifiable|nomodified|nomore|nomousef|nomousefocus|nomousehide|nonu|nonumber|noodev|noopendevice|nopaste|nopi|nopreserveindent|nopreviewwindow|noprompt|nopvw|noreadonly|noremap|norestorescreen|norevins|nori|norightleft|norightleftcmd|norl|norlc|noro|nors|noru|noruler|nosb|nosc|noscb|noscrollbind|noscs|nosecure|nosft|noshellslash|noshelltemp|noshiftround|noshortname|noshowcmd|noshowfulltag|noshowmatch|noshowmode|nosi|nosm|nosmartcase|nosmartindent|nosmarttab|nosmd|nosn|nosol|nospell|nosplitbelow|nosplitright|nospr|nosr|nossl|nosta|nostartofline|nostmp|noswapfile|noswf|nota|notagbsearch|notagrelative|notagstack|notbi|notbidi|notbs|notermbidi|noterse|notextauto|notextmode|notf|notgst|notildeop|notimeout|notitle|noto|notop|notr|nottimeout|nottybuiltin|nottyfast|notx|novb|novisualbell|nowa|nowarn|nowb|noweirdinvert|nowfh|nowfw|nowildmenu|nowinfixheight|nowinfixwidth|nowiv|nowmnu|nowrap|nowrapscan|nowrite|nowriteany|nowritebackup|nows|nrformats|numberwidth|nuw|odev|oft|ofu|omnifunc|opendevice|operatorfunc|opfunc|osfiletype|pa|para|paragraphs|paste|pastetoggle|patchexpr|patchmode|path|pdev|penc|pex|pexpr|pfn|ph|pheader|pi|pm|pmbcs|pmbfn|popt|preserveindent|previewheight|previewwindow|printdevice|printencoding|printexpr|printfont|printheader|printmbcharset|printmbfont|printoptions|prompt|pt|pumheight|pvh|pvw|qe|quoteescape|readonly|remap|report|restorescreen|revins|rightleft|rightleftcmd|rl|rlc|ro|rs|rtp|ruf|ruler|rulerformat|runtimepath|sbo|sc|scb|scr|scroll|scrollbind|scrolljump|scrolloff|scrollopt|scs|sect|sections|secure|sel|selection|selectmode|sessionoptions|sft|shcf|shellcmdflag|shellpipe|shellquote|shellredir|shellslash|shelltemp|shelltype|shellxquote|shiftround|shiftwidth|shm|shortmess|shortname|showbreak|showcmd|showfulltag|showmatch|showmode|showtabline|shq|si|sidescroll|sidescrolloff|siso|sj|slm|smartcase|smartindent|smarttab|smc|smd|softtabstop|sol|spc|spell|spellcapcheck|spellfile|spelllang|spellsuggest|spf|spl|splitbelow|splitright|sps|sr|srr|ss|ssl|ssop|stal|startofline|statusline|stl|stmp|su|sua|suffixes|suffixesadd|sw|swapfile|swapsync|swb|swf|switchbuf|sws|sxq|syn|synmaxcol|syntax|t_AB|t_AF|t_AL|t_CS|t_CV|t_Ce|t_Co|t_Cs|t_DL|t_EI|t_F1|t_F2|t_F3|t_F4|t_F5|t_F6|t_F7|t_F8|t_F9|t_IE|t_IS|t_K1|t_K3|t_K4|t_K5|t_K6|t_K7|t_K8|t_K9|t_KA|t_KB|t_KC|t_KD|t_KE|t_KF|t_KG|t_KH|t_KI|t_KJ|t_KK|t_KL|t_RI|t_RV|t_SI|t_Sb|t_Sf|t_WP|t_WS|t_ZH|t_ZR|t_al|t_bc|t_cd|t_ce|t_cl|t_cm|t_cs|t_da|t_db|t_dl|t_fs|t_k1|t_k2|t_k3|t_k4|t_k5|t_k6|t_k7|t_k8|t_k9|t_kB|t_kD|t_kI|t_kN|t_kP|t_kb|t_kd|t_ke|t_kh|t_kl|t_kr|t_ks|t_ku|t_le|t_mb|t_md|t_me|t_mr|t_ms|t_nd|t_op|t_se|t_so|t_sr|t_te|t_ti|t_ts|t_ue|t_us|t_ut|t_vb|t_ve|t_vi|t_vs|t_xs|tabline|tabpagemax|tabstop|tagbsearch|taglength|tagrelative|tagstack|tal|tb|tbi|tbidi|tbis|tbs|tenc|term|termbidi|termencoding|terse|textauto|textmode|textwidth|tgst|thesaurus|tildeop|timeout|timeoutlen|title|titlelen|titleold|titlestring|toolbar|toolbariconsize|top|tpm|tsl|tsr|ttimeout|ttimeoutlen|ttm|tty|ttybuiltin|ttyfast|ttym|ttymouse|ttyscroll|ttytype|tw|tx|uc|ul|undolevels|updatecount|updatetime|ut|vb|vbs|vdir|verbosefile|vfile|viewdir|viewoptions|viminfo|virtualedit|visualbell|vop|wak|warn|wb|wc|wcm|wd|weirdinvert|wfh|wfw|whichwrap|wi|wig|wildchar|wildcharm|wildignore|wildmenu|wildmode|wildoptions|wim|winaltkeys|window|winfixheight|winfixwidth|winheight|winminheight|winminwidth|winwidth|wiv|wiw|wm|wmh|wmnu|wmw|wop|wrap|wrapmargin|wrapscan|writeany|writebackup|writedelay|ww)\b/,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?)\b/i,operator:/\|\||&&|[-+.]=?|[=!](?:[=~][#?]?)?|[<>]=?[#?]?|[*\/%?]|\b(?:is(?:not)?)\b/,punctuation:/[{}[\](),;:]/}}return tx}var nx,RF;function EEe(){if(RF)return nx;RF=1,nx=e,e.displayName="visualBasic",e.aliases=[];function e(t){t.languages["visual-basic"]={comment:{pattern:/(?:['‘’]|REM\b)(?:[^\r\n_]|_(?:\r\n?|\n)?)*/i,inside:{keyword:/^REM/i}},directive:{pattern:/#(?:Const|Else|ElseIf|End|ExternalChecksum|ExternalSource|If|Region)(?:\b_[ \t]*(?:\r\n?|\n)|.)+/i,alias:"property",greedy:!0},string:{pattern:/\$?["“”](?:["“”]{2}|[^"“”])*["“”]C?/i,greedy:!0},date:{pattern:/#[ \t]*(?:\d+([/-])\d+\1\d+(?:[ \t]+(?:\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?))?|\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?)[ \t]*#/i,alias:"number"},number:/(?:(?:\b\d+(?:\.\d+)?|\.\d+)(?:E[+-]?\d+)?|&[HO][\dA-F]+)(?:[FRD]|U?[ILS])?/i,boolean:/\b(?:False|Nothing|True)\b/i,keyword:/\b(?:AddHandler|AddressOf|Alias|And(?:Also)?|As|Boolean|ByRef|Byte|ByVal|Call|Case|Catch|C(?:Bool|Byte|Char|Date|Dbl|Dec|Int|Lng|Obj|SByte|Short|Sng|Str|Type|UInt|ULng|UShort)|Char|Class|Const|Continue|Currency|Date|Decimal|Declare|Default|Delegate|Dim|DirectCast|Do|Double|Each|Else(?:If)?|End(?:If)?|Enum|Erase|Error|Event|Exit|Finally|For|Friend|Function|Get(?:Type|XMLNamespace)?|Global|GoSub|GoTo|Handles|If|Implements|Imports|In|Inherits|Integer|Interface|Is|IsNot|Let|Lib|Like|Long|Loop|Me|Mod|Module|Must(?:Inherit|Override)|My(?:Base|Class)|Namespace|Narrowing|New|Next|Not(?:Inheritable|Overridable)?|Object|Of|On|Operator|Option(?:al)?|Or(?:Else)?|Out|Overloads|Overridable|Overrides|ParamArray|Partial|Private|Property|Protected|Public|RaiseEvent|ReadOnly|ReDim|RemoveHandler|Resume|Return|SByte|Select|Set|Shadows|Shared|short|Single|Static|Step|Stop|String|Structure|Sub|SyncLock|Then|Throw|To|Try|TryCast|Type|TypeOf|U(?:Integer|Long|Short)|Until|Using|Variant|Wend|When|While|Widening|With(?:Events)?|WriteOnly|Xor)\b/i,operator:/[+\-*/\\^<=>&#@$%!]|\b_(?=[ \t]*[\r\n])/,punctuation:/[{}().,:?]/},t.languages.vb=t.languages["visual-basic"],t.languages.vba=t.languages["visual-basic"]}return nx}var rx,CF;function wEe(){if(CF)return rx;CF=1,rx=e,e.displayName="warpscript",e.aliases=[];function e(t){t.languages.warpscript={comment:/#.*|\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'|<'(?:[^\\']|'(?!>)|\\.)*'>/,greedy:!0},variable:/\$\S+/,macro:{pattern:/@\S+/,alias:"property"},keyword:/\b(?:BREAK|CHECKMACRO|CONTINUE|CUDF|DEFINED|DEFINEDMACRO|EVAL|FAIL|FOR|FOREACH|FORSTEP|IFT|IFTE|MSGFAIL|NRETURN|RETHROW|RETURN|SWITCH|TRY|UDF|UNTIL|WHILE)\b/,number:/[+-]?\b(?:NaN|Infinity|\d+(?:\.\d*)?(?:[Ee][+-]?\d+)?|0x[\da-fA-F]+|0b[01]+)\b/,boolean:/\b(?:F|T|false|true)\b/,punctuation:/<%|%>|[{}[\]()]/,operator:/==|&&?|\|\|?|\*\*?|>>>?|<<|[<>!~]=?|[-/%^]|\+!?|\b(?:AND|NOT|OR)\b/}}return rx}var ax,_F;function xEe(){if(_F)return ax;_F=1,ax=e,e.displayName="wasm",e.aliases=[];function e(t){t.languages.wasm={comment:[/\(;[\s\S]*?;\)/,{pattern:/;;.*/,greedy:!0}],string:{pattern:/"(?:\\[\s\S]|[^"\\])*"/,greedy:!0},keyword:[{pattern:/\b(?:align|offset)=/,inside:{operator:/=/}},{pattern:/\b(?:(?:f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|neg?|nearest|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|sqrt|store(?:8|16|32)?|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))?|memory\.(?:grow|size))\b/,inside:{punctuation:/\./}},/\b(?:anyfunc|block|br(?:_if|_table)?|call(?:_indirect)?|data|drop|elem|else|end|export|func|get_(?:global|local)|global|if|import|local|loop|memory|module|mut|nop|offset|param|result|return|select|set_(?:global|local)|start|table|tee_local|then|type|unreachable)\b/],variable:/\$[\w!#$%&'*+\-./:<=>?@\\^`|~]+/,number:/[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/,punctuation:/[()]/}}return ax}var ox,NF;function kEe(){if(NF)return ox;NF=1,ox=e,e.displayName="webIdl",e.aliases=[];function e(t){(function(n){var r=/(?:\B-|\b_|\b)[A-Za-z][\w-]*(?![\w-])/.source,a="(?:"+/\b(?:unsigned\s+)?long\s+long(?![\w-])/.source+"|"+/\b(?:unrestricted|unsigned)\s+[a-z]+(?![\w-])/.source+"|"+/(?!(?:unrestricted|unsigned)\b)/.source+r+/(?:\s*<(?:[^<>]|<[^<>]*>)*>)?/.source+")"+/(?:\s*\?)?/.source,o={};n.languages["web-idl"]={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/"[^"]*"/,greedy:!0},namespace:{pattern:RegExp(/(\bnamespace\s+)/.source+r),lookbehind:!0},"class-name":[{pattern:/(^|[^\w-])(?:iterable|maplike|setlike)\s*<(?:[^<>]|<[^<>]*>)*>/,lookbehind:!0,inside:o},{pattern:RegExp(/(\b(?:attribute|const|deleter|getter|optional|setter)\s+)/.source+a),lookbehind:!0,inside:o},{pattern:RegExp("("+/\bcallback\s+/.source+r+/\s*=\s*/.source+")"+a),lookbehind:!0,inside:o},{pattern:RegExp(/(\btypedef\b\s*)/.source+a),lookbehind:!0,inside:o},{pattern:RegExp(/(\b(?:callback|dictionary|enum|interface(?:\s+mixin)?)\s+)(?!(?:interface|mixin)\b)/.source+r),lookbehind:!0},{pattern:RegExp(/(:\s*)/.source+r),lookbehind:!0},RegExp(r+/(?=\s+(?:implements|includes)\b)/.source),{pattern:RegExp(/(\b(?:implements|includes)\s+)/.source+r),lookbehind:!0},{pattern:RegExp(a+"(?="+/\s*(?:\.{3}\s*)?/.source+r+/\s*[(),;=]/.source+")"),inside:o}],builtin:/\b(?:ArrayBuffer|BigInt64Array|BigUint64Array|ByteString|DOMString|DataView|Float32Array|Float64Array|FrozenArray|Int16Array|Int32Array|Int8Array|ObservableArray|Promise|USVString|Uint16Array|Uint32Array|Uint8Array|Uint8ClampedArray)\b/,keyword:[/\b(?:async|attribute|callback|const|constructor|deleter|dictionary|enum|getter|implements|includes|inherit|interface|mixin|namespace|null|optional|or|partial|readonly|required|setter|static|stringifier|typedef|unrestricted)\b/,/\b(?:any|bigint|boolean|byte|double|float|iterable|long|maplike|object|octet|record|sequence|setlike|short|symbol|undefined|unsigned|void)\b/],boolean:/\b(?:false|true)\b/,number:{pattern:/(^|[^\w-])-?(?:0x[0-9a-f]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|NaN|Infinity)(?![\w-])/i,lookbehind:!0},operator:/\.{3}|[=:?<>-]/,punctuation:/[(){}[\].,;]/};for(var s in n.languages["web-idl"])s!=="class-name"&&(o[s]=n.languages["web-idl"][s]);n.languages.webidl=n.languages["web-idl"]})(t)}return ox}var ix,OF;function TEe(){if(OF)return ix;OF=1,ix=e,e.displayName="wiki",e.aliases=[];function e(t){t.languages.wiki=t.languages.extend("markup",{"block-comment":{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0,alias:"comment"},heading:{pattern:/^(=+)[^=\r\n].*?\1/m,inside:{punctuation:/^=+|=+$/,important:/.+/}},emphasis:{pattern:/('{2,5}).+?\1/,inside:{"bold-italic":{pattern:/(''''').+?(?=\1)/,lookbehind:!0,alias:["bold","italic"]},bold:{pattern:/(''')[^'](?:.*?[^'])?(?=\1)/,lookbehind:!0},italic:{pattern:/('')[^'](?:.*?[^'])?(?=\1)/,lookbehind:!0},punctuation:/^''+|''+$/}},hr:{pattern:/^-{4,}/m,alias:"punctuation"},url:[/ISBN +(?:97[89][ -]?)?(?:\d[ -]?){9}[\dx]\b|(?:PMID|RFC) +\d+/i,/\[\[.+?\]\]|\[.+?\]/],variable:[/__[A-Z]+__/,/\{{3}.+?\}{3}/,/\{\{.+?\}\}/],symbol:[/^#redirect/im,/~{3,5}/],"table-tag":{pattern:/((?:^|[|!])[|!])[^|\r\n]+\|(?!\|)/m,lookbehind:!0,inside:{"table-bar":{pattern:/\|$/,alias:"punctuation"},rest:t.languages.markup.tag.inside}},punctuation:/^(?:\{\||\|\}|\|-|[*#:;!|])|\|\||!!/m}),t.languages.insertBefore("wiki","tag",{nowiki:{pattern:/<(nowiki|pre|source)\b[^>]*>[\s\S]*?<\/\1>/i,inside:{tag:{pattern:/<(?:nowiki|pre|source)\b[^>]*>|<\/(?:nowiki|pre|source)>/i,inside:t.languages.markup.tag.inside}}}})}return ix}var sx,IF;function AEe(){if(IF)return sx;IF=1,sx=e,e.displayName="wolfram",e.aliases=["mathematica","wl","nb"];function e(t){t.languages.wolfram={comment:/\(\*(?:\(\*(?:[^*]|\*(?!\)))*\*\)|(?!\(\*)[\s\S])*?\*\)/,string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},keyword:/\b(?:Abs|AbsArg|Accuracy|Block|Do|For|Function|If|Manipulate|Module|Nest|NestList|None|Return|Switch|Table|Which|While)\b/,context:{pattern:/\b\w+`+\w*/,alias:"class-name"},blank:{pattern:/\b\w+_\b/,alias:"regex"},"global-variable":{pattern:/\$\w+/,alias:"variable"},boolean:/\b(?:False|True)\b/,number:/(?:\b(?=\d)|\B(?=\.))(?:0[bo])?(?:(?:\d|0x[\da-f])[\da-f]*(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?j?\b/i,operator:/\/\.|;|=\.|\^=|\^:=|:=|<<|>>|<\||\|>|:>|\|->|->|<-|@@@|@@|@|\/@|=!=|===|==|=|\+|-|\^|\[\/-+%=\]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,punctuation:/[{}[\];(),.:]/},t.languages.mathematica=t.languages.wolfram,t.languages.wl=t.languages.wolfram,t.languages.nb=t.languages.wolfram}return sx}var lx,DF;function REe(){if(DF)return lx;DF=1,lx=e,e.displayName="wren",e.aliases=[];function e(t){t.languages.wren={comment:[{pattern:/\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*))*\*\/)*\*\/)*\*\//,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],"triple-quoted-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},"string-literal":null,hashbang:{pattern:/^#!\/.+/,greedy:!0,alias:"comment"},attribute:{pattern:/#!?[ \t\u3000]*\w+/,alias:"keyword"},"class-name":[{pattern:/(\bclass\s+)\w+/,lookbehind:!0},/\b[A-Z][a-z\d_]*\b/],constant:/\b[A-Z][A-Z\d_]*\b/,null:{pattern:/\bnull\b/,alias:"keyword"},keyword:/\b(?:as|break|class|construct|continue|else|for|foreign|if|import|in|is|return|static|super|this|var|while)\b/,boolean:/\b(?:false|true)\b/,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,function:/\b[a-z_]\w*(?=\s*[({])/i,operator:/<<|>>|[=!<>]=?|&&|\|\||[-+*/%~^&|?:]|\.{2,3}/,punctuation:/[\[\](){}.,;]/},t.languages.wren["string-literal"]={pattern:/(^|[^\\"])"(?:[^\\"%]|\\[\s\S]|%(?!\()|%\((?:[^()]|\((?:[^()]|\([^)]*\))*\))*\))*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)%\((?:[^()]|\((?:[^()]|\([^)]*\))*\))*\)/,lookbehind:!0,inside:{expression:{pattern:/^(%\()[\s\S]+(?=\)$)/,lookbehind:!0,inside:t.languages.wren},"interpolation-punctuation":{pattern:/^%\(|\)$/,alias:"punctuation"}}},string:/[\s\S]+/}}}return lx}var cx,LF;function CEe(){if(LF)return cx;LF=1,cx=e,e.displayName="xeora",e.aliases=["xeoracube"];function e(t){(function(n){n.languages.xeora=n.languages.extend("markup",{constant:{pattern:/\$(?:DomainContents|PageRenderDuration)\$/,inside:{punctuation:{pattern:/\$/}}},variable:{pattern:/\$@?(?:#+|[-+*~=^])?[\w.]+\$/,inside:{punctuation:{pattern:/[$.]/},operator:{pattern:/#+|[-+*~=^@]/}}},"function-inline":{pattern:/\$F:[-\w.]+\?[-\w.]+(?:,(?:(?:@[-#]*\w+\.[\w+.]\.*)*\|)*(?:(?:[\w+]|[-#*.~^]+[\w+]|=\S)(?:[^$=]|=+[^=])*=*|(?:@[-#]*\w+\.[\w+.]\.*)+(?:(?:[\w+]|[-#*~^][-#*.~^]*[\w+]|=\S)(?:[^$=]|=+[^=])*=*)?)?)?\$/,inside:{variable:{pattern:/(?:[,|])@?(?:#+|[-+*~=^])?[\w.]+/,inside:{punctuation:{pattern:/[,.|]/},operator:{pattern:/#+|[-+*~=^@]/}}},punctuation:{pattern:/\$\w:|[$:?.,|]/}},alias:"function"},"function-block":{pattern:/\$XF:\{[-\w.]+\?[-\w.]+(?:,(?:(?:@[-#]*\w+\.[\w+.]\.*)*\|)*(?:(?:[\w+]|[-#*.~^]+[\w+]|=\S)(?:[^$=]|=+[^=])*=*|(?:@[-#]*\w+\.[\w+.]\.*)+(?:(?:[\w+]|[-#*~^][-#*.~^]*[\w+]|=\S)(?:[^$=]|=+[^=])*=*)?)?)?\}:XF\$/,inside:{punctuation:{pattern:/[$:{}?.,|]/}},alias:"function"},"directive-inline":{pattern:/\$\w(?:#\d+\+?)?(?:\[[-\w.]+\])?:[-\/\w.]+\$/,inside:{punctuation:{pattern:/\$(?:\w:|C(?:\[|#\d))?|[:{[\]]/,inside:{tag:{pattern:/#\d/}}}},alias:"function"},"directive-block-open":{pattern:/\$\w+:\{|\$\w(?:#\d+\+?)?(?:\[[-\w.]+\])?:[-\w.]+:\{(?:![A-Z]+)?/,inside:{punctuation:{pattern:/\$(?:\w:|C(?:\[|#\d))?|[:{[\]]/,inside:{tag:{pattern:/#\d/}}},attribute:{pattern:/![A-Z]+$/,inside:{punctuation:{pattern:/!/}},alias:"keyword"}},alias:"function"},"directive-block-separator":{pattern:/\}:[-\w.]+:\{/,inside:{punctuation:{pattern:/[:{}]/}},alias:"function"},"directive-block-close":{pattern:/\}:[-\w.]+\$/,inside:{punctuation:{pattern:/[:{}$]/}},alias:"function"}}),n.languages.insertBefore("inside","punctuation",{variable:n.languages.xeora["function-inline"].inside.variable},n.languages.xeora["function-block"]),n.languages.xeoracube=n.languages.xeora})(t)}return cx}var ux,MF;function _Ee(){if(MF)return ux;MF=1,ux=e,e.displayName="xmlDoc",e.aliases=[];function e(t){(function(n){function r(l,u){n.languages[l]&&n.languages.insertBefore(l,"comment",{"doc-comment":u})}var a=n.languages.markup.tag,o={pattern:/\/\/\/.*/,greedy:!0,alias:"comment",inside:{tag:a}},s={pattern:/'''.*/,greedy:!0,alias:"comment",inside:{tag:a}};r("csharp",o),r("fsharp",o),r("vbnet",s)})(t)}return ux}var dx,PF;function NEe(){if(PF)return dx;PF=1,dx=e,e.displayName="xojo",e.aliases=[];function e(t){t.languages.xojo={comment:{pattern:/(?:'|\/\/|Rem\b).+/i,greedy:!0},string:{pattern:/"(?:""|[^"])*"/,greedy:!0},number:[/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,/&[bchou][a-z\d]+/i],directive:{pattern:/#(?:Else|ElseIf|Endif|If|Pragma)\b/i,alias:"property"},keyword:/\b(?:AddHandler|App|Array|As(?:signs)?|Auto|Boolean|Break|By(?:Ref|Val)|Byte|Call|Case|Catch|CFStringRef|CGFloat|Class|Color|Const|Continue|CString|Currency|CurrentMethodName|Declare|Delegate|Dim|Do(?:uble|wnTo)?|Each|Else(?:If)?|End|Enumeration|Event|Exception|Exit|Extends|False|Finally|For|Function|Get|GetTypeInfo|Global|GOTO|If|Implements|In|Inherits|Int(?:8|16|32|64|eger|erface)?|Lib|Loop|Me|Module|Next|Nil|Object|Optional|OSType|ParamArray|Private|Property|Protected|PString|Ptr|Raise(?:Event)?|ReDim|RemoveHandler|Return|Select(?:or)?|Self|Set|Shared|Short|Single|Soft|Static|Step|String|Sub|Super|Text|Then|To|True|Try|Ubound|UInt(?:8|16|32|64|eger)?|Until|Using|Var(?:iant)?|Wend|While|WindowPtr|WString)\b/i,operator:/<[=>]?|>=?|[+\-*\/\\^=]|\b(?:AddressOf|And|Ctype|IsA?|Mod|New|Not|Or|WeakAddressOf|Xor)\b/i,punctuation:/[.,;:()]/}}return dx}var fx,FF;function OEe(){if(FF)return fx;FF=1,fx=e,e.displayName="xquery",e.aliases=[];function e(t){(function(n){n.languages.xquery=n.languages.extend("markup",{"xquery-comment":{pattern:/\(:[\s\S]*?:\)/,greedy:!0,alias:"comment"},string:{pattern:/(["'])(?:\1\1|(?!\1)[\s\S])*\1/,greedy:!0},extension:{pattern:/\(#.+?#\)/,alias:"symbol"},variable:/\$[-\w:]+/,axis:{pattern:/(^|[^-])(?:ancestor(?:-or-self)?|attribute|child|descendant(?:-or-self)?|following(?:-sibling)?|parent|preceding(?:-sibling)?|self)(?=::)/,lookbehind:!0,alias:"operator"},"keyword-operator":{pattern:/(^|[^:-])\b(?:and|castable as|div|eq|except|ge|gt|idiv|instance of|intersect|is|le|lt|mod|ne|or|union)\b(?=$|[^:-])/,lookbehind:!0,alias:"operator"},keyword:{pattern:/(^|[^:-])\b(?:as|ascending|at|base-uri|boundary-space|case|cast as|collation|construction|copy-namespaces|declare|default|descending|else|empty (?:greatest|least)|encoding|every|external|for|function|if|import|in|inherit|lax|let|map|module|namespace|no-inherit|no-preserve|option|order(?: by|ed|ing)?|preserve|return|satisfies|schema|some|stable|strict|strip|then|to|treat as|typeswitch|unordered|validate|variable|version|where|xquery)\b(?=$|[^:-])/,lookbehind:!0},function:/[\w-]+(?::[\w-]+)*(?=\s*\()/,"xquery-element":{pattern:/(element\s+)[\w-]+(?::[\w-]+)*/,lookbehind:!0,alias:"tag"},"xquery-attribute":{pattern:/(attribute\s+)[\w-]+(?::[\w-]+)*/,lookbehind:!0,alias:"attr-name"},builtin:{pattern:/(^|[^:-])\b(?:attribute|comment|document|element|processing-instruction|text|xs:(?:ENTITIES|ENTITY|ID|IDREFS?|NCName|NMTOKENS?|NOTATION|Name|QName|anyAtomicType|anyType|anyURI|base64Binary|boolean|byte|date|dateTime|dayTimeDuration|decimal|double|duration|float|gDay|gMonth|gMonthDay|gYear|gYearMonth|hexBinary|int|integer|language|long|negativeInteger|nonNegativeInteger|nonPositiveInteger|normalizedString|positiveInteger|short|string|time|token|unsigned(?:Byte|Int|Long|Short)|untyped(?:Atomic)?|yearMonthDuration))\b(?=$|[^:-])/,lookbehind:!0},number:/\b\d+(?:\.\d+)?(?:E[+-]?\d+)?/,operator:[/[+*=?|@]|\.\.?|:=|!=|<[=<]?|>[=>]?/,{pattern:/(\s)-(?=\s)/,lookbehind:!0}],punctuation:/[[\](){},;:/]/}),n.languages.xquery.tag.pattern=/<\/?(?!\d)[^\s>\/=$<%]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/,n.languages.xquery.tag.inside["attr-value"].pattern=/=(?:("|')(?:\\[\s\S]|\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}|(?!\1)[^\\])*\1|[^\s'">=]+)/,n.languages.xquery.tag.inside["attr-value"].inside.punctuation=/^="|"$/,n.languages.xquery.tag.inside["attr-value"].inside.expression={pattern:/\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}/,inside:n.languages.xquery,alias:"language-xquery"};var r=function(o){return typeof o=="string"?o:typeof o.content=="string"?o.content:o.content.map(r).join("")},a=function(o){for(var s=[],l=0;l<o.length;l++){var u=o[l],d=!1;if(typeof u!="string"&&(u.type==="tag"&&u.content[0]&&u.content[0].type==="tag"?u.content[0].content[0].content==="</"?s.length>0&&s[s.length-1].tagName===r(u.content[0].content[1])&&s.pop():u.content[u.content.length-1].content==="/>"||s.push({tagName:r(u.content[0].content[1]),openedBraces:0}):s.length>0&&u.type==="punctuation"&&u.content==="{"&&(!o[l+1]||o[l+1].type!=="punctuation"||o[l+1].content!=="{")&&(!o[l-1]||o[l-1].type!=="plain-text"||o[l-1].content!=="{")?s[s.length-1].openedBraces++:s.length>0&&s[s.length-1].openedBraces>0&&u.type==="punctuation"&&u.content==="}"?s[s.length-1].openedBraces--:u.type!=="comment"&&(d=!0)),(d||typeof u=="string")&&s.length>0&&s[s.length-1].openedBraces===0){var p=r(u);l<o.length-1&&(typeof o[l+1]=="string"||o[l+1].type==="plain-text")&&(p+=r(o[l+1]),o.splice(l+1,1)),l>0&&(typeof o[l-1]=="string"||o[l-1].type==="plain-text")&&(p=r(o[l-1])+p,o.splice(l-1,1),l--),/^\s+$/.test(p)?o[l]=p:o[l]=new n.Token("plain-text",p,null,p)}u.content&&typeof u.content!="string"&&a(u.content)}};n.hooks.add("after-tokenize",function(o){o.language==="xquery"&&a(o.tokens)})})(t)}return fx}var px,zF;function IEe(){if(zF)return px;zF=1,px=e,e.displayName="yang",e.aliases=[];function e(t){t.languages.yang={comment:/\/\*[\s\S]*?\*\/|\/\/.*/,string:{pattern:/"(?:[^\\"]|\\.)*"|'[^']*'/,greedy:!0},keyword:{pattern:/(^|[{};\r\n][ \t]*)[a-z_][\w.-]*/i,lookbehind:!0},namespace:{pattern:/(\s)[a-z_][\w.-]*(?=:)/i,lookbehind:!0},boolean:/\b(?:false|true)\b/,operator:/\+/,punctuation:/[{};:]/}}return px}var gx,BF;function DEe(){if(BF)return gx;BF=1,gx=e,e.displayName="zig",e.aliases=[];function e(t){(function(n){function r(p){return function(){return p}}var a=/\b(?:align|allowzero|and|anyframe|anytype|asm|async|await|break|cancel|catch|comptime|const|continue|defer|else|enum|errdefer|error|export|extern|fn|for|if|inline|linksection|nakedcc|noalias|nosuspend|null|or|orelse|packed|promise|pub|resume|return|stdcallcc|struct|suspend|switch|test|threadlocal|try|undefined|union|unreachable|usingnamespace|var|volatile|while)\b/,o="\\b(?!"+a.source+")(?!\\d)\\w+\\b",s=/align\s*\((?:[^()]|\([^()]*\))*\)/.source,l=/(?:\?|\bpromise->|(?:\[[^[\]]*\]|\*(?!\*)|\*\*)(?:\s*<ALIGN>|\s*const\b|\s*volatile\b|\s*allowzero\b)*)/.source.replace(/<ALIGN>/g,r(s)),u=/(?:\bpromise\b|(?:\berror\.)?<ID>(?:\.<ID>)*(?!\s+<ID>))/.source.replace(/<ID>/g,r(o)),d="(?!\\s)(?:!?\\s*(?:"+l+"\\s*)*"+u+")+";n.languages.zig={comment:[{pattern:/\/\/[/!].*/,alias:"doc-comment"},/\/{2}.*/],string:[{pattern:/(^|[^\\@])c?"(?:[^"\\\r\n]|\\.)*"/,lookbehind:!0,greedy:!0},{pattern:/([\r\n])([ \t]+c?\\{2}).*(?:(?:\r\n?|\n)\2.*)*/,lookbehind:!0,greedy:!0}],char:{pattern:/(^|[^\\])'(?:[^'\\\r\n]|[\uD800-\uDFFF]{2}|\\(?:.|x[a-fA-F\d]{2}|u\{[a-fA-F\d]{1,6}\}))'/,lookbehind:!0,greedy:!0},builtin:/\B@(?!\d)\w+(?=\s*\()/,label:{pattern:/(\b(?:break|continue)\s*:\s*)\w+\b|\b(?!\d)\w+\b(?=\s*:\s*(?:\{|while\b))/,lookbehind:!0},"class-name":[/\b(?!\d)\w+(?=\s*=\s*(?:(?:extern|packed)\s+)?(?:enum|struct|union)\s*[({])/,{pattern:RegExp(/(:\s*)<TYPE>(?=\s*(?:<ALIGN>\s*)?[=;,)])|<TYPE>(?=\s*(?:<ALIGN>\s*)?\{)/.source.replace(/<TYPE>/g,r(d)).replace(/<ALIGN>/g,r(s))),lookbehind:!0,inside:null},{pattern:RegExp(/(\)\s*)<TYPE>(?=\s*(?:<ALIGN>\s*)?;)/.source.replace(/<TYPE>/g,r(d)).replace(/<ALIGN>/g,r(s))),lookbehind:!0,inside:null}],"builtin-type":{pattern:/\b(?:anyerror|bool|c_u?(?:int|long|longlong|short)|c_longdouble|c_void|comptime_(?:float|int)|f(?:16|32|64|128)|[iu](?:8|16|32|64|128|size)|noreturn|type|void)\b/,alias:"keyword"},keyword:a,function:/\b(?!\d)\w+(?=\s*\()/,number:/\b(?:0b[01]+|0o[0-7]+|0x[a-fA-F\d]+(?:\.[a-fA-F\d]*)?(?:[pP][+-]?[a-fA-F\d]+)?|\d+(?:\.\d*)?(?:[eE][+-]?\d+)?)\b/,boolean:/\b(?:false|true)\b/,operator:/\.[*?]|\.{2,3}|[-=]>|\*\*|\+\+|\|\||(?:<<|>>|[-+*]%|[-+*/%^&|<>!=])=?|[?~]/,punctuation:/[.:,;(){}[\]]/},n.languages.zig["class-name"].forEach(function(p){p.inside===null&&(p.inside=n.languages.zig)})})(t)}return gx}var hx,jF;function LEe(){if(jF)return hx;jF=1;var e=Xme();return hx=e,e.register(Qme()),e.register(Jme()),e.register(ebe()),e.register(tbe()),e.register(nbe()),e.register(rbe()),e.register(abe()),e.register(obe()),e.register(ibe()),e.register(sbe()),e.register(lbe()),e.register(cbe()),e.register(ube()),e.register(dbe()),e.register(fbe()),e.register(pbe()),e.register(gbe()),e.register(hbe()),e.register(mbe()),e.register(bbe()),e.register(ybe()),e.register(vbe()),e.register(jH()),e.register(UH()),e.register(Sbe()),e.register(Ebe()),e.register(wbe()),e.register(xbe()),e.register(kbe()),e.register(Tbe()),e.register(Abe()),e.register(Rbe()),e.register(Cbe()),e.register(_be()),e.register(Ci()),e.register(Nbe()),e.register(Obe()),e.register(Ibe()),e.register(Dbe()),e.register(Lbe()),e.register(Mbe()),e.register(Pbe()),e.register(Fbe()),e.register(zbe()),e.register(vA()),e.register(Bbe()),e.register(zp()),e.register(jbe()),e.register(Ube()),e.register(Gbe()),e.register(Hbe()),e.register($be()),e.register(qbe()),e.register(Vbe()),e.register(Wbe()),e.register(Ybe()),e.register(Kbe()),e.register(Xbe()),e.register(Zbe()),e.register(Qbe()),e.register(Jbe()),e.register(eye()),e.register(tye()),e.register(nye()),e.register(rye()),e.register(aye()),e.register(oye()),e.register(iye()),e.register(sye()),e.register(lye()),e.register(cye()),e.register(uye()),e.register(dye()),e.register(fye()),e.register(pye()),e.register(gye()),e.register(hye()),e.register(mye()),e.register(bye()),e.register(yye()),e.register(vye()),e.register(Sye()),e.register(Eye()),e.register(wye()),e.register(xye()),e.register(kye()),e.register(Tye()),e.register(Aye()),e.register(Rye()),e.register(Cye()),e.register(_ye()),e.register(Nye()),e.register(Oye()),e.register(Iye()),e.register(SA()),e.register(Dye()),e.register(Lye()),e.register(Mye()),e.register(Pye()),e.register(Fye()),e.register(zye()),e.register(Bye()),e.register(jye()),e.register(Uye()),e.register(Gye()),e.register(Hye()),e.register($ye()),e.register(qye()),e.register(Vye()),e.register(Wye()),e.register(Yye()),e.register(Kye()),e.register(EA()),e.register(Xye()),e.register(jp()),e.register(Zye()),e.register(Qye()),e.register(Jye()),e.register(eve()),e.register(tve()),e.register(nve()),e.register(rve()),e.register(xA()),e.register(ave()),e.register(ove()),e.register(ive()),e.register(HH()),e.register(sve()),e.register(lve()),e.register(cve()),e.register(uve()),e.register(dve()),e.register(fve()),e.register(pve()),e.register(gve()),e.register(hve()),e.register(mve()),e.register(bve()),e.register(yve()),e.register(vve()),e.register(Sve()),e.register(Eve()),e.register(wve()),e.register(GH()),e.register(xve()),e.register(kve()),e.register(Tve()),e.register(Wn()),e.register(Ave()),e.register(Rve()),e.register(Cve()),e.register(_ve()),e.register(Nve()),e.register(Ove()),e.register(Ive()),e.register(Dve()),e.register(Lve()),e.register(Mve()),e.register(Pve()),e.register(Fve()),e.register(zve()),e.register(Bve()),e.register(jve()),e.register(Uve()),e.register(Gve()),e.register(Hve()),e.register($ve()),e.register(qve()),e.register(Vve()),e.register(Wve()),e.register(Yve()),e.register(Kve()),e.register(Xve()),e.register(Zve()),e.register(Qve()),e.register(Jve()),e.register(eSe()),e.register(tSe()),e.register(nSe()),e.register(rSe()),e.register(Up()),e.register(aSe()),e.register(oSe()),e.register(iSe()),e.register(sSe()),e.register(lSe()),e.register(cSe()),e.register(uSe()),e.register(dSe()),e.register(fSe()),e.register(pSe()),e.register(gSe()),e.register(hSe()),e.register(mSe()),e.register(bSe()),e.register(ySe()),e.register(vSe()),e.register(SSe()),e.register(ESe()),e.register(wSe()),e.register(xSe()),e.register(kSe()),e.register(TSe()),e.register(ASe()),e.register(RSe()),e.register(CSe()),e.register(_Se()),e.register(NSe()),e.register(OSe()),e.register(ISe()),e.register(DSe()),e.register(Bp()),e.register(LSe()),e.register(MSe()),e.register(PSe()),e.register(FSe()),e.register(kA()),e.register(zSe()),e.register(BSe()),e.register(jSe()),e.register(USe()),e.register(GSe()),e.register(HSe()),e.register($Se()),e.register(qSe()),e.register(VSe()),e.register(WSe()),e.register(YSe()),e.register(KSe()),e.register(yA()),e.register(XSe()),e.register(ZSe()),e.register(QSe()),e.register(JSe()),e.register(eEe()),e.register(tEe()),e.register(TA()),e.register(nEe()),e.register(rEe()),e.register(aEe()),e.register(oEe()),e.register(iEe()),e.register(sEe()),e.register(lEe()),e.register(cEe()),e.register($H()),e.register(uEe()),e.register(wA()),e.register(dEe()),e.register(fEe()),e.register(pEe()),e.register(gEe()),e.register(hEe()),e.register(mEe()),e.register(qH()),e.register(bEe()),e.register(yEe()),e.register(vEe()),e.register(SEe()),e.register(EEe()),e.register(wEe()),e.register(xEe()),e.register(kEe()),e.register(TEe()),e.register(AEe()),e.register(REe()),e.register(CEe()),e.register(_Ee()),e.register(NEe()),e.register(OEe()),e.register(VH()),e.register(IEe()),e.register(DEe()),hx}var MEe=LEe();const PEe=un(MEe);var WH=wge(PEe,Zme);WH.supportedLanguages=xge;var mx={},bx={exports:{}},UF;function FEe(){return UF||(UF=1,function(e){function t(n){return n&&n.__esModule?n:{default:n}}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports}(bx)),bx.exports}var yx={},GF;function zEe(){return GF||(GF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",maxHeight:"inherit",height:"inherit",padding:"0 1em",display:"block",overflow:"auto"},'pre[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",position:"relative",margin:".5em 0",overflow:"visible",padding:"1px",backgroundColor:"#fdfdfd",WebkitBoxSizing:"border-box",MozBoxSizing:"border-box",boxSizing:"border-box",marginBottom:"1em"},'pre[class*="language-"] > code':{position:"relative",zIndex:"1",borderLeft:"10px solid #358ccb",boxShadow:"-1px 0px 0px 0px #358ccb, 0px 0px 0px 1px #dfdfdf",backgroundColor:"#fdfdfd",backgroundImage:"linear-gradient(transparent 50%, rgba(69, 142, 209, 0.04) 50%)",backgroundSize:"3em 3em",backgroundOrigin:"content-box",backgroundAttachment:"local"},':not(pre) > code[class*="language-"]':{backgroundColor:"#fdfdfd",WebkitBoxSizing:"border-box",MozBoxSizing:"border-box",boxSizing:"border-box",marginBottom:"1em",position:"relative",padding:".2em",borderRadius:"0.3em",color:"#c92c2c",border:"1px solid rgba(0, 0, 0, 0.1)",display:"inline",whiteSpace:"normal"},'pre[class*="language-"]:before':{content:"''",display:"block",position:"absolute",bottom:"0.75em",left:"0.18em",width:"40%",height:"20%",maxHeight:"13em",boxShadow:"0px 13px 8px #979797",WebkitTransform:"rotate(-2deg)",MozTransform:"rotate(-2deg)",msTransform:"rotate(-2deg)",OTransform:"rotate(-2deg)",transform:"rotate(-2deg)"},'pre[class*="language-"]:after':{content:"''",display:"block",position:"absolute",bottom:"0.75em",left:"auto",width:"40%",height:"20%",maxHeight:"13em",boxShadow:"0px 13px 8px #979797",WebkitTransform:"rotate(2deg)",MozTransform:"rotate(2deg)",msTransform:"rotate(2deg)",OTransform:"rotate(2deg)",transform:"rotate(2deg)",right:"0.75em"},comment:{color:"#7D8B99"},"block-comment":{color:"#7D8B99"},prolog:{color:"#7D8B99"},doctype:{color:"#7D8B99"},cdata:{color:"#7D8B99"},punctuation:{color:"#5F6364"},property:{color:"#c92c2c"},tag:{color:"#c92c2c"},boolean:{color:"#c92c2c"},number:{color:"#c92c2c"},"function-name":{color:"#c92c2c"},constant:{color:"#c92c2c"},symbol:{color:"#c92c2c"},deleted:{color:"#c92c2c"},selector:{color:"#2f9c0a"},"attr-name":{color:"#2f9c0a"},string:{color:"#2f9c0a"},char:{color:"#2f9c0a"},function:{color:"#2f9c0a"},builtin:{color:"#2f9c0a"},inserted:{color:"#2f9c0a"},operator:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},entity:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)",cursor:"help"},url:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},variable:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},atrule:{color:"#1990b8"},"attr-value":{color:"#1990b8"},keyword:{color:"#1990b8"},"class-name":{color:"#1990b8"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"normal"},".language-css .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},".style .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:".7"},'pre[class*="language-"].line-numbers.line-numbers':{paddingLeft:"0"},'pre[class*="language-"].line-numbers.line-numbers code':{paddingLeft:"3.8em"},'pre[class*="language-"].line-numbers.line-numbers .line-numbers-rows':{left:"0"},'pre[class*="language-"][data-line]':{paddingTop:"0",paddingBottom:"0",paddingLeft:"0"},"pre[data-line] code":{position:"relative",paddingLeft:"4em"},"pre .line-highlight":{marginTop:"0"}}}(yx)),yx}var vx={},HF;function BEe(){return HF||(HF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"white",background:"none",textShadow:"0 -.1em .2em black",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"white",background:"hsl(30, 20%, 25%)",textShadow:"0 -.1em .2em black",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",border:".3em solid hsl(30, 20%, 40%)",borderRadius:".5em",boxShadow:"1px 1px .5em black inset"},':not(pre) > code[class*="language-"]':{background:"hsl(30, 20%, 25%)",padding:".15em .2em .05em",borderRadius:".3em",border:".13em solid hsl(30, 20%, 40%)",boxShadow:"1px 1px .3em -.1em black inset",whiteSpace:"normal"},comment:{color:"hsl(30, 20%, 50%)"},prolog:{color:"hsl(30, 20%, 50%)"},doctype:{color:"hsl(30, 20%, 50%)"},cdata:{color:"hsl(30, 20%, 50%)"},punctuation:{Opacity:".7"},namespace:{Opacity:".7"},property:{color:"hsl(350, 40%, 70%)"},tag:{color:"hsl(350, 40%, 70%)"},boolean:{color:"hsl(350, 40%, 70%)"},number:{color:"hsl(350, 40%, 70%)"},constant:{color:"hsl(350, 40%, 70%)"},symbol:{color:"hsl(350, 40%, 70%)"},selector:{color:"hsl(75, 70%, 60%)"},"attr-name":{color:"hsl(75, 70%, 60%)"},string:{color:"hsl(75, 70%, 60%)"},char:{color:"hsl(75, 70%, 60%)"},builtin:{color:"hsl(75, 70%, 60%)"},inserted:{color:"hsl(75, 70%, 60%)"},operator:{color:"hsl(40, 90%, 60%)"},entity:{color:"hsl(40, 90%, 60%)",cursor:"help"},url:{color:"hsl(40, 90%, 60%)"},".language-css .token.string":{color:"hsl(40, 90%, 60%)"},".style .token.string":{color:"hsl(40, 90%, 60%)"},variable:{color:"hsl(40, 90%, 60%)"},atrule:{color:"hsl(350, 40%, 70%)"},"attr-value":{color:"hsl(350, 40%, 70%)"},keyword:{color:"hsl(350, 40%, 70%)"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},deleted:{color:"red"}}}(vx)),vx}var Sx={},$F;function jEe(){return $F||($F=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"black",color:"white",boxShadow:"-.3em 0 0 .3em black, .3em 0 0 .3em black"},'pre[class*="language-"]':{fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:".4em .8em",margin:".5em 0",overflow:"auto",background:`url('data:image/svg+xml;charset=utf-8,<svg%20version%3D"1.1"%20xmlns%3D"http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg"%20width%3D"100"%20height%3D"100"%20fill%3D"rgba(0%2C0%2C0%2C.2)">%0D%0A<polygon%20points%3D"0%2C50%2050%2C0%200%2C0"%20%2F>%0D%0A<polygon%20points%3D"0%2C100%2050%2C100%20100%2C50%20100%2C0"%20%2F>%0D%0A<%2Fsvg>')`,backgroundSize:"1em 1em"},':not(pre) > code[class*="language-"]':{padding:".2em",borderRadius:".3em",boxShadow:"none",whiteSpace:"normal"},comment:{color:"#aaa"},prolog:{color:"#aaa"},doctype:{color:"#aaa"},cdata:{color:"#aaa"},punctuation:{color:"#999"},namespace:{Opacity:".7"},property:{color:"#0cf"},tag:{color:"#0cf"},boolean:{color:"#0cf"},number:{color:"#0cf"},constant:{color:"#0cf"},symbol:{color:"#0cf"},selector:{color:"yellow"},"attr-name":{color:"yellow"},string:{color:"yellow"},char:{color:"yellow"},builtin:{color:"yellow"},operator:{color:"yellowgreen"},entity:{color:"yellowgreen",cursor:"help"},url:{color:"yellowgreen"},".language-css .token.string":{color:"yellowgreen"},variable:{color:"yellowgreen"},inserted:{color:"yellowgreen"},atrule:{color:"deeppink"},"attr-value":{color:"deeppink"},keyword:{color:"deeppink"},regex:{color:"orange"},important:{color:"orange",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},deleted:{color:"red"},"pre.diff-highlight.diff-highlight > code .token.deleted:not(.prefix)":{backgroundColor:"rgba(255, 0, 0, .3)",display:"inline"},"pre > code.diff-highlight.diff-highlight .token.deleted:not(.prefix)":{backgroundColor:"rgba(255, 0, 0, .3)",display:"inline"},"pre.diff-highlight.diff-highlight > code .token.inserted:not(.prefix)":{backgroundColor:"rgba(0, 255, 128, .3)",display:"inline"},"pre > code.diff-highlight.diff-highlight .token.inserted:not(.prefix)":{backgroundColor:"rgba(0, 255, 128, .3)",display:"inline"}}}(Sx)),Sx}var Ex={},qF;function UEe(){return qF||(qF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#272822",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#272822",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#8292a2"},prolog:{color:"#8292a2"},doctype:{color:"#8292a2"},cdata:{color:"#8292a2"},punctuation:{color:"#f8f8f2"},namespace:{Opacity:".7"},property:{color:"#f92672"},tag:{color:"#f92672"},constant:{color:"#f92672"},symbol:{color:"#f92672"},deleted:{color:"#f92672"},boolean:{color:"#ae81ff"},number:{color:"#ae81ff"},selector:{color:"#a6e22e"},"attr-name":{color:"#a6e22e"},string:{color:"#a6e22e"},char:{color:"#a6e22e"},builtin:{color:"#a6e22e"},inserted:{color:"#a6e22e"},operator:{color:"#f8f8f2"},entity:{color:"#f8f8f2",cursor:"help"},url:{color:"#f8f8f2"},".language-css .token.string":{color:"#f8f8f2"},".style .token.string":{color:"#f8f8f2"},variable:{color:"#f8f8f2"},atrule:{color:"#e6db74"},"attr-value":{color:"#e6db74"},function:{color:"#e6db74"},"class-name":{color:"#e6db74"},keyword:{color:"#66d9ef"},regex:{color:"#fd971f"},important:{color:"#fd971f",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Ex)),Ex}var wx={},VF;function GEe(){return VF||(VF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#657b83",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#657b83",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em",backgroundColor:"#fdf6e3"},'pre[class*="language-"]::-moz-selection':{background:"#073642"},'pre[class*="language-"] ::-moz-selection':{background:"#073642"},'code[class*="language-"]::-moz-selection':{background:"#073642"},'code[class*="language-"] ::-moz-selection':{background:"#073642"},'pre[class*="language-"]::selection':{background:"#073642"},'pre[class*="language-"] ::selection':{background:"#073642"},'code[class*="language-"]::selection':{background:"#073642"},'code[class*="language-"] ::selection':{background:"#073642"},':not(pre) > code[class*="language-"]':{backgroundColor:"#fdf6e3",padding:".1em",borderRadius:".3em"},comment:{color:"#93a1a1"},prolog:{color:"#93a1a1"},doctype:{color:"#93a1a1"},cdata:{color:"#93a1a1"},punctuation:{color:"#586e75"},namespace:{Opacity:".7"},property:{color:"#268bd2"},tag:{color:"#268bd2"},boolean:{color:"#268bd2"},number:{color:"#268bd2"},constant:{color:"#268bd2"},symbol:{color:"#268bd2"},deleted:{color:"#268bd2"},selector:{color:"#2aa198"},"attr-name":{color:"#2aa198"},string:{color:"#2aa198"},char:{color:"#2aa198"},builtin:{color:"#2aa198"},url:{color:"#2aa198"},inserted:{color:"#2aa198"},entity:{color:"#657b83",background:"#eee8d5",cursor:"help"},atrule:{color:"#859900"},"attr-value":{color:"#859900"},keyword:{color:"#859900"},function:{color:"#b58900"},"class-name":{color:"#b58900"},regex:{color:"#cb4b16"},important:{color:"#cb4b16",fontWeight:"bold"},variable:{color:"#cb4b16"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(wx)),wx}var xx={},WF;function HEe(){return WF||(WF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#ccc",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#ccc",background:"#2d2d2d",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto"},':not(pre) > code[class*="language-"]':{background:"#2d2d2d",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#999"},"block-comment":{color:"#999"},prolog:{color:"#999"},doctype:{color:"#999"},cdata:{color:"#999"},punctuation:{color:"#ccc"},tag:{color:"#e2777a"},"attr-name":{color:"#e2777a"},namespace:{color:"#e2777a"},deleted:{color:"#e2777a"},"function-name":{color:"#6196cc"},boolean:{color:"#f08d49"},number:{color:"#f08d49"},function:{color:"#f08d49"},property:{color:"#f8c555"},"class-name":{color:"#f8c555"},constant:{color:"#f8c555"},symbol:{color:"#f8c555"},selector:{color:"#cc99cd"},important:{color:"#cc99cd",fontWeight:"bold"},atrule:{color:"#cc99cd"},keyword:{color:"#cc99cd"},builtin:{color:"#cc99cd"},string:{color:"#7ec699"},char:{color:"#7ec699"},"attr-value":{color:"#7ec699"},regex:{color:"#7ec699"},variable:{color:"#7ec699"},operator:{color:"#67cdcc"},entity:{color:"#67cdcc",cursor:"help"},url:{color:"#67cdcc"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{color:"green"}}}(xx)),xx}var kx={},YF;function $Ee(){return YF||(YF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"white",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",textShadow:"0 -.1em .2em black",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"white",background:"hsl(0, 0%, 8%)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",textShadow:"0 -.1em .2em black",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",borderRadius:".5em",border:".3em solid hsl(0, 0%, 33%)",boxShadow:"1px 1px .5em black inset",margin:".5em 0",overflow:"auto",padding:"1em"},':not(pre) > code[class*="language-"]':{background:"hsl(0, 0%, 8%)",borderRadius:".3em",border:".13em solid hsl(0, 0%, 33%)",boxShadow:"1px 1px .3em -.1em black inset",padding:".15em .2em .05em",whiteSpace:"normal"},'pre[class*="language-"]::-moz-selection':{background:"hsla(0, 0%, 93%, 0.15)",textShadow:"none"},'pre[class*="language-"]::selection':{background:"hsla(0, 0%, 93%, 0.15)",textShadow:"none"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"]::selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"] ::selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},comment:{color:"hsl(0, 0%, 47%)"},prolog:{color:"hsl(0, 0%, 47%)"},doctype:{color:"hsl(0, 0%, 47%)"},cdata:{color:"hsl(0, 0%, 47%)"},punctuation:{Opacity:".7"},namespace:{Opacity:".7"},tag:{color:"hsl(14, 58%, 55%)"},boolean:{color:"hsl(14, 58%, 55%)"},number:{color:"hsl(14, 58%, 55%)"},deleted:{color:"hsl(14, 58%, 55%)"},keyword:{color:"hsl(53, 89%, 79%)"},property:{color:"hsl(53, 89%, 79%)"},selector:{color:"hsl(53, 89%, 79%)"},constant:{color:"hsl(53, 89%, 79%)"},symbol:{color:"hsl(53, 89%, 79%)"},builtin:{color:"hsl(53, 89%, 79%)"},"attr-name":{color:"hsl(76, 21%, 52%)"},"attr-value":{color:"hsl(76, 21%, 52%)"},string:{color:"hsl(76, 21%, 52%)"},char:{color:"hsl(76, 21%, 52%)"},operator:{color:"hsl(76, 21%, 52%)"},entity:{color:"hsl(76, 21%, 52%)",cursor:"help"},url:{color:"hsl(76, 21%, 52%)"},".language-css .token.string":{color:"hsl(76, 21%, 52%)"},".style .token.string":{color:"hsl(76, 21%, 52%)"},variable:{color:"hsl(76, 21%, 52%)"},inserted:{color:"hsl(76, 21%, 52%)"},atrule:{color:"hsl(218, 22%, 55%)"},regex:{color:"hsl(42, 75%, 65%)"},important:{color:"hsl(42, 75%, 65%)",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},".language-markup .token.tag":{color:"hsl(33, 33%, 52%)"},".language-markup .token.attr-name":{color:"hsl(33, 33%, 52%)"},".language-markup .token.punctuation":{color:"hsl(33, 33%, 52%)"},"":{position:"relative",zIndex:"1"},".line-highlight.line-highlight":{background:"linear-gradient(to right, hsla(0, 0%, 33%, .1) 70%, hsla(0, 0%, 33%, 0))",borderBottom:"1px dashed hsl(0, 0%, 33%)",borderTop:"1px dashed hsl(0, 0%, 33%)",marginTop:"0.75em",zIndex:"0"},".line-highlight.line-highlight:before":{backgroundColor:"hsl(215, 15%, 59%)",color:"hsl(24, 20%, 95%)"},".line-highlight.line-highlight[data-end]:after":{backgroundColor:"hsl(215, 15%, 59%)",color:"hsl(24, 20%, 95%)"}}}(kx)),kx}var Tx={},KF;function qEe(){return KF||(KF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"black",background:"none",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"black",background:"#f5f2f0",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},':not(pre) > code[class*="language-"]':{background:"#f5f2f0",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"slategray"},prolog:{color:"slategray"},doctype:{color:"slategray"},cdata:{color:"slategray"},punctuation:{color:"#999"},namespace:{Opacity:".7"},property:{color:"#905"},tag:{color:"#905"},boolean:{color:"#905"},number:{color:"#905"},constant:{color:"#905"},symbol:{color:"#905"},deleted:{color:"#905"},selector:{color:"#690"},"attr-name":{color:"#690"},string:{color:"#690"},char:{color:"#690"},builtin:{color:"#690"},inserted:{color:"#690"},operator:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},entity:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)",cursor:"help"},url:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".language-css .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".style .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},atrule:{color:"#07a"},"attr-value":{color:"#07a"},keyword:{color:"#07a"},function:{color:"#DD4A68"},"class-name":{color:"#DD4A68"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"bold"},variable:{color:"#e90"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Tx)),Tx}var Ax={},XF;function VEe(){return XF||(XF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#2b2b2b",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#2b2b2b",padding:"0.1em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"#d4d0ab"},prolog:{color:"#d4d0ab"},doctype:{color:"#d4d0ab"},cdata:{color:"#d4d0ab"},punctuation:{color:"#fefefe"},property:{color:"#ffa07a"},tag:{color:"#ffa07a"},constant:{color:"#ffa07a"},symbol:{color:"#ffa07a"},deleted:{color:"#ffa07a"},boolean:{color:"#00e0e0"},number:{color:"#00e0e0"},selector:{color:"#abe338"},"attr-name":{color:"#abe338"},string:{color:"#abe338"},char:{color:"#abe338"},builtin:{color:"#abe338"},inserted:{color:"#abe338"},operator:{color:"#00e0e0"},entity:{color:"#00e0e0",cursor:"help"},url:{color:"#00e0e0"},".language-css .token.string":{color:"#00e0e0"},".style .token.string":{color:"#00e0e0"},variable:{color:"#00e0e0"},atrule:{color:"#ffd700"},"attr-value":{color:"#ffd700"},function:{color:"#ffd700"},keyword:{color:"#00e0e0"},regex:{color:"#ffd700"},important:{color:"#ffd700",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Ax)),Ax}var Rx={},ZF;function WEe(){return ZF||(ZF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#c5c8c6",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#c5c8c6",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em",background:"#1d1f21"},':not(pre) > code[class*="language-"]':{background:"#1d1f21",padding:".1em",borderRadius:".3em"},comment:{color:"#7C7C7C"},prolog:{color:"#7C7C7C"},doctype:{color:"#7C7C7C"},cdata:{color:"#7C7C7C"},punctuation:{color:"#c5c8c6"},".namespace":{Opacity:".7"},property:{color:"#96CBFE"},keyword:{color:"#96CBFE"},tag:{color:"#96CBFE"},"class-name":{color:"#FFFFB6",textDecoration:"underline"},boolean:{color:"#99CC99"},constant:{color:"#99CC99"},symbol:{color:"#f92672"},deleted:{color:"#f92672"},number:{color:"#FF73FD"},selector:{color:"#A8FF60"},"attr-name":{color:"#A8FF60"},string:{color:"#A8FF60"},char:{color:"#A8FF60"},builtin:{color:"#A8FF60"},inserted:{color:"#A8FF60"},variable:{color:"#C6C5FE"},operator:{color:"#EDEDED"},entity:{color:"#FFFFB6",cursor:"help"},url:{color:"#96CBFE"},".language-css .token.string":{color:"#87C38A"},".style .token.string":{color:"#87C38A"},atrule:{color:"#F9EE98"},"attr-value":{color:"#F9EE98"},function:{color:"#DAD085"},regex:{color:"#E9C062"},important:{color:"#fd971f",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Rx)),Rx}var Cx={},QF;function YEe(){return QF||(QF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#f5f7ff",color:"#5e6687"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#f5f7ff",color:"#5e6687",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#dfe2f1"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"]::selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#dfe2f1"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#898ea4"},prolog:{color:"#898ea4"},doctype:{color:"#898ea4"},cdata:{color:"#898ea4"},punctuation:{color:"#5e6687"},namespace:{Opacity:".7"},operator:{color:"#c76b29"},boolean:{color:"#c76b29"},number:{color:"#c76b29"},property:{color:"#c08b30"},tag:{color:"#3d8fd1"},string:{color:"#22a2c9"},selector:{color:"#6679cc"},"attr-name":{color:"#c76b29"},entity:{color:"#22a2c9",cursor:"help"},url:{color:"#22a2c9"},".language-css .token.string":{color:"#22a2c9"},".style .token.string":{color:"#22a2c9"},"attr-value":{color:"#ac9739"},keyword:{color:"#ac9739"},control:{color:"#ac9739"},directive:{color:"#ac9739"},unit:{color:"#ac9739"},statement:{color:"#22a2c9"},regex:{color:"#22a2c9"},atrule:{color:"#22a2c9"},placeholder:{color:"#3d8fd1"},variable:{color:"#3d8fd1"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #202746",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#c94922"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:"0.4em solid #c94922",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#dfe2f1"},".line-numbers .line-numbers-rows > span:before":{color:"#979db4"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(107, 115, 148, 0.2) 70%, rgba(107, 115, 148, 0))"}}}(Cx)),Cx}var _x={},JF;function KEe(){return JF||(JF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#fff",textShadow:"0 1px 1px #000",fontFamily:'Menlo, Monaco, "Courier New", monospace',direction:"ltr",textAlign:"left",wordSpacing:"normal",whiteSpace:"pre",wordWrap:"normal",lineHeight:"1.4",background:"none",border:"0",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#fff",textShadow:"0 1px 1px #000",fontFamily:'Menlo, Monaco, "Courier New", monospace',direction:"ltr",textAlign:"left",wordSpacing:"normal",whiteSpace:"pre",wordWrap:"normal",lineHeight:"1.4",background:"#222",border:"0",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"15px",margin:"1em 0",overflow:"auto",MozBorderRadius:"8px",WebkitBorderRadius:"8px",borderRadius:"8px"},'pre[class*="language-"] code':{float:"left",padding:"0 15px 0 0"},':not(pre) > code[class*="language-"]':{background:"#222",padding:"5px 10px",lineHeight:"1",MozBorderRadius:"3px",WebkitBorderRadius:"3px",borderRadius:"3px"},comment:{color:"#797979"},prolog:{color:"#797979"},doctype:{color:"#797979"},cdata:{color:"#797979"},selector:{color:"#fff"},operator:{color:"#fff"},punctuation:{color:"#fff"},namespace:{Opacity:".7"},tag:{color:"#ffd893"},boolean:{color:"#ffd893"},atrule:{color:"#B0C975"},"attr-value":{color:"#B0C975"},hex:{color:"#B0C975"},string:{color:"#B0C975"},property:{color:"#c27628"},entity:{color:"#c27628",cursor:"help"},url:{color:"#c27628"},"attr-name":{color:"#c27628"},keyword:{color:"#c27628"},regex:{color:"#9B71C6"},function:{color:"#e5a638"},constant:{color:"#e5a638"},variable:{color:"#fdfba8"},number:{color:"#8799B0"},important:{color:"#E45734"},deliminator:{color:"#E45734"},".line-highlight.line-highlight":{background:"rgba(255, 255, 255, .2)"},".line-highlight.line-highlight:before":{top:".3em",backgroundColor:"rgba(255, 255, 255, .3)",color:"#fff",MozBorderRadius:"8px",WebkitBorderRadius:"8px",borderRadius:"8px"},".line-highlight.line-highlight[data-end]:after":{top:".3em",backgroundColor:"rgba(255, 255, 255, .3)",color:"#fff",MozBorderRadius:"8px",WebkitBorderRadius:"8px",borderRadius:"8px"},".line-numbers .line-numbers-rows > span":{borderRight:"3px #d9d336 solid"}}}(_x)),_x}var Nx={},ez;function XEe(){return ez||(ez=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#111b27",background:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#111b27",background:"#e3eaf2",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{background:"#8da1b9"},'pre[class*="language-"] ::-moz-selection':{background:"#8da1b9"},'code[class*="language-"]::-moz-selection':{background:"#8da1b9"},'code[class*="language-"] ::-moz-selection':{background:"#8da1b9"},'pre[class*="language-"]::selection':{background:"#8da1b9"},'pre[class*="language-"] ::selection':{background:"#8da1b9"},'code[class*="language-"]::selection':{background:"#8da1b9"},'code[class*="language-"] ::selection':{background:"#8da1b9"},':not(pre) > code[class*="language-"]':{background:"#e3eaf2",padding:"0.1em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"#3c526d"},prolog:{color:"#3c526d"},doctype:{color:"#3c526d"},cdata:{color:"#3c526d"},punctuation:{color:"#111b27"},"delimiter.important":{color:"#006d6d",fontWeight:"inherit"},"selector.parent":{color:"#006d6d"},tag:{color:"#006d6d"},"tag.punctuation":{color:"#006d6d"},"attr-name":{color:"#755f00"},boolean:{color:"#755f00"},"boolean.important":{color:"#755f00"},number:{color:"#755f00"},constant:{color:"#755f00"},"selector.attribute":{color:"#755f00"},"class-name":{color:"#005a8e"},key:{color:"#005a8e"},parameter:{color:"#005a8e"},property:{color:"#005a8e"},"property-access":{color:"#005a8e"},variable:{color:"#005a8e"},"attr-value":{color:"#116b00"},inserted:{color:"#116b00"},color:{color:"#116b00"},"selector.value":{color:"#116b00"},string:{color:"#116b00"},"string.url-link":{color:"#116b00"},builtin:{color:"#af00af"},"keyword-array":{color:"#af00af"},package:{color:"#af00af"},regex:{color:"#af00af"},function:{color:"#7c00aa"},"selector.class":{color:"#7c00aa"},"selector.id":{color:"#7c00aa"},"atrule.rule":{color:"#a04900"},combinator:{color:"#a04900"},keyword:{color:"#a04900"},operator:{color:"#a04900"},"pseudo-class":{color:"#a04900"},"pseudo-element":{color:"#a04900"},selector:{color:"#a04900"},unit:{color:"#a04900"},deleted:{color:"#c22f2e"},important:{color:"#c22f2e",fontWeight:"bold"},"keyword-this":{color:"#005a8e",fontWeight:"bold"},this:{color:"#005a8e",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},entity:{cursor:"help"},".language-markdown .token.title":{color:"#005a8e",fontWeight:"bold"},".language-markdown .token.title .token.punctuation":{color:"#005a8e",fontWeight:"bold"},".language-markdown .token.blockquote.punctuation":{color:"#af00af"},".language-markdown .token.code":{color:"#006d6d"},".language-markdown .token.hr.punctuation":{color:"#005a8e"},".language-markdown .token.url > .token.content":{color:"#116b00"},".language-markdown .token.url-link":{color:"#755f00"},".language-markdown .token.list.punctuation":{color:"#af00af"},".language-markdown .token.table-header":{color:"#111b27"},".language-json .token.operator":{color:"#111b27"},".language-scss .token.variable":{color:"#006d6d"},"token.tab:not(:empty):before":{color:"#3c526d"},"token.cr:before":{color:"#3c526d"},"token.lf:before":{color:"#3c526d"},"token.space:before":{color:"#3c526d"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{color:"#e3eaf2",background:"#005a8e"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{color:"#e3eaf2",background:"#005a8e"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{color:"#e3eaf2",background:"#3c526d"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{color:"#e3eaf2",background:"#3c526d"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{color:"#e3eaf2",background:"#3c526d"},".line-highlight.line-highlight":{background:"linear-gradient(to right, #8da1b92f 70%, #8da1b925)"},".line-highlight.line-highlight:before":{backgroundColor:"#3c526d",color:"#e3eaf2",boxShadow:"0 1px #8da1b9"},".line-highlight.line-highlight[data-end]:after":{backgroundColor:"#3c526d",color:"#e3eaf2",boxShadow:"0 1px #8da1b9"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"#3c526d1f"},".line-numbers.line-numbers .line-numbers-rows":{borderRight:"1px solid #8da1b97a",background:"#d0dae77a"},".line-numbers .line-numbers-rows > span:before":{color:"#3c526dda"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"#755f00"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"#755f00"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"#755f00"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"#af00af"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"#af00af"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"#af00af"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"#005a8e"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"#005a8e"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"#005a8e"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"#7c00aa"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"#7c00aa"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"#7c00aa"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"#c22f2e1f"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"#c22f2e1f"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"#116b001f"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"#116b001f"},".command-line .command-line-prompt":{borderRight:"1px solid #8da1b97a"},".command-line .command-line-prompt > span:before":{color:"#3c526dda"}}}(Nx)),Nx}var Ox={},tz;function ZEe(){return tz||(tz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#e3eaf2",background:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#e3eaf2",background:"#111b27",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{background:"#3c526d"},'pre[class*="language-"] ::-moz-selection':{background:"#3c526d"},'code[class*="language-"]::-moz-selection':{background:"#3c526d"},'code[class*="language-"] ::-moz-selection':{background:"#3c526d"},'pre[class*="language-"]::selection':{background:"#3c526d"},'pre[class*="language-"] ::selection':{background:"#3c526d"},'code[class*="language-"]::selection':{background:"#3c526d"},'code[class*="language-"] ::selection':{background:"#3c526d"},':not(pre) > code[class*="language-"]':{background:"#111b27",padding:"0.1em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"#8da1b9"},prolog:{color:"#8da1b9"},doctype:{color:"#8da1b9"},cdata:{color:"#8da1b9"},punctuation:{color:"#e3eaf2"},"delimiter.important":{color:"#66cccc",fontWeight:"inherit"},"selector.parent":{color:"#66cccc"},tag:{color:"#66cccc"},"tag.punctuation":{color:"#66cccc"},"attr-name":{color:"#e6d37a"},boolean:{color:"#e6d37a"},"boolean.important":{color:"#e6d37a"},number:{color:"#e6d37a"},constant:{color:"#e6d37a"},"selector.attribute":{color:"#e6d37a"},"class-name":{color:"#6cb8e6"},key:{color:"#6cb8e6"},parameter:{color:"#6cb8e6"},property:{color:"#6cb8e6"},"property-access":{color:"#6cb8e6"},variable:{color:"#6cb8e6"},"attr-value":{color:"#91d076"},inserted:{color:"#91d076"},color:{color:"#91d076"},"selector.value":{color:"#91d076"},string:{color:"#91d076"},"string.url-link":{color:"#91d076"},builtin:{color:"#f4adf4"},"keyword-array":{color:"#f4adf4"},package:{color:"#f4adf4"},regex:{color:"#f4adf4"},function:{color:"#c699e3"},"selector.class":{color:"#c699e3"},"selector.id":{color:"#c699e3"},"atrule.rule":{color:"#e9ae7e"},combinator:{color:"#e9ae7e"},keyword:{color:"#e9ae7e"},operator:{color:"#e9ae7e"},"pseudo-class":{color:"#e9ae7e"},"pseudo-element":{color:"#e9ae7e"},selector:{color:"#e9ae7e"},unit:{color:"#e9ae7e"},deleted:{color:"#cd6660"},important:{color:"#cd6660",fontWeight:"bold"},"keyword-this":{color:"#6cb8e6",fontWeight:"bold"},this:{color:"#6cb8e6",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},entity:{cursor:"help"},".language-markdown .token.title":{color:"#6cb8e6",fontWeight:"bold"},".language-markdown .token.title .token.punctuation":{color:"#6cb8e6",fontWeight:"bold"},".language-markdown .token.blockquote.punctuation":{color:"#f4adf4"},".language-markdown .token.code":{color:"#66cccc"},".language-markdown .token.hr.punctuation":{color:"#6cb8e6"},".language-markdown .token.url .token.content":{color:"#91d076"},".language-markdown .token.url-link":{color:"#e6d37a"},".language-markdown .token.list.punctuation":{color:"#f4adf4"},".language-markdown .token.table-header":{color:"#e3eaf2"},".language-json .token.operator":{color:"#e3eaf2"},".language-scss .token.variable":{color:"#66cccc"},"token.tab:not(:empty):before":{color:"#8da1b9"},"token.cr:before":{color:"#8da1b9"},"token.lf:before":{color:"#8da1b9"},"token.space:before":{color:"#8da1b9"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{color:"#111b27",background:"#6cb8e6"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{color:"#111b27",background:"#6cb8e6"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{color:"#111b27",background:"#8da1b9"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{color:"#111b27",background:"#8da1b9"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{color:"#111b27",background:"#8da1b9"},".line-highlight.line-highlight":{background:"linear-gradient(to right, #3c526d5f 70%, #3c526d55)"},".line-highlight.line-highlight:before":{backgroundColor:"#8da1b9",color:"#111b27",boxShadow:"0 1px #3c526d"},".line-highlight.line-highlight[data-end]:after":{backgroundColor:"#8da1b9",color:"#111b27",boxShadow:"0 1px #3c526d"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"#8da1b918"},".line-numbers.line-numbers .line-numbers-rows":{borderRight:"1px solid #0b121b",background:"#0b121b7a"},".line-numbers .line-numbers-rows > span:before":{color:"#8da1b9da"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"#e6d37a"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"#e6d37a"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"#e6d37a"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"#f4adf4"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"#f4adf4"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"#f4adf4"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"#6cb8e6"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"#6cb8e6"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"#6cb8e6"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"#c699e3"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"#c699e3"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"#c699e3"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"#cd66601f"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"#cd66601f"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"#91d0761f"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"#91d0761f"},".command-line .command-line-prompt":{borderRight:"1px solid #0b121b"},".command-line .command-line-prompt > span:before":{color:"#8da1b9da"}}}(Ox)),Ox}var Ix={},nz;function QEe(){return nz||(nz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",position:"relative",borderLeft:"10px solid #358ccb",boxShadow:"-1px 0 0 0 #358ccb, 0 0 0 1px #dfdfdf",backgroundColor:"#fdfdfd",backgroundImage:"linear-gradient(transparent 50%, rgba(69, 142, 209, 0.04) 50%)",backgroundSize:"3em 3em",backgroundOrigin:"content-box",backgroundAttachment:"local",margin:".5em 0",padding:"0 1em"},'pre[class*="language-"] > code':{display:"block"},':not(pre) > code[class*="language-"]':{position:"relative",padding:".2em",borderRadius:"0.3em",color:"#c92c2c",border:"1px solid rgba(0, 0, 0, 0.1)",display:"inline",whiteSpace:"normal",backgroundColor:"#fdfdfd",WebkitBoxSizing:"border-box",MozBoxSizing:"border-box",boxSizing:"border-box"},comment:{color:"#7D8B99"},"block-comment":{color:"#7D8B99"},prolog:{color:"#7D8B99"},doctype:{color:"#7D8B99"},cdata:{color:"#7D8B99"},punctuation:{color:"#5F6364"},property:{color:"#c92c2c"},tag:{color:"#c92c2c"},boolean:{color:"#c92c2c"},number:{color:"#c92c2c"},"function-name":{color:"#c92c2c"},constant:{color:"#c92c2c"},symbol:{color:"#c92c2c"},deleted:{color:"#c92c2c"},selector:{color:"#2f9c0a"},"attr-name":{color:"#2f9c0a"},string:{color:"#2f9c0a"},char:{color:"#2f9c0a"},function:{color:"#2f9c0a"},builtin:{color:"#2f9c0a"},inserted:{color:"#2f9c0a"},operator:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},entity:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)",cursor:"help"},url:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},variable:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},atrule:{color:"#1990b8"},"attr-value":{color:"#1990b8"},keyword:{color:"#1990b8"},"class-name":{color:"#1990b8"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"normal"},".language-css .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},".style .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:".7"}}}(Ix)),Ix}var Dx={},rz;function JEe(){return rz||(rz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#a9b7c6",fontFamily:"Consolas, Monaco, 'Andale Mono', monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#a9b7c6",fontFamily:"Consolas, Monaco, 'Andale Mono', monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",background:"#2b2b2b"},'pre[class*="language-"]::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'pre[class*="language-"] ::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"]::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"] ::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'pre[class*="language-"]::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'pre[class*="language-"] ::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"]::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"] ::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},':not(pre) > code[class*="language-"]':{background:"#2b2b2b",padding:".1em",borderRadius:".3em"},comment:{color:"#808080"},prolog:{color:"#808080"},cdata:{color:"#808080"},delimiter:{color:"#cc7832"},boolean:{color:"#cc7832"},keyword:{color:"#cc7832"},selector:{color:"#cc7832"},important:{color:"#cc7832"},atrule:{color:"#cc7832"},operator:{color:"#a9b7c6"},punctuation:{color:"#a9b7c6"},"attr-name":{color:"#a9b7c6"},tag:{color:"#e8bf6a"},"tag.punctuation":{color:"#e8bf6a"},doctype:{color:"#e8bf6a"},builtin:{color:"#e8bf6a"},entity:{color:"#6897bb"},number:{color:"#6897bb"},symbol:{color:"#6897bb"},property:{color:"#9876aa"},constant:{color:"#9876aa"},variable:{color:"#9876aa"},string:{color:"#6a8759"},char:{color:"#6a8759"},"attr-value":{color:"#a5c261"},"attr-value.punctuation":{color:"#a5c261"},"attr-value.punctuation:first-child":{color:"#a9b7c6"},url:{color:"#287bde",textDecoration:"underline"},function:{color:"#ffc66d"},regex:{background:"#364135"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#294436"},deleted:{background:"#484a4a"},"code.language-css .token.property":{color:"#a9b7c6"},"code.language-css .token.property + .token.punctuation":{color:"#a9b7c6"},"code.language-css .token.id":{color:"#ffc66d"},"code.language-css .token.selector > .token.class":{color:"#ffc66d"},"code.language-css .token.selector > .token.attribute":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-class":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-element":{color:"#ffc66d"}}}(Dx)),Dx}var Lx={},az;function ewe(){return az||(az=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#282a36",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#282a36",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#6272a4"},prolog:{color:"#6272a4"},doctype:{color:"#6272a4"},cdata:{color:"#6272a4"},punctuation:{color:"#f8f8f2"},".namespace":{Opacity:".7"},property:{color:"#ff79c6"},tag:{color:"#ff79c6"},constant:{color:"#ff79c6"},symbol:{color:"#ff79c6"},deleted:{color:"#ff79c6"},boolean:{color:"#bd93f9"},number:{color:"#bd93f9"},selector:{color:"#50fa7b"},"attr-name":{color:"#50fa7b"},string:{color:"#50fa7b"},char:{color:"#50fa7b"},builtin:{color:"#50fa7b"},inserted:{color:"#50fa7b"},operator:{color:"#f8f8f2"},entity:{color:"#f8f8f2",cursor:"help"},url:{color:"#f8f8f2"},".language-css .token.string":{color:"#f8f8f2"},".style .token.string":{color:"#f8f8f2"},variable:{color:"#f8f8f2"},atrule:{color:"#f1fa8c"},"attr-value":{color:"#f1fa8c"},function:{color:"#f1fa8c"},"class-name":{color:"#f1fa8c"},keyword:{color:"#8be9fd"},regex:{color:"#ffb86c"},important:{color:"#ffb86c",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Lx)),Lx}var Mx={},oz;function twe(){return oz||(oz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2734",color:"#9a86fd"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2734",color:"#9a86fd",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6a51e6"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6a51e6"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#6a51e6"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"]::selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#6a51e6"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#6c6783"},prolog:{color:"#6c6783"},doctype:{color:"#6c6783"},cdata:{color:"#6c6783"},punctuation:{color:"#6c6783"},namespace:{Opacity:".7"},tag:{color:"#e09142"},operator:{color:"#e09142"},number:{color:"#e09142"},property:{color:"#9a86fd"},function:{color:"#9a86fd"},"tag-id":{color:"#eeebff"},selector:{color:"#eeebff"},"atrule-id":{color:"#eeebff"},"code.language-javascript":{color:"#c4b9fe"},"attr-name":{color:"#c4b9fe"},"code.language-css":{color:"#ffcc99"},"code.language-scss":{color:"#ffcc99"},boolean:{color:"#ffcc99"},string:{color:"#ffcc99"},entity:{color:"#ffcc99",cursor:"help"},url:{color:"#ffcc99"},".language-css .token.string":{color:"#ffcc99"},".language-scss .token.string":{color:"#ffcc99"},".style .token.string":{color:"#ffcc99"},"attr-value":{color:"#ffcc99"},keyword:{color:"#ffcc99"},control:{color:"#ffcc99"},directive:{color:"#ffcc99"},unit:{color:"#ffcc99"},statement:{color:"#ffcc99"},regex:{color:"#ffcc99"},atrule:{color:"#ffcc99"},placeholder:{color:"#ffcc99"},variable:{color:"#ffcc99"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #eeebff",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#c4b9fe"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #8a75f5",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#2c2937"},".line-numbers .line-numbers-rows > span:before":{color:"#3c3949"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(224, 145, 66, 0.2) 70%, rgba(224, 145, 66, 0))"}}}(Mx)),Mx}var Px={},iz;function nwe(){return iz||(iz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#322d29",color:"#88786d"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#322d29",color:"#88786d",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6f5849"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6f5849"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#6f5849"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"]::selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#6f5849"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#6a5f58"},prolog:{color:"#6a5f58"},doctype:{color:"#6a5f58"},cdata:{color:"#6a5f58"},punctuation:{color:"#6a5f58"},namespace:{Opacity:".7"},tag:{color:"#bfa05a"},operator:{color:"#bfa05a"},number:{color:"#bfa05a"},property:{color:"#88786d"},function:{color:"#88786d"},"tag-id":{color:"#fff3eb"},selector:{color:"#fff3eb"},"atrule-id":{color:"#fff3eb"},"code.language-javascript":{color:"#a48774"},"attr-name":{color:"#a48774"},"code.language-css":{color:"#fcc440"},"code.language-scss":{color:"#fcc440"},boolean:{color:"#fcc440"},string:{color:"#fcc440"},entity:{color:"#fcc440",cursor:"help"},url:{color:"#fcc440"},".language-css .token.string":{color:"#fcc440"},".language-scss .token.string":{color:"#fcc440"},".style .token.string":{color:"#fcc440"},"attr-value":{color:"#fcc440"},keyword:{color:"#fcc440"},control:{color:"#fcc440"},directive:{color:"#fcc440"},unit:{color:"#fcc440"},statement:{color:"#fcc440"},regex:{color:"#fcc440"},atrule:{color:"#fcc440"},placeholder:{color:"#fcc440"},variable:{color:"#fcc440"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #fff3eb",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#a48774"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #816d5f",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#35302b"},".line-numbers .line-numbers-rows > span:before":{color:"#46403d"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(191, 160, 90, 0.2) 70%, rgba(191, 160, 90, 0))"}}}(Px)),Px}var Fx={},sz;function rwe(){return sz||(sz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2d2a",color:"#687d68"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2d2a",color:"#687d68",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#435643"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#435643"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#435643"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#435643"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#435643"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#435643"},'code[class*="language-"]::selection':{textShadow:"none",background:"#435643"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#435643"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#535f53"},prolog:{color:"#535f53"},doctype:{color:"#535f53"},cdata:{color:"#535f53"},punctuation:{color:"#535f53"},namespace:{Opacity:".7"},tag:{color:"#a2b34d"},operator:{color:"#a2b34d"},number:{color:"#a2b34d"},property:{color:"#687d68"},function:{color:"#687d68"},"tag-id":{color:"#f0fff0"},selector:{color:"#f0fff0"},"atrule-id":{color:"#f0fff0"},"code.language-javascript":{color:"#b3d6b3"},"attr-name":{color:"#b3d6b3"},"code.language-css":{color:"#e5fb79"},"code.language-scss":{color:"#e5fb79"},boolean:{color:"#e5fb79"},string:{color:"#e5fb79"},entity:{color:"#e5fb79",cursor:"help"},url:{color:"#e5fb79"},".language-css .token.string":{color:"#e5fb79"},".language-scss .token.string":{color:"#e5fb79"},".style .token.string":{color:"#e5fb79"},"attr-value":{color:"#e5fb79"},keyword:{color:"#e5fb79"},control:{color:"#e5fb79"},directive:{color:"#e5fb79"},unit:{color:"#e5fb79"},statement:{color:"#e5fb79"},regex:{color:"#e5fb79"},atrule:{color:"#e5fb79"},placeholder:{color:"#e5fb79"},variable:{color:"#e5fb79"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #f0fff0",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#b3d6b3"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #5c705c",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#2c302c"},".line-numbers .line-numbers-rows > span:before":{color:"#3b423b"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(162, 179, 77, 0.2) 70%, rgba(162, 179, 77, 0))"}}}(Fx)),Fx}var zx={},lz;function awe(){return lz||(lz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#faf8f5",color:"#728fcb"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#faf8f5",color:"#728fcb",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#faf8f5"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#faf8f5"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#faf8f5"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"]::selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#faf8f5"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#b6ad9a"},prolog:{color:"#b6ad9a"},doctype:{color:"#b6ad9a"},cdata:{color:"#b6ad9a"},punctuation:{color:"#b6ad9a"},namespace:{Opacity:".7"},tag:{color:"#063289"},operator:{color:"#063289"},number:{color:"#063289"},property:{color:"#b29762"},function:{color:"#b29762"},"tag-id":{color:"#2d2006"},selector:{color:"#2d2006"},"atrule-id":{color:"#2d2006"},"code.language-javascript":{color:"#896724"},"attr-name":{color:"#896724"},"code.language-css":{color:"#728fcb"},"code.language-scss":{color:"#728fcb"},boolean:{color:"#728fcb"},string:{color:"#728fcb"},entity:{color:"#728fcb",cursor:"help"},url:{color:"#728fcb"},".language-css .token.string":{color:"#728fcb"},".language-scss .token.string":{color:"#728fcb"},".style .token.string":{color:"#728fcb"},"attr-value":{color:"#728fcb"},keyword:{color:"#728fcb"},control:{color:"#728fcb"},directive:{color:"#728fcb"},unit:{color:"#728fcb"},statement:{color:"#728fcb"},regex:{color:"#728fcb"},atrule:{color:"#728fcb"},placeholder:{color:"#93abdc"},variable:{color:"#93abdc"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #2d2006",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#896724"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #896724",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#ece8de"},".line-numbers .line-numbers-rows > span:before":{color:"#cdc4b1"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(45, 32, 6, 0.2) 70%, rgba(45, 32, 6, 0))"}}}(zx)),zx}var Bx={},cz;function owe(){return cz||(cz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#1d262f",color:"#57718e"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#1d262f",color:"#57718e",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#004a9e"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#004a9e"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#004a9e"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"]::selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#004a9e"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#4a5f78"},prolog:{color:"#4a5f78"},doctype:{color:"#4a5f78"},cdata:{color:"#4a5f78"},punctuation:{color:"#4a5f78"},namespace:{Opacity:".7"},tag:{color:"#0aa370"},operator:{color:"#0aa370"},number:{color:"#0aa370"},property:{color:"#57718e"},function:{color:"#57718e"},"tag-id":{color:"#ebf4ff"},selector:{color:"#ebf4ff"},"atrule-id":{color:"#ebf4ff"},"code.language-javascript":{color:"#7eb6f6"},"attr-name":{color:"#7eb6f6"},"code.language-css":{color:"#47ebb4"},"code.language-scss":{color:"#47ebb4"},boolean:{color:"#47ebb4"},string:{color:"#47ebb4"},entity:{color:"#47ebb4",cursor:"help"},url:{color:"#47ebb4"},".language-css .token.string":{color:"#47ebb4"},".language-scss .token.string":{color:"#47ebb4"},".style .token.string":{color:"#47ebb4"},"attr-value":{color:"#47ebb4"},keyword:{color:"#47ebb4"},control:{color:"#47ebb4"},directive:{color:"#47ebb4"},unit:{color:"#47ebb4"},statement:{color:"#47ebb4"},regex:{color:"#47ebb4"},atrule:{color:"#47ebb4"},placeholder:{color:"#47ebb4"},variable:{color:"#47ebb4"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #ebf4ff",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#7eb6f6"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #34659d",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#1f2932"},".line-numbers .line-numbers-rows > span:before":{color:"#2c3847"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(10, 163, 112, 0.2) 70%, rgba(10, 163, 112, 0))"}}}(Bx)),Bx}var jx={},uz;function iwe(){return uz||(uz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#24242e",color:"#767693"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#24242e",color:"#767693",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#5151e6"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#5151e6"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#5151e6"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"]::selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#5151e6"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#5b5b76"},prolog:{color:"#5b5b76"},doctype:{color:"#5b5b76"},cdata:{color:"#5b5b76"},punctuation:{color:"#5b5b76"},namespace:{Opacity:".7"},tag:{color:"#dd672c"},operator:{color:"#dd672c"},number:{color:"#dd672c"},property:{color:"#767693"},function:{color:"#767693"},"tag-id":{color:"#ebebff"},selector:{color:"#ebebff"},"atrule-id":{color:"#ebebff"},"code.language-javascript":{color:"#aaaaca"},"attr-name":{color:"#aaaaca"},"code.language-css":{color:"#fe8c52"},"code.language-scss":{color:"#fe8c52"},boolean:{color:"#fe8c52"},string:{color:"#fe8c52"},entity:{color:"#fe8c52",cursor:"help"},url:{color:"#fe8c52"},".language-css .token.string":{color:"#fe8c52"},".language-scss .token.string":{color:"#fe8c52"},".style .token.string":{color:"#fe8c52"},"attr-value":{color:"#fe8c52"},keyword:{color:"#fe8c52"},control:{color:"#fe8c52"},directive:{color:"#fe8c52"},unit:{color:"#fe8c52"},statement:{color:"#fe8c52"},regex:{color:"#fe8c52"},atrule:{color:"#fe8c52"},placeholder:{color:"#fe8c52"},variable:{color:"#fe8c52"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #ebebff",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#aaaaca"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #7676f4",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#262631"},".line-numbers .line-numbers-rows > span:before":{color:"#393949"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(221, 103, 44, 0.2) 70%, rgba(221, 103, 44, 0))"}}}(jx)),jx}var Ux={},dz;function swe(){return dz||(dz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",border:"1px solid #dddddd",backgroundColor:"white"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{background:"#b3d4fc"},'pre[class*="language-"] ::-moz-selection':{background:"#b3d4fc"},'code[class*="language-"]::-moz-selection':{background:"#b3d4fc"},'code[class*="language-"] ::-moz-selection':{background:"#b3d4fc"},'pre[class*="language-"]::selection':{background:"#b3d4fc"},'pre[class*="language-"] ::selection':{background:"#b3d4fc"},'code[class*="language-"]::selection':{background:"#b3d4fc"},'code[class*="language-"] ::selection':{background:"#b3d4fc"},':not(pre) > code[class*="language-"]':{padding:".2em",paddingTop:"1px",paddingBottom:"1px",background:"#f8f8f8",border:"1px solid #dddddd"},comment:{color:"#999988",fontStyle:"italic"},prolog:{color:"#999988",fontStyle:"italic"},doctype:{color:"#999988",fontStyle:"italic"},cdata:{color:"#999988",fontStyle:"italic"},namespace:{Opacity:".7"},string:{color:"#e3116c"},"attr-value":{color:"#e3116c"},punctuation:{color:"#393A34"},operator:{color:"#393A34"},entity:{color:"#36acaa"},url:{color:"#36acaa"},symbol:{color:"#36acaa"},number:{color:"#36acaa"},boolean:{color:"#36acaa"},variable:{color:"#36acaa"},constant:{color:"#36acaa"},property:{color:"#36acaa"},regex:{color:"#36acaa"},inserted:{color:"#36acaa"},atrule:{color:"#00a4db"},keyword:{color:"#00a4db"},"attr-name":{color:"#00a4db"},".language-autohotkey .token.selector":{color:"#00a4db"},function:{color:"#9a050f",fontWeight:"bold"},deleted:{color:"#9a050f"},".language-autohotkey .token.tag":{color:"#9a050f"},tag:{color:"#00009f"},selector:{color:"#00009f"},".language-autohotkey .token.keyword":{color:"#00009f"},important:{fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Ux)),Ux}var Gx={},fz;function lwe(){return fz||(fz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#ebdbb2",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#ebdbb2",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",background:"#1d2021"},'pre[class*="language-"]::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'pre[class*="language-"] ::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"]::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"] ::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'pre[class*="language-"]::selection':{color:"#fbf1c7",background:"#7c6f64"},'pre[class*="language-"] ::selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"]::selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"] ::selection':{color:"#fbf1c7",background:"#7c6f64"},':not(pre) > code[class*="language-"]':{background:"#1d2021",padding:"0.1em",borderRadius:"0.3em"},comment:{color:"#a89984"},prolog:{color:"#a89984"},cdata:{color:"#a89984"},delimiter:{color:"#fb4934"},boolean:{color:"#fb4934"},keyword:{color:"#fb4934"},selector:{color:"#fb4934"},important:{color:"#fb4934"},atrule:{color:"#fb4934"},operator:{color:"#a89984"},punctuation:{color:"#a89984"},"attr-name":{color:"#a89984"},tag:{color:"#fabd2f"},"tag.punctuation":{color:"#fabd2f"},doctype:{color:"#fabd2f"},builtin:{color:"#fabd2f"},entity:{color:"#d3869b"},number:{color:"#d3869b"},symbol:{color:"#d3869b"},property:{color:"#fb4934"},constant:{color:"#fb4934"},variable:{color:"#fb4934"},string:{color:"#b8bb26"},char:{color:"#b8bb26"},"attr-value":{color:"#a89984"},"attr-value.punctuation":{color:"#a89984"},url:{color:"#b8bb26",textDecoration:"underline"},function:{color:"#fabd2f"},regex:{background:"#b8bb26"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#a89984"},deleted:{background:"#fb4934"}}}(Gx)),Gx}var Hx={},pz;function cwe(){return pz||(pz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#3c3836",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#3c3836",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",background:"#f9f5d7"},'pre[class*="language-"]::-moz-selection':{color:"#282828",background:"#a89984"},'pre[class*="language-"] ::-moz-selection':{color:"#282828",background:"#a89984"},'code[class*="language-"]::-moz-selection':{color:"#282828",background:"#a89984"},'code[class*="language-"] ::-moz-selection':{color:"#282828",background:"#a89984"},'pre[class*="language-"]::selection':{color:"#282828",background:"#a89984"},'pre[class*="language-"] ::selection':{color:"#282828",background:"#a89984"},'code[class*="language-"]::selection':{color:"#282828",background:"#a89984"},'code[class*="language-"] ::selection':{color:"#282828",background:"#a89984"},':not(pre) > code[class*="language-"]':{background:"#f9f5d7",padding:"0.1em",borderRadius:"0.3em"},comment:{color:"#7c6f64"},prolog:{color:"#7c6f64"},cdata:{color:"#7c6f64"},delimiter:{color:"#9d0006"},boolean:{color:"#9d0006"},keyword:{color:"#9d0006"},selector:{color:"#9d0006"},important:{color:"#9d0006"},atrule:{color:"#9d0006"},operator:{color:"#7c6f64"},punctuation:{color:"#7c6f64"},"attr-name":{color:"#7c6f64"},tag:{color:"#b57614"},"tag.punctuation":{color:"#b57614"},doctype:{color:"#b57614"},builtin:{color:"#b57614"},entity:{color:"#8f3f71"},number:{color:"#8f3f71"},symbol:{color:"#8f3f71"},property:{color:"#9d0006"},constant:{color:"#9d0006"},variable:{color:"#9d0006"},string:{color:"#797403"},char:{color:"#797403"},"attr-value":{color:"#7c6f64"},"attr-value.punctuation":{color:"#7c6f64"},url:{color:"#797403",textDecoration:"underline"},function:{color:"#b57614"},regex:{background:"#797403"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#7c6f64"},deleted:{background:"#9d0006"}}}(Hx)),Hx}var $x={},gz;function uwe(){return gz||(gz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={"code[class*='language-']":{color:"#d6e7ff",background:"#030314",textShadow:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',fontSize:"1em",lineHeight:"1.5",letterSpacing:".2px",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",textAlign:"left",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},"pre[class*='language-']":{color:"#d6e7ff",background:"#030314",textShadow:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',fontSize:"1em",lineHeight:"1.5",letterSpacing:".2px",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",textAlign:"left",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",border:"1px solid #2a4555",borderRadius:"5px",padding:"1.5em 1em",margin:"1em 0",overflow:"auto"},"pre[class*='language-']::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"pre[class*='language-'] ::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-']::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-'] ::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"pre[class*='language-']::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"pre[class*='language-'] ::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-']::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-'] ::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},":not(pre) > code[class*='language-']":{color:"#f0f6f6",background:"#2a4555",padding:"0.2em 0.3em",borderRadius:"0.2em",boxDecorationBreak:"clone"},comment:{color:"#446e69"},prolog:{color:"#446e69"},doctype:{color:"#446e69"},cdata:{color:"#446e69"},punctuation:{color:"#d6b007"},property:{color:"#d6e7ff"},tag:{color:"#d6e7ff"},boolean:{color:"#d6e7ff"},number:{color:"#d6e7ff"},constant:{color:"#d6e7ff"},symbol:{color:"#d6e7ff"},deleted:{color:"#d6e7ff"},selector:{color:"#e60067"},"attr-name":{color:"#e60067"},builtin:{color:"#e60067"},inserted:{color:"#e60067"},string:{color:"#49c6ec"},char:{color:"#49c6ec"},operator:{color:"#ec8e01",background:"transparent"},entity:{color:"#ec8e01",background:"transparent"},url:{color:"#ec8e01",background:"transparent"},".language-css .token.string":{color:"#ec8e01",background:"transparent"},".style .token.string":{color:"#ec8e01",background:"transparent"},atrule:{color:"#0fe468"},"attr-value":{color:"#0fe468"},keyword:{color:"#0fe468"},function:{color:"#78f3e9"},"class-name":{color:"#78f3e9"},regex:{color:"#d6e7ff"},important:{color:"#d6e7ff"},variable:{color:"#d6e7ff"}}}($x)),$x}var qx={},hz;function dwe(){return hz||(hz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'"Fira Mono", Menlo, Monaco, "Lucida Console", "Courier New", Courier, monospace',fontSize:"16px",lineHeight:"1.375",direction:"ltr",textAlign:"left",wordSpacing:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",background:"#322931",color:"#b9b5b8"},'pre[class*="language-"]':{fontFamily:'"Fira Mono", Menlo, Monaco, "Lucida Console", "Courier New", Courier, monospace',fontSize:"16px",lineHeight:"1.375",direction:"ltr",textAlign:"left",wordSpacing:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",background:"#322931",color:"#b9b5b8",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#797379"},prolog:{color:"#797379"},doctype:{color:"#797379"},cdata:{color:"#797379"},punctuation:{color:"#b9b5b8"},".namespace":{Opacity:".7"},null:{color:"#fd8b19"},operator:{color:"#fd8b19"},boolean:{color:"#fd8b19"},number:{color:"#fd8b19"},property:{color:"#fdcc59"},tag:{color:"#1290bf"},string:{color:"#149b93"},selector:{color:"#c85e7c"},"attr-name":{color:"#fd8b19"},entity:{color:"#149b93",cursor:"help"},url:{color:"#149b93"},".language-css .token.string":{color:"#149b93"},".style .token.string":{color:"#149b93"},"attr-value":{color:"#8fc13e"},keyword:{color:"#8fc13e"},control:{color:"#8fc13e"},directive:{color:"#8fc13e"},unit:{color:"#8fc13e"},statement:{color:"#149b93"},regex:{color:"#149b93"},atrule:{color:"#149b93"},placeholder:{color:"#1290bf"},variable:{color:"#1290bf"},important:{color:"#dd464c",fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid red",OutlineOffset:".4em"}}}(qx)),qx}var Vx={},mz;function fwe(){return mz||(mz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Monaco, Consolas, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#263E52",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Monaco, Consolas, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#263E52",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#5c98cd"},prolog:{color:"#5c98cd"},doctype:{color:"#5c98cd"},cdata:{color:"#5c98cd"},punctuation:{color:"#f8f8f2"},".namespace":{Opacity:".7"},property:{color:"#F05E5D"},tag:{color:"#F05E5D"},constant:{color:"#F05E5D"},symbol:{color:"#F05E5D"},deleted:{color:"#F05E5D"},boolean:{color:"#BC94F9"},number:{color:"#BC94F9"},selector:{color:"#FCFCD6"},"attr-name":{color:"#FCFCD6"},string:{color:"#FCFCD6"},char:{color:"#FCFCD6"},builtin:{color:"#FCFCD6"},inserted:{color:"#FCFCD6"},operator:{color:"#f8f8f2"},entity:{color:"#f8f8f2",cursor:"help"},url:{color:"#f8f8f2"},".language-css .token.string":{color:"#f8f8f2"},".style .token.string":{color:"#f8f8f2"},variable:{color:"#f8f8f2"},atrule:{color:"#66D8EF"},"attr-value":{color:"#66D8EF"},function:{color:"#66D8EF"},"class-name":{color:"#66D8EF"},keyword:{color:"#6EB26E"},regex:{color:"#F05E5D"},important:{color:"#F05E5D",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Vx)),Vx}var Wx={},bz;function pwe(){return bz||(bz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#eee",background:"#2f2f2f",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#eee",background:"#2f2f2f",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",overflow:"auto",position:"relative",margin:"0.5em 0",padding:"1.25em 1em"},'code[class*="language-"]::-moz-selection':{background:"#363636"},'pre[class*="language-"]::-moz-selection':{background:"#363636"},'code[class*="language-"] ::-moz-selection':{background:"#363636"},'pre[class*="language-"] ::-moz-selection':{background:"#363636"},'code[class*="language-"]::selection':{background:"#363636"},'pre[class*="language-"]::selection':{background:"#363636"},'code[class*="language-"] ::selection':{background:"#363636"},'pre[class*="language-"] ::selection':{background:"#363636"},':not(pre) > code[class*="language-"]':{whiteSpace:"normal",borderRadius:"0.2em",padding:"0.1em"},".language-css > code":{color:"#fd9170"},".language-sass > code":{color:"#fd9170"},".language-scss > code":{color:"#fd9170"},'[class*="language-"] .namespace':{Opacity:"0.7"},atrule:{color:"#c792ea"},"attr-name":{color:"#ffcb6b"},"attr-value":{color:"#a5e844"},attribute:{color:"#a5e844"},boolean:{color:"#c792ea"},builtin:{color:"#ffcb6b"},cdata:{color:"#80cbc4"},char:{color:"#80cbc4"},class:{color:"#ffcb6b"},"class-name":{color:"#f2ff00"},comment:{color:"#616161"},constant:{color:"#c792ea"},deleted:{color:"#ff6666"},doctype:{color:"#616161"},entity:{color:"#ff6666"},function:{color:"#c792ea"},hexcode:{color:"#f2ff00"},id:{color:"#c792ea",fontWeight:"bold"},important:{color:"#c792ea",fontWeight:"bold"},inserted:{color:"#80cbc4"},keyword:{color:"#c792ea"},number:{color:"#fd9170"},operator:{color:"#89ddff"},prolog:{color:"#616161"},property:{color:"#80cbc4"},"pseudo-class":{color:"#a5e844"},"pseudo-element":{color:"#a5e844"},punctuation:{color:"#89ddff"},regex:{color:"#f2ff00"},selector:{color:"#ff6666"},string:{color:"#a5e844"},symbol:{color:"#c792ea"},tag:{color:"#ff6666"},unit:{color:"#fd9170"},url:{color:"#ff6666"},variable:{color:"#ff6666"}}}(Wx)),Wx}var Yx={},yz;function gwe(){return yz||(yz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#90a4ae",background:"#fafafa",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#90a4ae",background:"#fafafa",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",overflow:"auto",position:"relative",margin:"0.5em 0",padding:"1.25em 1em"},'code[class*="language-"]::-moz-selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"]::-moz-selection':{background:"#cceae7",color:"#263238"},'code[class*="language-"] ::-moz-selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"] ::-moz-selection':{background:"#cceae7",color:"#263238"},'code[class*="language-"]::selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"]::selection':{background:"#cceae7",color:"#263238"},'code[class*="language-"] ::selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"] ::selection':{background:"#cceae7",color:"#263238"},':not(pre) > code[class*="language-"]':{whiteSpace:"normal",borderRadius:"0.2em",padding:"0.1em"},".language-css > code":{color:"#f76d47"},".language-sass > code":{color:"#f76d47"},".language-scss > code":{color:"#f76d47"},'[class*="language-"] .namespace':{Opacity:"0.7"},atrule:{color:"#7c4dff"},"attr-name":{color:"#39adb5"},"attr-value":{color:"#f6a434"},attribute:{color:"#f6a434"},boolean:{color:"#7c4dff"},builtin:{color:"#39adb5"},cdata:{color:"#39adb5"},char:{color:"#39adb5"},class:{color:"#39adb5"},"class-name":{color:"#6182b8"},comment:{color:"#aabfc9"},constant:{color:"#7c4dff"},deleted:{color:"#e53935"},doctype:{color:"#aabfc9"},entity:{color:"#e53935"},function:{color:"#7c4dff"},hexcode:{color:"#f76d47"},id:{color:"#7c4dff",fontWeight:"bold"},important:{color:"#7c4dff",fontWeight:"bold"},inserted:{color:"#39adb5"},keyword:{color:"#7c4dff"},number:{color:"#f76d47"},operator:{color:"#39adb5"},prolog:{color:"#aabfc9"},property:{color:"#39adb5"},"pseudo-class":{color:"#f6a434"},"pseudo-element":{color:"#f6a434"},punctuation:{color:"#39adb5"},regex:{color:"#6182b8"},selector:{color:"#e53935"},string:{color:"#f6a434"},symbol:{color:"#7c4dff"},tag:{color:"#e53935"},unit:{color:"#f76d47"},url:{color:"#e53935"},variable:{color:"#e53935"}}}(Yx)),Yx}var Kx={},vz;function hwe(){return vz||(vz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#c3cee3",background:"#263238",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#c3cee3",background:"#263238",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",overflow:"auto",position:"relative",margin:"0.5em 0",padding:"1.25em 1em"},'code[class*="language-"]::-moz-selection':{background:"#363636"},'pre[class*="language-"]::-moz-selection':{background:"#363636"},'code[class*="language-"] ::-moz-selection':{background:"#363636"},'pre[class*="language-"] ::-moz-selection':{background:"#363636"},'code[class*="language-"]::selection':{background:"#363636"},'pre[class*="language-"]::selection':{background:"#363636"},'code[class*="language-"] ::selection':{background:"#363636"},'pre[class*="language-"] ::selection':{background:"#363636"},':not(pre) > code[class*="language-"]':{whiteSpace:"normal",borderRadius:"0.2em",padding:"0.1em"},".language-css > code":{color:"#fd9170"},".language-sass > code":{color:"#fd9170"},".language-scss > code":{color:"#fd9170"},'[class*="language-"] .namespace':{Opacity:"0.7"},atrule:{color:"#c792ea"},"attr-name":{color:"#ffcb6b"},"attr-value":{color:"#c3e88d"},attribute:{color:"#c3e88d"},boolean:{color:"#c792ea"},builtin:{color:"#ffcb6b"},cdata:{color:"#80cbc4"},char:{color:"#80cbc4"},class:{color:"#ffcb6b"},"class-name":{color:"#f2ff00"},color:{color:"#f2ff00"},comment:{color:"#546e7a"},constant:{color:"#c792ea"},deleted:{color:"#f07178"},doctype:{color:"#546e7a"},entity:{color:"#f07178"},function:{color:"#c792ea"},hexcode:{color:"#f2ff00"},id:{color:"#c792ea",fontWeight:"bold"},important:{color:"#c792ea",fontWeight:"bold"},inserted:{color:"#80cbc4"},keyword:{color:"#c792ea",fontStyle:"italic"},number:{color:"#fd9170"},operator:{color:"#89ddff"},prolog:{color:"#546e7a"},property:{color:"#80cbc4"},"pseudo-class":{color:"#c3e88d"},"pseudo-element":{color:"#c3e88d"},punctuation:{color:"#89ddff"},regex:{color:"#f2ff00"},selector:{color:"#f07178"},string:{color:"#c3e88d"},symbol:{color:"#c792ea"},tag:{color:"#f07178"},unit:{color:"#f07178"},url:{color:"#fd9170"},variable:{color:"#f07178"}}}(Kx)),Kx}var Xx={},Sz;function mwe(){return Sz||(Sz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#d6deeb",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",fontSize:"1em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"white",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",fontSize:"1em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",background:"#011627"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},':not(pre) > code[class*="language-"]':{color:"white",background:"#011627",padding:"0.1em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"rgb(99, 119, 119)",fontStyle:"italic"},prolog:{color:"rgb(99, 119, 119)",fontStyle:"italic"},cdata:{color:"rgb(99, 119, 119)",fontStyle:"italic"},punctuation:{color:"rgb(199, 146, 234)"},".namespace":{color:"rgb(178, 204, 214)"},deleted:{color:"rgba(239, 83, 80, 0.56)",fontStyle:"italic"},symbol:{color:"rgb(128, 203, 196)"},property:{color:"rgb(128, 203, 196)"},tag:{color:"rgb(127, 219, 202)"},operator:{color:"rgb(127, 219, 202)"},keyword:{color:"rgb(127, 219, 202)"},boolean:{color:"rgb(255, 88, 116)"},number:{color:"rgb(247, 140, 108)"},constant:{color:"rgb(130, 170, 255)"},function:{color:"rgb(130, 170, 255)"},builtin:{color:"rgb(130, 170, 255)"},char:{color:"rgb(130, 170, 255)"},selector:{color:"rgb(199, 146, 234)",fontStyle:"italic"},doctype:{color:"rgb(199, 146, 234)",fontStyle:"italic"},"attr-name":{color:"rgb(173, 219, 103)",fontStyle:"italic"},inserted:{color:"rgb(173, 219, 103)",fontStyle:"italic"},string:{color:"rgb(173, 219, 103)"},url:{color:"rgb(173, 219, 103)"},entity:{color:"rgb(173, 219, 103)"},".language-css .token.string":{color:"rgb(173, 219, 103)"},".style .token.string":{color:"rgb(173, 219, 103)"},"class-name":{color:"rgb(255, 203, 139)"},atrule:{color:"rgb(255, 203, 139)"},"attr-value":{color:"rgb(255, 203, 139)"},regex:{color:"rgb(214, 222, 235)"},important:{color:"rgb(214, 222, 235)",fontWeight:"bold"},variable:{color:"rgb(214, 222, 235)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Xx)),Xx}var Zx={},Ez;function bwe(){return Ez||(Ez=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",fontFamily:`"Fira Code", Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace`,textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#2E3440",fontFamily:`"Fira Code", Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace`,textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#2E3440",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#636f88"},prolog:{color:"#636f88"},doctype:{color:"#636f88"},cdata:{color:"#636f88"},punctuation:{color:"#81A1C1"},".namespace":{Opacity:".7"},property:{color:"#81A1C1"},tag:{color:"#81A1C1"},constant:{color:"#81A1C1"},symbol:{color:"#81A1C1"},deleted:{color:"#81A1C1"},number:{color:"#B48EAD"},boolean:{color:"#81A1C1"},selector:{color:"#A3BE8C"},"attr-name":{color:"#A3BE8C"},string:{color:"#A3BE8C"},char:{color:"#A3BE8C"},builtin:{color:"#A3BE8C"},inserted:{color:"#A3BE8C"},operator:{color:"#81A1C1"},entity:{color:"#81A1C1",cursor:"help"},url:{color:"#81A1C1"},".language-css .token.string":{color:"#81A1C1"},".style .token.string":{color:"#81A1C1"},variable:{color:"#81A1C1"},atrule:{color:"#88C0D0"},"attr-value":{color:"#88C0D0"},function:{color:"#88C0D0"},"class-name":{color:"#88C0D0"},keyword:{color:"#81A1C1"},regex:{color:"#EBCB8B"},important:{color:"#EBCB8B",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Zx)),Zx}var Qx={},wz;function ywe(){return wz||(wz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{background:"hsl(220, 13%, 18%)",color:"hsl(220, 14%, 71%)",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{background:"hsl(220, 13%, 18%)",color:"hsl(220, 14%, 71%)",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",borderRadius:"0.3em"},'code[class*="language-"]::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"] *::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'pre[class*="language-"] *::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"]::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"] *::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'pre[class*="language-"] *::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},':not(pre) > code[class*="language-"]':{padding:"0.2em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},prolog:{color:"hsl(220, 10%, 40%)"},cdata:{color:"hsl(220, 10%, 40%)"},doctype:{color:"hsl(220, 14%, 71%)"},punctuation:{color:"hsl(220, 14%, 71%)"},entity:{color:"hsl(220, 14%, 71%)",cursor:"help"},"attr-name":{color:"hsl(29, 54%, 61%)"},"class-name":{color:"hsl(29, 54%, 61%)"},boolean:{color:"hsl(29, 54%, 61%)"},constant:{color:"hsl(29, 54%, 61%)"},number:{color:"hsl(29, 54%, 61%)"},atrule:{color:"hsl(29, 54%, 61%)"},keyword:{color:"hsl(286, 60%, 67%)"},property:{color:"hsl(355, 65%, 65%)"},tag:{color:"hsl(355, 65%, 65%)"},symbol:{color:"hsl(355, 65%, 65%)"},deleted:{color:"hsl(355, 65%, 65%)"},important:{color:"hsl(355, 65%, 65%)"},selector:{color:"hsl(95, 38%, 62%)"},string:{color:"hsl(95, 38%, 62%)"},char:{color:"hsl(95, 38%, 62%)"},builtin:{color:"hsl(95, 38%, 62%)"},inserted:{color:"hsl(95, 38%, 62%)"},regex:{color:"hsl(95, 38%, 62%)"},"attr-value":{color:"hsl(95, 38%, 62%)"},"attr-value > .token.punctuation":{color:"hsl(95, 38%, 62%)"},variable:{color:"hsl(207, 82%, 66%)"},operator:{color:"hsl(207, 82%, 66%)"},function:{color:"hsl(207, 82%, 66%)"},url:{color:"hsl(187, 47%, 55%)"},"attr-value > .token.punctuation.attr-equals":{color:"hsl(220, 14%, 71%)"},"special-attr > .token.attr-value > .token.value.css":{color:"hsl(220, 14%, 71%)"},".language-css .token.selector":{color:"hsl(355, 65%, 65%)"},".language-css .token.property":{color:"hsl(220, 14%, 71%)"},".language-css .token.function":{color:"hsl(187, 47%, 55%)"},".language-css .token.url > .token.function":{color:"hsl(187, 47%, 55%)"},".language-css .token.url > .token.string.url":{color:"hsl(95, 38%, 62%)"},".language-css .token.important":{color:"hsl(286, 60%, 67%)"},".language-css .token.atrule .token.rule":{color:"hsl(286, 60%, 67%)"},".language-javascript .token.operator":{color:"hsl(286, 60%, 67%)"},".language-javascript .token.template-string > .token.interpolation > .token.interpolation-punctuation.punctuation":{color:"hsl(5, 48%, 51%)"},".language-json .token.operator":{color:"hsl(220, 14%, 71%)"},".language-json .token.null.keyword":{color:"hsl(29, 54%, 61%)"},".language-markdown .token.url":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url > .token.operator":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url-reference.url > .token.string":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url > .token.content":{color:"hsl(207, 82%, 66%)"},".language-markdown .token.url > .token.url":{color:"hsl(187, 47%, 55%)"},".language-markdown .token.url-reference.url":{color:"hsl(187, 47%, 55%)"},".language-markdown .token.blockquote.punctuation":{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},".language-markdown .token.hr.punctuation":{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},".language-markdown .token.code-snippet":{color:"hsl(95, 38%, 62%)"},".language-markdown .token.bold .token.content":{color:"hsl(29, 54%, 61%)"},".language-markdown .token.italic .token.content":{color:"hsl(286, 60%, 67%)"},".language-markdown .token.strike .token.content":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.strike .token.punctuation":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.list.punctuation":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.title.important > .token.punctuation":{color:"hsl(355, 65%, 65%)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:"0.8"},"token.tab:not(:empty):before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.cr:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.lf:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.space:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item":{marginRight:"0.4em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},".line-highlight.line-highlight":{background:"hsla(220, 100%, 80%, 0.04)"},".line-highlight.line-highlight:before":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 14%, 71%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},".line-highlight.line-highlight[data-end]:after":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 14%, 71%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"hsla(220, 100%, 80%, 0.04)"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"hsla(220, 14%, 71%, 0.15)"},".command-line .command-line-prompt":{borderRightColor:"hsla(220, 14%, 71%, 0.15)"},".line-numbers .line-numbers-rows > span:before":{color:"hsl(220, 14%, 45%)"},".command-line .command-line-prompt > span:before":{color:"hsl(220, 14%, 45%)"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"hsl(286, 60%, 67%)"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"hsl(286, 60%, 67%)"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"hsl(286, 60%, 67%)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},".prism-previewer.prism-previewer:before":{borderColor:"hsl(224, 13%, 17%)"},".prism-previewer-gradient.prism-previewer-gradient div":{borderColor:"hsl(224, 13%, 17%)",borderRadius:"0.3em"},".prism-previewer-color.prism-previewer-color:before":{borderRadius:"0.3em"},".prism-previewer-easing.prism-previewer-easing:before":{borderRadius:"0.3em"},".prism-previewer.prism-previewer:after":{borderTopColor:"hsl(224, 13%, 17%)"},".prism-previewer-flipped.prism-previewer-flipped.after":{borderBottomColor:"hsl(224, 13%, 17%)"},".prism-previewer-angle.prism-previewer-angle:before":{background:"hsl(219, 13%, 22%)"},".prism-previewer-time.prism-previewer-time:before":{background:"hsl(219, 13%, 22%)"},".prism-previewer-easing.prism-previewer-easing":{background:"hsl(219, 13%, 22%)"},".prism-previewer-angle.prism-previewer-angle circle":{stroke:"hsl(220, 14%, 71%)",strokeOpacity:"1"},".prism-previewer-time.prism-previewer-time circle":{stroke:"hsl(220, 14%, 71%)",strokeOpacity:"1"},".prism-previewer-easing.prism-previewer-easing circle":{stroke:"hsl(220, 14%, 71%)",fill:"transparent"},".prism-previewer-easing.prism-previewer-easing path":{stroke:"hsl(220, 14%, 71%)"},".prism-previewer-easing.prism-previewer-easing line":{stroke:"hsl(220, 14%, 71%)"}}}(Qx)),Qx}var Jx={},xz;function vwe(){return xz||(xz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{background:"hsl(230, 1%, 98%)",color:"hsl(230, 8%, 24%)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{background:"hsl(230, 1%, 98%)",color:"hsl(230, 8%, 24%)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",borderRadius:"0.3em"},'code[class*="language-"]::-moz-selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'code[class*="language-"] *::-moz-selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'pre[class*="language-"] *::-moz-selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'code[class*="language-"]::selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'code[class*="language-"] *::selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'pre[class*="language-"] *::selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},':not(pre) > code[class*="language-"]':{padding:"0.2em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"hsl(230, 4%, 64%)",fontStyle:"italic"},prolog:{color:"hsl(230, 4%, 64%)"},cdata:{color:"hsl(230, 4%, 64%)"},doctype:{color:"hsl(230, 8%, 24%)"},punctuation:{color:"hsl(230, 8%, 24%)"},entity:{color:"hsl(230, 8%, 24%)",cursor:"help"},"attr-name":{color:"hsl(35, 99%, 36%)"},"class-name":{color:"hsl(35, 99%, 36%)"},boolean:{color:"hsl(35, 99%, 36%)"},constant:{color:"hsl(35, 99%, 36%)"},number:{color:"hsl(35, 99%, 36%)"},atrule:{color:"hsl(35, 99%, 36%)"},keyword:{color:"hsl(301, 63%, 40%)"},property:{color:"hsl(5, 74%, 59%)"},tag:{color:"hsl(5, 74%, 59%)"},symbol:{color:"hsl(5, 74%, 59%)"},deleted:{color:"hsl(5, 74%, 59%)"},important:{color:"hsl(5, 74%, 59%)"},selector:{color:"hsl(119, 34%, 47%)"},string:{color:"hsl(119, 34%, 47%)"},char:{color:"hsl(119, 34%, 47%)"},builtin:{color:"hsl(119, 34%, 47%)"},inserted:{color:"hsl(119, 34%, 47%)"},regex:{color:"hsl(119, 34%, 47%)"},"attr-value":{color:"hsl(119, 34%, 47%)"},"attr-value > .token.punctuation":{color:"hsl(119, 34%, 47%)"},variable:{color:"hsl(221, 87%, 60%)"},operator:{color:"hsl(221, 87%, 60%)"},function:{color:"hsl(221, 87%, 60%)"},url:{color:"hsl(198, 99%, 37%)"},"attr-value > .token.punctuation.attr-equals":{color:"hsl(230, 8%, 24%)"},"special-attr > .token.attr-value > .token.value.css":{color:"hsl(230, 8%, 24%)"},".language-css .token.selector":{color:"hsl(5, 74%, 59%)"},".language-css .token.property":{color:"hsl(230, 8%, 24%)"},".language-css .token.function":{color:"hsl(198, 99%, 37%)"},".language-css .token.url > .token.function":{color:"hsl(198, 99%, 37%)"},".language-css .token.url > .token.string.url":{color:"hsl(119, 34%, 47%)"},".language-css .token.important":{color:"hsl(301, 63%, 40%)"},".language-css .token.atrule .token.rule":{color:"hsl(301, 63%, 40%)"},".language-javascript .token.operator":{color:"hsl(301, 63%, 40%)"},".language-javascript .token.template-string > .token.interpolation > .token.interpolation-punctuation.punctuation":{color:"hsl(344, 84%, 43%)"},".language-json .token.operator":{color:"hsl(230, 8%, 24%)"},".language-json .token.null.keyword":{color:"hsl(35, 99%, 36%)"},".language-markdown .token.url":{color:"hsl(230, 8%, 24%)"},".language-markdown .token.url > .token.operator":{color:"hsl(230, 8%, 24%)"},".language-markdown .token.url-reference.url > .token.string":{color:"hsl(230, 8%, 24%)"},".language-markdown .token.url > .token.content":{color:"hsl(221, 87%, 60%)"},".language-markdown .token.url > .token.url":{color:"hsl(198, 99%, 37%)"},".language-markdown .token.url-reference.url":{color:"hsl(198, 99%, 37%)"},".language-markdown .token.blockquote.punctuation":{color:"hsl(230, 4%, 64%)",fontStyle:"italic"},".language-markdown .token.hr.punctuation":{color:"hsl(230, 4%, 64%)",fontStyle:"italic"},".language-markdown .token.code-snippet":{color:"hsl(119, 34%, 47%)"},".language-markdown .token.bold .token.content":{color:"hsl(35, 99%, 36%)"},".language-markdown .token.italic .token.content":{color:"hsl(301, 63%, 40%)"},".language-markdown .token.strike .token.content":{color:"hsl(5, 74%, 59%)"},".language-markdown .token.strike .token.punctuation":{color:"hsl(5, 74%, 59%)"},".language-markdown .token.list.punctuation":{color:"hsl(5, 74%, 59%)"},".language-markdown .token.title.important > .token.punctuation":{color:"hsl(5, 74%, 59%)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:"0.8"},"token.tab:not(:empty):before":{color:"hsla(230, 8%, 24%, 0.2)"},"token.cr:before":{color:"hsla(230, 8%, 24%, 0.2)"},"token.lf:before":{color:"hsla(230, 8%, 24%, 0.2)"},"token.space:before":{color:"hsla(230, 8%, 24%, 0.2)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item":{marginRight:"0.4em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 6%, 44%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 6%, 44%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 6%, 44%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},".line-highlight.line-highlight":{background:"hsla(230, 8%, 24%, 0.05)"},".line-highlight.line-highlight:before":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 8%, 24%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},".line-highlight.line-highlight[data-end]:after":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 8%, 24%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"hsla(230, 8%, 24%, 0.05)"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"hsla(230, 8%, 24%, 0.2)"},".command-line .command-line-prompt":{borderRightColor:"hsla(230, 8%, 24%, 0.2)"},".line-numbers .line-numbers-rows > span:before":{color:"hsl(230, 1%, 62%)"},".command-line .command-line-prompt > span:before":{color:"hsl(230, 1%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"hsl(5, 74%, 59%)"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"hsl(5, 74%, 59%)"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"hsl(5, 74%, 59%)"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"hsl(119, 34%, 47%)"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"hsl(119, 34%, 47%)"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"hsl(119, 34%, 47%)"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"hsl(221, 87%, 60%)"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"hsl(221, 87%, 60%)"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"hsl(221, 87%, 60%)"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"hsl(301, 63%, 40%)"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"hsl(301, 63%, 40%)"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"hsl(301, 63%, 40%)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},".prism-previewer.prism-previewer:before":{borderColor:"hsl(0, 0, 95%)"},".prism-previewer-gradient.prism-previewer-gradient div":{borderColor:"hsl(0, 0, 95%)",borderRadius:"0.3em"},".prism-previewer-color.prism-previewer-color:before":{borderRadius:"0.3em"},".prism-previewer-easing.prism-previewer-easing:before":{borderRadius:"0.3em"},".prism-previewer.prism-previewer:after":{borderTopColor:"hsl(0, 0, 95%)"},".prism-previewer-flipped.prism-previewer-flipped.after":{borderBottomColor:"hsl(0, 0, 95%)"},".prism-previewer-angle.prism-previewer-angle:before":{background:"hsl(0, 0%, 100%)"},".prism-previewer-time.prism-previewer-time:before":{background:"hsl(0, 0%, 100%)"},".prism-previewer-easing.prism-previewer-easing":{background:"hsl(0, 0%, 100%)"},".prism-previewer-angle.prism-previewer-angle circle":{stroke:"hsl(230, 8%, 24%)",strokeOpacity:"1"},".prism-previewer-time.prism-previewer-time circle":{stroke:"hsl(230, 8%, 24%)",strokeOpacity:"1"},".prism-previewer-easing.prism-previewer-easing circle":{stroke:"hsl(230, 8%, 24%)",fill:"transparent"},".prism-previewer-easing.prism-previewer-easing path":{stroke:"hsl(230, 8%, 24%)"},".prism-previewer-easing.prism-previewer-easing line":{stroke:"hsl(230, 8%, 24%)"}}}(Jx)),Jx}var e0={},kz;function Swe(){return kz||(kz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"15px",lineHeight:"1.5",color:"#dccf8f",textShadow:"0"},'pre[class*="language-"]':{MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"15px",lineHeight:"1.5",color:"#DCCF8F",textShadow:"0",borderRadius:"5px",border:"1px solid #000",background:"#181914 url('data:image/jpeg;base64,/9j/4AAQSkZJRgABAgAAZABkAAD/7AARRHVja3kAAQAEAAAAMAAA/+4ADkFkb2JlAGTAAAAAAf/bAIQACQYGBgcGCQcHCQ0IBwgNDwsJCQsPEQ4ODw4OERENDg4ODg0RERQUFhQUERoaHBwaGiYmJiYmKysrKysrKysrKwEJCAgJCgkMCgoMDwwODA8TDg4ODhMVDg4PDg4VGhMRERERExoXGhYWFhoXHR0aGh0dJCQjJCQrKysrKysrKysr/8AAEQgAjACMAwEiAAIRAQMRAf/EAF4AAQEBAAAAAAAAAAAAAAAAAAABBwEBAQAAAAAAAAAAAAAAAAAAAAIQAAEDAwIHAQEAAAAAAAAAAADwAREhYaExkUFRcYGxwdHh8REBAAAAAAAAAAAAAAAAAAAAAP/aAAwDAQACEQMRAD8AyGFEjHaBS2fDDs2zkhKmBKktb7km+ZwwCnXPkLVmCTMItj6AXFxRS465/BTnkAJvkLkJe+7AKKoi2AtRS2zuAWsCb5GOlBN8gKfmuGHZ8MFqIth3ALmFoFwbwKWyAlTAp17uKqBvgBD8sM4fTjhvAhkzhaRkBMKBrfs7jGPIpzy7gFrAqnC0C0gB0EWwBDW2cBVQwm+QtPpa3wBO3sVvszCnLAhkzgL5/RLf13cLQd8/AGlu0Cb5HTx9KuAEieGJEdcehS3eRTp2ATdt3CpIm+QtZwAhROXFeb7swp/ahaM3kBE/jSIUBc/AWrgBN8uNFAl+b7sAXFxFn2YLUU5Ns7gFX8C4ib+hN8gFWXwK3bZglxEJm+gKdciLPsFV/TClsgJUwKJ5FVA7tvIFrfZhVfGJDcsCKaYgAqv6YRbE+RWOWBtu7+AL3yRalXLyKqAIIfk+zARbDgFyEsncYwJvlgFRW+GEWntIi2P0BooyFxcNr8Ep3+ANLbMO+QyhvbiqdgC0kVvgUUiLYgBS2QtPbiVI1/sgOmG9uO+Y8DW+7jS2zAOnj6O2BndwuIAUtkdRN8gFoK3wwXMQyZwHVbClsuNLd4E3yAUR6FVDBR+BafQGt93LVMxJTv8ABts4CVLhcfYWsCb5kC9/BHdU8CLYFY5bMAd+eX9MGthhpbA1vu4B7+RKkaW2Yq4AQtVBBFsAJU/AuIXBhN8gGWnstefhiZyWvLAEnbYS1uzSFP6Jvn4Baxx70JKkQojLib5AVTey1jjgkKJGO0AKWyOm7N7cSpgSpAdPH0Tfd/gp1z5C1ZgKqN9J2wFxcUUuAFLZAm+QC0Fb4YUVRFsAOvj4KW2dwtYE3yAWk/wS/PLMKfmuGHZ8MAXF/Ja32Yi5haAKWz4Ydm2cSpgU693Atb7km+Zwwh+WGcPpxw3gAkzCLY+iYUDW/Z3Adc/gpzyFrAqnALkJe+7DoItgAtRS2zuKqGE3yAx0oJvkdvYrfZmALURbDuL5/RLf13cAuDeBS2RpbtAm+QFVA3wR+3fUtFHoBDJnC0jIXH0HWsgMY8inPLuOkd9chp4z20ALQLSA8cI9jYAIa2zjzjBd8gRafS1vgiUho/kAKcsCGTOGWvoOpkAtB3z8Hm8x2Ff5ADp4+lXAlIvcmwH/2Q==') repeat left top",padding:"12px",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},':not(pre) > code[class*="language-"]':{borderRadius:"5px",border:"1px solid #000",color:"#DCCF8F",background:"#181914 url('data:image/jpeg;base64,/9j/4AAQSkZJRgABAgAAZABkAAD/7AARRHVja3kAAQAEAAAAMAAA/+4ADkFkb2JlAGTAAAAAAf/bAIQACQYGBgcGCQcHCQ0IBwgNDwsJCQsPEQ4ODw4OERENDg4ODg0RERQUFhQUERoaHBwaGiYmJiYmKysrKysrKysrKwEJCAgJCgkMCgoMDwwODA8TDg4ODhMVDg4PDg4VGhMRERERExoXGhYWFhoXHR0aGh0dJCQjJCQrKysrKysrKysr/8AAEQgAjACMAwEiAAIRAQMRAf/EAF4AAQEBAAAAAAAAAAAAAAAAAAABBwEBAQAAAAAAAAAAAAAAAAAAAAIQAAEDAwIHAQEAAAAAAAAAAADwAREhYaExkUFRcYGxwdHh8REBAAAAAAAAAAAAAAAAAAAAAP/aAAwDAQACEQMRAD8AyGFEjHaBS2fDDs2zkhKmBKktb7km+ZwwCnXPkLVmCTMItj6AXFxRS465/BTnkAJvkLkJe+7AKKoi2AtRS2zuAWsCb5GOlBN8gKfmuGHZ8MFqIth3ALmFoFwbwKWyAlTAp17uKqBvgBD8sM4fTjhvAhkzhaRkBMKBrfs7jGPIpzy7gFrAqnC0C0gB0EWwBDW2cBVQwm+QtPpa3wBO3sVvszCnLAhkzgL5/RLf13cLQd8/AGlu0Cb5HTx9KuAEieGJEdcehS3eRTp2ATdt3CpIm+QtZwAhROXFeb7swp/ahaM3kBE/jSIUBc/AWrgBN8uNFAl+b7sAXFxFn2YLUU5Ns7gFX8C4ib+hN8gFWXwK3bZglxEJm+gKdciLPsFV/TClsgJUwKJ5FVA7tvIFrfZhVfGJDcsCKaYgAqv6YRbE+RWOWBtu7+AL3yRalXLyKqAIIfk+zARbDgFyEsncYwJvlgFRW+GEWntIi2P0BooyFxcNr8Ep3+ANLbMO+QyhvbiqdgC0kVvgUUiLYgBS2QtPbiVI1/sgOmG9uO+Y8DW+7jS2zAOnj6O2BndwuIAUtkdRN8gFoK3wwXMQyZwHVbClsuNLd4E3yAUR6FVDBR+BafQGt93LVMxJTv8ABts4CVLhcfYWsCb5kC9/BHdU8CLYFY5bMAd+eX9MGthhpbA1vu4B7+RKkaW2Yq4AQtVBBFsAJU/AuIXBhN8gGWnstefhiZyWvLAEnbYS1uzSFP6Jvn4Baxx70JKkQojLib5AVTey1jjgkKJGO0AKWyOm7N7cSpgSpAdPH0Tfd/gp1z5C1ZgKqN9J2wFxcUUuAFLZAm+QC0Fb4YUVRFsAOvj4KW2dwtYE3yAWk/wS/PLMKfmuGHZ8MAXF/Ja32Yi5haAKWz4Ydm2cSpgU693Atb7km+Zwwh+WGcPpxw3gAkzCLY+iYUDW/Z3Adc/gpzyFrAqnALkJe+7DoItgAtRS2zuKqGE3yAx0oJvkdvYrfZmALURbDuL5/RLf13cAuDeBS2RpbtAm+QFVA3wR+3fUtFHoBDJnC0jIXH0HWsgMY8inPLuOkd9chp4z20ALQLSA8cI9jYAIa2zjzjBd8gRafS1vgiUho/kAKcsCGTOGWvoOpkAtB3z8Hm8x2Ff5ADp4+lXAlIvcmwH/2Q==') repeat left top",padding:"2px 6px"},namespace:{Opacity:".7"},comment:{color:"#586e75",fontStyle:"italic"},prolog:{color:"#586e75",fontStyle:"italic"},doctype:{color:"#586e75",fontStyle:"italic"},cdata:{color:"#586e75",fontStyle:"italic"},number:{color:"#b89859"},string:{color:"#468966"},char:{color:"#468966"},builtin:{color:"#468966"},inserted:{color:"#468966"},"attr-name":{color:"#b89859"},operator:{color:"#dccf8f"},entity:{color:"#dccf8f",cursor:"help"},url:{color:"#dccf8f"},".language-css .token.string":{color:"#dccf8f"},".style .token.string":{color:"#dccf8f"},selector:{color:"#859900"},regex:{color:"#859900"},atrule:{color:"#cb4b16"},keyword:{color:"#cb4b16"},"attr-value":{color:"#468966"},function:{color:"#b58900"},variable:{color:"#b58900"},placeholder:{color:"#b58900"},property:{color:"#b89859"},tag:{color:"#ffb03b"},boolean:{color:"#b89859"},constant:{color:"#b89859"},symbol:{color:"#b89859"},important:{color:"#dc322f"},statement:{color:"#dc322f"},deleted:{color:"#dc322f"},punctuation:{color:"#dccf8f"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(e0)),e0}var t0={},Tz;function Ewe(){return Tz||(Tz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={"code[class*='language-']":{color:"#9efeff",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",fontFamily:"'Operator Mono', 'Fira Code', Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontWeight:"400",fontSize:"17px",lineHeight:"25px",letterSpacing:"0.5px",textShadow:"0 1px #222245"},"pre[class*='language-']":{color:"#9efeff",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",fontFamily:"'Operator Mono', 'Fira Code', Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontWeight:"400",fontSize:"17px",lineHeight:"25px",letterSpacing:"0.5px",textShadow:"0 1px #222245",padding:"2em",margin:"0.5em 0",overflow:"auto",background:"#1e1e3f"},"pre[class*='language-']::-moz-selection":{color:"inherit",background:"#a599e9"},"pre[class*='language-'] ::-moz-selection":{color:"inherit",background:"#a599e9"},"code[class*='language-']::-moz-selection":{color:"inherit",background:"#a599e9"},"code[class*='language-'] ::-moz-selection":{color:"inherit",background:"#a599e9"},"pre[class*='language-']::selection":{color:"inherit",background:"#a599e9"},"pre[class*='language-'] ::selection":{color:"inherit",background:"#a599e9"},"code[class*='language-']::selection":{color:"inherit",background:"#a599e9"},"code[class*='language-'] ::selection":{color:"inherit",background:"#a599e9"},":not(pre) > code[class*='language-']":{background:"#1e1e3f",padding:"0.1em",borderRadius:"0.3em"},"":{fontWeight:"400"},comment:{color:"#b362ff"},prolog:{color:"#b362ff"},cdata:{color:"#b362ff"},delimiter:{color:"#ff9d00"},keyword:{color:"#ff9d00"},selector:{color:"#ff9d00"},important:{color:"#ff9d00"},atrule:{color:"#ff9d00"},operator:{color:"rgb(255, 180, 84)",background:"none"},"attr-name":{color:"rgb(255, 180, 84)"},punctuation:{color:"#ffffff"},boolean:{color:"rgb(255, 98, 140)"},tag:{color:"rgb(255, 157, 0)"},"tag.punctuation":{color:"rgb(255, 157, 0)"},doctype:{color:"rgb(255, 157, 0)"},builtin:{color:"rgb(255, 157, 0)"},entity:{color:"#6897bb",background:"none"},symbol:{color:"#6897bb"},number:{color:"#ff628c"},property:{color:"#ff628c"},constant:{color:"#ff628c"},variable:{color:"#ff628c"},string:{color:"#a5ff90"},char:{color:"#a5ff90"},"attr-value":{color:"#a5c261"},"attr-value.punctuation":{color:"#a5c261"},"attr-value.punctuation:first-child":{color:"#a9b7c6"},url:{color:"#287bde",textDecoration:"underline",background:"none"},function:{color:"rgb(250, 208, 0)"},regex:{background:"#364135"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#00ff00"},deleted:{background:"#ff000d"},"code.language-css .token.property":{color:"#a9b7c6"},"code.language-css .token.property + .token.punctuation":{color:"#a9b7c6"},"code.language-css .token.id":{color:"#ffc66d"},"code.language-css .token.selector > .token.class":{color:"#ffc66d"},"code.language-css .token.selector > .token.attribute":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-class":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-element":{color:"#ffc66d"},"class-name":{color:"#fb94ff"},".language-css .token.string":{background:"none"},".style .token.string":{background:"none"},".line-highlight.line-highlight":{marginTop:"36px",background:"linear-gradient(to right, rgba(179, 98, 255, 0.17), transparent)"},".line-highlight.line-highlight:before":{content:"''"},".line-highlight.line-highlight[data-end]:after":{content:"''"}}}(t0)),t0}var n0={},Az;function wwe(){return Az||(Az=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#839496",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#839496",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em",background:"#002b36"},':not(pre) > code[class*="language-"]':{background:"#002b36",padding:".1em",borderRadius:".3em"},comment:{color:"#586e75"},prolog:{color:"#586e75"},doctype:{color:"#586e75"},cdata:{color:"#586e75"},punctuation:{color:"#93a1a1"},".namespace":{Opacity:".7"},property:{color:"#268bd2"},keyword:{color:"#268bd2"},tag:{color:"#268bd2"},"class-name":{color:"#FFFFB6",textDecoration:"underline"},boolean:{color:"#b58900"},constant:{color:"#b58900"},symbol:{color:"#dc322f"},deleted:{color:"#dc322f"},number:{color:"#859900"},selector:{color:"#859900"},"attr-name":{color:"#859900"},string:{color:"#859900"},char:{color:"#859900"},builtin:{color:"#859900"},inserted:{color:"#859900"},variable:{color:"#268bd2"},operator:{color:"#EDEDED"},function:{color:"#268bd2"},regex:{color:"#E9C062"},important:{color:"#fd971f",fontWeight:"bold"},entity:{color:"#FFFFB6",cursor:"help"},url:{color:"#96CBFE"},".language-css .token.string":{color:"#87C38A"},".style .token.string":{color:"#87C38A"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},atrule:{color:"#F9EE98"},"attr-value":{color:"#F9EE98"}}}(n0)),n0}var r0={},Rz;function xwe(){return Rz||(Rz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",backgroundColor:"transparent !important",backgroundImage:"linear-gradient(to bottom, #2a2139 75%, #34294f)"},':not(pre) > code[class*="language-"]':{backgroundColor:"transparent !important",backgroundImage:"linear-gradient(to bottom, #2a2139 75%, #34294f)",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#8e8e8e"},"block-comment":{color:"#8e8e8e"},prolog:{color:"#8e8e8e"},doctype:{color:"#8e8e8e"},cdata:{color:"#8e8e8e"},punctuation:{color:"#ccc"},tag:{color:"#e2777a"},"attr-name":{color:"#e2777a"},namespace:{color:"#e2777a"},number:{color:"#e2777a"},unit:{color:"#e2777a"},hexcode:{color:"#e2777a"},deleted:{color:"#e2777a"},property:{color:"#72f1b8",textShadow:"0 0 2px #100c0f, 0 0 10px #257c5575, 0 0 35px #21272475"},selector:{color:"#72f1b8",textShadow:"0 0 2px #100c0f, 0 0 10px #257c5575, 0 0 35px #21272475"},"function-name":{color:"#6196cc"},boolean:{color:"#fdfdfd",textShadow:"0 0 2px #001716, 0 0 3px #03edf975, 0 0 5px #03edf975, 0 0 8px #03edf975"},"selector.id":{color:"#fdfdfd",textShadow:"0 0 2px #001716, 0 0 3px #03edf975, 0 0 5px #03edf975, 0 0 8px #03edf975"},function:{color:"#fdfdfd",textShadow:"0 0 2px #001716, 0 0 3px #03edf975, 0 0 5px #03edf975, 0 0 8px #03edf975"},"class-name":{color:"#fff5f6",textShadow:"0 0 2px #000, 0 0 10px #fc1f2c75, 0 0 5px #fc1f2c75, 0 0 25px #fc1f2c75"},constant:{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3"},symbol:{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3"},important:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575",fontWeight:"bold"},atrule:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},keyword:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},"selector.class":{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},builtin:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},string:{color:"#f87c32"},char:{color:"#f87c32"},"attr-value":{color:"#f87c32"},regex:{color:"#f87c32"},variable:{color:"#f87c32"},operator:{color:"#67cdcc"},entity:{color:"#67cdcc",cursor:"help"},url:{color:"#67cdcc"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{color:"green"}}}(r0)),r0}var a0={},Cz;function kwe(){return Cz||(Cz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",border:"1px solid #dddddd",backgroundColor:"white"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{background:"#C1DEF1"},'pre[class*="language-"] ::-moz-selection':{background:"#C1DEF1"},'code[class*="language-"]::-moz-selection':{background:"#C1DEF1"},'code[class*="language-"] ::-moz-selection':{background:"#C1DEF1"},'pre[class*="language-"]::selection':{background:"#C1DEF1"},'pre[class*="language-"] ::selection':{background:"#C1DEF1"},'code[class*="language-"]::selection':{background:"#C1DEF1"},'code[class*="language-"] ::selection':{background:"#C1DEF1"},':not(pre) > code[class*="language-"]':{padding:".2em",paddingTop:"1px",paddingBottom:"1px",background:"#f8f8f8",border:"1px solid #dddddd"},comment:{color:"#008000",fontStyle:"italic"},prolog:{color:"#008000",fontStyle:"italic"},doctype:{color:"#008000",fontStyle:"italic"},cdata:{color:"#008000",fontStyle:"italic"},namespace:{Opacity:".7"},string:{color:"#A31515"},punctuation:{color:"#393A34"},operator:{color:"#393A34"},url:{color:"#36acaa"},symbol:{color:"#36acaa"},number:{color:"#36acaa"},boolean:{color:"#36acaa"},variable:{color:"#36acaa"},constant:{color:"#36acaa"},inserted:{color:"#36acaa"},atrule:{color:"#0000ff"},keyword:{color:"#0000ff"},"attr-value":{color:"#0000ff"},".language-autohotkey .token.selector":{color:"#0000ff"},".language-json .token.boolean":{color:"#0000ff"},".language-json .token.number":{color:"#0000ff"},'code[class*="language-css"]':{color:"#0000ff"},function:{color:"#393A34"},deleted:{color:"#9a050f"},".language-autohotkey .token.tag":{color:"#9a050f"},selector:{color:"#800000"},".language-autohotkey .token.keyword":{color:"#00009f"},important:{color:"#e90",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},"class-name":{color:"#2B91AF"},".language-json .token.property":{color:"#2B91AF"},tag:{color:"#800000"},"attr-name":{color:"#ff0000"},property:{color:"#ff0000"},regex:{color:"#ff0000"},entity:{color:"#ff0000"},"directive.tag.tag":{background:"#ffff00",color:"#393A34"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#a5a5a5"},".line-numbers .line-numbers-rows > span:before":{color:"#2B91AF"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(193, 222, 241, 0.2) 70%, rgba(221, 222, 241, 0))"}}}(a0)),a0}var o0={},_z;function Twe(){return _z||(_z=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'pre[class*="language-"]':{color:"#d4d4d4",fontSize:"13px",textShadow:"none",fontFamily:'Menlo, Monaco, Consolas, "Andale Mono", "Ubuntu Mono", "Courier New", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",background:"#1e1e1e"},'code[class*="language-"]':{color:"#d4d4d4",fontSize:"13px",textShadow:"none",fontFamily:'Menlo, Monaco, Consolas, "Andale Mono", "Ubuntu Mono", "Courier New", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#264F78"},'code[class*="language-"]::selection':{textShadow:"none",background:"#264F78"},'pre[class*="language-"] *::selection':{textShadow:"none",background:"#264F78"},'code[class*="language-"] *::selection':{textShadow:"none",background:"#264F78"},':not(pre) > code[class*="language-"]':{padding:".1em .3em",borderRadius:".3em",color:"#db4c69",background:"#1e1e1e"},".namespace":{Opacity:".7"},"doctype.doctype-tag":{color:"#569CD6"},"doctype.name":{color:"#9cdcfe"},comment:{color:"#6a9955"},prolog:{color:"#6a9955"},punctuation:{color:"#d4d4d4"},".language-html .language-css .token.punctuation":{color:"#d4d4d4"},".language-html .language-javascript .token.punctuation":{color:"#d4d4d4"},property:{color:"#9cdcfe"},tag:{color:"#569cd6"},boolean:{color:"#569cd6"},number:{color:"#b5cea8"},constant:{color:"#9cdcfe"},symbol:{color:"#b5cea8"},inserted:{color:"#b5cea8"},unit:{color:"#b5cea8"},selector:{color:"#d7ba7d"},"attr-name":{color:"#9cdcfe"},string:{color:"#ce9178"},char:{color:"#ce9178"},builtin:{color:"#ce9178"},deleted:{color:"#ce9178"},".language-css .token.string.url":{textDecoration:"underline"},operator:{color:"#d4d4d4"},entity:{color:"#569cd6"},"operator.arrow":{color:"#569CD6"},atrule:{color:"#ce9178"},"atrule.rule":{color:"#c586c0"},"atrule.url":{color:"#9cdcfe"},"atrule.url.function":{color:"#dcdcaa"},"atrule.url.punctuation":{color:"#d4d4d4"},keyword:{color:"#569CD6"},"keyword.module":{color:"#c586c0"},"keyword.control-flow":{color:"#c586c0"},function:{color:"#dcdcaa"},"function.maybe-class-name":{color:"#dcdcaa"},regex:{color:"#d16969"},important:{color:"#569cd6"},italic:{fontStyle:"italic"},"class-name":{color:"#4ec9b0"},"maybe-class-name":{color:"#4ec9b0"},console:{color:"#9cdcfe"},parameter:{color:"#9cdcfe"},interpolation:{color:"#9cdcfe"},"punctuation.interpolation-punctuation":{color:"#569cd6"},variable:{color:"#9cdcfe"},"imports.maybe-class-name":{color:"#9cdcfe"},"exports.maybe-class-name":{color:"#9cdcfe"},escape:{color:"#d7ba7d"},"tag.punctuation":{color:"#808080"},cdata:{color:"#808080"},"attr-value":{color:"#ce9178"},"attr-value.punctuation":{color:"#ce9178"},"attr-value.punctuation.attr-equals":{color:"#d4d4d4"},namespace:{color:"#4ec9b0"},'pre[class*="language-javascript"]':{color:"#9cdcfe"},'code[class*="language-javascript"]':{color:"#9cdcfe"},'pre[class*="language-jsx"]':{color:"#9cdcfe"},'code[class*="language-jsx"]':{color:"#9cdcfe"},'pre[class*="language-typescript"]':{color:"#9cdcfe"},'code[class*="language-typescript"]':{color:"#9cdcfe"},'pre[class*="language-tsx"]':{color:"#9cdcfe"},'code[class*="language-tsx"]':{color:"#9cdcfe"},'pre[class*="language-css"]':{color:"#ce9178"},'code[class*="language-css"]':{color:"#ce9178"},'pre[class*="language-html"]':{color:"#d4d4d4"},'code[class*="language-html"]':{color:"#d4d4d4"},".language-regex .token.anchor":{color:"#dcdcaa"},".language-html .token.punctuation":{color:"#808080"},'pre[class*="language-"] > code[class*="language-"]':{position:"relative",zIndex:"1"},".line-highlight.line-highlight":{background:"#f7ebc6",boxShadow:"inset 5px 0 0 #f7d87c",zIndex:"0"}}}(o0)),o0}var i0={},Nz;function Awe(){return Nz||(Nz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordWrap:"normal",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"14px",color:"#76d9e6",textShadow:"none"},'pre[class*="language-"]':{MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordWrap:"normal",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"14px",color:"#76d9e6",textShadow:"none",background:"#2a2a2a",padding:"15px",borderRadius:"4px",border:"1px solid #e1e1e8",overflow:"auto",position:"relative"},'pre > code[class*="language-"]':{fontSize:"1em"},':not(pre) > code[class*="language-"]':{background:"#2a2a2a",padding:"0.15em 0.2em 0.05em",borderRadius:".3em",border:"0.13em solid #7a6652",boxShadow:"1px 1px 0.3em -0.1em #000 inset"},'pre[class*="language-"] code':{whiteSpace:"pre",display:"block"},namespace:{Opacity:".7"},comment:{color:"#6f705e"},prolog:{color:"#6f705e"},doctype:{color:"#6f705e"},cdata:{color:"#6f705e"},operator:{color:"#a77afe"},boolean:{color:"#a77afe"},number:{color:"#a77afe"},"attr-name":{color:"#e6d06c"},string:{color:"#e6d06c"},entity:{color:"#e6d06c",cursor:"help"},url:{color:"#e6d06c"},".language-css .token.string":{color:"#e6d06c"},".style .token.string":{color:"#e6d06c"},selector:{color:"#a6e22d"},inserted:{color:"#a6e22d"},atrule:{color:"#ef3b7d"},"attr-value":{color:"#ef3b7d"},keyword:{color:"#ef3b7d"},important:{color:"#ef3b7d",fontWeight:"bold"},deleted:{color:"#ef3b7d"},regex:{color:"#76d9e6"},statement:{color:"#76d9e6",fontWeight:"bold"},placeholder:{color:"#fff"},variable:{color:"#fff"},bold:{fontWeight:"bold"},punctuation:{color:"#bebec5"},italic:{fontStyle:"italic"},"code.language-markup":{color:"#f9f9f9"},"code.language-markup .token.tag":{color:"#ef3b7d"},"code.language-markup .token.attr-name":{color:"#a6e22d"},"code.language-markup .token.attr-value":{color:"#e6d06c"},"code.language-markup .token.style":{color:"#76d9e6"},"code.language-markup .token.script":{color:"#76d9e6"},"code.language-markup .token.script .token.keyword":{color:"#76d9e6"},".line-highlight.line-highlight":{padding:"0",background:"rgba(255, 255, 255, 0.08)"},".line-highlight.line-highlight:before":{padding:"0.2em 0.5em",backgroundColor:"rgba(255, 255, 255, 0.4)",color:"black",height:"1em",lineHeight:"1em",boxShadow:"0 1px 1px rgba(255, 255, 255, 0.7)"},".line-highlight.line-highlight[data-end]:after":{padding:"0.2em 0.5em",backgroundColor:"rgba(255, 255, 255, 0.4)",color:"black",height:"1em",lineHeight:"1em",boxShadow:"0 1px 1px rgba(255, 255, 255, 0.7)"}}}(i0)),i0}var s0={},Oz;function Rwe(){return Oz||(Oz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#22da17",fontFamily:"monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",lineHeight:"25px",fontSize:"18px",margin:"5px 0"},'pre[class*="language-"]':{color:"white",fontFamily:"monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",lineHeight:"25px",fontSize:"18px",margin:"0.5em 0",background:"#0a143c",padding:"1em",overflow:"auto"},'pre[class*="language-"] *':{fontFamily:"monospace"},':not(pre) > code[class*="language-"]':{color:"white",background:"#0a143c",padding:"0.1em",borderRadius:"0.3em",whiteSpace:"normal"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},comment:{color:"rgb(99, 119, 119)",fontStyle:"italic"},prolog:{color:"rgb(99, 119, 119)",fontStyle:"italic"},cdata:{color:"rgb(99, 119, 119)",fontStyle:"italic"},punctuation:{color:"rgb(199, 146, 234)"},".namespace":{color:"rgb(178, 204, 214)"},deleted:{color:"rgba(239, 83, 80, 0.56)",fontStyle:"italic"},symbol:{color:"rgb(128, 203, 196)"},property:{color:"rgb(128, 203, 196)"},tag:{color:"rgb(127, 219, 202)"},operator:{color:"rgb(127, 219, 202)"},keyword:{color:"rgb(127, 219, 202)"},boolean:{color:"rgb(255, 88, 116)"},number:{color:"rgb(247, 140, 108)"},constant:{color:"rgb(34 183 199)"},function:{color:"rgb(34 183 199)"},builtin:{color:"rgb(34 183 199)"},char:{color:"rgb(34 183 199)"},selector:{color:"rgb(199, 146, 234)",fontStyle:"italic"},doctype:{color:"rgb(199, 146, 234)",fontStyle:"italic"},"attr-name":{color:"rgb(173, 219, 103)",fontStyle:"italic"},inserted:{color:"rgb(173, 219, 103)",fontStyle:"italic"},string:{color:"rgb(173, 219, 103)"},url:{color:"rgb(173, 219, 103)"},entity:{color:"rgb(173, 219, 103)"},".language-css .token.string":{color:"rgb(173, 219, 103)"},".style .token.string":{color:"rgb(173, 219, 103)"},"class-name":{color:"rgb(255, 203, 139)"},atrule:{color:"rgb(255, 203, 139)"},"attr-value":{color:"rgb(255, 203, 139)"},regex:{color:"rgb(214, 222, 235)"},important:{color:"rgb(214, 222, 235)",fontWeight:"bold"},variable:{color:"rgb(214, 222, 235)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(s0)),s0}var Iz;function Cwe(){return Iz||(Iz=1,function(e){var t=FEe();Object.defineProperty(e,"__esModule",{value:!0}),Object.defineProperty(e,"a11yDark",{enumerable:!0,get:function(){return p.default}}),Object.defineProperty(e,"atomDark",{enumerable:!0,get:function(){return g.default}}),Object.defineProperty(e,"base16AteliersulphurpoolLight",{enumerable:!0,get:function(){return m.default}}),Object.defineProperty(e,"cb",{enumerable:!0,get:function(){return b.default}}),Object.defineProperty(e,"coldarkCold",{enumerable:!0,get:function(){return v.default}}),Object.defineProperty(e,"coldarkDark",{enumerable:!0,get:function(){return y.default}}),Object.defineProperty(e,"coy",{enumerable:!0,get:function(){return n.default}}),Object.defineProperty(e,"coyWithoutShadows",{enumerable:!0,get:function(){return k.default}}),Object.defineProperty(e,"darcula",{enumerable:!0,get:function(){return A.default}}),Object.defineProperty(e,"dark",{enumerable:!0,get:function(){return r.default}}),Object.defineProperty(e,"dracula",{enumerable:!0,get:function(){return x.default}}),Object.defineProperty(e,"duotoneDark",{enumerable:!0,get:function(){return R.default}}),Object.defineProperty(e,"duotoneEarth",{enumerable:!0,get:function(){return O.default}}),Object.defineProperty(e,"duotoneForest",{enumerable:!0,get:function(){return N.default}}),Object.defineProperty(e,"duotoneLight",{enumerable:!0,get:function(){return C.default}}),Object.defineProperty(e,"duotoneSea",{enumerable:!0,get:function(){return _.default}}),Object.defineProperty(e,"duotoneSpace",{enumerable:!0,get:function(){return M.default}}),Object.defineProperty(e,"funky",{enumerable:!0,get:function(){return a.default}}),Object.defineProperty(e,"ghcolors",{enumerable:!0,get:function(){return I.default}}),Object.defineProperty(e,"gruvboxDark",{enumerable:!0,get:function(){return D.default}}),Object.defineProperty(e,"gruvboxLight",{enumerable:!0,get:function(){return U.default}}),Object.defineProperty(e,"holiTheme",{enumerable:!0,get:function(){return $.default}}),Object.defineProperty(e,"hopscotch",{enumerable:!0,get:function(){return B.default}}),Object.defineProperty(e,"lucario",{enumerable:!0,get:function(){return W.default}}),Object.defineProperty(e,"materialDark",{enumerable:!0,get:function(){return K.default}}),Object.defineProperty(e,"materialLight",{enumerable:!0,get:function(){return H.default}}),Object.defineProperty(e,"materialOceanic",{enumerable:!0,get:function(){return G.default}}),Object.defineProperty(e,"nightOwl",{enumerable:!0,get:function(){return z.default}}),Object.defineProperty(e,"nord",{enumerable:!0,get:function(){return Y.default}}),Object.defineProperty(e,"okaidia",{enumerable:!0,get:function(){return o.default}}),Object.defineProperty(e,"oneDark",{enumerable:!0,get:function(){return L.default}}),Object.defineProperty(e,"oneLight",{enumerable:!0,get:function(){return V.default}}),Object.defineProperty(e,"pojoaque",{enumerable:!0,get:function(){return j.default}}),Object.defineProperty(e,"prism",{enumerable:!0,get:function(){return d.default}}),Object.defineProperty(e,"shadesOfPurple",{enumerable:!0,get:function(){return P.default}}),Object.defineProperty(e,"solarizedDarkAtom",{enumerable:!0,get:function(){return Z.default}}),Object.defineProperty(e,"solarizedlight",{enumerable:!0,get:function(){return s.default}}),Object.defineProperty(e,"synthwave84",{enumerable:!0,get:function(){return Q.default}}),Object.defineProperty(e,"tomorrow",{enumerable:!0,get:function(){return l.default}}),Object.defineProperty(e,"twilight",{enumerable:!0,get:function(){return u.default}}),Object.defineProperty(e,"vs",{enumerable:!0,get:function(){return oe.default}}),Object.defineProperty(e,"vscDarkPlus",{enumerable:!0,get:function(){return ae.default}}),Object.defineProperty(e,"xonokai",{enumerable:!0,get:function(){return ce.default}}),Object.defineProperty(e,"zTouch",{enumerable:!0,get:function(){return Re.default}});var n=t(zEe()),r=t(BEe()),a=t(jEe()),o=t(UEe()),s=t(GEe()),l=t(HEe()),u=t($Ee()),d=t(qEe()),p=t(VEe()),g=t(WEe()),m=t(YEe()),b=t(KEe()),v=t(XEe()),y=t(ZEe()),k=t(QEe()),A=t(JEe()),x=t(ewe()),R=t(twe()),O=t(nwe()),N=t(rwe()),C=t(awe()),_=t(owe()),M=t(iwe()),I=t(swe()),D=t(lwe()),U=t(cwe()),$=t(uwe()),B=t(dwe()),W=t(fwe()),K=t(pwe()),H=t(gwe()),G=t(hwe()),z=t(mwe()),Y=t(bwe()),L=t(ywe()),V=t(vwe()),j=t(Swe()),P=t(Ewe()),Z=t(wwe()),Q=t(xwe()),oe=t(kwe()),ae=t(Twe()),ce=t(Awe()),Re=t(Rwe())}(mx)),mx}var Dz=Cwe();const _we=({message:e})=>{const{t}=Et(),n=w.useCallback(async()=>{if(e.content)try{await navigator.clipboard.writeText(e.content)}catch(r){console.error(t("chat.copyError"),r)}},[e]);return E.jsxs("div",{className:`max-w-[80%] rounded-lg px-4 py-2 ${e.role==="user"?"bg-primary text-primary-foreground":e.isError?"bg-red-100 text-red-600 dark:bg-red-950 dark:text-red-400":"bg-muted"}`,children:[E.jsxs("pre",{className:"relative break-words whitespace-pre-wrap",children:[E.jsx(_de,{className:"dark:prose-invert max-w-none text-base text-sm",remarkPlugins:[Upe,Jpe],rehypePlugins:[Gpe],skipHtml:!1,components:{code:Owe},children:e.content}),e.role==="assistant"&&e.content.length>0&&E.jsx(nt,{onClick:n,className:"absolute right-0 bottom-0 size-6 rounded-md opacity-20 transition-opacity hover:opacity-100",tooltip:t("retrievePanel.chatMessage.copyTooltip"),variant:"default",size:"icon",children:E.jsx(uZ,{})})]}),e.content.length===0&&E.jsx(RZ,{className:"animate-spin duration-2000"})]})},Nwe=e=>!(e.children||[]).filter(n=>n.type==="text").map(n=>n.value).join("").includes(`
`),Owe=({className:e,children:t,node:n,...r})=>{const{theme:a}=A5(),o=e==null?void 0:e.match(/language-(\w+)/),s=o?o[1]:void 0;return(n?Nwe(n):!1)?E.jsx("code",{className:Me(e,"mx-1 rounded-xs bg-black/10 px-1 dark:bg-gray-100/20"),...r,children:t}):E.jsx(WH,{style:a==="dark"?Dz.oneDark:Dz.oneLight,PreTag:"div",language:s,...r,children:String(t).replace(/\n$/,"")})};function Iwe(){const{t:e}=Et(),[t,n]=w.useState(()=>De.getState().retrievalHistory||[]),[r,a]=w.useState(""),[o,s]=w.useState(!1),l=w.useRef(null),u=w.useCallback(()=>{var m;(m=l.current)==null||m.scrollIntoView({behavior:"smooth"})},[]),d=w.useCallback(async m=>{if(m.preventDefault(),!r.trim()||o)return;const b={content:r,role:"user"},v={content:"",role:"assistant"},y=[...t];n([...y,b,v]),a(""),s(!0);const k=(R,O)=>{v.content+=R,n(N=>{const C=[...N],_=C[C.length-1];return _.role==="assistant"&&(_.content=v.content,_.isError=O),C})},A=De.getState(),x={...A.querySettings,query:b.content,conversation_history:y.filter(R=>R.isError!==!0).map(R=>({role:R.role,content:R.content}))};try{if(A.querySettings.stream){let R="";await NV(x,k,O=>{R+=O}),R&&(v.content&&(R=v.content+`
`+R),k(R,!0))}else{const R=await _V(x);k(R.response)}}catch(R){k(`${e("retrievePanel.retrieval.error")}
${Gn(R)}`,!0)}finally{s(!1),De.getState().setRetrievalHistory([...y,b,v])}},[r,o,t,n,e]),p=qT(t,100);w.useEffect(()=>u(),[p,u]);const g=w.useCallback(()=>{n([]),De.getState().setRetrievalHistory([])},[n]);return E.jsxs("div",{className:"flex size-full gap-2 px-2 pb-12 overflow-hidden",children:[E.jsxs("div",{className:"flex grow flex-col gap-4",children:[E.jsx("div",{className:"relative grow",children:E.jsx("div",{className:"bg-primary-foreground/60 absolute inset-0 flex flex-col overflow-auto rounded-lg border p-2",children:E.jsxs("div",{className:"flex min-h-0 flex-1 flex-col gap-2",children:[t.length===0?E.jsx("div",{className:"text-muted-foreground flex h-full items-center justify-center text-lg",children:e("retrievePanel.retrieval.startPrompt")}):t.map((m,b)=>E.jsx("div",{className:`flex ${m.role==="user"?"justify-end":"justify-start"}`,children:E.jsx(_we,{message:m})},b)),E.jsx("div",{ref:l,className:"pb-1"})]})})}),E.jsxs("form",{onSubmit:d,className:"flex shrink-0 items-center gap-2",children:[E.jsxs(nt,{type:"button",variant:"outline",onClick:g,disabled:o,size:"sm",children:[E.jsx(zU,{}),e("retrievePanel.retrieval.clear")]}),E.jsxs("div",{className:"flex-1 relative",children:[E.jsx("label",{htmlFor:"query-input",className:"sr-only",children:e("retrievePanel.retrieval.placeholder")}),E.jsx(kr,{id:"query-input",className:"w-full",value:r,onChange:m=>a(m.target.value),placeholder:e("retrievePanel.retrieval.placeholder"),disabled:o})]}),E.jsxs(nt,{type:"submit",variant:"default",disabled:o,size:"sm",children:[E.jsx(XZ,{}),e("retrievePanel.retrieval.send")]})]})]}),E.jsx(yse,{})]})}const Dwe=()=>{const e=w.useContext(aj);if(!e)throw new Error("useTabVisibility must be used within a TabVisibilityProvider");return e};function Lwe(){const{t:e}=Et(),{isTabVisible:t}=Dwe(),n=t("api"),[r,a]=w.useState(!1);return w.useEffect(()=>{r||a(!0)},[r]),E.jsx("div",{className:`size-full ${n?"":"hidden"}`,children:r?E.jsx("iframe",{src:WB+"/docs",className:"size-full w-full h-full",style:{width:"100%",height:"100%",border:"none"}},"api-docs-iframe"):E.jsx("div",{className:"flex h-full w-full items-center justify-center bg-background",children:E.jsxs("div",{className:"text-center",children:[E.jsx("div",{className:"mb-2 h-8 w-8 animate-spin rounded-full border-4 border-primary border-t-transparent"}),E.jsx("p",{children:e("apiSite.loading")})]})})})}function Mwe(){const e=rr.use.message(),t=De.use.enableHealthCheck(),n=De.use.currentTab(),[r,a]=w.useState(!1),[o,s]=w.useState(!0),l=w.useRef(!1),u=w.useCallback(g=>{a(g),g||rr.getState().clear()},[]),d=w.useRef(!0);w.useEffect(()=>{d.current=!0;const g=()=>{d.current=!1};return window.addEventListener("beforeunload",g),()=>{d.current=!1,window.removeEventListener("beforeunload",g)}},[]),w.useEffect(()=>{if(!t||r)return;const m=setInterval(async()=>{try{d.current&&await rr.getState().check()}catch(b){console.error("Health check error:",b)}},gV*1e3);return()=>clearInterval(m)},[t,r]),w.useEffect(()=>{(async()=>{if(l.current)return;if(l.current=!0,sessionStorage.getItem("VERSION_CHECKED_FROM_LOGIN")==="true"){s(!1);return}try{s(!0);const b=localStorage.getItem("LIGHTRAG-API-TOKEN"),v=await JB();if(!v.auth_configured&&v.access_token)wr.getState().login(v.access_token,!0,v.core_version,v.api_version,v.webui_title||null,v.webui_description||null);else if(b&&(v.core_version||v.api_version||v.webui_title||v.webui_description)){const y=v.auth_mode==="disabled"||wr.getState().isGuestMode;wr.getState().login(b,y,v.core_version,v.api_version,v.webui_title||null,v.webui_description||null)}sessionStorage.setItem("VERSION_CHECKED_FROM_LOGIN","true")}catch(b){console.error("Failed to get version info:",b)}finally{s(!1)}})()},[]);const p=w.useCallback(g=>De.getState().setCurrentTab(g),[]);return w.useEffect(()=>{e&&(e.includes(XB)||e.includes(ZB))&&a(!0)},[e]),E.jsx(rj,{children:E.jsx(gW,{children:o?E.jsxs("div",{className:"flex h-screen w-screen flex-col",children:[E.jsxs("header",{className:"border-border/40 bg-background/95 supports-[backdrop-filter]:bg-background/60 sticky top-0 z-50 flex h-10 w-full border-b px-4 backdrop-blur",children:[E.jsx("div",{className:"min-w-[200px] w-auto flex items-center",children:E.jsxs("a",{href:YB,className:"flex items-center gap-2",children:[E.jsx(ET,{className:"size-4 text-emerald-400","aria-hidden":"true"}),E.jsx("span",{className:"font-bold md:inline-block",children:x0.name})]})}),E.jsx("div",{className:"flex h-10 flex-1 items-center justify-center"}),E.jsx("nav",{className:"w-[200px] flex items-center justify-end"})]}),E.jsx("div",{className:"flex flex-1 items-center justify-center",children:E.jsxs("div",{className:"text-center",children:[E.jsx("div",{className:"mb-2 h-8 w-8 animate-spin rounded-full border-4 border-primary border-t-transparent"}),E.jsx("p",{children:"Initializing..."})]})})]}):E.jsxs("main",{className:"flex h-screen w-screen overflow-hidden",children:[E.jsxs(gJ,{defaultValue:n,className:"!m-0 flex grow flex-col !p-0 overflow-hidden",onValueChange:p,children:[E.jsx(mJ,{}),E.jsxs("div",{className:"relative grow",children:[E.jsx(gc,{value:"documents",className:"absolute top-0 right-0 bottom-0 left-0 overflow-auto",children:E.jsx(Wie,{})}),E.jsx(gc,{value:"knowledge-graph",className:"absolute top-0 right-0 bottom-0 left-0 overflow-hidden",children:E.jsx(Poe,{})}),E.jsx(gc,{value:"retrieval",className:"absolute top-0 right-0 bottom-0 left-0 overflow-hidden",children:E.jsx(Iwe,{})}),E.jsx(gc,{value:"api",className:"absolute top-0 right-0 bottom-0 left-0 overflow-hidden",children:E.jsx(Lwe,{})})]})]}),t&&E.jsx(fQ,{}),E.jsx(GX,{open:r,onOpenChange:u})]})})})}const Pwe=()=>{const e=Ok(),{login:t,isAuthenticated:n}=wr(),{t:r}=Et(),[a,o]=w.useState(!1),[s,l]=w.useState(""),[u,d]=w.useState(""),[p,g]=w.useState(!0),m=w.useRef(!1);if(w.useEffect(()=>{console.log("LoginPage mounted")},[]),w.useEffect(()=>((async()=>{if(!m.current){m.current=!0;try{if(n){e("/");return}const y=await JB();if((y.core_version||y.api_version)&&sessionStorage.setItem("VERSION_CHECKED_FROM_LOGIN","true"),!y.auth_configured&&y.access_token){t(y.access_token,!0,y.core_version,y.api_version,y.webui_title||null,y.webui_description||null),y.message&&Ft.info(y.message),e("/");return}g(!1)}catch(y){console.error("Failed to check auth configuration:",y),g(!1)}}})(),()=>{}),[n,t,e]),p)return null;const b=async v=>{if(v.preventDefault(),!s||!u){Ft.error(r("login.errorEmptyFields"));return}try{o(!0);const y=await MV(s,u),k=y.auth_mode==="disabled";t(y.access_token,k,y.core_version,y.api_version,y.webui_title||null,y.webui_description||null),(y.core_version||y.api_version)&&sessionStorage.setItem("VERSION_CHECKED_FROM_LOGIN","true"),k?Ft.info(y.message||r("login.authDisabled","Authentication is disabled. Using guest access.")):Ft.success(r("login.successMessage")),e("/")}catch(y){console.error("Login failed...",y),Ft.error(r("login.errorInvalidCredentials")),wr.getState().logout(),localStorage.removeItem("LIGHTRAG-API-TOKEN")}finally{o(!1)}};return E.jsxs("div",{className:"flex h-screen w-screen items-center justify-center bg-gradient-to-br from-emerald-50 to-teal-100 dark:from-gray-900 dark:to-gray-800",children:[E.jsx("div",{className:"absolute top-4 right-4 flex items-center gap-2",children:E.jsx(H3,{className:"bg-white/30 dark:bg-gray-800/30 backdrop-blur-sm rounded-md"})}),E.jsxs(Ei,{className:"w-full max-w-[480px] shadow-lg mx-4",children:[E.jsx(_c,{className:"flex items-center justify-center space-y-2 pb-8 pt-6",children:E.jsxs("div",{className:"flex flex-col items-center space-y-4",children:[E.jsxs("div",{className:"flex items-center gap-3",children:[E.jsx("img",{src:"logo.png",alt:"LightRAG Logo",className:"h-12 w-12"}),E.jsx(ET,{className:"size-10 text-emerald-400","aria-hidden":"true"})]}),E.jsxs("div",{className:"text-center space-y-2",children:[E.jsx("h1",{className:"text-3xl font-bold tracking-tight",children:"LightRAG"}),E.jsx("p",{className:"text-muted-foreground text-sm",children:r("login.description")})]})]})}),E.jsx(Oc,{className:"px-8 pb-8",children:E.jsxs("form",{onSubmit:b,className:"space-y-6",children:[E.jsxs("div",{className:"flex items-center gap-4",children:[E.jsx("label",{htmlFor:"username-input",className:"text-sm font-medium w-16 shrink-0",children:r("login.username")}),E.jsx(kr,{id:"username-input",placeholder:r("login.usernamePlaceholder"),value:s,onChange:v=>l(v.target.value),required:!0,className:"h-11 flex-1"})]}),E.jsxs("div",{className:"flex items-center gap-4",children:[E.jsx("label",{htmlFor:"password-input",className:"text-sm font-medium w-16 shrink-0",children:r("login.password")}),E.jsx(kr,{id:"password-input",type:"password",placeholder:r("login.passwordPlaceholder"),value:u,onChange:v=>d(v.target.value),required:!0,className:"h-11 flex-1"})]}),E.jsx(nt,{type:"submit",className:"w-full h-11 text-base font-medium mt-2",disabled:a,children:r(a?"login.loggingIn":"login.loginButton")})]})})]})]})},Fwe=()=>{const[e,t]=w.useState(!0),{isAuthenticated:n}=wr(),r=Ok();return w.useEffect(()=>{Gk.setNavigate(r)},[r]),w.useEffect(()=>((async()=>{try{const o=localStorage.getItem("LIGHTRAG-API-TOKEN");if(o&&n){t(!1);return}o||wr.getState().logout()}catch(o){console.error("Auth initialization error:",o),n||wr.getState().logout()}finally{t(!1)}})(),()=>{}),[n]),w.useEffect(()=>{!e&&!n&&window.location.hash.slice(1)!=="/login"&&(console.log("Not authenticated, redirecting to login"),r("/login"))},[e,n,r]),e?null:E.jsxs(c9,{children:[E.jsx(u0,{path:"/login",element:E.jsx(Pwe,{})}),E.jsx(u0,{path:"/*",element:n?E.jsx(Mwe,{}):null})]})},zwe=()=>E.jsx(rj,{children:E.jsxs(I9,{children:[E.jsx(Fwe,{}),E.jsx(dW,{position:"bottom-center",theme:"system",closeButton:!0,richColors:!0})]})}),tt=e=>typeof e=="string",fc=()=>{let e,t;const n=new Promise((r,a)=>{e=r,t=a});return n.resolve=e,n.reject=t,n},Lz=e=>e==null?"":""+e,Bwe=(e,t,n)=>{e.forEach(r=>{t[r]&&(n[r]=t[r])})},jwe=/###/g,Mz=e=>e&&e.indexOf("###")>-1?e.replace(jwe,"."):e,Pz=e=>!e||tt(e),Sc=(e,t,n)=>{const r=tt(t)?t.split("."):t;let a=0;for(;a<r.length-1;){if(Pz(e))return{};const o=Mz(r[a]);!e[o]&&n&&(e[o]=new n),Object.prototype.hasOwnProperty.call(e,o)?e=e[o]:e={},++a}return Pz(e)?{}:{obj:e,k:Mz(r[a])}},Fz=(e,t,n)=>{const{obj:r,k:a}=Sc(e,t,Object);if(r!==void 0||t.length===1){r[a]=n;return}let o=t[t.length-1],s=t.slice(0,t.length-1),l=Sc(e,s,Object);for(;l.obj===void 0&&s.length;)o=`${s[s.length-1]}.${o}`,s=s.slice(0,s.length-1),l=Sc(e,s,Object),l!=null&&l.obj&&typeof l.obj[`${l.k}.${o}`]<"u"&&(l.obj=void 0);l.obj[`${l.k}.${o}`]=n},Uwe=(e,t,n,r)=>{const{obj:a,k:o}=Sc(e,t,Object);a[o]=a[o]||[],a[o].push(n)},Uf=(e,t)=>{const{obj:n,k:r}=Sc(e,t);if(n&&Object.prototype.hasOwnProperty.call(n,r))return n[r]},Gwe=(e,t,n)=>{const r=Uf(e,n);return r!==void 0?r:Uf(t,n)},YH=(e,t,n)=>{for(const r in t)r!=="__proto__"&&r!=="constructor"&&(r in e?tt(e[r])||e[r]instanceof String||tt(t[r])||t[r]instanceof String?n&&(e[r]=t[r]):YH(e[r],t[r],n):e[r]=t[r]);return e},ys=e=>e.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g,"\\$&");var Hwe={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","/":"&#x2F;"};const $we=e=>tt(e)?e.replace(/[&<>"'\/]/g,t=>Hwe[t]):e;class qwe{constructor(t){this.capacity=t,this.regExpMap=new Map,this.regExpQueue=[]}getRegExp(t){const n=this.regExpMap.get(t);if(n!==void 0)return n;const r=new RegExp(t);return this.regExpQueue.length===this.capacity&&this.regExpMap.delete(this.regExpQueue.shift()),this.regExpMap.set(t,r),this.regExpQueue.push(t),r}}const Vwe=[" ",",","?","!",";"],Wwe=new qwe(20),Ywe=(e,t,n)=>{t=t||"",n=n||"";const r=Vwe.filter(s=>t.indexOf(s)<0&&n.indexOf(s)<0);if(r.length===0)return!0;const a=Wwe.getRegExp(`(${r.map(s=>s==="?"?"\\?":s).join("|")})`);let o=!a.test(e);if(!o){const s=e.indexOf(n);s>0&&!a.test(e.substring(0,s))&&(o=!0)}return o},_k=function(e,t){let n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:".";if(!e)return;if(e[t])return Object.prototype.hasOwnProperty.call(e,t)?e[t]:void 0;const r=t.split(n);let a=e;for(let o=0;o<r.length;){if(!a||typeof a!="object")return;let s,l="";for(let u=o;u<r.length;++u)if(u!==o&&(l+=n),l+=r[u],s=a[l],s!==void 0){if(["string","number","boolean"].indexOf(typeof s)>-1&&u<r.length-1)continue;o+=u-o+1;break}a=s}return a},Gf=e=>e==null?void 0:e.replace("_","-"),Kwe={type:"logger",log(e){this.output("log",e)},warn(e){this.output("warn",e)},error(e){this.output("error",e)},output(e,t){var n,r;(r=(n=console==null?void 0:console[e])==null?void 0:n.apply)==null||r.call(n,console,t)}};class Hf{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.init(t,n)}init(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.prefix=n.prefix||"i18next:",this.logger=t||Kwe,this.options=n,this.debug=n.debug}log(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"log","",!0)}warn(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"warn","",!0)}error(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"error","")}deprecate(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return this.forward(n,"warn","WARNING DEPRECATED: ",!0)}forward(t,n,r,a){return a&&!this.debug?null:(tt(t[0])&&(t[0]=`${r}${this.prefix} ${t[0]}`),this.logger[n](t))}create(t){return new Hf(this.logger,{prefix:`${this.prefix}:${t}:`,...this.options})}clone(t){return t=t||this.options,t.prefix=t.prefix||this.prefix,new Hf(this.logger,t)}}var aa=new Hf;class Gp{constructor(){this.observers={}}on(t,n){return t.split(" ").forEach(r=>{this.observers[r]||(this.observers[r]=new Map);const a=this.observers[r].get(n)||0;this.observers[r].set(n,a+1)}),this}off(t,n){if(this.observers[t]){if(!n){delete this.observers[t];return}this.observers[t].delete(n)}}emit(t){for(var n=arguments.length,r=new Array(n>1?n-1:0),a=1;a<n;a++)r[a-1]=arguments[a];this.observers[t]&&Array.from(this.observers[t].entries()).forEach(s=>{let[l,u]=s;for(let d=0;d<u;d++)l(...r)}),this.observers["*"]&&Array.from(this.observers["*"].entries()).forEach(s=>{let[l,u]=s;for(let d=0;d<u;d++)l.apply(l,[t,...r])})}}class zz extends Gp{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{ns:["translation"],defaultNS:"translation"};super(),this.data=t||{},this.options=n,this.options.keySeparator===void 0&&(this.options.keySeparator="."),this.options.ignoreJSONStructure===void 0&&(this.options.ignoreJSONStructure=!0)}addNamespaces(t){this.options.ns.indexOf(t)<0&&this.options.ns.push(t)}removeNamespaces(t){const n=this.options.ns.indexOf(t);n>-1&&this.options.ns.splice(n,1)}getResource(t,n,r){var d,p;let a=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};const o=a.keySeparator!==void 0?a.keySeparator:this.options.keySeparator,s=a.ignoreJSONStructure!==void 0?a.ignoreJSONStructure:this.options.ignoreJSONStructure;let l;t.indexOf(".")>-1?l=t.split("."):(l=[t,n],r&&(Array.isArray(r)?l.push(...r):tt(r)&&o?l.push(...r.split(o)):l.push(r)));const u=Uf(this.data,l);return!u&&!n&&!r&&t.indexOf(".")>-1&&(t=l[0],n=l[1],r=l.slice(2).join(".")),u||!s||!tt(r)?u:_k((p=(d=this.data)==null?void 0:d[t])==null?void 0:p[n],r,o)}addResource(t,n,r,a){let o=arguments.length>4&&arguments[4]!==void 0?arguments[4]:{silent:!1};const s=o.keySeparator!==void 0?o.keySeparator:this.options.keySeparator;let l=[t,n];r&&(l=l.concat(s?r.split(s):r)),t.indexOf(".")>-1&&(l=t.split("."),a=n,n=l[1]),this.addNamespaces(n),Fz(this.data,l,a),o.silent||this.emit("added",t,n,r,a)}addResources(t,n,r){let a=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{silent:!1};for(const o in r)(tt(r[o])||Array.isArray(r[o]))&&this.addResource(t,n,o,r[o],{silent:!0});a.silent||this.emit("added",t,n,r)}addResourceBundle(t,n,r,a,o){let s=arguments.length>5&&arguments[5]!==void 0?arguments[5]:{silent:!1,skipCopy:!1},l=[t,n];t.indexOf(".")>-1&&(l=t.split("."),a=r,r=n,n=l[1]),this.addNamespaces(n);let u=Uf(this.data,l)||{};s.skipCopy||(r=JSON.parse(JSON.stringify(r))),a?YH(u,r,o):u={...u,...r},Fz(this.data,l,u),s.silent||this.emit("added",t,n,r)}removeResourceBundle(t,n){this.hasResourceBundle(t,n)&&delete this.data[t][n],this.removeNamespaces(n),this.emit("removed",t,n)}hasResourceBundle(t,n){return this.getResource(t,n)!==void 0}getResourceBundle(t,n){return n||(n=this.options.defaultNS),this.getResource(t,n)}getDataByLanguage(t){return this.data[t]}hasLanguageSomeTranslations(t){const n=this.getDataByLanguage(t);return!!(n&&Object.keys(n)||[]).find(a=>n[a]&&Object.keys(n[a]).length>0)}toJSON(){return this.data}}var KH={processors:{},addPostProcessor(e){this.processors[e.name]=e},handle(e,t,n,r,a){return e.forEach(o=>{var s;t=((s=this.processors[o])==null?void 0:s.process(t,n,r,a))??t}),t}};const Bz={},jz=e=>!tt(e)&&typeof e!="boolean"&&typeof e!="number";class $f extends Gp{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};super(),Bwe(["resourceStore","languageUtils","pluralResolver","interpolator","backendConnector","i18nFormat","utils"],t,this),this.options=n,this.options.keySeparator===void 0&&(this.options.keySeparator="."),this.logger=aa.create("translator")}changeLanguage(t){t&&(this.language=t)}exists(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{interpolation:{}};if(t==null)return!1;const r=this.resolve(t,n);return(r==null?void 0:r.res)!==void 0}extractFromKey(t,n){let r=n.nsSeparator!==void 0?n.nsSeparator:this.options.nsSeparator;r===void 0&&(r=":");const a=n.keySeparator!==void 0?n.keySeparator:this.options.keySeparator;let o=n.ns||this.options.defaultNS||[];const s=r&&t.indexOf(r)>-1,l=!this.options.userDefinedKeySeparator&&!n.keySeparator&&!this.options.userDefinedNsSeparator&&!n.nsSeparator&&!Ywe(t,r,a);if(s&&!l){const u=t.match(this.interpolator.nestingRegexp);if(u&&u.length>0)return{key:t,namespaces:tt(o)?[o]:o};const d=t.split(r);(r!==a||r===a&&this.options.ns.indexOf(d[0])>-1)&&(o=d.shift()),t=d.join(a)}return{key:t,namespaces:tt(o)?[o]:o}}translate(t,n,r){if(typeof n!="object"&&this.options.overloadTranslationOptionHandler&&(n=this.options.overloadTranslationOptionHandler(arguments)),typeof n=="object"&&(n={...n}),n||(n={}),t==null)return"";Array.isArray(t)||(t=[String(t)]);const a=n.returnDetails!==void 0?n.returnDetails:this.options.returnDetails,o=n.keySeparator!==void 0?n.keySeparator:this.options.keySeparator,{key:s,namespaces:l}=this.extractFromKey(t[t.length-1],n),u=l[l.length-1],d=n.lng||this.language,p=n.appendNamespaceToCIMode||this.options.appendNamespaceToCIMode;if((d==null?void 0:d.toLowerCase())==="cimode"){if(p){const U=n.nsSeparator||this.options.nsSeparator;return a?{res:`${u}${U}${s}`,usedKey:s,exactUsedKey:s,usedLng:d,usedNS:u,usedParams:this.getUsedParamsDetails(n)}:`${u}${U}${s}`}return a?{res:s,usedKey:s,exactUsedKey:s,usedLng:d,usedNS:u,usedParams:this.getUsedParamsDetails(n)}:s}const g=this.resolve(t,n);let m=g==null?void 0:g.res;const b=(g==null?void 0:g.usedKey)||s,v=(g==null?void 0:g.exactUsedKey)||s,y=["[object Number]","[object Function]","[object RegExp]"],k=n.joinArrays!==void 0?n.joinArrays:this.options.joinArrays,A=!this.i18nFormat||this.i18nFormat.handleAsObject,x=n.count!==void 0&&!tt(n.count),R=$f.hasDefaultValue(n),O=x?this.pluralResolver.getSuffix(d,n.count,n):"",N=n.ordinal&&x?this.pluralResolver.getSuffix(d,n.count,{ordinal:!1}):"",C=x&&!n.ordinal&&n.count===0,_=C&&n[`defaultValue${this.options.pluralSeparator}zero`]||n[`defaultValue${O}`]||n[`defaultValue${N}`]||n.defaultValue;let M=m;A&&!m&&R&&(M=_);const I=jz(M),D=Object.prototype.toString.apply(M);if(A&&M&&I&&y.indexOf(D)<0&&!(tt(k)&&Array.isArray(M))){if(!n.returnObjects&&!this.options.returnObjects){this.options.returnedObjectHandler||this.logger.warn("accessing an object - but returnObjects options is not enabled!");const U=this.options.returnedObjectHandler?this.options.returnedObjectHandler(b,M,{...n,ns:l}):`key '${s} (${this.language})' returned an object instead of string.`;return a?(g.res=U,g.usedParams=this.getUsedParamsDetails(n),g):U}if(o){const U=Array.isArray(M),$=U?[]:{},B=U?v:b;for(const W in M)if(Object.prototype.hasOwnProperty.call(M,W)){const K=`${B}${o}${W}`;R&&!m?$[W]=this.translate(K,{...n,defaultValue:jz(_)?_[W]:void 0,joinArrays:!1,ns:l}):$[W]=this.translate(K,{...n,joinArrays:!1,ns:l}),$[W]===K&&($[W]=M[W])}m=$}}else if(A&&tt(k)&&Array.isArray(m))m=m.join(k),m&&(m=this.extendTranslation(m,t,n,r));else{let U=!1,$=!1;!this.isValidLookup(m)&&R&&(U=!0,m=_),this.isValidLookup(m)||($=!0,m=s);const W=(n.missingKeyNoValueFallbackToKey||this.options.missingKeyNoValueFallbackToKey)&&$?void 0:m,K=R&&_!==m&&this.options.updateMissing;if($||U||K){if(this.logger.log(K?"updateKey":"missingKey",d,u,s,K?_:m),o){const Y=this.resolve(s,{...n,keySeparator:!1});Y&&Y.res&&this.logger.warn("Seems the loaded translations were in flat JSON format instead of nested. Either set keySeparator: false on init or make sure your translations are published in nested format.")}let H=[];const G=this.languageUtils.getFallbackCodes(this.options.fallbackLng,n.lng||this.language);if(this.options.saveMissingTo==="fallback"&&G&&G[0])for(let Y=0;Y<G.length;Y++)H.push(G[Y]);else this.options.saveMissingTo==="all"?H=this.languageUtils.toResolveHierarchy(n.lng||this.language):H.push(n.lng||this.language);const z=(Y,L,V)=>{var P;const j=R&&V!==m?V:W;this.options.missingKeyHandler?this.options.missingKeyHandler(Y,u,L,j,K,n):(P=this.backendConnector)!=null&&P.saveMissing&&this.backendConnector.saveMissing(Y,u,L,j,K,n),this.emit("missingKey",Y,u,L,m)};this.options.saveMissing&&(this.options.saveMissingPlurals&&x?H.forEach(Y=>{const L=this.pluralResolver.getSuffixes(Y,n);C&&n[`defaultValue${this.options.pluralSeparator}zero`]&&L.indexOf(`${this.options.pluralSeparator}zero`)<0&&L.push(`${this.options.pluralSeparator}zero`),L.forEach(V=>{z([Y],s+V,n[`defaultValue${V}`]||_)})}):z(H,s,_))}m=this.extendTranslation(m,t,n,g,r),$&&m===s&&this.options.appendNamespaceToMissingKey&&(m=`${u}:${s}`),($||U)&&this.options.parseMissingKeyHandler&&(m=this.options.parseMissingKeyHandler(this.options.appendNamespaceToMissingKey?`${u}:${s}`:s,U?m:void 0))}return a?(g.res=m,g.usedParams=this.getUsedParamsDetails(n),g):m}extendTranslation(t,n,r,a,o){var d,p;var s=this;if((d=this.i18nFormat)!=null&&d.parse)t=this.i18nFormat.parse(t,{...this.options.interpolation.defaultVariables,...r},r.lng||this.language||a.usedLng,a.usedNS,a.usedKey,{resolved:a});else if(!r.skipInterpolation){r.interpolation&&this.interpolator.init({...r,interpolation:{...this.options.interpolation,...r.interpolation}});const g=tt(t)&&(((p=r==null?void 0:r.interpolation)==null?void 0:p.skipOnVariables)!==void 0?r.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables);let m;if(g){const v=t.match(this.interpolator.nestingRegexp);m=v&&v.length}let b=r.replace&&!tt(r.replace)?r.replace:r;if(this.options.interpolation.defaultVariables&&(b={...this.options.interpolation.defaultVariables,...b}),t=this.interpolator.interpolate(t,b,r.lng||this.language||a.usedLng,r),g){const v=t.match(this.interpolator.nestingRegexp),y=v&&v.length;m<y&&(r.nest=!1)}!r.lng&&a&&a.res&&(r.lng=this.language||a.usedLng),r.nest!==!1&&(t=this.interpolator.nest(t,function(){for(var v=arguments.length,y=new Array(v),k=0;k<v;k++)y[k]=arguments[k];return(o==null?void 0:o[0])===y[0]&&!r.context?(s.logger.warn(`It seems you are nesting recursively key: ${y[0]} in key: ${n[0]}`),null):s.translate(...y,n)},r)),r.interpolation&&this.interpolator.reset()}const l=r.postProcess||this.options.postProcess,u=tt(l)?[l]:l;return t!=null&&(u!=null&&u.length)&&r.applyPostProcessor!==!1&&(t=KH.handle(u,t,n,this.options&&this.options.postProcessPassResolved?{i18nResolved:{...a,usedParams:this.getUsedParamsDetails(r)},...r}:r,this)),t}resolve(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r,a,o,s,l;return tt(t)&&(t=[t]),t.forEach(u=>{if(this.isValidLookup(r))return;const d=this.extractFromKey(u,n),p=d.key;a=p;let g=d.namespaces;this.options.fallbackNS&&(g=g.concat(this.options.fallbackNS));const m=n.count!==void 0&&!tt(n.count),b=m&&!n.ordinal&&n.count===0,v=n.context!==void 0&&(tt(n.context)||typeof n.context=="number")&&n.context!=="",y=n.lngs?n.lngs:this.languageUtils.toResolveHierarchy(n.lng||this.language,n.fallbackLng);g.forEach(k=>{var A,x;this.isValidLookup(r)||(l=k,!Bz[`${y[0]}-${k}`]&&((A=this.utils)!=null&&A.hasLoadedNamespace)&&!((x=this.utils)!=null&&x.hasLoadedNamespace(l))&&(Bz[`${y[0]}-${k}`]=!0,this.logger.warn(`key "${a}" for languages "${y.join(", ")}" won't get resolved as namespace "${l}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!")),y.forEach(R=>{var C;if(this.isValidLookup(r))return;s=R;const O=[p];if((C=this.i18nFormat)!=null&&C.addLookupKeys)this.i18nFormat.addLookupKeys(O,p,R,k,n);else{let _;m&&(_=this.pluralResolver.getSuffix(R,n.count,n));const M=`${this.options.pluralSeparator}zero`,I=`${this.options.pluralSeparator}ordinal${this.options.pluralSeparator}`;if(m&&(O.push(p+_),n.ordinal&&_.indexOf(I)===0&&O.push(p+_.replace(I,this.options.pluralSeparator)),b&&O.push(p+M)),v){const D=`${p}${this.options.contextSeparator}${n.context}`;O.push(D),m&&(O.push(D+_),n.ordinal&&_.indexOf(I)===0&&O.push(D+_.replace(I,this.options.pluralSeparator)),b&&O.push(D+M))}}let N;for(;N=O.pop();)this.isValidLookup(r)||(o=N,r=this.getResource(R,k,N,n))}))})}),{res:r,usedKey:a,exactUsedKey:o,usedLng:s,usedNS:l}}isValidLookup(t){return t!==void 0&&!(!this.options.returnNull&&t===null)&&!(!this.options.returnEmptyString&&t==="")}getResource(t,n,r){var o;let a=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};return(o=this.i18nFormat)!=null&&o.getResource?this.i18nFormat.getResource(t,n,r,a):this.resourceStore.getResource(t,n,r,a)}getUsedParamsDetails(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};const n=["defaultValue","ordinal","context","replace","lng","lngs","fallbackLng","ns","keySeparator","nsSeparator","returnObjects","returnDetails","joinArrays","postProcess","interpolation"],r=t.replace&&!tt(t.replace);let a=r?t.replace:t;if(r&&typeof t.count<"u"&&(a.count=t.count),this.options.interpolation.defaultVariables&&(a={...this.options.interpolation.defaultVariables,...a}),!r){a={...a};for(const o of n)delete a[o]}return a}static hasDefaultValue(t){const n="defaultValue";for(const r in t)if(Object.prototype.hasOwnProperty.call(t,r)&&n===r.substring(0,n.length)&&t[r]!==void 0)return!0;return!1}}class Uz{constructor(t){this.options=t,this.supportedLngs=this.options.supportedLngs||!1,this.logger=aa.create("languageUtils")}getScriptPartFromCode(t){if(t=Gf(t),!t||t.indexOf("-")<0)return null;const n=t.split("-");return n.length===2||(n.pop(),n[n.length-1].toLowerCase()==="x")?null:this.formatLanguageCode(n.join("-"))}getLanguagePartFromCode(t){if(t=Gf(t),!t||t.indexOf("-")<0)return t;const n=t.split("-");return this.formatLanguageCode(n[0])}formatLanguageCode(t){if(tt(t)&&t.indexOf("-")>-1){let n;try{n=Intl.getCanonicalLocales(t)[0]}catch{}return n&&this.options.lowerCaseLng&&(n=n.toLowerCase()),n||(this.options.lowerCaseLng?t.toLowerCase():t)}return this.options.cleanCode||this.options.lowerCaseLng?t.toLowerCase():t}isSupportedCode(t){return(this.options.load==="languageOnly"||this.options.nonExplicitSupportedLngs)&&(t=this.getLanguagePartFromCode(t)),!this.supportedLngs||!this.supportedLngs.length||this.supportedLngs.indexOf(t)>-1}getBestMatchFromCodes(t){if(!t)return null;let n;return t.forEach(r=>{if(n)return;const a=this.formatLanguageCode(r);(!this.options.supportedLngs||this.isSupportedCode(a))&&(n=a)}),!n&&this.options.supportedLngs&&t.forEach(r=>{if(n)return;const a=this.getLanguagePartFromCode(r);if(this.isSupportedCode(a))return n=a;n=this.options.supportedLngs.find(o=>{if(o===a)return o;if(!(o.indexOf("-")<0&&a.indexOf("-")<0)&&(o.indexOf("-")>0&&a.indexOf("-")<0&&o.substring(0,o.indexOf("-"))===a||o.indexOf(a)===0&&a.length>1))return o})}),n||(n=this.getFallbackCodes(this.options.fallbackLng)[0]),n}getFallbackCodes(t,n){if(!t)return[];if(typeof t=="function"&&(t=t(n)),tt(t)&&(t=[t]),Array.isArray(t))return t;if(!n)return t.default||[];let r=t[n];return r||(r=t[this.getScriptPartFromCode(n)]),r||(r=t[this.formatLanguageCode(n)]),r||(r=t[this.getLanguagePartFromCode(n)]),r||(r=t.default),r||[]}toResolveHierarchy(t,n){const r=this.getFallbackCodes(n||this.options.fallbackLng||[],t),a=[],o=s=>{s&&(this.isSupportedCode(s)?a.push(s):this.logger.warn(`rejecting language code not found in supportedLngs: ${s}`))};return tt(t)&&(t.indexOf("-")>-1||t.indexOf("_")>-1)?(this.options.load!=="languageOnly"&&o(this.formatLanguageCode(t)),this.options.load!=="languageOnly"&&this.options.load!=="currentOnly"&&o(this.getScriptPartFromCode(t)),this.options.load!=="currentOnly"&&o(this.getLanguagePartFromCode(t))):tt(t)&&o(this.formatLanguageCode(t)),r.forEach(s=>{a.indexOf(s)<0&&o(this.formatLanguageCode(s))}),a}}const Gz={zero:0,one:1,two:2,few:3,many:4,other:5},Hz={select:e=>e===1?"one":"other",resolvedOptions:()=>({pluralCategories:["one","other"]})};class Xwe{constructor(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};this.languageUtils=t,this.options=n,this.logger=aa.create("pluralResolver"),this.pluralRulesCache={}}addRule(t,n){this.rules[t]=n}clearCache(){this.pluralRulesCache={}}getRule(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};const r=Gf(t==="dev"?"en":t),a=n.ordinal?"ordinal":"cardinal",o=JSON.stringify({cleanedCode:r,type:a});if(o in this.pluralRulesCache)return this.pluralRulesCache[o];let s;try{s=new Intl.PluralRules(r,{type:a})}catch{if(!Intl)return this.logger.error("No Intl support, please use an Intl polyfill!"),Hz;if(!t.match(/-|_/))return Hz;const u=this.languageUtils.getLanguagePartFromCode(t);s=this.getRule(u,n)}return this.pluralRulesCache[o]=s,s}needsPlural(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=this.getRule(t,n);return r||(r=this.getRule("dev",n)),(r==null?void 0:r.resolvedOptions().pluralCategories.length)>1}getPluralFormsOfKey(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};return this.getSuffixes(t,r).map(a=>`${n}${a}`)}getSuffixes(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=this.getRule(t,n);return r||(r=this.getRule("dev",n)),r?r.resolvedOptions().pluralCategories.sort((a,o)=>Gz[a]-Gz[o]).map(a=>`${this.options.prepend}${n.ordinal?`ordinal${this.options.prepend}`:""}${a}`):[]}getSuffix(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};const a=this.getRule(t,r);return a?`${this.options.prepend}${r.ordinal?`ordinal${this.options.prepend}`:""}${a.select(n)}`:(this.logger.warn(`no plural rule found for: ${t}`),this.getSuffix("dev",n,r))}}const $z=function(e,t,n){let r=arguments.length>3&&arguments[3]!==void 0?arguments[3]:".",a=arguments.length>4&&arguments[4]!==void 0?arguments[4]:!0,o=Gwe(e,t,n);return!o&&a&&tt(n)&&(o=_k(e,n,r),o===void 0&&(o=_k(t,n,r))),o},l0=e=>e.replace(/\$/g,"$$$$");class Zwe{constructor(){var n;let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};this.logger=aa.create("interpolator"),this.options=t,this.format=((n=t==null?void 0:t.interpolation)==null?void 0:n.format)||(r=>r),this.init(t)}init(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};t.interpolation||(t.interpolation={escapeValue:!0});const{escape:n,escapeValue:r,useRawValueToEscape:a,prefix:o,prefixEscaped:s,suffix:l,suffixEscaped:u,formatSeparator:d,unescapeSuffix:p,unescapePrefix:g,nestingPrefix:m,nestingPrefixEscaped:b,nestingSuffix:v,nestingSuffixEscaped:y,nestingOptionsSeparator:k,maxReplaces:A,alwaysFormat:x}=t.interpolation;this.escape=n!==void 0?n:$we,this.escapeValue=r!==void 0?r:!0,this.useRawValueToEscape=a!==void 0?a:!1,this.prefix=o?ys(o):s||"{{",this.suffix=l?ys(l):u||"}}",this.formatSeparator=d||",",this.unescapePrefix=p?"":g||"-",this.unescapeSuffix=this.unescapePrefix?"":p||"",this.nestingPrefix=m?ys(m):b||ys("$t("),this.nestingSuffix=v?ys(v):y||ys(")"),this.nestingOptionsSeparator=k||",",this.maxReplaces=A||1e3,this.alwaysFormat=x!==void 0?x:!1,this.resetRegExp()}reset(){this.options&&this.init(this.options)}resetRegExp(){const t=(n,r)=>(n==null?void 0:n.source)===r?(n.lastIndex=0,n):new RegExp(r,"g");this.regexp=t(this.regexp,`${this.prefix}(.+?)${this.suffix}`),this.regexpUnescape=t(this.regexpUnescape,`${this.prefix}${this.unescapePrefix}(.+?)${this.unescapeSuffix}${this.suffix}`),this.nestingRegexp=t(this.nestingRegexp,`${this.nestingPrefix}(.+?)${this.nestingSuffix}`)}interpolate(t,n,r,a){var b;let o,s,l;const u=this.options&&this.options.interpolation&&this.options.interpolation.defaultVariables||{},d=v=>{if(v.indexOf(this.formatSeparator)<0){const x=$z(n,u,v,this.options.keySeparator,this.options.ignoreJSONStructure);return this.alwaysFormat?this.format(x,void 0,r,{...a,...n,interpolationkey:v}):x}const y=v.split(this.formatSeparator),k=y.shift().trim(),A=y.join(this.formatSeparator).trim();return this.format($z(n,u,k,this.options.keySeparator,this.options.ignoreJSONStructure),A,r,{...a,...n,interpolationkey:k})};this.resetRegExp();const p=(a==null?void 0:a.missingInterpolationHandler)||this.options.missingInterpolationHandler,g=((b=a==null?void 0:a.interpolation)==null?void 0:b.skipOnVariables)!==void 0?a.interpolation.skipOnVariables:this.options.interpolation.skipOnVariables;return[{regex:this.regexpUnescape,safeValue:v=>l0(v)},{regex:this.regexp,safeValue:v=>this.escapeValue?l0(this.escape(v)):l0(v)}].forEach(v=>{for(l=0;o=v.regex.exec(t);){const y=o[1].trim();if(s=d(y),s===void 0)if(typeof p=="function"){const A=p(t,o,a);s=tt(A)?A:""}else if(a&&Object.prototype.hasOwnProperty.call(a,y))s="";else if(g){s=o[0];continue}else this.logger.warn(`missed to pass in variable ${y} for interpolating ${t}`),s="";else!tt(s)&&!this.useRawValueToEscape&&(s=Lz(s));const k=v.safeValue(s);if(t=t.replace(o[0],k),g?(v.regex.lastIndex+=s.length,v.regex.lastIndex-=o[0].length):v.regex.lastIndex=0,l++,l>=this.maxReplaces)break}}),t}nest(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},a,o,s;const l=(u,d)=>{const p=this.nestingOptionsSeparator;if(u.indexOf(p)<0)return u;const g=u.split(new RegExp(`${p}[ ]*{`));let m=`{${g[1]}`;u=g[0],m=this.interpolate(m,s);const b=m.match(/'/g),v=m.match(/"/g);(((b==null?void 0:b.length)??0)%2===0&&!v||v.length%2!==0)&&(m=m.replace(/'/g,'"'));try{s=JSON.parse(m),d&&(s={...d,...s})}catch(y){return this.logger.warn(`failed parsing options string in nesting for key ${u}`,y),`${u}${p}${m}`}return s.defaultValue&&s.defaultValue.indexOf(this.prefix)>-1&&delete s.defaultValue,u};for(;a=this.nestingRegexp.exec(t);){let u=[];s={...r},s=s.replace&&!tt(s.replace)?s.replace:s,s.applyPostProcessor=!1,delete s.defaultValue;let d=!1;if(a[0].indexOf(this.formatSeparator)!==-1&&!/{.*}/.test(a[1])){const p=a[1].split(this.formatSeparator).map(g=>g.trim());a[1]=p.shift(),u=p,d=!0}if(o=n(l.call(this,a[1].trim(),s),s),o&&a[0]===t&&!tt(o))return o;tt(o)||(o=Lz(o)),o||(this.logger.warn(`missed to resolve ${a[1]} for nesting ${t}`),o=""),d&&(o=u.reduce((p,g)=>this.format(p,g,r.lng,{...r,interpolationkey:a[1].trim()}),o.trim())),t=t.replace(a[0],o),this.regexp.lastIndex=0}return t}}const Qwe=e=>{let t=e.toLowerCase().trim();const n={};if(e.indexOf("(")>-1){const r=e.split("(");t=r[0].toLowerCase().trim();const a=r[1].substring(0,r[1].length-1);t==="currency"&&a.indexOf(":")<0?n.currency||(n.currency=a.trim()):t==="relativetime"&&a.indexOf(":")<0?n.range||(n.range=a.trim()):a.split(";").forEach(s=>{if(s){const[l,...u]=s.split(":"),d=u.join(":").trim().replace(/^'+|'+$/g,""),p=l.trim();n[p]||(n[p]=d),d==="false"&&(n[p]=!1),d==="true"&&(n[p]=!0),isNaN(d)||(n[p]=parseInt(d,10))}})}return{formatName:t,formatOptions:n}},vs=e=>{const t={};return(n,r,a)=>{let o=a;a&&a.interpolationkey&&a.formatParams&&a.formatParams[a.interpolationkey]&&a[a.interpolationkey]&&(o={...o,[a.interpolationkey]:void 0});const s=r+JSON.stringify(o);let l=t[s];return l||(l=e(Gf(r),a),t[s]=l),l(n)}};class Jwe{constructor(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};this.logger=aa.create("formatter"),this.options=t,this.formats={number:vs((n,r)=>{const a=new Intl.NumberFormat(n,{...r});return o=>a.format(o)}),currency:vs((n,r)=>{const a=new Intl.NumberFormat(n,{...r,style:"currency"});return o=>a.format(o)}),datetime:vs((n,r)=>{const a=new Intl.DateTimeFormat(n,{...r});return o=>a.format(o)}),relativetime:vs((n,r)=>{const a=new Intl.RelativeTimeFormat(n,{...r});return o=>a.format(o,r.range||"day")}),list:vs((n,r)=>{const a=new Intl.ListFormat(n,{...r});return o=>a.format(o)})},this.init(t)}init(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{interpolation:{}};this.formatSeparator=n.interpolation.formatSeparator||","}add(t,n){this.formats[t.toLowerCase().trim()]=n}addCached(t,n){this.formats[t.toLowerCase().trim()]=vs(n)}format(t,n,r){let a=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};const o=n.split(this.formatSeparator);if(o.length>1&&o[0].indexOf("(")>1&&o[0].indexOf(")")<0&&o.find(l=>l.indexOf(")")>-1)){const l=o.findIndex(u=>u.indexOf(")")>-1);o[0]=[o[0],...o.splice(1,l)].join(this.formatSeparator)}return o.reduce((l,u)=>{var g;const{formatName:d,formatOptions:p}=Qwe(u);if(this.formats[d]){let m=l;try{const b=((g=a==null?void 0:a.formatParams)==null?void 0:g[a.interpolationkey])||{},v=b.locale||b.lng||a.locale||a.lng||r;m=this.formats[d](l,v,{...p,...a,...b})}catch(b){this.logger.warn(b)}return m}else this.logger.warn(`there was no format function for ${d}`);return l},t)}}const exe=(e,t)=>{e.pending[t]!==void 0&&(delete e.pending[t],e.pendingCount--)};class txe extends Gp{constructor(t,n,r){var o,s;let a=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{};super(),this.backend=t,this.store=n,this.services=r,this.languageUtils=r.languageUtils,this.options=a,this.logger=aa.create("backendConnector"),this.waitingReads=[],this.maxParallelReads=a.maxParallelReads||10,this.readingCalls=0,this.maxRetries=a.maxRetries>=0?a.maxRetries:5,this.retryTimeout=a.retryTimeout>=1?a.retryTimeout:350,this.state={},this.queue=[],(s=(o=this.backend)==null?void 0:o.init)==null||s.call(o,r,a.backend,a)}queueLoad(t,n,r,a){const o={},s={},l={},u={};return t.forEach(d=>{let p=!0;n.forEach(g=>{const m=`${d}|${g}`;!r.reload&&this.store.hasResourceBundle(d,g)?this.state[m]=2:this.state[m]<0||(this.state[m]===1?s[m]===void 0&&(s[m]=!0):(this.state[m]=1,p=!1,s[m]===void 0&&(s[m]=!0),o[m]===void 0&&(o[m]=!0),u[g]===void 0&&(u[g]=!0)))}),p||(l[d]=!0)}),(Object.keys(o).length||Object.keys(s).length)&&this.queue.push({pending:s,pendingCount:Object.keys(s).length,loaded:{},errors:[],callback:a}),{toLoad:Object.keys(o),pending:Object.keys(s),toLoadLanguages:Object.keys(l),toLoadNamespaces:Object.keys(u)}}loaded(t,n,r){const a=t.split("|"),o=a[0],s=a[1];n&&this.emit("failedLoading",o,s,n),!n&&r&&this.store.addResourceBundle(o,s,r,void 0,void 0,{skipCopy:!0}),this.state[t]=n?-1:2,n&&r&&(this.state[t]=0);const l={};this.queue.forEach(u=>{Uwe(u.loaded,[o],s),exe(u,t),n&&u.errors.push(n),u.pendingCount===0&&!u.done&&(Object.keys(u.loaded).forEach(d=>{l[d]||(l[d]={});const p=u.loaded[d];p.length&&p.forEach(g=>{l[d][g]===void 0&&(l[d][g]=!0)})}),u.done=!0,u.errors.length?u.callback(u.errors):u.callback())}),this.emit("loaded",l),this.queue=this.queue.filter(u=>!u.done)}read(t,n,r){let a=arguments.length>3&&arguments[3]!==void 0?arguments[3]:0,o=arguments.length>4&&arguments[4]!==void 0?arguments[4]:this.retryTimeout,s=arguments.length>5?arguments[5]:void 0;if(!t.length)return s(null,{});if(this.readingCalls>=this.maxParallelReads){this.waitingReads.push({lng:t,ns:n,fcName:r,tried:a,wait:o,callback:s});return}this.readingCalls++;const l=(d,p)=>{if(this.readingCalls--,this.waitingReads.length>0){const g=this.waitingReads.shift();this.read(g.lng,g.ns,g.fcName,g.tried,g.wait,g.callback)}if(d&&p&&a<this.maxRetries){setTimeout(()=>{this.read.call(this,t,n,r,a+1,o*2,s)},o);return}s(d,p)},u=this.backend[r].bind(this.backend);if(u.length===2){try{const d=u(t,n);d&&typeof d.then=="function"?d.then(p=>l(null,p)).catch(l):l(null,d)}catch(d){l(d)}return}return u(t,n,l)}prepareLoading(t,n){let r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},a=arguments.length>3?arguments[3]:void 0;if(!this.backend)return this.logger.warn("No backend was added via i18next.use. Will not load resources."),a&&a();tt(t)&&(t=this.languageUtils.toResolveHierarchy(t)),tt(n)&&(n=[n]);const o=this.queueLoad(t,n,r,a);if(!o.toLoad.length)return o.pending.length||a(),null;o.toLoad.forEach(s=>{this.loadOne(s)})}load(t,n,r){this.prepareLoading(t,n,{},r)}reload(t,n,r){this.prepareLoading(t,n,{reload:!0},r)}loadOne(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"";const r=t.split("|"),a=r[0],o=r[1];this.read(a,o,"read",void 0,void 0,(s,l)=>{s&&this.logger.warn(`${n}loading namespace ${o} for language ${a} failed`,s),!s&&l&&this.logger.log(`${n}loaded namespace ${o} for language ${a}`,l),this.loaded(t,s,l)})}saveMissing(t,n,r,a,o){var u,d,p,g,m;let s=arguments.length>5&&arguments[5]!==void 0?arguments[5]:{},l=arguments.length>6&&arguments[6]!==void 0?arguments[6]:()=>{};if((d=(u=this.services)==null?void 0:u.utils)!=null&&d.hasLoadedNamespace&&!((g=(p=this.services)==null?void 0:p.utils)!=null&&g.hasLoadedNamespace(n))){this.logger.warn(`did not save key "${r}" as the namespace "${n}" was not yet loaded`,"This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!");return}if(!(r==null||r==="")){if((m=this.backend)!=null&&m.create){const b={...s,isUpdate:o},v=this.backend.create.bind(this.backend);if(v.length<6)try{let y;v.length===5?y=v(t,n,r,a,b):y=v(t,n,r,a),y&&typeof y.then=="function"?y.then(k=>l(null,k)).catch(l):l(null,y)}catch(y){l(y)}else v(t,n,r,a,l,b)}!t||!t[0]||this.store.addResource(t[0],n,r,a)}}}const qz=()=>({debug:!1,initAsync:!0,ns:["translation"],defaultNS:["translation"],fallbackLng:["dev"],fallbackNS:!1,supportedLngs:!1,nonExplicitSupportedLngs:!1,load:"all",preload:!1,simplifyPluralSuffix:!0,keySeparator:".",nsSeparator:":",pluralSeparator:"_",contextSeparator:"_",partialBundledLanguages:!1,saveMissing:!1,updateMissing:!1,saveMissingTo:"fallback",saveMissingPlurals:!0,missingKeyHandler:!1,missingInterpolationHandler:!1,postProcess:!1,postProcessPassResolved:!1,returnNull:!1,returnEmptyString:!0,returnObjects:!1,joinArrays:!1,returnedObjectHandler:!1,parseMissingKeyHandler:!1,appendNamespaceToMissingKey:!1,appendNamespaceToCIMode:!1,overloadTranslationOptionHandler:e=>{let t={};if(typeof e[1]=="object"&&(t=e[1]),tt(e[1])&&(t.defaultValue=e[1]),tt(e[2])&&(t.tDescription=e[2]),typeof e[2]=="object"||typeof e[3]=="object"){const n=e[3]||e[2];Object.keys(n).forEach(r=>{t[r]=n[r]})}return t},interpolation:{escapeValue:!0,format:e=>e,prefix:"{{",suffix:"}}",formatSeparator:",",unescapePrefix:"-",nestingPrefix:"$t(",nestingSuffix:")",nestingOptionsSeparator:",",maxReplaces:1e3,skipOnVariables:!0}}),Vz=e=>{var t,n;return tt(e.ns)&&(e.ns=[e.ns]),tt(e.fallbackLng)&&(e.fallbackLng=[e.fallbackLng]),tt(e.fallbackNS)&&(e.fallbackNS=[e.fallbackNS]),((n=(t=e.supportedLngs)==null?void 0:t.indexOf)==null?void 0:n.call(t,"cimode"))<0&&(e.supportedLngs=e.supportedLngs.concat(["cimode"])),typeof e.initImmediate=="boolean"&&(e.initAsync=e.initImmediate),e},Wd=()=>{},nxe=e=>{Object.getOwnPropertyNames(Object.getPrototypeOf(e)).forEach(n=>{typeof e[n]=="function"&&(e[n]=e[n].bind(e))})};class zc extends Gp{constructor(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},n=arguments.length>1?arguments[1]:void 0;if(super(),this.options=Vz(t),this.services={},this.logger=aa,this.modules={external:[]},nxe(this),n&&!this.isInitialized&&!t.isClone){if(!this.options.initAsync)return this.init(t,n),this;setTimeout(()=>{this.init(t,n)},0)}}init(){var t=this;let n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},r=arguments.length>1?arguments[1]:void 0;this.isInitializing=!0,typeof n=="function"&&(r=n,n={}),n.defaultNS==null&&n.ns&&(tt(n.ns)?n.defaultNS=n.ns:n.ns.indexOf("translation")<0&&(n.defaultNS=n.ns[0]));const a=qz();this.options={...a,...this.options,...Vz(n)},this.options.interpolation={...a.interpolation,...this.options.interpolation},n.keySeparator!==void 0&&(this.options.userDefinedKeySeparator=n.keySeparator),n.nsSeparator!==void 0&&(this.options.userDefinedNsSeparator=n.nsSeparator);const o=p=>p?typeof p=="function"?new p:p:null;if(!this.options.isClone){this.modules.logger?aa.init(o(this.modules.logger),this.options):aa.init(null,this.options);let p;this.modules.formatter?p=this.modules.formatter:p=Jwe;const g=new Uz(this.options);this.store=new zz(this.options.resources,this.options);const m=this.services;m.logger=aa,m.resourceStore=this.store,m.languageUtils=g,m.pluralResolver=new Xwe(g,{prepend:this.options.pluralSeparator,simplifyPluralSuffix:this.options.simplifyPluralSuffix}),p&&(!this.options.interpolation.format||this.options.interpolation.format===a.interpolation.format)&&(m.formatter=o(p),m.formatter.init(m,this.options),this.options.interpolation.format=m.formatter.format.bind(m.formatter)),m.interpolator=new Zwe(this.options),m.utils={hasLoadedNamespace:this.hasLoadedNamespace.bind(this)},m.backendConnector=new txe(o(this.modules.backend),m.resourceStore,m,this.options),m.backendConnector.on("*",function(b){for(var v=arguments.length,y=new Array(v>1?v-1:0),k=1;k<v;k++)y[k-1]=arguments[k];t.emit(b,...y)}),this.modules.languageDetector&&(m.languageDetector=o(this.modules.languageDetector),m.languageDetector.init&&m.languageDetector.init(m,this.options.detection,this.options)),this.modules.i18nFormat&&(m.i18nFormat=o(this.modules.i18nFormat),m.i18nFormat.init&&m.i18nFormat.init(this)),this.translator=new $f(this.services,this.options),this.translator.on("*",function(b){for(var v=arguments.length,y=new Array(v>1?v-1:0),k=1;k<v;k++)y[k-1]=arguments[k];t.emit(b,...y)}),this.modules.external.forEach(b=>{b.init&&b.init(this)})}if(this.format=this.options.interpolation.format,r||(r=Wd),this.options.fallbackLng&&!this.services.languageDetector&&!this.options.lng){const p=this.services.languageUtils.getFallbackCodes(this.options.fallbackLng);p.length>0&&p[0]!=="dev"&&(this.options.lng=p[0])}!this.services.languageDetector&&!this.options.lng&&this.logger.warn("init: no languageDetector is used and no lng is defined"),["getResource","hasResourceBundle","getResourceBundle","getDataByLanguage"].forEach(p=>{this[p]=function(){return t.store[p](...arguments)}}),["addResource","addResources","addResourceBundle","removeResourceBundle"].forEach(p=>{this[p]=function(){return t.store[p](...arguments),t}});const u=fc(),d=()=>{const p=(g,m)=>{this.isInitializing=!1,this.isInitialized&&!this.initializedStoreOnce&&this.logger.warn("init: i18next is already initialized. You should call init just once!"),this.isInitialized=!0,this.options.isClone||this.logger.log("initialized",this.options),this.emit("initialized",this.options),u.resolve(m),r(g,m)};if(this.languages&&!this.isInitialized)return p(null,this.t.bind(this));this.changeLanguage(this.options.lng,p)};return this.options.resources||!this.options.initAsync?d():setTimeout(d,0),u}loadResources(t){var o,s;let r=arguments.length>1&&arguments[1]!==void 0?arguments[1]:Wd;const a=tt(t)?t:this.language;if(typeof t=="function"&&(r=t),!this.options.resources||this.options.partialBundledLanguages){if((a==null?void 0:a.toLowerCase())==="cimode"&&(!this.options.preload||this.options.preload.length===0))return r();const l=[],u=d=>{if(!d||d==="cimode")return;this.services.languageUtils.toResolveHierarchy(d).forEach(g=>{g!=="cimode"&&l.indexOf(g)<0&&l.push(g)})};a?u(a):this.services.languageUtils.getFallbackCodes(this.options.fallbackLng).forEach(p=>u(p)),(s=(o=this.options.preload)==null?void 0:o.forEach)==null||s.call(o,d=>u(d)),this.services.backendConnector.load(l,this.options.ns,d=>{!d&&!this.resolvedLanguage&&this.language&&this.setResolvedLanguage(this.language),r(d)})}else r(null)}reloadResources(t,n,r){const a=fc();return typeof t=="function"&&(r=t,t=void 0),typeof n=="function"&&(r=n,n=void 0),t||(t=this.languages),n||(n=this.options.ns),r||(r=Wd),this.services.backendConnector.reload(t,n,o=>{a.resolve(),r(o)}),a}use(t){if(!t)throw new Error("You are passing an undefined module! Please check the object you are passing to i18next.use()");if(!t.type)throw new Error("You are passing a wrong module! Please check the object you are passing to i18next.use()");return t.type==="backend"&&(this.modules.backend=t),(t.type==="logger"||t.log&&t.warn&&t.error)&&(this.modules.logger=t),t.type==="languageDetector"&&(this.modules.languageDetector=t),t.type==="i18nFormat"&&(this.modules.i18nFormat=t),t.type==="postProcessor"&&KH.addPostProcessor(t),t.type==="formatter"&&(this.modules.formatter=t),t.type==="3rdParty"&&this.modules.external.push(t),this}setResolvedLanguage(t){if(!(!t||!this.languages)&&!(["cimode","dev"].indexOf(t)>-1))for(let n=0;n<this.languages.length;n++){const r=this.languages[n];if(!(["cimode","dev"].indexOf(r)>-1)&&this.store.hasLanguageSomeTranslations(r)){this.resolvedLanguage=r;break}}}changeLanguage(t,n){var r=this;this.isLanguageChangingTo=t;const a=fc();this.emit("languageChanging",t);const o=u=>{this.language=u,this.languages=this.services.languageUtils.toResolveHierarchy(u),this.resolvedLanguage=void 0,this.setResolvedLanguage(u)},s=(u,d)=>{d?(o(d),this.translator.changeLanguage(d),this.isLanguageChangingTo=void 0,this.emit("languageChanged",d),this.logger.log("languageChanged",d)):this.isLanguageChangingTo=void 0,a.resolve(function(){return r.t(...arguments)}),n&&n(u,function(){return r.t(...arguments)})},l=u=>{var p,g;!t&&!u&&this.services.languageDetector&&(u=[]);const d=tt(u)?u:this.services.languageUtils.getBestMatchFromCodes(u);d&&(this.language||o(d),this.translator.language||this.translator.changeLanguage(d),(g=(p=this.services.languageDetector)==null?void 0:p.cacheUserLanguage)==null||g.call(p,d)),this.loadResources(d,m=>{s(m,d)})};return!t&&this.services.languageDetector&&!this.services.languageDetector.async?l(this.services.languageDetector.detect()):!t&&this.services.languageDetector&&this.services.languageDetector.async?this.services.languageDetector.detect.length===0?this.services.languageDetector.detect().then(l):this.services.languageDetector.detect(l):l(t),a}getFixedT(t,n,r){var a=this;const o=function(s,l){let u;if(typeof l!="object"){for(var d=arguments.length,p=new Array(d>2?d-2:0),g=2;g<d;g++)p[g-2]=arguments[g];u=a.options.overloadTranslationOptionHandler([s,l].concat(p))}else u={...l};u.lng=u.lng||o.lng,u.lngs=u.lngs||o.lngs,u.ns=u.ns||o.ns,u.keyPrefix!==""&&(u.keyPrefix=u.keyPrefix||r||o.keyPrefix);const m=a.options.keySeparator||".";let b;return u.keyPrefix&&Array.isArray(s)?b=s.map(v=>`${u.keyPrefix}${m}${v}`):b=u.keyPrefix?`${u.keyPrefix}${m}${s}`:s,a.t(b,u)};return tt(t)?o.lng=t:o.lngs=t,o.ns=n,o.keyPrefix=r,o}t(){var a;for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return(a=this.translator)==null?void 0:a.translate(...n)}exists(){var a;for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return(a=this.translator)==null?void 0:a.exists(...n)}setDefaultNamespace(t){this.options.defaultNS=t}hasLoadedNamespace(t){let n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};if(!this.isInitialized)return this.logger.warn("hasLoadedNamespace: i18next was not initialized",this.languages),!1;if(!this.languages||!this.languages.length)return this.logger.warn("hasLoadedNamespace: i18n.languages were undefined or empty",this.languages),!1;const r=n.lng||this.resolvedLanguage||this.languages[0],a=this.options?this.options.fallbackLng:!1,o=this.languages[this.languages.length-1];if(r.toLowerCase()==="cimode")return!0;const s=(l,u)=>{const d=this.services.backendConnector.state[`${l}|${u}`];return d===-1||d===0||d===2};if(n.precheck){const l=n.precheck(this,s);if(l!==void 0)return l}return!!(this.hasResourceBundle(r,t)||!this.services.backendConnector.backend||this.options.resources&&!this.options.partialBundledLanguages||s(r,t)&&(!a||s(o,t)))}loadNamespaces(t,n){const r=fc();return this.options.ns?(tt(t)&&(t=[t]),t.forEach(a=>{this.options.ns.indexOf(a)<0&&this.options.ns.push(a)}),this.loadResources(a=>{r.resolve(),n&&n(a)}),r):(n&&n(),Promise.resolve())}loadLanguages(t,n){const r=fc();tt(t)&&(t=[t]);const a=this.options.preload||[],o=t.filter(s=>a.indexOf(s)<0&&this.services.languageUtils.isSupportedCode(s));return o.length?(this.options.preload=a.concat(o),this.loadResources(s=>{r.resolve(),n&&n(s)}),r):(n&&n(),Promise.resolve())}dir(t){var a,o;if(t||(t=this.resolvedLanguage||(((a=this.languages)==null?void 0:a.length)>0?this.languages[0]:this.language)),!t)return"rtl";const n=["ar","shu","sqr","ssh","xaa","yhd","yud","aao","abh","abv","acm","acq","acw","acx","acy","adf","ads","aeb","aec","afb","ajp","apc","apd","arb","arq","ars","ary","arz","auz","avl","ayh","ayl","ayn","ayp","bbz","pga","he","iw","ps","pbt","pbu","pst","prp","prd","ug","ur","ydd","yds","yih","ji","yi","hbo","men","xmn","fa","jpr","peo","pes","prs","dv","sam","ckb"],r=((o=this.services)==null?void 0:o.languageUtils)||new Uz(qz());return n.indexOf(r.getLanguagePartFromCode(t))>-1||t.toLowerCase().indexOf("-arab")>1?"rtl":"ltr"}static createInstance(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},n=arguments.length>1?arguments[1]:void 0;return new zc(t,n)}cloneInstance(){let t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:Wd;const r=t.forkResourceStore;r&&delete t.forkResourceStore;const a={...this.options,...t,isClone:!0},o=new zc(a);if((t.debug!==void 0||t.prefix!==void 0)&&(o.logger=o.logger.clone(t)),["store","services","language"].forEach(l=>{o[l]=this[l]}),o.services={...this.services},o.services.utils={hasLoadedNamespace:o.hasLoadedNamespace.bind(o)},r){const l=Object.keys(this.store.data).reduce((u,d)=>(u[d]={...this.store.data[d]},Object.keys(u[d]).reduce((p,g)=>(p[g]={...u[d][g]},p),{})),{});o.store=new zz(l,a),o.services.resourceStore=o.store}return o.translator=new $f(o.services,a),o.translator.on("*",function(l){for(var u=arguments.length,d=new Array(u>1?u-1:0),p=1;p<u;p++)d[p-1]=arguments[p];o.emit(l,...d)}),o.init(a,n),o.translator.options=a,o.translator.backendConnector.services.utils={hasLoadedNamespace:o.hasLoadedNamespace.bind(o)},o}toJSON(){return{options:this.options,store:this.store,language:this.language,languages:this.languages,resolvedLanguage:this.resolvedLanguage}}}const rn=zc.createInstance();rn.createInstance=zc.createInstance;rn.createInstance;rn.dir;rn.init;rn.loadResources;rn.reloadResources;rn.use;rn.changeLanguage;rn.getFixedT;rn.t;rn.exists;rn.setDefaultNamespace;rn.hasLoadedNamespace;rn.loadNamespaces;rn.loadLanguages;const rxe=Object.freeze(Object.defineProperty({__proto__:null,default:rn},Symbol.toStringTag,{value:"Module"})),axe={language:"Language",theme:"Theme",light:"Light",dark:"Dark",system:"System"},oxe={documents:"Documents",knowledgeGraph:"Knowledge Graph",retrieval:"Retrieval",api:"API",projectRepository:"Project Repository",logout:"Logout",themeToggle:{switchToLight:"Switch to light theme",switchToDark:"Switch to dark theme"}},ixe={description:"Please enter your account and password to log in to the system",username:"Username",usernamePlaceholder:"Please input a username",password:"Password",passwordPlaceholder:"Please input a password",loginButton:"Login",loggingIn:"Logging in...",successMessage:"Login succeeded",errorEmptyFields:"Please enter your username and password",errorInvalidCredentials:"Login failed, please check username and password",authDisabled:"Authentication is disabled. Using login free mode.",guestMode:"Login Free"},sxe={cancel:"Cancel"},lxe={clearDocuments:{button:"Clear",tooltip:"Clear documents",title:"Clear Documents",description:"This will remove all documents from the system",warning:"WARNING: This action will permanently delete all documents and cannot be undone!",confirm:"Do you really want to clear all documents?",confirmPrompt:"Type 'yes' to confirm this action",confirmPlaceholder:"Type yes to confirm",clearCache:"Clear LLM cache",confirmButton:"YES",success:"Documents cleared successfully",cacheCleared:"Cache cleared successfully",cacheClearFailed:`Failed to clear cache:
{{error}}`,failed:`Clear Documents Failed:
{{message}}`,error:`Clear Documents Failed:
{{error}}`},uploadDocuments:{button:"Upload",tooltip:"Upload documents",title:"Upload Documents",description:"Drag and drop your documents here or click to browse.",single:{uploading:"Uploading {{name}}: {{percent}}%",success:`Upload Success:
{{name}} uploaded successfully`,failed:`Upload Failed:
{{name}}
{{message}}`,error:`Upload Failed:
{{name}}
{{error}}`},batch:{uploading:"Uploading files...",success:"Files uploaded successfully",error:"Some files failed to upload"},generalError:`Upload Failed
{{error}}`,fileTypes:"Supported types: TXT, MD, DOCX, PDF, PPTX, RTF, ODT, EPUB, HTML, HTM, TEX, JSON, XML, YAML, YML, CSV, LOG, CONF, INI, PROPERTIES, SQL, BAT, SH, C, CPP, PY, JAVA, JS, TS, SWIFT, GO, RB, PHP, CSS, SCSS, LESS",fileUploader:{singleFileLimit:"Cannot upload more than 1 file at a time",maxFilesLimit:"Cannot upload more than {{count}} files",fileRejected:"File {{name}} was rejected",unsupportedType:"Unsupported file type",fileTooLarge:"File too large, maximum size is {{maxSize}}",dropHere:"Drop the files here",dragAndDrop:"Drag and drop files here, or click to select files",removeFile:"Remove file",uploadDescription:"You can upload {{isMultiple ? 'multiple' : count}} files (up to {{maxSize}} each)",duplicateFile:"File name already exists in server cache"}},documentManager:{title:"Document Management",scanButton:"Scan",scanTooltip:"Scan documents in input folder",pipelineStatusButton:"Pipeline Status",pipelineStatusTooltip:"View pipeline status",uploadedTitle:"Uploaded Documents",uploadedDescription:"List of uploaded documents and their statuses.",emptyTitle:"No Documents",emptyDescription:"There are no uploaded documents yet.",columns:{id:"ID",summary:"Summary",status:"Status",length:"Length",chunks:"Chunks",created:"Created",updated:"Updated",metadata:"Metadata"},status:{all:"All",completed:"Completed",processing:"Processing",pending:"Pending",failed:"Failed"},errors:{loadFailed:`Failed to load documents
{{error}}`,scanFailed:`Failed to scan documents
{{error}}`,scanProgressFailed:`Failed to get scan progress
{{error}}`},fileNameLabel:"File Name",showButton:"Show",hideButton:"Hide",showFileNameTooltip:"Show file name",hideFileNameTooltip:"Hide file name"},pipelineStatus:{title:"Pipeline Status",busy:"Pipeline Busy",requestPending:"Request Pending",jobName:"Job Name",startTime:"Start Time",progress:"Progress",unit:"batch",latestMessage:"Latest Message",historyMessages:"History Messages",errors:{fetchFailed:`Failed to get pipeline status
{{error}}`}}},cxe={dataIsTruncated:"Graph data is truncated to Max Nodes",statusDialog:{title:"LightRAG Server Settings",description:"View current system status and connection information"},legend:"Legend",nodeTypes:{person:"Person",category:"Category",geo:"Geographic",location:"Location",organization:"Organization",event:"Event",equipment:"Equipment",weapon:"Weapon",animal:"Animal",unknown:"Unknown",technology:"Technology"},sideBar:{settings:{settings:"Settings",healthCheck:"Health Check",showPropertyPanel:"Show Property Panel",showSearchBar:"Show Search Bar",showNodeLabel:"Show Node Label",nodeDraggable:"Node Draggable",showEdgeLabel:"Show Edge Label",hideUnselectedEdges:"Hide Unselected Edges",edgeEvents:"Edge Events",maxQueryDepth:"Max Query Depth",maxNodes:"Max Nodes",maxLayoutIterations:"Max Layout Iterations",resetToDefault:"Reset to default",edgeSizeRange:"Edge Size Range",depth:"D",max:"Max",degree:"Degree",apiKey:"API Key",enterYourAPIkey:"Enter your API key",save:"Save",refreshLayout:"Refresh Layout"},zoomControl:{zoomIn:"Zoom In",zoomOut:"Zoom Out",resetZoom:"Reset Zoom",rotateCamera:"Clockwise Rotate",rotateCameraCounterClockwise:"Counter-Clockwise Rotate"},layoutsControl:{startAnimation:"Continue layout animation",stopAnimation:"Stop layout animation",layoutGraph:"Layout Graph",layouts:{Circular:"Circular",Circlepack:"Circlepack",Random:"Random",Noverlaps:"Noverlaps","Force Directed":"Force Directed","Force Atlas":"Force Atlas"}},fullScreenControl:{fullScreen:"Full Screen",windowed:"Windowed"},legendControl:{toggleLegend:"Toggle Legend"}},statusIndicator:{connected:"Connected",disconnected:"Disconnected"},statusCard:{unavailable:"Status information unavailable",storageInfo:"Storage Info",workingDirectory:"Working Directory",inputDirectory:"Input Directory",llmConfig:"LLM Configuration",llmBinding:"LLM Binding",llmBindingHost:"LLM Binding Host",llmModel:"LLM Model",maxTokens:"Max Tokens",embeddingConfig:"Embedding Configuration",embeddingBinding:"Embedding Binding",embeddingBindingHost:"Embedding Binding Host",embeddingModel:"Embedding Model",storageConfig:"Storage Configuration",kvStorage:"KV Storage",docStatusStorage:"Doc Status Storage",graphStorage:"Graph Storage",vectorStorage:"Vector Storage"},propertiesView:{node:{title:"Node",id:"ID",labels:"Labels",degree:"Degree",properties:"Properties",relationships:"Relations(within subgraph)",expandNode:"Expand Node",pruneNode:"Prune Node",deleteAllNodesError:"Refuse to delete all nodes in the graph",nodesRemoved:"{{count}} nodes removed, including orphan nodes",noNewNodes:"No expandable nodes found",propertyNames:{description:"Description",entity_id:"Name",entity_type:"Type",source_id:"SrcID",Neighbour:"Neigh",file_path:"Source"}},edge:{title:"Relationship",id:"ID",type:"Type",source:"Source",target:"Target",properties:"Properties"}},search:{placeholder:"Search nodes...",message:"And {count} others"},graphLabels:{selectTooltip:"Select query label",noLabels:"No labels found",label:"Label",placeholder:"Search labels...",andOthers:"And {count} others",refreshTooltip:"Reload graph data"},emptyGraph:"Graph Is Empty"},uxe={chatMessage:{copyTooltip:"Copy to clipboard",copyError:"Failed to copy text to clipboard"},retrieval:{startPrompt:"Start a retrieval by typing your query below",clear:"Clear",send:"Send",placeholder:"Type your query...",error:"Error: Failed to get response"},querySettings:{parametersTitle:"Parameters",parametersDescription:"Configure your query parameters",queryMode:"Query Mode",queryModeTooltip:`Select the retrieval strategy:
• Naive: Basic search without advanced techniques
• Local: Context-dependent information retrieval
• Global: Utilizes global knowledge base
• Hybrid: Combines local and global retrieval
• Mix: Integrates knowledge graph with vector retrieval`,queryModeOptions:{naive:"Naive",local:"Local",global:"Global",hybrid:"Hybrid",mix:"Mix"},responseFormat:"Response Format",responseFormatTooltip:`Defines the response format. Examples:
• Multiple Paragraphs
• Single Paragraph
• Bullet Points`,responseFormatOptions:{multipleParagraphs:"Multiple Paragraphs",singleParagraph:"Single Paragraph",bulletPoints:"Bullet Points"},topK:"Top K Results",topKTooltip:"Number of top items to retrieve. Represents entities in 'local' mode and relationships in 'global' mode",topKPlaceholder:"Number of results",maxTokensTextUnit:"Max Tokens for Text Unit",maxTokensTextUnitTooltip:"Maximum number of tokens allowed for each retrieved text chunk",maxTokensGlobalContext:"Max Tokens for Global Context",maxTokensGlobalContextTooltip:"Maximum number of tokens allocated for relationship descriptions in global retrieval",maxTokensLocalContext:"Max Tokens for Local Context",maxTokensLocalContextTooltip:"Maximum number of tokens allocated for entity descriptions in local retrieval",historyTurns:"History Turns",historyTurnsTooltip:"Number of complete conversation turns (user-assistant pairs) to consider in the response context",historyTurnsPlaceholder:"Number of history turns",hlKeywords:"High-Level Keywords",hlKeywordsTooltip:"List of high-level keywords to prioritize in retrieval. Separate with commas",hlkeywordsPlaceHolder:"Enter keywords",llKeywords:"Low-Level Keywords",llKeywordsTooltip:"List of low-level keywords to refine retrieval focus. Separate with commas",onlyNeedContext:"Only Need Context",onlyNeedContextTooltip:"If True, only returns the retrieved context without generating a response",onlyNeedPrompt:"Only Need Prompt",onlyNeedPromptTooltip:"If True, only returns the generated prompt without producing a response",streamResponse:"Stream Response",streamResponseTooltip:"If True, enables streaming output for real-time responses"}},dxe={loading:"Loading API Documentation..."},fxe={title:"API Key is required",description:"Please enter your API key to access the service",placeholder:"Enter your API key",save:"Save"},pxe={settings:axe,header:oxe,login:ixe,common:sxe,documentPanel:lxe,graphPanel:cxe,retrievePanel:uxe,apiSite:dxe,apiKeyAlert:fxe},gxe={language:"语言",theme:"主题",light:"浅色",dark:"深色",system:"系统"},hxe={documents:"文档",knowledgeGraph:"知识图谱",retrieval:"检索",api:"API",projectRepository:"项目仓库",logout:"退出登录",themeToggle:{switchToLight:"切换到浅色主题",switchToDark:"切换到深色主题"}},mxe={description:"请输入您的账号和密码登录系统",username:"用户名",usernamePlaceholder:"请输入用户名",password:"密码",passwordPlaceholder:"请输入密码",loginButton:"登录",loggingIn:"登录中...",successMessage:"登录成功",errorEmptyFields:"请输入您的用户名和密码",errorInvalidCredentials:"登录失败，请检查用户名和密码",authDisabled:"认证已禁用，使用无需登陆模式。",guestMode:"无需登陆"},bxe={cancel:"取消"},yxe={clearDocuments:{button:"清空",tooltip:"清空文档",title:"清空文档",description:"此操作将从系统中移除所有文档",warning:"警告：此操作将永久删除所有文档，无法恢复！",confirm:"确定要清空所有文档吗？",confirmPrompt:"请输入 yes 确认操作",confirmPlaceholder:"输入 yes 确认",clearCache:"清空LLM缓存",confirmButton:"确定",success:"文档清空成功",cacheCleared:"缓存清空成功",cacheClearFailed:`清空缓存失败：
{{error}}`,failed:`清空文档失败：
{{message}}`,error:`清空文档失败：
{{error}}`},uploadDocuments:{button:"上传",tooltip:"上传文档",title:"上传文档",description:"拖拽文件到此处或点击浏览",single:{uploading:"正在上传 {{name}}：{{percent}}%",success:`上传成功：
{{name}} 上传完成`,failed:`上传失败：
{{name}}
{{message}}`,error:`上传失败：
{{name}}
{{error}}`},batch:{uploading:"正在上传文件...",success:"文件上传完成",error:"部分文件上传失败"},generalError:`上传失败
{{error}}`,fileTypes:"支持的文件类型：TXT, MD, DOCX, PDF, PPTX, RTF, ODT, EPUB, HTML, HTM, TEX, JSON, XML, YAML, YML, CSV, LOG, CONF, INI, PROPERTIES, SQL, BAT, SH, C, CPP, PY, JAVA, JS, TS, SWIFT, GO, RB, PHP, CSS, SCSS, LESS",fileUploader:{singleFileLimit:"一次只能上传一个文件",maxFilesLimit:"最多只能上传 {{count}} 个文件",fileRejected:"文件 {{name}} 被拒绝",unsupportedType:"不支持的文件类型",fileTooLarge:"文件过大，最大允许 {{maxSize}}",dropHere:"将文件拖放到此处",dragAndDrop:"拖放文件到此处，或点击选择文件",removeFile:"移除文件",uploadDescription:"您可以上传{{isMultiple ? '多个' : count}}个文件（每个文件最大{{maxSize}}）",duplicateFile:"文件名与服务器上的缓存重复"}},documentManager:{title:"文档管理",scanButton:"扫描",scanTooltip:"扫描输入目录中的文档",pipelineStatusButton:"流水线状态",pipelineStatusTooltip:"查看流水线状态",uploadedTitle:"已上传文档",uploadedDescription:"已上传文档列表及其状态",emptyTitle:"无文档",emptyDescription:"还没有上传任何文档",columns:{id:"ID",summary:"摘要",status:"状态",length:"长度",chunks:"分块",created:"创建时间",updated:"更新时间",metadata:"元数据"},status:{all:"全部",completed:"已完成",processing:"处理中",pending:"等待中",failed:"失败"},errors:{loadFailed:`加载文档失败
{{error}}`,scanFailed:`扫描文档失败
{{error}}`,scanProgressFailed:`获取扫描进度失败
{{error}}`},fileNameLabel:"文件名",showButton:"显示",hideButton:"隐藏",showFileNameTooltip:"显示文件名",hideFileNameTooltip:"隐藏文件名"},pipelineStatus:{title:"流水线状态",busy:"流水线忙碌",requestPending:"待处理请求",jobName:"作业名称",startTime:"开始时间",progress:"进度",unit:"批",latestMessage:"最新消息",historyMessages:"历史消息",errors:{fetchFailed:`获取流水线状态失败
{{error}}`}}},vxe={dataIsTruncated:"图数据已截断至最大返回节点数",statusDialog:{title:"LightRAG 服务器设置",description:"查看当前系统状态和连接信息"},legend:"图例",nodeTypes:{person:"人物",category:"类别",geo:"地理名称",location:"位置",organization:"组织机构",event:"事件",equipment:"装备",weapon:"武器",animal:"动物",unknown:"未知",technology:"技术"},sideBar:{settings:{settings:"设置",healthCheck:"健康检查",showPropertyPanel:"显示属性面板",showSearchBar:"显示搜索栏",showNodeLabel:"显示节点标签",nodeDraggable:"节点可拖动",showEdgeLabel:"显示边标签",hideUnselectedEdges:"隐藏未选中的边",edgeEvents:"边事件",maxQueryDepth:"最大查询深度",maxNodes:"最大返回节点数",maxLayoutIterations:"最大布局迭代次数",resetToDefault:"重置为默认值",edgeSizeRange:"边粗细范围",depth:"深",max:"Max",degree:"邻边",apiKey:"API密钥",enterYourAPIkey:"输入您的API密钥",save:"保存",refreshLayout:"刷新布局"},zoomControl:{zoomIn:"放大",zoomOut:"缩小",resetZoom:"重置缩放",rotateCamera:"顺时针旋转图形",rotateCameraCounterClockwise:"逆时针旋转图形"},layoutsControl:{startAnimation:"继续布局动画",stopAnimation:"停止布局动画",layoutGraph:"图布局",layouts:{Circular:"环形",Circlepack:"圆形打包",Random:"随机",Noverlaps:"无重叠","Force Directed":"力导向","Force Atlas":"力地图"}},fullScreenControl:{fullScreen:"全屏",windowed:"窗口"},legendControl:{toggleLegend:"切换图例显示"}},statusIndicator:{connected:"已连接",disconnected:"未连接"},statusCard:{unavailable:"状态信息不可用",storageInfo:"存储信息",workingDirectory:"工作目录",inputDirectory:"输入目录",llmConfig:"LLM配置",llmBinding:"LLM绑定",llmBindingHost:"LLM绑定主机",llmModel:"LLM模型",maxTokens:"最大令牌数",embeddingConfig:"嵌入配置",embeddingBinding:"嵌入绑定",embeddingBindingHost:"嵌入绑定主机",embeddingModel:"嵌入模型",storageConfig:"存储配置",kvStorage:"KV存储",docStatusStorage:"文档状态存储",graphStorage:"图存储",vectorStorage:"向量存储"},propertiesView:{node:{title:"节点",id:"ID",labels:"标签",degree:"度数",properties:"属性",relationships:"关系(子图内)",expandNode:"扩展节点",pruneNode:"修剪节点",deleteAllNodesError:"拒绝删除图中的所有节点",nodesRemoved:"已删除 {{count}} 个节点，包括孤立节点",noNewNodes:"没有发现可以扩展的节点",propertyNames:{description:"描述",entity_id:"名称",entity_type:"类型",source_id:"信源ID",Neighbour:"邻接",file_path:"信源"}},edge:{title:"关系",id:"ID",type:"类型",source:"源节点",target:"目标节点",properties:"属性"}},search:{placeholder:"搜索节点...",message:"还有 {count} 个"},graphLabels:{selectTooltip:"选择查询标签",noLabels:"未找到标签",label:"标签",placeholder:"搜索标签...",andOthers:"还有 {count} 个",refreshTooltip:"重新加载图形数据"},emptyGraph:"图谱数据为空"},Sxe={chatMessage:{copyTooltip:"复制到剪贴板",copyError:"复制文本到剪贴板失败"},retrieval:{startPrompt:"输入查询开始检索",clear:"清空",send:"发送",placeholder:"输入查询...",error:"错误：获取响应失败"},querySettings:{parametersTitle:"参数",parametersDescription:"配置查询参数",queryMode:"查询模式",queryModeTooltip:`选择检索策略：
• Naive：基础搜索，无高级技术
• Local：上下文相关信息检索
• Global：利用全局知识库
• Hybrid：结合本地和全局检索
• Mix：整合知识图谱和向量检索`,queryModeOptions:{naive:"Naive",local:"Local",global:"Global",hybrid:"Hybrid",mix:"Mix"},responseFormat:"响应格式",responseFormatTooltip:`定义响应格式。例如：
• 多段落
• 单段落
• 要点`,responseFormatOptions:{multipleParagraphs:"多段落",singleParagraph:"单段落",bulletPoints:"要点"},topK:"Top K结果",topKTooltip:"检索的顶部项目数。在'local'模式下表示实体，在'global'模式下表示关系",topKPlaceholder:"结果数量",maxTokensTextUnit:"文本单元最大令牌数",maxTokensTextUnitTooltip:"每个检索文本块允许的最大令牌数",maxTokensGlobalContext:"全局上下文最大令牌数",maxTokensGlobalContextTooltip:"全局检索中关系描述的最大令牌数",maxTokensLocalContext:"本地上下文最大令牌数",maxTokensLocalContextTooltip:"本地检索中实体描述的最大令牌数",historyTurns:"历史轮次",historyTurnsTooltip:"响应上下文中考虑的完整对话轮次（用户-助手对）数量",historyTurnsPlaceholder:"历史轮次数",hlKeywords:"高级关键词",hlKeywordsTooltip:"检索中优先考虑的高级关键词列表。用逗号分隔",hlkeywordsPlaceHolder:"输入关键词",llKeywords:"低级关键词",llKeywordsTooltip:"用于细化检索重点的低级关键词列表。用逗号分隔",onlyNeedContext:"仅需上下文",onlyNeedContextTooltip:"如果为True，仅返回检索到的上下文而不生成响应",onlyNeedPrompt:"仅需提示",onlyNeedPromptTooltip:"如果为True，仅返回生成的提示而不产生响应",streamResponse:"流式响应",streamResponseTooltip:"如果为True，启用实时流式输出响应"}},Exe={loading:"正在加载 API 文档..."},wxe={title:"需要 API Key",description:"请输入您的 API Key 以访问服务",placeholder:"请输入 API Key",save:"保存"},xxe={settings:gxe,header:hxe,login:mxe,common:bxe,documentPanel:yxe,graphPanel:vxe,retrievePanel:Sxe,apiSite:Exe,apiKeyAlert:wxe},kxe={language:"Langue",theme:"Thème",light:"Clair",dark:"Sombre",system:"Système"},Txe={documents:"Documents",knowledgeGraph:"Graphe de connaissances",retrieval:"Récupération",api:"API",projectRepository:"Référentiel du projet",logout:"Déconnexion",themeToggle:{switchToLight:"Passer au thème clair",switchToDark:"Passer au thème sombre"}},Axe={description:"Veuillez entrer votre compte et mot de passe pour vous connecter au système",username:"Nom d'utilisateur",usernamePlaceholder:"Veuillez saisir un nom d'utilisateur",password:"Mot de passe",passwordPlaceholder:"Veuillez saisir un mot de passe",loginButton:"Connexion",loggingIn:"Connexion en cours...",successMessage:"Connexion réussie",errorEmptyFields:"Veuillez saisir votre nom d'utilisateur et mot de passe",errorInvalidCredentials:"Échec de la connexion, veuillez vérifier le nom d'utilisateur et le mot de passe",authDisabled:"L'authentification est désactivée. Utilisation du mode sans connexion.",guestMode:"Mode sans connexion"},Rxe={cancel:"Annuler"},Cxe={clearDocuments:{button:"Effacer",tooltip:"Effacer les documents",title:"Effacer les documents",description:"Cette action supprimera tous les documents du système",warning:"ATTENTION : Cette action supprimera définitivement tous les documents et ne peut pas être annulée !",confirm:"Voulez-vous vraiment effacer tous les documents ?",confirmPrompt:"Tapez 'yes' pour confirmer cette action",confirmPlaceholder:"Tapez yes pour confirmer",clearCache:"Effacer le cache LLM",confirmButton:"OUI",success:"Documents effacés avec succès",cacheCleared:"Cache effacé avec succès",cacheClearFailed:`Échec de l'effacement du cache :
{{error}}`,failed:`Échec de l'effacement des documents :
{{message}}`,error:`Échec de l'effacement des documents :
{{error}}`},uploadDocuments:{button:"Télécharger",tooltip:"Télécharger des documents",title:"Télécharger des documents",description:"Glissez-déposez vos documents ici ou cliquez pour parcourir.",single:{uploading:"Téléchargement de {{name}} : {{percent}}%",success:`Succès du téléchargement :
{{name}} téléchargé avec succès`,failed:`Échec du téléchargement :
{{name}}
{{message}}`,error:`Échec du téléchargement :
{{name}}
{{error}}`},batch:{uploading:"Téléchargement des fichiers...",success:"Fichiers téléchargés avec succès",error:"Certains fichiers n'ont pas pu être téléchargés"},generalError:`Échec du téléchargement
{{error}}`,fileTypes:"Types pris en charge : TXT, MD, DOCX, PDF, PPTX, RTF, ODT, EPUB, HTML, HTM, TEX, JSON, XML, YAML, YML, CSV, LOG, CONF, INI, PROPERTIES, SQL, BAT, SH, C, CPP, PY, JAVA, JS, TS, SWIFT, GO, RB, PHP, CSS, SCSS, LESS",fileUploader:{singleFileLimit:"Impossible de télécharger plus d'un fichier à la fois",maxFilesLimit:"Impossible de télécharger plus de {{count}} fichiers",fileRejected:"Le fichier {{name}} a été rejeté",unsupportedType:"Type de fichier non pris en charge",fileTooLarge:"Fichier trop volumineux, taille maximale {{maxSize}}",dropHere:"Déposez les fichiers ici",dragAndDrop:"Glissez et déposez les fichiers ici, ou cliquez pour sélectionner",removeFile:"Supprimer le fichier",uploadDescription:"Vous pouvez télécharger {{isMultiple ? 'plusieurs' : count}} fichiers (jusqu'à {{maxSize}} chacun)",duplicateFile:"Le nom du fichier existe déjà dans le cache du serveur"}},documentManager:{title:"Gestion des documents",scanButton:"Scanner",scanTooltip:"Scanner les documents dans le dossier d'entrée",pipelineStatusButton:"État du Pipeline",pipelineStatusTooltip:"Voir l'état du pipeline",uploadedTitle:"Documents téléchargés",uploadedDescription:"Liste des documents téléchargés et leurs statuts.",emptyTitle:"Aucun document",emptyDescription:"Il n'y a pas encore de documents téléchargés.",columns:{id:"ID",summary:"Résumé",status:"Statut",length:"Longueur",chunks:"Fragments",created:"Créé",updated:"Mis à jour",metadata:"Métadonnées"},status:{all:"Tous",completed:"Terminé",processing:"En traitement",pending:"En attente",failed:"Échoué"},errors:{loadFailed:`Échec du chargement des documents
{{error}}`,scanFailed:`Échec de la numérisation des documents
{{error}}`,scanProgressFailed:`Échec de l'obtention de la progression de la numérisation
{{error}}`},fileNameLabel:"Nom du fichier",showButton:"Afficher",hideButton:"Masquer",showFileNameTooltip:"Afficher le nom du fichier",hideFileNameTooltip:"Masquer le nom du fichier"},pipelineStatus:{title:"État du Pipeline",busy:"Pipeline occupé",requestPending:"Requête en attente",jobName:"Nom du travail",startTime:"Heure de début",progress:"Progression",unit:"lot",latestMessage:"Dernier message",historyMessages:"Historique des messages",errors:{fetchFailed:`Échec de la récupération de l'état du pipeline
{{error}}`}}},_xe={dataIsTruncated:"Les données du graphe sont tronquées au nombre maximum de nœuds",statusDialog:{title:"Paramètres du Serveur LightRAG",description:"Afficher l'état actuel du système et les informations de connexion"},legend:"Légende",nodeTypes:{person:"Personne",category:"Catégorie",geo:"Géographique",location:"Emplacement",organization:"Organisation",event:"Événement",equipment:"Équipement",weapon:"Arme",animal:"Animal",unknown:"Inconnu",technology:"Technologie"},sideBar:{settings:{settings:"Paramètres",healthCheck:"Vérification de l'état",showPropertyPanel:"Afficher le panneau des propriétés",showSearchBar:"Afficher la barre de recherche",showNodeLabel:"Afficher l'étiquette du nœud",nodeDraggable:"Nœud déplaçable",showEdgeLabel:"Afficher l'étiquette de l'arête",hideUnselectedEdges:"Masquer les arêtes non sélectionnées",edgeEvents:"Événements des arêtes",maxQueryDepth:"Profondeur maximale de la requête",maxNodes:"Nombre maximum de nœuds",maxLayoutIterations:"Itérations maximales de mise en page",resetToDefault:"Réinitialiser par défaut",edgeSizeRange:"Plage de taille des arêtes",depth:"D",max:"Max",degree:"Degré",apiKey:"Clé API",enterYourAPIkey:"Entrez votre clé API",save:"Sauvegarder",refreshLayout:"Actualiser la mise en page"},zoomControl:{zoomIn:"Zoom avant",zoomOut:"Zoom arrière",resetZoom:"Réinitialiser le zoom",rotateCamera:"Rotation horaire",rotateCameraCounterClockwise:"Rotation antihoraire"},layoutsControl:{startAnimation:"Démarrer l'animation de mise en page",stopAnimation:"Arrêter l'animation de mise en page",layoutGraph:"Mettre en page le graphe",layouts:{Circular:"Circulaire",Circlepack:"Paquet circulaire",Random:"Aléatoire",Noverlaps:"Sans chevauchement","Force Directed":"Dirigé par la force","Force Atlas":"Atlas de force"}},fullScreenControl:{fullScreen:"Plein écran",windowed:"Fenêtré"},legendControl:{toggleLegend:"Basculer la légende"}},statusIndicator:{connected:"Connecté",disconnected:"Déconnecté"},statusCard:{unavailable:"Informations sur l'état indisponibles",storageInfo:"Informations de stockage",workingDirectory:"Répertoire de travail",inputDirectory:"Répertoire d'entrée",llmConfig:"Configuration du modèle de langage",llmBinding:"Liaison du modèle de langage",llmBindingHost:"Hôte de liaison du modèle de langage",llmModel:"Modèle de langage",maxTokens:"Nombre maximum de jetons",embeddingConfig:"Configuration d'incorporation",embeddingBinding:"Liaison d'incorporation",embeddingBindingHost:"Hôte de liaison d'incorporation",embeddingModel:"Modèle d'incorporation",storageConfig:"Configuration de stockage",kvStorage:"Stockage clé-valeur",docStatusStorage:"Stockage de l'état des documents",graphStorage:"Stockage du graphe",vectorStorage:"Stockage vectoriel"},propertiesView:{node:{title:"Nœud",id:"ID",labels:"Étiquettes",degree:"Degré",properties:"Propriétés",relationships:"Relations(dans le sous-graphe)",expandNode:"Développer le nœud",pruneNode:"Élaguer le nœud",deleteAllNodesError:"Refus de supprimer tous les nœuds du graphe",nodesRemoved:"{{count}} nœuds supprimés, y compris les nœuds orphelins",noNewNodes:"Aucun nœud développable trouvé",propertyNames:{description:"Description",entity_id:"Nom",entity_type:"Type",source_id:"ID source",Neighbour:"Voisin",file_path:"Source"}},edge:{title:"Relation",id:"ID",type:"Type",source:"Source",target:"Cible",properties:"Propriétés"}},search:{placeholder:"Rechercher des nœuds...",message:"Et {{count}} autres"},graphLabels:{selectTooltip:"Sélectionner l'étiquette de la requête",noLabels:"Aucune étiquette trouvée",label:"Étiquette",placeholder:"Rechercher des étiquettes...",andOthers:"Et {{count}} autres",refreshTooltip:"Recharger les données du graphe"},emptyGraph:"Le graphe est vide"},Nxe={chatMessage:{copyTooltip:"Copier dans le presse-papiers",copyError:"Échec de la copie du texte dans le presse-papiers"},retrieval:{startPrompt:"Démarrez une récupération en tapant votre requête ci-dessous",clear:"Effacer",send:"Envoyer",placeholder:"Tapez votre requête...",error:"Erreur : Échec de l'obtention de la réponse"},querySettings:{parametersTitle:"Paramètres",parametersDescription:"Configurez vos paramètres de requête",queryMode:"Mode de requête",queryModeTooltip:`Sélectionnez la stratégie de récupération :
• Naïf : Recherche de base sans techniques avancées
• Local : Récupération d'informations dépendante du contexte
• Global : Utilise une base de connaissances globale
• Hybride : Combine récupération locale et globale
• Mixte : Intègre le graphe de connaissances avec la récupération vectorielle`,queryModeOptions:{naive:"Naïf",local:"Local",global:"Global",hybrid:"Hybride",mix:"Mixte"},responseFormat:"Format de réponse",responseFormatTooltip:`Définit le format de la réponse. Exemples :
• Plusieurs paragraphes
• Paragraphe unique
• Points à puces`,responseFormatOptions:{multipleParagraphs:"Plusieurs paragraphes",singleParagraph:"Paragraphe unique",bulletPoints:"Points à puces"},topK:"Top K résultats",topKTooltip:"Nombre d'éléments supérieurs à récupérer. Représente les entités en mode 'local' et les relations en mode 'global'",topKPlaceholder:"Nombre de résultats",maxTokensTextUnit:"Nombre maximum de jetons pour l'unité de texte",maxTokensTextUnitTooltip:"Nombre maximum de jetons autorisés pour chaque fragment de texte récupéré",maxTokensGlobalContext:"Nombre maximum de jetons pour le contexte global",maxTokensGlobalContextTooltip:"Nombre maximum de jetons alloués pour les descriptions des relations dans la récupération globale",maxTokensLocalContext:"Nombre maximum de jetons pour le contexte local",maxTokensLocalContextTooltip:"Nombre maximum de jetons alloués pour les descriptions des entités dans la récupération locale",historyTurns:"Tours d'historique",historyTurnsTooltip:"Nombre de tours complets de conversation (paires utilisateur-assistant) à prendre en compte dans le contexte de la réponse",historyTurnsPlaceholder:"Nombre de tours d'historique",hlKeywords:"Mots-clés de haut niveau",hlKeywordsTooltip:"Liste de mots-clés de haut niveau à prioriser dans la récupération. Séparez par des virgules",hlkeywordsPlaceHolder:"Entrez les mots-clés",llKeywords:"Mots-clés de bas niveau",llKeywordsTooltip:"Liste de mots-clés de bas niveau pour affiner la focalisation de la récupération. Séparez par des virgules",onlyNeedContext:"Besoin uniquement du contexte",onlyNeedContextTooltip:"Si vrai, ne renvoie que le contexte récupéré sans générer de réponse",onlyNeedPrompt:"Besoin uniquement de l'invite",onlyNeedPromptTooltip:"Si vrai, ne renvoie que l'invite générée sans produire de réponse",streamResponse:"Réponse en flux",streamResponseTooltip:"Si vrai, active la sortie en flux pour des réponses en temps réel"}},Oxe={loading:"Chargement de la documentation de l'API..."},Ixe={title:"Clé API requise",description:"Veuillez entrer votre clé API pour accéder au service",placeholder:"Entrez votre clé API",save:"Sauvegarder"},Dxe={settings:kxe,header:Txe,login:Axe,common:Rxe,documentPanel:Cxe,graphPanel:_xe,retrievePanel:Nxe,apiSite:Oxe,apiKeyAlert:Ixe},Lxe={language:"اللغة",theme:"السمة",light:"فاتح",dark:"داكن",system:"النظام"},Mxe={documents:"المستندات",knowledgeGraph:"شبكة المعرفة",retrieval:"الاسترجاع",api:"واجهة برمجة التطبيقات",projectRepository:"مستودع المشروع",logout:"تسجيل الخروج",themeToggle:{switchToLight:"التحويل إلى السمة الفاتحة",switchToDark:"التحويل إلى السمة الداكنة"}},Pxe={description:"الرجاء إدخال حسابك وكلمة المرور لتسجيل الدخول إلى النظام",username:"اسم المستخدم",usernamePlaceholder:"الرجاء إدخال اسم المستخدم",password:"كلمة المرور",passwordPlaceholder:"الرجاء إدخال كلمة المرور",loginButton:"تسجيل الدخول",loggingIn:"جاري تسجيل الدخول...",successMessage:"تم تسجيل الدخول بنجاح",errorEmptyFields:"الرجاء إدخال اسم المستخدم وكلمة المرور",errorInvalidCredentials:"فشل تسجيل الدخول، يرجى التحقق من اسم المستخدم وكلمة المرور",authDisabled:"تم تعطيل المصادقة. استخدام وضع بدون تسجيل دخول.",guestMode:"وضع بدون تسجيل دخول"},Fxe={cancel:"إلغاء"},zxe={clearDocuments:{button:"مسح",tooltip:"مسح المستندات",title:"مسح المستندات",description:"سيؤدي هذا إلى إزالة جميع المستندات من النظام",warning:"تحذير: سيؤدي هذا الإجراء إلى حذف جميع المستندات بشكل دائم ولا يمكن التراجع عنه!",confirm:"هل تريد حقًا مسح جميع المستندات؟",confirmPrompt:"اكتب 'yes' لتأكيد هذا الإجراء",confirmPlaceholder:"اكتب yes للتأكيد",clearCache:"مسح كاش نموذج اللغة",confirmButton:"نعم",success:"تم مسح المستندات بنجاح",cacheCleared:"تم مسح ذاكرة التخزين المؤقت بنجاح",cacheClearFailed:`فشل مسح ذاكرة التخزين المؤقت:
{{error}}`,failed:`فشل مسح المستندات:
{{message}}`,error:`فشل مسح المستندات:
{{error}}`},uploadDocuments:{button:"رفع",tooltip:"رفع المستندات",title:"رفع المستندات",description:"اسحب وأفلت مستنداتك هنا أو انقر للتصفح.",single:{uploading:"جارٍ الرفع {{name}}: {{percent}}%",success:`نجاح الرفع:
تم رفع {{name}} بنجاح`,failed:`فشل الرفع:
{{name}}
{{message}}`,error:`فشل الرفع:
{{name}}
{{error}}`},batch:{uploading:"جارٍ رفع الملفات...",success:"تم رفع الملفات بنجاح",error:"فشل رفع بعض الملفات"},generalError:`فشل الرفع
{{error}}`,fileTypes:"الأنواع المدعومة: TXT، MD، DOCX، PDF، PPTX، RTF، ODT، EPUB، HTML، HTM، TEX، JSON، XML، YAML، YML، CSV، LOG، CONF، INI، PROPERTIES، SQL، BAT، SH، C، CPP، PY، JAVA، JS، TS، SWIFT، GO، RB، PHP، CSS، SCSS، LESS",fileUploader:{singleFileLimit:"لا يمكن رفع أكثر من ملف واحد في المرة الواحدة",maxFilesLimit:"لا يمكن رفع أكثر من {{count}} ملفات",fileRejected:"تم رفض الملف {{name}}",unsupportedType:"نوع الملف غير مدعوم",fileTooLarge:"حجم الملف كبير جدًا، الحد الأقصى {{maxSize}}",dropHere:"أفلت الملفات هنا",dragAndDrop:"اسحب وأفلت الملفات هنا، أو انقر للاختيار",removeFile:"إزالة الملف",uploadDescription:"يمكنك رفع {{isMultiple ? 'عدة' : count}} ملفات (حتى {{maxSize}} لكل منها)",duplicateFile:"اسم الملف موجود بالفعل في ذاكرة التخزين المؤقت للخادم"}},documentManager:{title:"إدارة المستندات",scanButton:"مسح ضوئي",scanTooltip:"مسح المستندات ضوئيًا في مجلد الإدخال",pipelineStatusButton:"حالة خط المعالجة",pipelineStatusTooltip:"عرض حالة خط المعالجة",uploadedTitle:"المستندات المرفوعة",uploadedDescription:"قائمة المستندات المرفوعة وحالاتها.",emptyTitle:"لا توجد مستندات",emptyDescription:"لا توجد مستندات مرفوعة بعد.",columns:{id:"المعرف",summary:"الملخص",status:"الحالة",length:"الطول",chunks:"الأجزاء",created:"تم الإنشاء",updated:"تم التحديث",metadata:"البيانات الوصفية"},status:{all:"الكل",completed:"مكتمل",processing:"قيد المعالجة",pending:"معلق",failed:"فشل"},errors:{loadFailed:`فشل تحميل المستندات
{{error}}`,scanFailed:`فشل مسح المستندات
{{error}}`,scanProgressFailed:`فشل الحصول على تقدم المسح
{{error}}`},fileNameLabel:"اسم الملف",showButton:"عرض",hideButton:"إخفاء",showFileNameTooltip:"عرض اسم الملف",hideFileNameTooltip:"إخفاء اسم الملف"},pipelineStatus:{title:"حالة خط المعالجة",busy:"خط المعالجة مشغول",requestPending:"الطلب معلق",jobName:"اسم المهمة",startTime:"وقت البدء",progress:"التقدم",unit:"دفعة",latestMessage:"آخر رسالة",historyMessages:"سجل الرسائل",errors:{fetchFailed:`فشل في جلب حالة خط المعالجة
{{error}}`}}},Bxe={dataIsTruncated:"تم اقتصار بيانات الرسم البياني على الحد الأقصى للعقد",statusDialog:{title:"إعدادات خادم LightRAG",description:"عرض حالة النظام الحالية ومعلومات الاتصال"},legend:"المفتاح",nodeTypes:{person:"شخص",category:"فئة",geo:"كيان جغرافي",location:"موقع",organization:"منظمة",event:"حدث",equipment:"معدات",weapon:"سلاح",animal:"حيوان",unknown:"غير معروف",technology:"العلوم"},sideBar:{settings:{settings:"الإعدادات",healthCheck:"فحص الحالة",showPropertyPanel:"إظهار لوحة الخصائص",showSearchBar:"إظهار شريط البحث",showNodeLabel:"إظهار تسمية العقدة",nodeDraggable:"العقدة قابلة للسحب",showEdgeLabel:"إظهار تسمية الحافة",hideUnselectedEdges:"إخفاء الحواف غير المحددة",edgeEvents:"أحداث الحافة",maxQueryDepth:"أقصى عمق للاستعلام",maxNodes:"الحد الأقصى للعقد",maxLayoutIterations:"أقصى تكرارات التخطيط",resetToDefault:"إعادة التعيين إلى الافتراضي",edgeSizeRange:"نطاق حجم الحافة",depth:"D",max:"Max",degree:"الدرجة",apiKey:"مفتاح واجهة برمجة التطبيقات",enterYourAPIkey:"أدخل مفتاح واجهة برمجة التطبيقات الخاص بك",save:"حفظ",refreshLayout:"تحديث التخطيط"},zoomControl:{zoomIn:"تكبير",zoomOut:"تصغير",resetZoom:"إعادة تعيين التكبير",rotateCamera:"تدوير في اتجاه عقارب الساعة",rotateCameraCounterClockwise:"تدوير عكس اتجاه عقارب الساعة"},layoutsControl:{startAnimation:"بدء حركة التخطيط",stopAnimation:"إيقاف حركة التخطيط",layoutGraph:"تخطيط الرسم البياني",layouts:{Circular:"دائري",Circlepack:"حزمة دائرية",Random:"عشوائي",Noverlaps:"بدون تداخل","Force Directed":"موجه بالقوة","Force Atlas":"أطلس القوة"}},fullScreenControl:{fullScreen:"شاشة كاملة",windowed:"نوافذ"},legendControl:{toggleLegend:"تبديل المفتاح"}},statusIndicator:{connected:"متصل",disconnected:"غير متصل"},statusCard:{unavailable:"معلومات الحالة غير متوفرة",storageInfo:"معلومات التخزين",workingDirectory:"دليل العمل",inputDirectory:"دليل الإدخال",llmConfig:"تكوين نموذج اللغة الكبير",llmBinding:"ربط نموذج اللغة الكبير",llmBindingHost:"مضيف ربط نموذج اللغة الكبير",llmModel:"نموذج اللغة الكبير",maxTokens:"أقصى عدد من الرموز",embeddingConfig:"تكوين التضمين",embeddingBinding:"ربط التضمين",embeddingBindingHost:"مضيف ربط التضمين",embeddingModel:"نموذج التضمين",storageConfig:"تكوين التخزين",kvStorage:"تخزين المفتاح-القيمة",docStatusStorage:"تخزين حالة المستند",graphStorage:"تخزين الرسم البياني",vectorStorage:"تخزين المتجهات"},propertiesView:{node:{title:"عقدة",id:"المعرف",labels:"التسميات",degree:"الدرجة",properties:"الخصائص",relationships:"العلاقات (داخل الرسم الفرعي)",expandNode:"توسيع العقدة",pruneNode:"تقليم العقدة",deleteAllNodesError:"رفض حذف جميع العقد في الرسم البياني",nodesRemoved:"تم إزالة {{count}} عقدة، بما في ذلك العقد اليتيمة",noNewNodes:"لم يتم العثور على عقد قابلة للتوسيع",propertyNames:{description:"الوصف",entity_id:"الاسم",entity_type:"النوع",source_id:"معرف المصدر",Neighbour:"الجار",file_path:"المصدر"}},edge:{title:"علاقة",id:"المعرف",type:"النوع",source:"المصدر",target:"الهدف",properties:"الخصائص"}},search:{placeholder:"ابحث في العقد...",message:"و {{count}} آخرون"},graphLabels:{selectTooltip:"حدد تسمية الاستعلام",noLabels:"لم يتم العثور على تسميات",label:"التسمية",placeholder:"ابحث في التسميات...",andOthers:"و {{count}} آخرون",refreshTooltip:"إعادة تحميل بيانات الرسم البياني"},emptyGraph:"الرسم البياني فارغ"},jxe={chatMessage:{copyTooltip:"نسخ إلى الحافظة",copyError:"فشل نسخ النص إلى الحافظة"},retrieval:{startPrompt:"ابدأ الاسترجاع بكتابة استفسارك أدناه",clear:"مسح",send:"إرسال",placeholder:"اكتب استفسارك...",error:"خطأ: فشل الحصول على الرد"},querySettings:{parametersTitle:"المعلمات",parametersDescription:"تكوين معلمات الاستعلام الخاص بك",queryMode:"وضع الاستعلام",queryModeTooltip:`حدد استراتيجية الاسترجاع:
• ساذج: بحث أساسي بدون تقنيات متقدمة
• محلي: استرجاع معلومات يعتمد على السياق
• عالمي: يستخدم قاعدة المعرفة العالمية
• مختلط: يجمع بين الاسترجاع المحلي والعالمي
• مزيج: يدمج شبكة المعرفة مع الاسترجاع المتجهي`,queryModeOptions:{naive:"ساذج",local:"محلي",global:"عالمي",hybrid:"مختلط",mix:"مزيج"},responseFormat:"تنسيق الرد",responseFormatTooltip:`يحدد تنسيق الرد. أمثلة:
• فقرات متعددة
• فقرة واحدة
• نقاط نقطية`,responseFormatOptions:{multipleParagraphs:"فقرات متعددة",singleParagraph:"فقرة واحدة",bulletPoints:"نقاط نقطية"},topK:"أعلى K نتائج",topKTooltip:"عدد العناصر العلوية للاسترجاع. يمثل الكيانات في وضع 'محلي' والعلاقات في وضع 'عالمي'",topKPlaceholder:"عدد النتائج",maxTokensTextUnit:"أقصى عدد من الرموز لوحدة النص",maxTokensTextUnitTooltip:"الحد الأقصى لعدد الرموز المسموح به لكل جزء نصي مسترجع",maxTokensGlobalContext:"أقصى عدد من الرموز للسياق العالمي",maxTokensGlobalContextTooltip:"الحد الأقصى لعدد الرموز المخصص لأوصاف العلاقات في الاسترجاع العالمي",maxTokensLocalContext:"أقصى عدد من الرموز للسياق المحلي",maxTokensLocalContextTooltip:"الحد الأقصى لعدد الرموز المخصص لأوصاف الكيانات في الاسترجاع المحلي",historyTurns:"دورات التاريخ",historyTurnsTooltip:"عدد الدورات الكاملة للمحادثة (أزواج المستخدم-المساعد) التي يجب مراعاتها في سياق الرد",historyTurnsPlaceholder:"عدد دورات التاريخ",hlKeywords:"الكلمات المفتاحية عالية المستوى",hlKeywordsTooltip:"قائمة الكلمات المفتاحية عالية المستوى لإعطائها الأولوية في الاسترجاع. افصل بينها بفواصل",hlkeywordsPlaceHolder:"أدخل الكلمات المفتاحية",llKeywords:"الكلمات المفتاحية منخفضة المستوى",llKeywordsTooltip:"قائمة الكلمات المفتاحية منخفضة المستوى لتحسين تركيز الاسترجاع. افصل بينها بفواصل",onlyNeedContext:"تحتاج فقط إلى السياق",onlyNeedContextTooltip:"إذا كان صحيحًا، يتم إرجاع السياق المسترجع فقط دون إنشاء رد",onlyNeedPrompt:"تحتاج فقط إلى المطالبة",onlyNeedPromptTooltip:"إذا كان صحيحًا، يتم إرجاع المطالبة المولدة فقط دون إنتاج رد",streamResponse:"تدفق الرد",streamResponseTooltip:"إذا كان صحيحًا، يتيح إخراج التدفق للردود في الوقت الفعلي"}},Uxe={loading:"جارٍ تحميل وثائق واجهة برمجة التطبيقات..."},Gxe={title:"مفتاح واجهة برمجة التطبيقات مطلوب",description:"الرجاء إدخال مفتاح واجهة برمجة التطبيقات للوصول إلى الخدمة",placeholder:"أدخل مفتاح واجهة برمجة التطبيقات",save:"حفظ"},Hxe={settings:Lxe,header:Mxe,login:Pxe,common:Fxe,documentPanel:zxe,graphPanel:Bxe,retrievePanel:jxe,apiSite:Uxe,apiKeyAlert:Gxe},$xe=()=>{var e;try{const t=localStorage.getItem("settings-storage");if(t)return((e=JSON.parse(t).state)==null?void 0:e.language)||"en"}catch(t){console.error("Failed to get stored language:",t)}return"en"};rn.use(AW).init({resources:{en:{translation:pxe},zh:{translation:xxe},fr:{translation:Dxe},ar:{translation:Hxe}},lng:$xe(),fallbackLng:"en",interpolation:{escapeValue:!1}});De.subscribe(e=>{const t=e.language;rn.language!==t&&rn.changeLanguage(t)});vq.createRoot(document.getElementById("root")).render(E.jsx(w.StrictMode,{children:E.jsx(zwe,{})}));
